@@ -78,6 +78,7 @@ typedef struct _ValaCCodeCaseStatementPrivate ValaCCodeCaseStatementPrivate;
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -89,9 +90,6 @@ typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -106,9 +104,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -118,9 +113,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a case block in a switch statement in C code.
- */
 struct _ValaCCodeCaseStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeCaseStatementPrivate * priv;
@@ -156,6 +148,7 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_CASE_STATEMENT_DUMMY_PROPERTY
 };
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 void vala_ccode_case_statement_set_expression (ValaCCodeCaseStatement* self, ValaCCodeExpression* value);
 ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expression);
 ValaCCodeCaseStatement* vala_ccode_case_statement_construct (GType object_type, ValaCCodeExpression* expression);
@@ -174,7 +167,7 @@ static void vala_ccode_case_statement_finalize (ValaCCodeNode* obj);
 ValaCCodeCaseStatement* vala_ccode_case_statement_construct (GType object_type, ValaCCodeExpression* expression) {
 	ValaCCodeCaseStatement* self;
 	g_return_val_if_fail (expression != NULL, NULL);
-	self = (ValaCCodeCaseStatement*) g_type_create_instance (object_type);
+	self = (ValaCCodeCaseStatement*) vala_ccode_statement_construct (object_type);
 	vala_ccode_case_statement_set_expression (self, expression);
 	return self;
 }
@@ -205,13 +198,15 @@ ValaCCodeExpression* vala_ccode_case_statement_get_expression (ValaCCodeCaseStat
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 void vala_ccode_case_statement_set_expression (ValaCCodeCaseStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL)), _tmp1_);
+	self->priv->_expression = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_expression), _tmp0_);
 }
 
 
@@ -231,7 +226,7 @@ static void vala_ccode_case_statement_instance_init (ValaCCodeCaseStatement * se
 static void vala_ccode_case_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeCaseStatement * self;
 	self = VALA_CCODE_CASE_STATEMENT (obj);
-	(self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL));
+	_vala_ccode_node_unref0 (self->priv->_expression);
 	VALA_CCODE_NODE_CLASS (vala_ccode_case_statement_parent_class)->finalize (obj);
 }
 
