@@ -57,10 +57,8 @@ typedef struct _ValaCCodeWriterClass ValaCCodeWriterClass;
 typedef struct _ValaCCodeComment ValaCCodeComment;
 typedef struct _ValaCCodeCommentClass ValaCCodeCommentClass;
 typedef struct _ValaCCodeCommentPrivate ValaCCodeCommentPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -75,9 +73,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a comment in the C code.
- */
 struct _ValaCCodeComment {
 	ValaCCodeNode parent_instance;
 	ValaCCodeCommentPrivate * priv;
@@ -111,10 +106,10 @@ GType vala_ccode_comment_get_type (void);
 enum  {
 	VALA_CCODE_COMMENT_DUMMY_PROPERTY
 };
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
 void vala_ccode_comment_set_text (ValaCCodeComment* self, const char* value);
 ValaCCodeComment* vala_ccode_comment_new (const char* _text);
 ValaCCodeComment* vala_ccode_comment_construct (GType object_type, const char* _text);
-ValaCCodeComment* vala_ccode_comment_new (const char* _text);
 void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text);
 const char* vala_ccode_comment_get_text (ValaCCodeComment* self);
 static void vala_ccode_comment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
@@ -125,7 +120,7 @@ static void vala_ccode_comment_finalize (ValaCCodeNode* obj);
 ValaCCodeComment* vala_ccode_comment_construct (GType object_type, const char* _text) {
 	ValaCCodeComment* self;
 	g_return_val_if_fail (_text != NULL, NULL);
-	self = (ValaCCodeComment*) g_type_create_instance (object_type);
+	self = (ValaCCodeComment*) vala_ccode_node_construct (object_type);
 	vala_ccode_comment_set_text (self, _text);
 	return self;
 }
@@ -153,12 +148,9 @@ const char* vala_ccode_comment_get_text (ValaCCodeComment* self) {
 
 
 void vala_ccode_comment_set_text (ValaCCodeComment* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_text = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_text = (g_free (self->priv->_text), NULL), _tmp1_);
+	self->priv->_text = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_text), _tmp0_);
 }
 
 
@@ -178,7 +170,7 @@ static void vala_ccode_comment_instance_init (ValaCCodeComment * self) {
 static void vala_ccode_comment_finalize (ValaCCodeNode* obj) {
 	ValaCCodeComment * self;
 	self = VALA_CCODE_COMMENT (obj);
-	self->priv->_text = (g_free (self->priv->_text), NULL);
+	_g_free0 (self->priv->_text);
 	VALA_CCODE_NODE_CLASS (vala_ccode_comment_parent_class)->finalize (obj);
 }
 
