@@ -78,6 +78,7 @@ typedef struct _ValaCCodeDoStatementPrivate ValaCCodeDoStatementPrivate;
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -99,9 +100,6 @@ typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 typedef struct _ValaCCodeBlock ValaCCodeBlock;
 typedef struct _ValaCCodeBlockClass ValaCCodeBlockClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -116,9 +114,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -128,9 +123,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a do iteration statement in the C code.
- */
 struct _ValaCCodeDoStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeDoStatementPrivate * priv;
@@ -167,11 +159,11 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_DO_STATEMENT_DUMMY_PROPERTY
 };
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 void vala_ccode_do_statement_set_body (ValaCCodeDoStatement* self, ValaCCodeStatement* value);
 void vala_ccode_do_statement_set_condition (ValaCCodeDoStatement* self, ValaCCodeExpression* value);
 ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, ValaCCodeExpression* cond);
 ValaCCodeDoStatement* vala_ccode_do_statement_construct (GType object_type, ValaCCodeStatement* stmt, ValaCCodeExpression* cond);
-ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, ValaCCodeExpression* cond);
 GType vala_ccode_line_directive_get_type (void);
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
@@ -190,7 +182,7 @@ ValaCCodeDoStatement* vala_ccode_do_statement_construct (GType object_type, Vala
 	ValaCCodeDoStatement* self;
 	g_return_val_if_fail (stmt != NULL, NULL);
 	g_return_val_if_fail (cond != NULL, NULL);
-	self = (ValaCCodeDoStatement*) g_type_create_instance (object_type);
+	self = (ValaCCodeDoStatement*) vala_ccode_statement_construct (object_type);
 	vala_ccode_do_statement_set_body (self, stmt);
 	vala_ccode_do_statement_set_condition (self, cond);
 	return self;
@@ -202,20 +194,22 @@ ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, Val
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 static void vala_ccode_do_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeDoStatement * self;
 	self = (ValaCCodeDoStatement*) base;
 	g_return_if_fail (writer != NULL);
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line ((ValaCCodeNode*) self));
 	vala_ccode_writer_write_string (writer, "do");
-	/* while shouldn't be on a separate line */
 	if (VALA_IS_CCODE_BLOCK (self->priv->_body)) {
-		ValaCCodeBlock* _tmp0_;
 		ValaCCodeBlock* cblock;
-		_tmp0_ = NULL;
-		cblock = (_tmp0_ = VALA_CCODE_BLOCK (self->priv->_body), (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_));
+		cblock = _vala_ccode_node_ref0 (VALA_CCODE_BLOCK (self->priv->_body));
 		vala_ccode_block_set_suppress_newline (cblock, TRUE);
-		(cblock == NULL) ? NULL : (cblock = (vala_ccode_node_unref (cblock), NULL));
+		_vala_ccode_node_unref0 (cblock);
 	}
 	vala_ccode_node_write ((ValaCCodeNode*) self->priv->_body, writer);
 	vala_ccode_writer_write_string (writer, " while (");
@@ -233,12 +227,9 @@ ValaCCodeStatement* vala_ccode_do_statement_get_body (ValaCCodeDoStatement* self
 
 
 void vala_ccode_do_statement_set_body (ValaCCodeDoStatement* self, ValaCCodeStatement* value) {
-	ValaCCodeStatement* _tmp1_;
 	ValaCCodeStatement* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_body = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL)), _tmp1_);
+	self->priv->_body = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_body), _tmp0_);
 }
 
 
@@ -251,12 +242,9 @@ ValaCCodeExpression* vala_ccode_do_statement_get_condition (ValaCCodeDoStatement
 
 
 void vala_ccode_do_statement_set_condition (ValaCCodeDoStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_condition = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp1_);
+	self->priv->_condition = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_condition), _tmp0_);
 }
 
 
@@ -276,8 +264,8 @@ static void vala_ccode_do_statement_instance_init (ValaCCodeDoStatement * self)
 static void vala_ccode_do_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeDoStatement * self;
 	self = VALA_CCODE_DO_STATEMENT (obj);
-	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_ccode_node_unref (self->priv->_body), NULL));
-	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL));
+	_vala_ccode_node_unref0 (self->priv->_body);
+	_vala_ccode_node_unref0 (self->priv->_condition);
 	VALA_CCODE_NODE_CLASS (vala_ccode_do_statement_parent_class)->finalize (obj);
 }
 
