@@ -70,10 +70,8 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
 typedef struct _ValaCCodeElementAccess ValaCCodeElementAccess;
 typedef struct _ValaCCodeElementAccessClass ValaCCodeElementAccessClass;
 typedef struct _ValaCCodeElementAccessPrivate ValaCCodeElementAccessPrivate;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -88,9 +86,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an expression node in the C code tree.
- */
 struct _ValaCCodeExpression {
 	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
@@ -101,9 +96,6 @@ struct _ValaCCodeExpressionClass {
 	void (*write_inner) (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an access to an array member in the C code.
- */
 struct _ValaCCodeElementAccess {
 	ValaCCodeExpression parent_instance;
 	ValaCCodeElementAccessPrivate * priv;
@@ -139,6 +131,7 @@ GType vala_ccode_element_access_get_type (void);
 enum  {
 	VALA_CCODE_ELEMENT_ACCESS_DUMMY_PROPERTY
 };
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type);
 void vala_ccode_element_access_set_container (ValaCCodeElementAccess* self, ValaCCodeExpression* value);
 void vala_ccode_element_access_set_index (ValaCCodeElementAccess* self, ValaCCodeExpression* value);
 ValaCCodeElementAccess* vala_ccode_element_access_new (ValaCCodeExpression* cont, ValaCCodeExpression* i);
@@ -157,7 +150,7 @@ ValaCCodeElementAccess* vala_ccode_element_access_construct (GType object_type,
 	ValaCCodeElementAccess* self;
 	g_return_val_if_fail (cont != NULL, NULL);
 	g_return_val_if_fail (i != NULL, NULL);
-	self = (ValaCCodeElementAccess*) g_type_create_instance (object_type);
+	self = (ValaCCodeElementAccess*) vala_ccode_expression_construct (object_type);
 	vala_ccode_element_access_set_container (self, cont);
 	vala_ccode_element_access_set_index (self, i);
 	return self;
@@ -188,13 +181,15 @@ ValaCCodeExpression* vala_ccode_element_access_get_container (ValaCCodeElementAc
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 void vala_ccode_element_access_set_container (ValaCCodeElementAccess* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_container = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_container == NULL) ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL)), _tmp1_);
+	self->priv->_container = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_container), _tmp0_);
 }
 
 
@@ -207,12 +202,9 @@ ValaCCodeExpression* vala_ccode_element_access_get_index (ValaCCodeElementAccess
 
 
 void vala_ccode_element_access_set_index (ValaCCodeElementAccess* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_index = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_index == NULL) ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL)), _tmp1_);
+	self->priv->_index = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_index), _tmp0_);
 }
 
 
@@ -232,8 +224,8 @@ static void vala_ccode_element_access_instance_init (ValaCCodeElementAccess * se
 static void vala_ccode_element_access_finalize (ValaCCodeNode* obj) {
 	ValaCCodeElementAccess * self;
 	self = VALA_CCODE_ELEMENT_ACCESS (obj);
-	(self->priv->_container == NULL) ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL));
-	(self->priv->_index == NULL) ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL));
+	_vala_ccode_node_unref0 (self->priv->_container);
+	_vala_ccode_node_unref0 (self->priv->_index);
 	VALA_CCODE_NODE_CLASS (vala_ccode_element_access_parent_class)->finalize (obj);
 }
 
