@@ -79,9 +79,6 @@ typedef struct _ValaCCodeEmptyStatementPrivate ValaCCodeEmptyStatementPrivate;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -96,9 +93,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -108,9 +102,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents an empty statement in the C code.
- */
 struct _ValaCCodeEmptyStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeEmptyStatementPrivate * priv;
@@ -121,6 +112,7 @@ struct _ValaCCodeEmptyStatementClass {
 };
 
 
+static gpointer vala_ccode_empty_statement_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -144,10 +136,9 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirecti
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 static void vala_ccode_empty_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 ValaCCodeEmptyStatement* vala_ccode_empty_statement_new (void);
 ValaCCodeEmptyStatement* vala_ccode_empty_statement_construct (GType object_type);
-ValaCCodeEmptyStatement* vala_ccode_empty_statement_new (void);
-static gpointer vala_ccode_empty_statement_parent_class = NULL;
 
 
 
@@ -161,12 +152,9 @@ static void vala_ccode_empty_statement_real_write (ValaCCodeNode* base, ValaCCod
 }
 
 
-/**
- * Represents an empty statement in the C code.
- */
 ValaCCodeEmptyStatement* vala_ccode_empty_statement_construct (GType object_type) {
 	ValaCCodeEmptyStatement* self;
-	self = (ValaCCodeEmptyStatement*) g_type_create_instance (object_type);
+	self = (ValaCCodeEmptyStatement*) vala_ccode_statement_construct (object_type);
 	return self;
 }
 
