@@ -67,10 +67,9 @@ typedef struct _ValaCCodeEnumValuePrivate ValaCCodeEnumValuePrivate;
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -85,9 +84,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an enum value in the C code.
- */
 struct _ValaCCodeEnumValue {
 	ValaCCodeNode parent_instance;
 	ValaCCodeEnumValuePrivate * priv;
@@ -123,6 +119,7 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_ENUM_VALUE_DUMMY_PROPERTY
 };
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
 void vala_ccode_enum_value_set_name (ValaCCodeEnumValue* self, const char* value);
 void vala_ccode_enum_value_set_value (ValaCCodeEnumValue* self, ValaCCodeExpression* value);
 ValaCCodeEnumValue* vala_ccode_enum_value_new (const char* name, ValaCCodeExpression* value);
@@ -139,7 +136,7 @@ static void vala_ccode_enum_value_finalize (ValaCCodeNode* obj);
 ValaCCodeEnumValue* vala_ccode_enum_value_construct (GType object_type, const char* name, ValaCCodeExpression* value) {
 	ValaCCodeEnumValue* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaCCodeEnumValue*) g_type_create_instance (object_type);
+	self = (ValaCCodeEnumValue*) vala_ccode_node_construct (object_type);
 	vala_ccode_enum_value_set_name (self, name);
 	vala_ccode_enum_value_set_value (self, value);
 	return self;
@@ -172,12 +169,9 @@ const char* vala_ccode_enum_value_get_name (ValaCCodeEnumValue* self) {
 
 
 void vala_ccode_enum_value_set_name (ValaCCodeEnumValue* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -189,13 +183,15 @@ ValaCCodeExpression* vala_ccode_enum_value_get_value (ValaCCodeEnumValue* self)
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 void vala_ccode_enum_value_set_value (ValaCCodeEnumValue* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_value = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_value == NULL) ? NULL : (self->priv->_value = (vala_ccode_node_unref (self->priv->_value), NULL)), _tmp1_);
+	self->priv->_value = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_value), _tmp0_);
 }
 
 
@@ -215,8 +211,8 @@ static void vala_ccode_enum_value_instance_init (ValaCCodeEnumValue * self) {
 static void vala_ccode_enum_value_finalize (ValaCCodeNode* obj) {
 	ValaCCodeEnumValue * self;
 	self = VALA_CCODE_ENUM_VALUE (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_value == NULL) ? NULL : (self->priv->_value = (vala_ccode_node_unref (self->priv->_value), NULL));
+	_g_free0 (self->priv->_name);
+	_vala_ccode_node_unref0 (self->priv->_value);
 	VALA_CCODE_NODE_CLASS (vala_ccode_enum_value_parent_class)->finalize (obj);
 }
 
