@@ -56,10 +56,9 @@ typedef struct _ValaCCodeWriterClass ValaCCodeWriterClass;
 typedef struct _ValaCCodeFragment ValaCCodeFragment;
 typedef struct _ValaCCodeFragmentClass ValaCCodeFragmentClass;
 typedef struct _ValaCCodeFragmentPrivate ValaCCodeFragmentPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -74,9 +73,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a container for C code nodes.
- */
 struct _ValaCCodeFragment {
 	ValaCCodeNode parent_instance;
 	ValaCCodeFragmentPrivate * priv;
@@ -118,17 +114,13 @@ void vala_ccode_node_write_declaration (ValaCCodeNode* self, ValaCCodeWriter* wr
 static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 void vala_ccode_node_write_combined (ValaCCodeNode* self, ValaCCodeWriter* writer);
 static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCCodeWriter* writer);
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
 ValaCCodeFragment* vala_ccode_fragment_new (void);
 ValaCCodeFragment* vala_ccode_fragment_construct (GType object_type);
 static void vala_ccode_fragment_finalize (ValaCCodeNode* obj);
 
 
 
-/**
- * Appends the specified code node to this code fragment.
- *
- * @param node a C code node
- */
 void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (node != NULL);
@@ -136,11 +128,6 @@ void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node) {
 }
 
 
-/**
- * Returns a copy of the list of children.
- *
- * @return children list
- */
 GeeList* vala_ccode_fragment_get_children (ValaCCodeFragment* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -163,9 +150,9 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 			}
 			node = (ValaCCodeNode*) gee_iterator_get (_node_it);
 			vala_ccode_node_write (node, writer);
-			(node == NULL) ? NULL : (node = (vala_ccode_node_unref (node), NULL));
+			_vala_ccode_node_unref0 (node);
 		}
-		(_node_it == NULL) ? NULL : (_node_it = (gee_collection_object_unref (_node_it), NULL));
+		_gee_collection_object_unref0 (_node_it);
 	}
 }
 
@@ -184,9 +171,9 @@ static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, Val
 			}
 			node = (ValaCCodeNode*) gee_iterator_get (_node_it);
 			vala_ccode_node_write_declaration (node, writer);
-			(node == NULL) ? NULL : (node = (vala_ccode_node_unref (node), NULL));
+			_vala_ccode_node_unref0 (node);
 		}
-		(_node_it == NULL) ? NULL : (_node_it = (gee_collection_object_unref (_node_it), NULL));
+		_gee_collection_object_unref0 (_node_it);
 	}
 }
 
@@ -205,19 +192,16 @@ static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCC
 			}
 			node = (ValaCCodeNode*) gee_iterator_get (_node_it);
 			vala_ccode_node_write_combined (node, writer);
-			(node == NULL) ? NULL : (node = (vala_ccode_node_unref (node), NULL));
+			_vala_ccode_node_unref0 (node);
 		}
-		(_node_it == NULL) ? NULL : (_node_it = (gee_collection_object_unref (_node_it), NULL));
+		_gee_collection_object_unref0 (_node_it);
 	}
 }
 
 
-/**
- * Represents a container for C code nodes.
- */
 ValaCCodeFragment* vala_ccode_fragment_construct (GType object_type) {
 	ValaCCodeFragment* self;
-	self = (ValaCCodeFragment*) g_type_create_instance (object_type);
+	self = (ValaCCodeFragment*) vala_ccode_node_construct (object_type);
 	return self;
 }
 
@@ -246,7 +230,7 @@ static void vala_ccode_fragment_instance_init (ValaCCodeFragment * self) {
 static void vala_ccode_fragment_finalize (ValaCCodeNode* obj) {
 	ValaCCodeFragment * self;
 	self = VALA_CCODE_FRAGMENT (obj);
-	(self->priv->children == NULL) ? NULL : (self->priv->children = (gee_collection_object_unref (self->priv->children), NULL));
+	_gee_collection_object_unref0 (self->priv->children);
 	VALA_CCODE_NODE_CLASS (vala_ccode_fragment_parent_class)->finalize (obj);
 }
 
