@@ -69,10 +69,9 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
 typedef struct _ValaCCodeFunctionCall ValaCCodeFunctionCall;
 typedef struct _ValaCCodeFunctionCallClass ValaCCodeFunctionCallClass;
 typedef struct _ValaCCodeFunctionCallPrivate ValaCCodeFunctionCallPrivate;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -87,9 +86,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an expression node in the C code tree.
- */
 struct _ValaCCodeExpression {
 	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
@@ -100,9 +96,6 @@ struct _ValaCCodeExpressionClass {
 	void (*write_inner) (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a function call in the C code.
- */
 struct _ValaCCodeFunctionCall {
 	ValaCCodeExpression parent_instance;
 	ValaCCodeFunctionCallPrivate * priv;
@@ -138,6 +131,7 @@ GType vala_ccode_function_call_get_type (void);
 enum  {
 	VALA_CCODE_FUNCTION_CALL_DUMMY_PROPERTY
 };
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type);
 void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value);
 ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call);
 ValaCCodeFunctionCall* vala_ccode_function_call_construct (GType object_type, ValaCCodeExpression* call);
@@ -155,7 +149,7 @@ static void vala_ccode_function_call_finalize (ValaCCodeNode* obj);
 
 ValaCCodeFunctionCall* vala_ccode_function_call_construct (GType object_type, ValaCCodeExpression* call) {
 	ValaCCodeFunctionCall* self;
-	self = (ValaCCodeFunctionCall*) g_type_create_instance (object_type);
+	self = (ValaCCodeFunctionCall*) vala_ccode_expression_construct (object_type);
 	vala_ccode_function_call_set_call (self, call);
 	return self;
 }
@@ -166,11 +160,6 @@ ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call)
 }
 
 
-/**
- * Appends the specified expression to the list of arguments.
- *
- * @param expr a C code expression
- */
 void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (expr != NULL);
@@ -185,11 +174,6 @@ void vala_ccode_function_call_insert_argument (ValaCCodeFunctionCall* self, gint
 }
 
 
-/**
- * Returns a copy of the list of arguments.
- *
- * @return list of arguments
- */
 GeeList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -223,9 +207,9 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 			if (expr != NULL) {
 				vala_ccode_node_write ((ValaCCodeNode*) expr, writer);
 			}
-			(expr == NULL) ? NULL : (expr = (vala_ccode_node_unref (expr), NULL));
+			_vala_ccode_node_unref0 (expr);
 		}
-		(_expr_it == NULL) ? NULL : (_expr_it = (gee_collection_object_unref (_expr_it), NULL));
+		_gee_collection_object_unref0 (_expr_it);
 	}
 	vala_ccode_writer_write_string (writer, ")");
 }
@@ -239,13 +223,15 @@ ValaCCodeExpression* vala_ccode_function_call_get_call (ValaCCodeFunctionCall* s
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 void vala_ccode_function_call_set_call (ValaCCodeFunctionCall* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_call = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_call == NULL) ? NULL : (self->priv->_call = (vala_ccode_node_unref (self->priv->_call), NULL)), _tmp1_);
+	self->priv->_call = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_call), _tmp0_);
 }
 
 
@@ -266,8 +252,8 @@ static void vala_ccode_function_call_instance_init (ValaCCodeFunctionCall * self
 static void vala_ccode_function_call_finalize (ValaCCodeNode* obj) {
 	ValaCCodeFunctionCall * self;
 	self = VALA_CCODE_FUNCTION_CALL (obj);
-	(self->priv->_call == NULL) ? NULL : (self->priv->_call = (vala_ccode_node_unref (self->priv->_call), NULL));
-	(self->priv->arguments == NULL) ? NULL : (self->priv->arguments = (gee_collection_object_unref (self->priv->arguments), NULL));
+	_vala_ccode_node_unref0 (self->priv->_call);
+	_gee_collection_object_unref0 (self->priv->arguments);
 	VALA_CCODE_NODE_CLASS (vala_ccode_function_call_parent_class)->finalize (obj);
 }
 
