@@ -68,6 +68,7 @@ typedef struct _ValaCCodeStatementPrivate ValaCCodeStatementPrivate;
 typedef struct _ValaCCodeGotoStatement ValaCCodeGotoStatement;
 typedef struct _ValaCCodeGotoStatementClass ValaCCodeGotoStatementClass;
 typedef struct _ValaCCodeGotoStatementPrivate ValaCCodeGotoStatementPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -79,9 +80,6 @@ typedef struct _ValaCCodeGotoStatementPrivate ValaCCodeGotoStatementPrivate;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -96,9 +94,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -108,9 +103,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a goto statement in the C code.
- */
 struct _ValaCCodeGotoStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeGotoStatementPrivate * priv;
@@ -145,6 +137,7 @@ GType vala_ccode_goto_statement_get_type (void);
 enum  {
 	VALA_CCODE_GOTO_STATEMENT_DUMMY_PROPERTY
 };
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 void vala_ccode_goto_statement_set_name (ValaCCodeGotoStatement* self, const char* value);
 ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name);
 ValaCCodeGotoStatement* vala_ccode_goto_statement_construct (GType object_type, const char* name);
@@ -161,7 +154,7 @@ static void vala_ccode_goto_statement_finalize (ValaCCodeNode* obj);
 ValaCCodeGotoStatement* vala_ccode_goto_statement_construct (GType object_type, const char* name) {
 	ValaCCodeGotoStatement* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaCCodeGotoStatement*) g_type_create_instance (object_type);
+	self = (ValaCCodeGotoStatement*) vala_ccode_statement_construct (object_type);
 	vala_ccode_goto_statement_set_name (self, name);
 	return self;
 }
@@ -193,12 +186,9 @@ const char* vala_ccode_goto_statement_get_name (ValaCCodeGotoStatement* self) {
 
 
 void vala_ccode_goto_statement_set_name (ValaCCodeGotoStatement* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -218,7 +208,7 @@ static void vala_ccode_goto_statement_instance_init (ValaCCodeGotoStatement * se
 static void vala_ccode_goto_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeGotoStatement * self;
 	self = VALA_CCODE_GOTO_STATEMENT (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
+	_g_free0 (self->priv->_name);
 	VALA_CCODE_NODE_CLASS (vala_ccode_goto_statement_parent_class)->finalize (obj);
 }
 
