@@ -68,10 +68,8 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
 typedef struct _ValaCCodeIdentifier ValaCCodeIdentifier;
 typedef struct _ValaCCodeIdentifierClass ValaCCodeIdentifierClass;
 typedef struct _ValaCCodeIdentifierPrivate ValaCCodeIdentifierPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -86,9 +84,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an expression node in the C code tree.
- */
 struct _ValaCCodeExpression {
 	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
@@ -99,9 +94,6 @@ struct _ValaCCodeExpressionClass {
 	void (*write_inner) (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a identifier in the C code.
- */
 struct _ValaCCodeIdentifier {
 	ValaCCodeExpression parent_instance;
 	ValaCCodeIdentifierPrivate * priv;
@@ -136,6 +128,7 @@ GType vala_ccode_identifier_get_type (void);
 enum  {
 	VALA_CCODE_IDENTIFIER_DUMMY_PROPERTY
 };
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type);
 void vala_ccode_identifier_set_name (ValaCCodeIdentifier* self, const char* value);
 ValaCCodeIdentifier* vala_ccode_identifier_new (const char* _name);
 ValaCCodeIdentifier* vala_ccode_identifier_construct (GType object_type, const char* _name);
@@ -149,7 +142,7 @@ static void vala_ccode_identifier_finalize (ValaCCodeNode* obj);
 ValaCCodeIdentifier* vala_ccode_identifier_construct (GType object_type, const char* _name) {
 	ValaCCodeIdentifier* self;
 	g_return_val_if_fail (_name != NULL, NULL);
-	self = (ValaCCodeIdentifier*) g_type_create_instance (object_type);
+	self = (ValaCCodeIdentifier*) vala_ccode_expression_construct (object_type);
 	vala_ccode_identifier_set_name (self, _name);
 	return self;
 }
@@ -177,12 +170,9 @@ const char* vala_ccode_identifier_get_name (ValaCCodeIdentifier* self) {
 
 
 void vala_ccode_identifier_set_name (ValaCCodeIdentifier* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -202,7 +192,7 @@ static void vala_ccode_identifier_instance_init (ValaCCodeIdentifier * self) {
 static void vala_ccode_identifier_finalize (ValaCCodeNode* obj) {
 	ValaCCodeIdentifier * self;
 	self = VALA_CCODE_IDENTIFIER (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
+	_g_free0 (self->priv->_name);
 	VALA_CCODE_NODE_CLASS (vala_ccode_identifier_parent_class)->finalize (obj);
 }
 
