@@ -78,6 +78,7 @@ typedef struct _ValaCCodeIfStatementPrivate ValaCCodeIfStatementPrivate;
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -99,9 +100,6 @@ typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 typedef struct _ValaCCodeBlock ValaCCodeBlock;
 typedef struct _ValaCCodeBlockClass ValaCCodeBlockClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -116,9 +114,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -128,9 +123,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents an if selection statement in the C code.
- */
 struct _ValaCCodeIfStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeIfStatementPrivate * priv;
@@ -169,6 +161,7 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_IF_STATEMENT_DUMMY_PROPERTY
 };
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 void vala_ccode_if_statement_set_condition (ValaCCodeIfStatement* self, ValaCCodeExpression* value);
 void vala_ccode_if_statement_set_true_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value);
 void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value);
@@ -196,7 +189,7 @@ ValaCCodeIfStatement* vala_ccode_if_statement_construct (GType object_type, Vala
 	ValaCCodeIfStatement* self;
 	g_return_val_if_fail (cond != NULL, NULL);
 	g_return_val_if_fail (true_stmt != NULL, NULL);
-	self = (ValaCCodeIfStatement*) g_type_create_instance (object_type);
+	self = (ValaCCodeIfStatement*) vala_ccode_statement_construct (object_type);
 	vala_ccode_if_statement_set_condition (self, cond);
 	vala_ccode_if_statement_set_true_statement (self, true_stmt);
 	vala_ccode_if_statement_set_false_statement (self, false_stmt);
@@ -209,6 +202,11 @@ ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, Va
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeIfStatement * self;
 	gboolean _tmp0_;
@@ -230,14 +228,11 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 	} else {
 		_tmp0_ = FALSE;
 	}
-	/* else shouldn't be on a separate line */
 	if (_tmp0_) {
-		ValaCCodeBlock* _tmp1_;
 		ValaCCodeBlock* cblock;
-		_tmp1_ = NULL;
-		cblock = (_tmp1_ = VALA_CCODE_BLOCK (self->priv->_true_statement), (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_));
+		cblock = _vala_ccode_node_ref0 (VALA_CCODE_BLOCK (self->priv->_true_statement));
 		vala_ccode_block_set_suppress_newline (cblock, TRUE);
-		(cblock == NULL) ? NULL : (cblock = (vala_ccode_node_unref (cblock), NULL));
+		_vala_ccode_node_unref0 (cblock);
 	}
 	vala_ccode_node_write ((ValaCCodeNode*) self->priv->_true_statement, writer);
 	if (self->priv->_false_statement != NULL) {
@@ -247,14 +242,11 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 		} else {
 			vala_ccode_writer_write_string (writer, " else");
 		}
-		/* else if should be on one line */
 		if (VALA_IS_CCODE_IF_STATEMENT (self->priv->_false_statement)) {
-			ValaCCodeIfStatement* _tmp2_;
 			ValaCCodeIfStatement* cif;
-			_tmp2_ = NULL;
-			cif = (_tmp2_ = VALA_CCODE_IF_STATEMENT (self->priv->_false_statement), (_tmp2_ == NULL) ? NULL : vala_ccode_node_ref (_tmp2_));
+			cif = _vala_ccode_node_ref0 (VALA_CCODE_IF_STATEMENT (self->priv->_false_statement));
 			vala_ccode_if_statement_set_else_if (cif, TRUE);
-			(cif == NULL) ? NULL : (cif = (vala_ccode_node_unref (cif), NULL));
+			_vala_ccode_node_unref0 (cif);
 		}
 		vala_ccode_node_write ((ValaCCodeNode*) self->priv->_false_statement, writer);
 	}
@@ -270,12 +262,9 @@ ValaCCodeExpression* vala_ccode_if_statement_get_condition (ValaCCodeIfStatement
 
 
 void vala_ccode_if_statement_set_condition (ValaCCodeIfStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_condition = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)), _tmp1_);
+	self->priv->_condition = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_condition), _tmp0_);
 }
 
 
@@ -288,12 +277,9 @@ ValaCCodeStatement* vala_ccode_if_statement_get_true_statement (ValaCCodeIfState
 
 
 void vala_ccode_if_statement_set_true_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
-	ValaCCodeStatement* _tmp1_;
 	ValaCCodeStatement* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_true_statement = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_ccode_node_unref (self->priv->_true_statement), NULL)), _tmp1_);
+	self->priv->_true_statement = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_true_statement), _tmp0_);
 }
 
 
@@ -306,12 +292,9 @@ ValaCCodeStatement* vala_ccode_if_statement_get_false_statement (ValaCCodeIfStat
 
 
 void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
-	ValaCCodeStatement* _tmp1_;
 	ValaCCodeStatement* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_false_statement = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_ccode_node_unref (self->priv->_false_statement), NULL)), _tmp1_);
+	self->priv->_false_statement = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_false_statement), _tmp0_);
 }
 
 
@@ -345,9 +328,9 @@ static void vala_ccode_if_statement_instance_init (ValaCCodeIfStatement * self)
 static void vala_ccode_if_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeIfStatement * self;
 	self = VALA_CCODE_IF_STATEMENT (obj);
-	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL));
-	(self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_ccode_node_unref (self->priv->_true_statement), NULL));
-	(self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_ccode_node_unref (self->priv->_false_statement), NULL));
+	_vala_ccode_node_unref0 (self->priv->_condition);
+	_vala_ccode_node_unref0 (self->priv->_true_statement);
+	_vala_ccode_node_unref0 (self->priv->_false_statement);
 	VALA_CCODE_NODE_CLASS (vala_ccode_if_statement_parent_class)->finalize (obj);
 }
 
