@@ -69,10 +69,9 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
 typedef struct _ValaCCodeInitializerList ValaCCodeInitializerList;
 typedef struct _ValaCCodeInitializerListClass ValaCCodeInitializerListClass;
 typedef struct _ValaCCodeInitializerListPrivate ValaCCodeInitializerListPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -87,9 +86,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an expression node in the C code tree.
- */
 struct _ValaCCodeExpression {
 	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
@@ -100,9 +96,6 @@ struct _ValaCCodeExpressionClass {
 	void (*write_inner) (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a struct or array initializer list in the C code.
- */
 struct _ValaCCodeInitializerList {
 	ValaCCodeExpression parent_instance;
 	ValaCCodeInitializerListPrivate * priv;
@@ -141,17 +134,13 @@ void vala_ccode_initializer_list_append (ValaCCodeInitializerList* self, ValaCCo
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 static void vala_ccode_initializer_list_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type);
 ValaCCodeInitializerList* vala_ccode_initializer_list_new (void);
 ValaCCodeInitializerList* vala_ccode_initializer_list_construct (GType object_type);
 static void vala_ccode_initializer_list_finalize (ValaCCodeNode* obj);
 
 
 
-/**
- * Appends the specified expression to this initializer list.
- *
- * @param expr an expression
- */
 void vala_ccode_initializer_list_append (ValaCCodeInitializerList* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (expr != NULL);
@@ -183,20 +172,17 @@ static void vala_ccode_initializer_list_real_write (ValaCCodeNode* base, ValaCCo
 			if (expr != NULL) {
 				vala_ccode_node_write ((ValaCCodeNode*) expr, writer);
 			}
-			(expr == NULL) ? NULL : (expr = (vala_ccode_node_unref (expr), NULL));
+			_vala_ccode_node_unref0 (expr);
 		}
-		(_expr_it == NULL) ? NULL : (_expr_it = (gee_collection_object_unref (_expr_it), NULL));
+		_gee_collection_object_unref0 (_expr_it);
 	}
 	vala_ccode_writer_write_string (writer, "}");
 }
 
 
-/**
- * Represents a struct or array initializer list in the C code.
- */
 ValaCCodeInitializerList* vala_ccode_initializer_list_construct (GType object_type) {
 	ValaCCodeInitializerList* self;
-	self = (ValaCCodeInitializerList*) g_type_create_instance (object_type);
+	self = (ValaCCodeInitializerList*) vala_ccode_expression_construct (object_type);
 	return self;
 }
 
@@ -223,7 +209,7 @@ static void vala_ccode_initializer_list_instance_init (ValaCCodeInitializerList
 static void vala_ccode_initializer_list_finalize (ValaCCodeNode* obj) {
 	ValaCCodeInitializerList * self;
 	self = VALA_CCODE_INITIALIZER_LIST (obj);
-	(self->priv->initializers == NULL) ? NULL : (self->priv->initializers = (gee_collection_object_unref (self->priv->initializers), NULL));
+	_gee_collection_object_unref0 (self->priv->initializers);
 	VALA_CCODE_NODE_CLASS (vala_ccode_initializer_list_parent_class)->finalize (obj);
 }
 
