@@ -68,6 +68,7 @@ typedef struct _ValaCCodeStatementPrivate ValaCCodeStatementPrivate;
 typedef struct _ValaCCodeLabel ValaCCodeLabel;
 typedef struct _ValaCCodeLabelClass ValaCCodeLabelClass;
 typedef struct _ValaCCodeLabelPrivate ValaCCodeLabelPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -79,9 +80,6 @@ typedef struct _ValaCCodeLabelPrivate ValaCCodeLabelPrivate;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -96,9 +94,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -108,9 +103,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a label declaration in the C code.
- */
 struct _ValaCCodeLabel {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeLabelPrivate * priv;
@@ -125,6 +117,7 @@ struct _ValaCCodeLabelPrivate {
 };
 
 
+static gpointer vala_ccode_label_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -144,17 +137,16 @@ GType vala_ccode_label_get_type (void);
 enum  {
 	VALA_CCODE_LABEL_DUMMY_PROPERTY
 };
+ValaCCodeStatement* vala_ccode_statement_construct (GType object_type);
 void vala_ccode_label_set_name (ValaCCodeLabel* self, const char* value);
 ValaCCodeLabel* vala_ccode_label_new (const char* name);
 ValaCCodeLabel* vala_ccode_label_construct (GType object_type, const char* name);
-ValaCCodeLabel* vala_ccode_label_new (const char* name);
 GType vala_ccode_line_directive_get_type (void);
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 const char* vala_ccode_label_get_name (ValaCCodeLabel* self);
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_label_parent_class = NULL;
 static void vala_ccode_label_finalize (ValaCCodeNode* obj);
 
 
@@ -162,7 +154,7 @@ static void vala_ccode_label_finalize (ValaCCodeNode* obj);
 ValaCCodeLabel* vala_ccode_label_construct (GType object_type, const char* name) {
 	ValaCCodeLabel* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaCCodeLabel*) g_type_create_instance (object_type);
+	self = (ValaCCodeLabel*) vala_ccode_statement_construct (object_type);
 	vala_ccode_label_set_name (self, name);
 	return self;
 }
@@ -185,18 +177,17 @@ static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 
 
 const char* vala_ccode_label_get_name (ValaCCodeLabel* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_name;
+	result = self->priv->_name;
+	return result;
 }
 
 
 void vala_ccode_label_set_name (ValaCCodeLabel* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -216,7 +207,7 @@ static void vala_ccode_label_instance_init (ValaCCodeLabel * self) {
 static void vala_ccode_label_finalize (ValaCCodeNode* obj) {
 	ValaCCodeLabel * self;
 	self = VALA_CCODE_LABEL (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
+	_g_free0 (self->priv->_name);
 	VALA_CCODE_NODE_CLASS (vala_ccode_label_parent_class)->finalize (obj);
 }
 
