@@ -67,6 +67,8 @@ typedef struct _ValaCCodeMacroReplacementPrivate ValaCCodeMacroReplacementPrivat
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -78,9 +80,6 @@ typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -95,9 +94,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a preprocessor macro replacement definition in the C code.
- */
 struct _ValaCCodeMacroReplacement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeMacroReplacementPrivate * priv;
@@ -134,6 +130,7 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_MACRO_REPLACEMENT_DUMMY_PROPERTY
 };
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
 void vala_ccode_macro_replacement_set_replacement (ValaCCodeMacroReplacement* self, const char* value);
 void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, const char* value);
 ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* name, const char* replacement);
@@ -158,7 +155,7 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_construct (GType object_
 	ValaCCodeMacroReplacement* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (replacement != NULL, NULL);
-	self = (ValaCCodeMacroReplacement*) g_type_create_instance (object_type);
+	self = (ValaCCodeMacroReplacement*) vala_ccode_node_construct (object_type);
 	vala_ccode_macro_replacement_set_replacement (self, replacement);
 	vala_ccode_macro_replacement_set_name (self, name);
 	return self;
@@ -174,7 +171,7 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_construct_with_expressio
 	ValaCCodeMacroReplacement* self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (replacement_expression != NULL, NULL);
-	self = (ValaCCodeMacroReplacement*) g_type_create_instance (object_type);
+	self = (ValaCCodeMacroReplacement*) vala_ccode_node_construct (object_type);
 	vala_ccode_macro_replacement_set_name (self, name);
 	vala_ccode_macro_replacement_set_replacement_expression (self, replacement_expression);
 	return self;
@@ -212,12 +209,9 @@ const char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* se
 
 
 void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -230,12 +224,9 @@ const char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacem
 
 
 void vala_ccode_macro_replacement_set_replacement (ValaCCodeMacroReplacement* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_replacement = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_replacement = (g_free (self->priv->_replacement), NULL), _tmp1_);
+	self->priv->_replacement = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_replacement), _tmp0_);
 }
 
 
@@ -247,13 +238,15 @@ ValaCCodeExpression* vala_ccode_macro_replacement_get_replacement_expression (Va
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 void vala_ccode_macro_replacement_set_replacement_expression (ValaCCodeMacroReplacement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_replacement_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_replacement_expression == NULL) ? NULL : (self->priv->_replacement_expression = (vala_ccode_node_unref (self->priv->_replacement_expression), NULL)), _tmp1_);
+	self->priv->_replacement_expression = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_replacement_expression), _tmp0_);
 }
 
 
@@ -273,9 +266,9 @@ static void vala_ccode_macro_replacement_instance_init (ValaCCodeMacroReplacemen
 static void vala_ccode_macro_replacement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeMacroReplacement * self;
 	self = VALA_CCODE_MACRO_REPLACEMENT (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	self->priv->_replacement = (g_free (self->priv->_replacement), NULL);
-	(self->priv->_replacement_expression == NULL) ? NULL : (self->priv->_replacement_expression = (vala_ccode_node_unref (self->priv->_replacement_expression), NULL));
+	_g_free0 (self->priv->_name);
+	_g_free0 (self->priv->_replacement);
+	_vala_ccode_node_unref0 (self->priv->_replacement_expression);
 	VALA_CCODE_NODE_CLASS (vala_ccode_macro_replacement_parent_class)->finalize (obj);
 }
 
