@@ -68,10 +68,8 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
 typedef struct _ValaCCodeParenthesizedExpression ValaCCodeParenthesizedExpression;
 typedef struct _ValaCCodeParenthesizedExpressionClass ValaCCodeParenthesizedExpressionClass;
 typedef struct _ValaCCodeParenthesizedExpressionPrivate ValaCCodeParenthesizedExpressionPrivate;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -86,9 +84,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents an expression node in the C code tree.
- */
 struct _ValaCCodeExpression {
 	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
@@ -99,9 +94,6 @@ struct _ValaCCodeExpressionClass {
 	void (*write_inner) (ValaCCodeExpression* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a parenthesized expression in the C code.
- */
 struct _ValaCCodeParenthesizedExpression {
 	ValaCCodeExpression parent_instance;
 	ValaCCodeParenthesizedExpressionPrivate * priv;
@@ -116,6 +108,7 @@ struct _ValaCCodeParenthesizedExpressionPrivate {
 };
 
 
+static gpointer vala_ccode_parenthesized_expression_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -135,15 +128,14 @@ GType vala_ccode_parenthesized_expression_get_type (void);
 enum  {
 	VALA_CCODE_PARENTHESIZED_EXPRESSION_DUMMY_PROPERTY
 };
+ValaCCodeExpression* vala_ccode_expression_construct (GType object_type);
 void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpression* self, ValaCCodeExpression* value);
 ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr);
 ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_construct (GType object_type, ValaCCodeExpression* expr);
-ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 ValaCCodeExpression* vala_ccode_parenthesized_expression_get_inner (ValaCCodeParenthesizedExpression* self);
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_parenthesized_expression_parent_class = NULL;
 static void vala_ccode_parenthesized_expression_finalize (ValaCCodeNode* obj);
 
 
@@ -151,7 +143,7 @@ static void vala_ccode_parenthesized_expression_finalize (ValaCCodeNode* obj);
 ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_construct (GType object_type, ValaCCodeExpression* expr) {
 	ValaCCodeParenthesizedExpression* self;
 	g_return_val_if_fail (expr != NULL, NULL);
-	self = (ValaCCodeParenthesizedExpression*) g_type_create_instance (object_type);
+	self = (ValaCCodeParenthesizedExpression*) vala_ccode_expression_construct (object_type);
 	vala_ccode_parenthesized_expression_set_inner (self, expr);
 	return self;
 }
@@ -173,18 +165,22 @@ static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base,
 
 
 ValaCCodeExpression* vala_ccode_parenthesized_expression_get_inner (ValaCCodeParenthesizedExpression* self) {
+	ValaCCodeExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_inner;
+	result = self->priv->_inner;
+	return result;
+}
+
+
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
 }
 
 
 void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpression* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp2_;
-	ValaCCodeExpression* _tmp1_;
+	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	self->priv->_inner = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL)), _tmp2_);
+	self->priv->_inner = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_inner), _tmp0_);
 }
 
 
@@ -204,7 +200,7 @@ static void vala_ccode_parenthesized_expression_instance_init (ValaCCodeParenthe
 static void vala_ccode_parenthesized_expression_finalize (ValaCCodeNode* obj) {
 	ValaCCodeParenthesizedExpression * self;
 	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (obj);
-	(self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_ccode_node_unref (self->priv->_inner), NULL));
+	_vala_ccode_node_unref0 (self->priv->_inner);
 	VALA_CCODE_NODE_CLASS (vala_ccode_parenthesized_expression_parent_class)->finalize (obj);
 }
 
