@@ -89,6 +89,7 @@ typedef struct _ValaCCodeSwitchStatementPrivate ValaCCodeSwitchStatementPrivate;
 
 typedef struct _ValaCCodeExpression ValaCCodeExpression;
 typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -100,9 +101,6 @@ typedef struct _ValaCCodeExpressionClass ValaCCodeExpressionClass;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -117,9 +115,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a statement in the C code.
- */
 struct _ValaCCodeStatement {
 	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
@@ -129,9 +124,6 @@ struct _ValaCCodeStatementClass {
 	ValaCCodeNodeClass parent_class;
 };
 
-/**
- * Represents a C code block.
- */
 struct _ValaCCodeBlock {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeBlockPrivate * priv;
@@ -141,9 +133,6 @@ struct _ValaCCodeBlockClass {
 	ValaCCodeStatementClass parent_class;
 };
 
-/**
- * Represents a switch selection statement in the C code.
- */
 struct _ValaCCodeSwitchStatement {
 	ValaCCodeBlock parent_instance;
 	ValaCCodeSwitchStatementPrivate * priv;
@@ -180,10 +169,11 @@ GType vala_ccode_expression_get_type (void);
 enum  {
 	VALA_CCODE_SWITCH_STATEMENT_DUMMY_PROPERTY
 };
+ValaCCodeBlock* vala_ccode_block_new (void);
+ValaCCodeBlock* vala_ccode_block_construct (GType object_type);
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value);
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression);
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_construct (GType object_type, ValaCCodeExpression* expression);
-ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression);
 GType vala_ccode_line_directive_get_type (void);
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self);
@@ -198,7 +188,7 @@ static void vala_ccode_switch_statement_finalize (ValaCCodeNode* obj);
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_construct (GType object_type, ValaCCodeExpression* expression) {
 	ValaCCodeSwitchStatement* self;
 	g_return_val_if_fail (expression != NULL, NULL);
-	self = (ValaCCodeSwitchStatement*) g_type_create_instance (object_type);
+	self = (ValaCCodeSwitchStatement*) vala_ccode_block_construct (object_type);
 	vala_ccode_switch_statement_set_expression (self, expression);
 	return self;
 }
@@ -229,13 +219,15 @@ ValaCCodeExpression* vala_ccode_switch_statement_get_expression (ValaCCodeSwitch
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL)), _tmp1_);
+	self->priv->_expression = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_expression), _tmp0_);
 }
 
 
@@ -255,7 +247,7 @@ static void vala_ccode_switch_statement_instance_init (ValaCCodeSwitchStatement
 static void vala_ccode_switch_statement_finalize (ValaCCodeNode* obj) {
 	ValaCCodeSwitchStatement * self;
 	self = VALA_CCODE_SWITCH_STATEMENT (obj);
-	(self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_ccode_node_unref (self->priv->_expression), NULL));
+	_vala_ccode_node_unref0 (self->priv->_expression);
 	VALA_CCODE_NODE_CLASS (vala_ccode_switch_statement_parent_class)->finalize (obj);
 }
 
