@@ -67,6 +67,8 @@ typedef struct _ValaCCodeTypeDefinitionPrivate ValaCCodeTypeDefinitionPrivate;
 
 typedef struct _ValaCCodeDeclarator ValaCCodeDeclarator;
 typedef struct _ValaCCodeDeclaratorClass ValaCCodeDeclaratorClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
 #define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
@@ -78,9 +80,6 @@ typedef struct _ValaCCodeDeclaratorClass ValaCCodeDeclaratorClass;
 typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 
-/**
- * Represents a node in the C code tree.
- */
 struct _ValaCCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -95,9 +94,6 @@ struct _ValaCCodeNodeClass {
 	void (*write_combined) (ValaCCodeNode* self, ValaCCodeWriter* writer);
 };
 
-/**
- * Represents a typedef in the C code.
- */
 struct _ValaCCodeTypeDefinition {
 	ValaCCodeNode parent_instance;
 	ValaCCodeTypeDefinitionPrivate * priv;
@@ -113,6 +109,7 @@ struct _ValaCCodeTypeDefinitionPrivate {
 };
 
 
+static gpointer vala_ccode_type_definition_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -132,11 +129,11 @@ GType vala_ccode_declarator_get_type (void);
 enum  {
 	VALA_CCODE_TYPE_DEFINITION_DUMMY_PROPERTY
 };
+ValaCCodeNode* vala_ccode_node_construct (GType object_type);
 void vala_ccode_type_definition_set_type_name (ValaCCodeTypeDefinition* self, const char* value);
 void vala_ccode_type_definition_set_declarator (ValaCCodeTypeDefinition* self, ValaCCodeDeclarator* value);
 ValaCCodeTypeDefinition* vala_ccode_type_definition_new (const char* type, ValaCCodeDeclarator* decl);
 ValaCCodeTypeDefinition* vala_ccode_type_definition_construct (GType object_type, const char* type, ValaCCodeDeclarator* decl);
-ValaCCodeTypeDefinition* vala_ccode_type_definition_new (const char* type, ValaCCodeDeclarator* decl);
 static void vala_ccode_type_definition_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 GType vala_ccode_line_directive_get_type (void);
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
@@ -146,7 +143,6 @@ ValaCCodeDeclarator* vala_ccode_type_definition_get_declarator (ValaCCodeTypeDef
 void vala_ccode_node_write_declaration (ValaCCodeNode* self, ValaCCodeWriter* writer);
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 static void vala_ccode_type_definition_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_type_definition_parent_class = NULL;
 static void vala_ccode_type_definition_finalize (ValaCCodeNode* obj);
 
 
@@ -155,7 +151,7 @@ ValaCCodeTypeDefinition* vala_ccode_type_definition_construct (GType object_type
 	ValaCCodeTypeDefinition* self;
 	g_return_val_if_fail (type != NULL, NULL);
 	g_return_val_if_fail (decl != NULL, NULL);
-	self = (ValaCCodeTypeDefinition*) g_type_create_instance (object_type);
+	self = (ValaCCodeTypeDefinition*) vala_ccode_node_construct (object_type);
 	vala_ccode_type_definition_set_type_name (self, type);
 	vala_ccode_type_definition_set_declarator (self, decl);
 	return self;
@@ -189,34 +185,37 @@ static void vala_ccode_type_definition_real_write_declaration (ValaCCodeNode* ba
 
 
 const char* vala_ccode_type_definition_get_type_name (ValaCCodeTypeDefinition* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_type_name;
+	result = self->priv->_type_name;
+	return result;
 }
 
 
 void vala_ccode_type_definition_set_type_name (ValaCCodeTypeDefinition* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_type_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_type_name = (g_free (self->priv->_type_name), NULL), _tmp2);
+	self->priv->_type_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_type_name), _tmp0_);
 }
 
 
 ValaCCodeDeclarator* vala_ccode_type_definition_get_declarator (ValaCCodeTypeDefinition* self) {
+	ValaCCodeDeclarator* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_declarator;
+	result = self->priv->_declarator;
+	return result;
+}
+
+
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
 }
 
 
 void vala_ccode_type_definition_set_declarator (ValaCCodeTypeDefinition* self, ValaCCodeDeclarator* value) {
-	ValaCCodeDeclarator* _tmp2;
-	ValaCCodeDeclarator* _tmp1;
+	ValaCCodeDeclarator* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_declarator == NULL) ? NULL : (self->priv->_declarator = (vala_ccode_node_unref (self->priv->_declarator), NULL)), _tmp2);
+	self->priv->_declarator = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_declarator), _tmp0_);
 }
 
 
@@ -237,8 +236,8 @@ static void vala_ccode_type_definition_instance_init (ValaCCodeTypeDefinition *
 static void vala_ccode_type_definition_finalize (ValaCCodeNode* obj) {
 	ValaCCodeTypeDefinition * self;
 	self = VALA_CCODE_TYPE_DEFINITION (obj);
-	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
-	(self->priv->_declarator == NULL) ? NULL : (self->priv->_declarator = (vala_ccode_node_unref (self->priv->_declarator), NULL));
+	_g_free0 (self->priv->_type_name);
+	_vala_ccode_node_unref0 (self->priv->_declarator);
 	VALA_CCODE_NODE_CLASS (vala_ccode_type_definition_parent_class)->finalize (obj);
 }
 
