@@ -39,6 +39,10 @@
 typedef struct _ValaCCodeWriter ValaCCodeWriter;
 typedef struct _ValaCCodeWriterClass ValaCCodeWriterClass;
 typedef struct _ValaCCodeWriterPrivate ValaCCodeWriterPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _fclose0(var) ((var == NULL) ? NULL : (var = (fclose (var), NULL)))
+#define _g_mapped_file_free0(var) ((var == NULL) ? NULL : (var = (g_mapped_file_free (var), NULL)))
+#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
 
 #define VALA_TYPE_CCODE_NODE (vala_ccode_node_get_type ())
 #define VALA_CCODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_NODE, ValaCCodeNode))
@@ -61,9 +65,6 @@ typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
 typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
 typedef struct _ValaParamSpecCCodeWriter ValaParamSpecCCodeWriter;
 
-/**
- * Represents a writer to write C source files.
- */
 struct _ValaCCodeWriter {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -107,7 +108,6 @@ enum  {
 void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value);
 ValaCCodeWriter* vala_ccode_writer_new (const char* filename);
 ValaCCodeWriter* vala_ccode_writer_construct (GType object_type, const char* filename);
-ValaCCodeWriter* vala_ccode_writer_new (const char* filename);
 const char* vala_ccode_writer_get_filename (ValaCCodeWriter* self);
 gboolean vala_ccode_writer_open (ValaCCodeWriter* self);
 void vala_ccode_writer_close (ValaCCodeWriter* self);
@@ -149,12 +149,6 @@ ValaCCodeWriter* vala_ccode_writer_new (const char* filename) {
 }
 
 
-/**
- * Opens the file.
- *
- * @return true if the file has been opened successfully,
- *         false otherwise
- */
 gboolean vala_ccode_writer_open (ValaCCodeWriter* self) {
 	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
@@ -162,30 +156,23 @@ gboolean vala_ccode_writer_open (ValaCCodeWriter* self) {
 	if (self->priv->file_exists) {
 		char* _tmp0_;
 		FILE* _tmp1_;
-		_tmp0_ = NULL;
-		self->priv->temp_filename = (_tmp0_ = g_strdup_printf ("%s.valatmp", self->priv->_filename), self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL), _tmp0_);
-		_tmp1_ = NULL;
-		self->priv->stream = (_tmp1_ = fopen (self->priv->temp_filename, "w"), (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp1_);
+		self->priv->temp_filename = (_tmp0_ = g_strdup_printf ("%s.valatmp", self->priv->_filename), _g_free0 (self->priv->temp_filename), _tmp0_);
+		self->priv->stream = (_tmp1_ = fopen (self->priv->temp_filename, "w"), _fclose0 (self->priv->stream), _tmp1_);
 	} else {
 		FILE* _tmp2_;
-		_tmp2_ = NULL;
-		self->priv->stream = (_tmp2_ = fopen (self->priv->_filename, "w"), (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp2_);
+		self->priv->stream = (_tmp2_ = fopen (self->priv->_filename, "w"), _fclose0 (self->priv->stream), _tmp2_);
 	}
 	result = self->priv->stream != NULL;
 	return result;
 }
 
 
-/**
- * Closes the file.
- */
 void vala_ccode_writer_close (ValaCCodeWriter* self) {
 	GError * _inner_error_;
 	FILE* _tmp0_;
 	g_return_if_fail (self != NULL);
 	_inner_error_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->stream = (_tmp0_ = NULL, (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp0_);
+	self->priv->stream = (_tmp0_ = NULL, _fclose0 (self->priv->stream), _tmp0_);
 	if (self->priv->file_exists) {
 		gboolean changed;
 		changed = TRUE;
@@ -204,7 +191,7 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 			}
 			new_file = g_mapped_file_new (self->priv->temp_filename, FALSE, &_inner_error_);
 			if (_inner_error_ != NULL) {
-				(old_file == NULL) ? NULL : (old_file = (g_mapped_file_free (old_file), NULL));
+				_g_mapped_file_free0 (old_file);
 				if (_inner_error_->domain == G_FILE_ERROR) {
 					goto __catch0_g_file_error;
 				}
@@ -216,12 +203,10 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 					changed = FALSE;
 				}
 			}
-			_tmp1_ = NULL;
-			old_file = (_tmp1_ = NULL, (old_file == NULL) ? NULL : (old_file = (g_mapped_file_free (old_file), NULL)), _tmp1_);
-			_tmp2_ = NULL;
-			new_file = (_tmp2_ = NULL, (new_file == NULL) ? NULL : (new_file = (g_mapped_file_free (new_file), NULL)), _tmp2_);
-			(old_file == NULL) ? NULL : (old_file = (g_mapped_file_free (old_file), NULL));
-			(new_file == NULL) ? NULL : (new_file = (g_mapped_file_free (new_file), NULL));
+			old_file = (_tmp1_ = NULL, _g_mapped_file_free0 (old_file), _tmp1_);
+			new_file = (_tmp2_ = NULL, _g_mapped_file_free0 (new_file), _tmp2_);
+			_g_mapped_file_free0 (old_file);
+			_g_mapped_file_free0 (new_file);
 		}
 		goto __finally0;
 		__catch0_g_file_error:
@@ -230,7 +215,7 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 			e = _inner_error_;
 			_inner_error_ = NULL;
 			{
-				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
+				_g_error_free0 (e);
 			}
 		}
 		__finally0:
@@ -239,7 +224,6 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 			g_clear_error (&_inner_error_);
 			return;
 		}
-		/* assume changed if mmap comparison doesn't work*/
 		if (changed) {
 			g_rename (self->priv->temp_filename, self->priv->_filename);
 		} else {
@@ -249,9 +233,6 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 }
 
 
-/**
- * Writes tabs according to the current indent level.
- */
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line) {
 	g_return_if_fail (self != NULL);
 	if (self->priv->_line_directives) {
@@ -262,12 +243,9 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirecti
 			if (self->priv->using_line_directive) {
 				char* _tmp1_;
 				char* _tmp0_;
-				/* no corresponding Vala line, emit line directive for C line*/
-				_tmp1_ = NULL;
-				_tmp0_ = NULL;
 				vala_ccode_writer_write_string (self, _tmp1_ = g_strdup_printf ("#line %d \"%s\"", self->priv->current_line_number + 1, _tmp0_ = g_path_get_basename (self->priv->_filename)));
-				_tmp1_ = (g_free (_tmp1_), NULL);
-				_tmp0_ = (g_free (_tmp0_), NULL);
+				_g_free0 (_tmp1_);
+				_g_free0 (_tmp0_);
 				vala_ccode_writer_write_newline (self);
 				self->priv->using_line_directive = FALSE;
 			}
@@ -298,22 +276,14 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirecti
 }
 
 
-/**
- * Writes the specified string.
- *
- * @param s a string
- */
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (s != NULL);
-	fprintf (self->priv->stream, "%s", s);
+	fputs (s, self->priv->stream);
 	self->priv->_bol = FALSE;
 }
 
 
-/**
- * Writes a newline.
- */
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self) {
 	g_return_if_fail (self != NULL);
 	fputc ('\n', self->priv->stream);
@@ -322,9 +292,6 @@ void vala_ccode_writer_write_newline (ValaCCodeWriter* self) {
 }
 
 
-/**
- * Opens a new block, increasing the indent level.
- */
 void vala_ccode_writer_write_begin_block (ValaCCodeWriter* self) {
 	g_return_if_fail (self != NULL);
 	if (!vala_ccode_writer_get_bol (self)) {
@@ -338,23 +305,15 @@ void vala_ccode_writer_write_begin_block (ValaCCodeWriter* self) {
 }
 
 
-/**
- * Closes the current block, decreasing the indent level.
- */
 void vala_ccode_writer_write_end_block (ValaCCodeWriter* self) {
 	g_return_if_fail (self != NULL);
 	g_assert (self->priv->indent > 0);
 	self->priv->indent--;
 	vala_ccode_writer_write_indent (self, NULL);
-	fprintf (self->priv->stream, "}");
+	fputc ('}', self->priv->stream);
 }
 
 
-/**
- * Writes the specified text as comment.
- *
- * @param text the comment text
- */
 void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 	gboolean first;
 	char** _tmp1_;
@@ -365,11 +324,8 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (text != NULL);
 	vala_ccode_writer_write_indent (self, NULL);
-	fprintf (self->priv->stream, "/*");
+	fputs ("/*", self->priv->stream);
 	first = TRUE;
-	/* separate declaration due to missing memory management in foreach statements */
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
 	lines = (_tmp1_ = _tmp0_ = g_strsplit (text, "\n", 0), lines_length1 = _vala_array_length (_tmp0_), lines_size = lines_length1, _tmp1_);
 	{
 		char** line_collection;
@@ -378,22 +334,47 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 		line_collection = lines;
 		line_collection_length1 = lines_length1;
 		for (line_it = 0; line_it < lines_length1; line_it = line_it + 1) {
-			const char* _tmp2_;
 			char* line;
-			_tmp2_ = NULL;
-			line = (_tmp2_ = line_collection[line_it], (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+			line = g_strdup (line_collection[line_it]);
 			{
+				char** _tmp3_;
+				gint lineparts_size;
+				gint lineparts_length1;
+				char** _tmp2_;
+				char** lineparts;
 				if (!first) {
 					vala_ccode_writer_write_indent (self, NULL);
 				} else {
 					first = FALSE;
 				}
-				fprintf (self->priv->stream, "%s", line);
-				line = (g_free (line), NULL);
+				lineparts = (_tmp3_ = _tmp2_ = g_strsplit (line, "*/", 0), lineparts_length1 = _vala_array_length (_tmp2_), lineparts_size = lineparts_length1, _tmp3_);
+				{
+					gint i;
+					i = 0;
+					{
+						gboolean _tmp4_;
+						_tmp4_ = TRUE;
+						while (TRUE) {
+							if (!_tmp4_) {
+								i++;
+							}
+							_tmp4_ = FALSE;
+							if (!(lineparts[i] != NULL)) {
+								break;
+							}
+							fputs (lineparts[i], self->priv->stream);
+							if (lineparts[i + 1] != NULL) {
+								fputs ("* /", self->priv->stream);
+							}
+						}
+					}
+				}
+				_g_free0 (line);
+				lineparts = (_vala_array_free (lineparts, lineparts_length1, (GDestroyNotify) g_free), NULL);
 			}
 		}
 	}
-	fprintf (self->priv->stream, "*/");
+	fputs ("*/", self->priv->stream);
 	vala_ccode_writer_write_newline (self);
 	lines = (_vala_array_free (lines, lines_length1, (GDestroyNotify) g_free), NULL);
 }
@@ -408,12 +389,9 @@ const char* vala_ccode_writer_get_filename (ValaCCodeWriter* self) {
 
 
 void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_filename = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp1_);
+	self->priv->_filename = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_filename), _tmp0_);
 }
 
 
@@ -550,9 +528,9 @@ static void vala_ccode_writer_instance_init (ValaCCodeWriter * self) {
 static void vala_ccode_writer_finalize (ValaCCodeWriter* obj) {
 	ValaCCodeWriter * self;
 	self = VALA_CCODE_WRITER (obj);
-	self->priv->_filename = (g_free (self->priv->_filename), NULL);
-	self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL);
-	(self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL));
+	_g_free0 (self->priv->_filename);
+	_g_free0 (self->priv->temp_filename);
+	_fclose0 (self->priv->stream);
 }
 
 
