@@ -47,6 +47,7 @@ typedef struct _ValaCCodeGeneratorPrivate ValaCCodeGeneratorPrivate;
 
 typedef struct _ValaCCodeModule ValaCCodeModule;
 typedef struct _ValaCCodeModuleClass ValaCCodeModuleClass;
+#define _vala_ccode_module_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_module_unref (var), NULL)))
 
 #define VALA_TYPE_CCODE_BASE_MODULE (vala_ccode_base_module_get_type ())
 #define VALA_CCODE_BASE_MODULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_BASE_MODULE, ValaCCodeBaseModule))
@@ -218,9 +219,6 @@ typedef struct _ValaDBusClientModuleClass ValaDBusClientModuleClass;
 typedef struct _ValaDBusServerModule ValaDBusServerModule;
 typedef struct _ValaDBusServerModuleClass ValaDBusServerModuleClass;
 
-/**
- * Code visitor generating C Code.
- */
 struct _ValaCCodeGenerator {
 	ValaCodeGenerator parent_instance;
 	ValaCCodeGeneratorPrivate * priv;
@@ -405,7 +403,7 @@ static void vala_ccode_generator_finalize (ValaCodeVisitor* obj);
 
 ValaCCodeGenerator* vala_ccode_generator_construct (GType object_type) {
 	ValaCCodeGenerator* self;
-	self = (ValaCCodeGenerator*) g_type_create_instance (object_type);
+	self = (ValaCCodeGenerator*) vala_code_generator_construct (object_type);
 	return self;
 }
 
@@ -422,43 +420,13 @@ static void vala_ccode_generator_real_emit (ValaCodeGenerator* base, ValaCodeCon
 	g_return_if_fail (context != NULL);
 	if (vala_code_context_get_profile (context) == VALA_PROFILE_GOBJECT) {
 		ValaCCodeModule* _tmp0_;
-		/* included by inheritance
-		head = new CCodeBaseModule (this, head);
-		head = new CCodeStructModule (this, head);
-		head = new CCodeMethodModule (this, head);
-		head = new CCodeControlFlowModule (this, head);
-		head = new CCodeMemberAccessModule (this, head);
-		head = new CCodeAssignmentModule (this, head);
-		head = new CCodeMethodCallModule (this, head);
-		head = new CCodeArrayModule (this, head);
-		head = new CCodeDelegateModule (this, head);
-		head = new GErrorModule (this, head);
-		head = new GTypeModule (this, head);
-		head = new GObjectModule (this, head);
-		head = new GSignalModule (this, head);
-		head = new GAsyncModule (this, head);
-		head = new DBusClientModule (this, head);
-		*/
-		_tmp0_ = NULL;
-		self->head = (_tmp0_ = (ValaCCodeModule*) vala_dbus_server_module_new (self, self->head), (self->head == NULL) ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL)), _tmp0_);
+		self->head = (_tmp0_ = (ValaCCodeModule*) vala_dbus_server_module_new (self, self->head), _vala_ccode_module_unref0 (self->head), _tmp0_);
 	} else {
 		ValaCCodeModule* _tmp1_;
-		/* included by inheritance
-		head = new CCodeBaseModule (this, head);
-		head = new CCodeStructModule (this, head);
-		head = new CCodeMethodModule (this, head);
-		head = new CCodeControlFlowModule (this, head);
-		head = new CCodeMemberAccessModule (this, head);
-		head = new CCodeAssignmentModule (this, head);
-		head = new CCodeMethodCallModule (this, head);
-		head = new CCodeArrayModule (this, head);
-		*/
-		_tmp1_ = NULL;
-		self->head = (_tmp1_ = (ValaCCodeModule*) vala_ccode_delegate_module_new (self, self->head), (self->head == NULL) ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL)), _tmp1_);
+		self->head = (_tmp1_ = (ValaCCodeModule*) vala_ccode_delegate_module_new (self, self->head), _vala_ccode_module_unref0 (self->head), _tmp1_);
 	}
 	vala_ccode_module_emit (self->head, context);
-	_tmp2_ = NULL;
-	self->head = (_tmp2_ = NULL, (self->head == NULL) ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL)), _tmp2_);
+	self->head = (_tmp2_ = NULL, _vala_ccode_module_unref0 (self->head), _tmp2_);
 }
 
 
@@ -1061,7 +1029,7 @@ static void vala_ccode_generator_instance_init (ValaCCodeGenerator * self) {
 static void vala_ccode_generator_finalize (ValaCodeVisitor* obj) {
 	ValaCCodeGenerator * self;
 	self = VALA_CCODE_GENERATOR (obj);
-	(self->head == NULL) ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL));
+	_vala_ccode_module_unref0 (self->head);
 	VALA_CODE_VISITOR_CLASS (vala_ccode_generator_parent_class)->finalize (obj);
 }
 
