@@ -50,10 +50,11 @@ typedef struct _ValaTypeRegisterFunctionPrivate ValaTypeRegisterFunctionPrivate;
 typedef struct _ValaClassRegisterFunction ValaClassRegisterFunction;
 typedef struct _ValaClassRegisterFunctionClass ValaClassRegisterFunctionClass;
 typedef struct _ValaClassRegisterFunctionPrivate ValaClassRegisterFunctionPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
-/**
- * C function to register a type at runtime.
- */
 struct _ValaTypeRegisterFunction {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -84,9 +85,6 @@ struct _ValaTypeRegisterFunctionClass {
 	ValaSymbolAccessibility (*get_accessibility) (ValaTypeRegisterFunction* self);
 };
 
-/**
- * C function to register a class at runtime.
- */
 struct _ValaClassRegisterFunction {
 	ValaTypeRegisterFunction parent_instance;
 	ValaClassRegisterFunctionPrivate * priv;
@@ -114,6 +112,7 @@ GType vala_class_register_function_get_type (void);
 enum  {
 	VALA_CLASS_REGISTER_FUNCTION_DUMMY_PROPERTY
 };
+ValaTypeRegisterFunction* vala_typeregister_function_construct (GType object_type);
 void vala_class_register_function_set_class_reference (ValaClassRegisterFunction* self, ValaClass* value);
 void vala_typeregister_function_set_context (ValaTypeRegisterFunction* self, ValaCodeContext* value);
 ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl, ValaCodeContext* context);
@@ -142,17 +141,11 @@ static void vala_class_register_function_finalize (ValaTypeRegisterFunction* obj
 
 
 
-/**
- * Creates a new C function to register the specified class at runtime.
- *
- * @param cl a class
- * @return   newly created class register function
- */
 ValaClassRegisterFunction* vala_class_register_function_construct (GType object_type, ValaClass* cl, ValaCodeContext* context) {
 	ValaClassRegisterFunction* self;
 	g_return_val_if_fail (cl != NULL, NULL);
 	g_return_val_if_fail (context != NULL, NULL);
-	self = (ValaClassRegisterFunction*) g_type_create_instance (object_type);
+	self = (ValaClassRegisterFunction*) vala_typeregister_function_construct (object_type);
 	vala_class_register_function_set_class_reference (self, cl);
 	vala_typeregister_function_set_context ((ValaTypeRegisterFunction*) self, context);
 	return self;
@@ -164,13 +157,16 @@ ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl, Vala
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static ValaTypeSymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	ValaTypeSymbol* result;
-	ValaTypeSymbol* _tmp0_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0_ = NULL;
-	result = (_tmp0_ = (ValaTypeSymbol*) self->priv->_class_reference, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	result = _vala_code_node_ref0 ((ValaTypeSymbol*) self->priv->_class_reference);
 	return result;
 }
 
@@ -181,9 +177,7 @@ static char* vala_class_register_function_real_get_type_struct_name (ValaTypeReg
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = g_strdup_printf ("%sClass", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_reference, FALSE)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strdup_printf ("%sClass", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_reference, FALSE)), _g_free0 (_tmp0_), _tmp1_);
 	return result;
 }
 
@@ -202,9 +196,7 @@ static char* vala_class_register_function_real_get_base_init_func_name (ValaType
 	if (_tmp0_) {
 		char* _tmp1_;
 		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strdup_printf ("%s_base_init", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp2_ = g_strdup_printf ("%s_base_init", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _g_free0 (_tmp1_), _tmp2_);
 		return result;
 	} else {
 		result = g_strdup ("NULL");
@@ -220,9 +212,7 @@ static char* vala_class_register_function_real_get_class_finalize_func_name (Val
 	if (vala_class_get_static_destructor (self->priv->_class_reference) != NULL) {
 		char* _tmp0_;
 		char* _tmp1_;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		result = (_tmp1_ = g_strdup_printf ("%s_class_finalize", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+		result = (_tmp1_ = g_strdup_printf ("%s_class_finalize", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _g_free0 (_tmp0_), _tmp1_);
 		return result;
 	} else {
 		result = g_strdup ("NULL");
@@ -245,9 +235,7 @@ static char* vala_class_register_function_real_get_base_finalize_func_name (Vala
 	if (_tmp0_) {
 		char* _tmp1_;
 		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strdup_printf ("%s_base_finalize", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp2_ = g_strdup_printf ("%s_base_finalize", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _g_free0 (_tmp1_), _tmp2_);
 		return result;
 	} else {
 		result = g_strdup ("NULL");
@@ -262,9 +250,7 @@ static char* vala_class_register_function_real_get_class_init_func_name (ValaTyp
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = g_strdup_printf ("%s_class_init", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strdup_printf ("%s_class_init", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _g_free0 (_tmp0_), _tmp1_);
 	return result;
 }
 
@@ -275,9 +261,7 @@ static char* vala_class_register_function_real_get_instance_struct_size (ValaTyp
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = g_strdup_printf ("sizeof (%s)", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_reference, FALSE)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strdup_printf ("sizeof (%s)", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_reference, FALSE)), _g_free0 (_tmp0_), _tmp1_);
 	return result;
 }
 
@@ -288,9 +272,7 @@ static char* vala_class_register_function_real_get_instance_init_func_name (Vala
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = g_strdup_printf ("%s_instance_init", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strdup_printf ("%s_instance_init", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _g_free0 (_tmp0_), _tmp1_);
 	return result;
 }
 
@@ -343,9 +325,7 @@ static char* vala_class_register_function_real_get_gtype_value_table_init_functi
 	if (is_fundamental) {
 		char* _tmp1_;
 		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strdup_printf ("%s_init", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp2_ = g_strdup_printf ("%s_init", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _g_free0 (_tmp1_), _tmp2_);
 		return result;
 	}
 	result = NULL;
@@ -369,9 +349,7 @@ static char* vala_class_register_function_real_get_gtype_value_table_free_functi
 	if (is_fundamental) {
 		char* _tmp1_;
 		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strdup_printf ("%s_free_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp2_ = g_strdup_printf ("%s_free_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _g_free0 (_tmp1_), _tmp2_);
 		return result;
 	}
 	result = NULL;
@@ -395,9 +373,7 @@ static char* vala_class_register_function_real_get_gtype_value_table_copy_functi
 	if (is_fundamental) {
 		char* _tmp1_;
 		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strdup_printf ("%s_copy_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp2_ = g_strdup_printf ("%s_copy_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _g_free0 (_tmp1_), _tmp2_);
 		return result;
 	}
 	result = NULL;
@@ -421,9 +397,7 @@ static char* vala_class_register_function_real_get_gtype_value_table_peek_pointe
 	if (is_fundamental) {
 		char* _tmp1_;
 		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strdup_printf ("%s_peek_pointer", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp2_ = g_strdup_printf ("%s_peek_pointer", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _g_free0 (_tmp1_), _tmp2_);
 		return result;
 	}
 	result = NULL;
@@ -447,9 +421,7 @@ static char* vala_class_register_function_real_get_gtype_value_table_collect_val
 	if (is_fundamental) {
 		char* _tmp1_;
 		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strdup_printf ("%s_collect_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp2_ = g_strdup_printf ("%s_collect_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _g_free0 (_tmp1_), _tmp2_);
 		return result;
 	}
 	result = NULL;
@@ -473,9 +445,7 @@ static char* vala_class_register_function_real_get_gtype_value_table_lcopy_value
 	if (is_fundamental) {
 		char* _tmp1_;
 		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strdup_printf ("%s_lcopy_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp2_ = g_strdup_printf ("%s_lcopy_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _g_free0 (_tmp1_), _tmp2_);
 		return result;
 	}
 	result = NULL;
@@ -493,55 +463,44 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 		GeeList* _tmp0_;
 		GeeIterator* _tmp1_;
 		GeeIterator* _base_type_it;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		_base_type_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_class_get_base_types (self->priv->_class_reference))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
+		_base_type_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_class_get_base_types (self->priv->_class_reference))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
 		while (TRUE) {
 			ValaDataType* base_type;
-			ValaInterface* _tmp2_;
 			ValaInterface* iface;
+			char* _tmp2_;
 			char* _tmp3_;
-			char* _tmp4_;
 			char* iface_info_name;
 			ValaCCodeDeclaration* ctypedecl;
-			ValaCCodeVariableDeclarator* _tmp9_;
-			ValaCCodeConstant* _tmp8_;
-			char* _tmp7_;
+			ValaCCodeVariableDeclarator* _tmp8_;
+			ValaCCodeConstant* _tmp7_;
 			char* _tmp6_;
 			char* _tmp5_;
+			char* _tmp4_;
 			if (!gee_iterator_next (_base_type_it)) {
 				break;
 			}
 			base_type = (ValaDataType*) gee_iterator_get (_base_type_it);
 			if (!VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type))) {
-				(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
+				_vala_code_node_unref0 (base_type);
 				continue;
 			}
-			_tmp2_ = NULL;
-			iface = (_tmp2_ = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
-			_tmp3_ = NULL;
-			_tmp4_ = NULL;
-			iface_info_name = (_tmp4_ = g_strdup_printf ("%s_info", _tmp3_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _tmp3_ = (g_free (_tmp3_), NULL), _tmp4_);
+			iface = _vala_code_node_ref0 (VALA_INTERFACE (vala_data_type_get_data_type (base_type)));
+			iface_info_name = (_tmp3_ = g_strdup_printf ("%s_info", _tmp2_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _g_free0 (_tmp2_), _tmp3_);
 			ctypedecl = vala_ccode_declaration_new ("const GInterfaceInfo");
 			vala_ccode_declaration_set_modifiers (ctypedecl, VALA_CCODE_MODIFIERS_STATIC);
-			_tmp9_ = NULL;
-			_tmp8_ = NULL;
-			_tmp7_ = NULL;
-			_tmp6_ = NULL;
-			_tmp5_ = NULL;
-			vala_ccode_declaration_add_declarator (ctypedecl, (ValaCCodeDeclarator*) (_tmp9_ = vala_ccode_variable_declarator_new (iface_info_name, (ValaCCodeExpression*) (_tmp8_ = vala_ccode_constant_new (_tmp7_ = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", _tmp5_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL), _tmp6_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)))), NULL)));
-			(_tmp9_ == NULL) ? NULL : (_tmp9_ = (vala_ccode_node_unref (_tmp9_), NULL));
-			(_tmp8_ == NULL) ? NULL : (_tmp8_ = (vala_ccode_node_unref (_tmp8_), NULL));
-			_tmp7_ = (g_free (_tmp7_), NULL);
-			_tmp6_ = (g_free (_tmp6_), NULL);
-			_tmp5_ = (g_free (_tmp5_), NULL);
+			vala_ccode_declaration_add_declarator (ctypedecl, (ValaCCodeDeclarator*) (_tmp8_ = vala_ccode_variable_declarator_new (iface_info_name, (ValaCCodeExpression*) (_tmp7_ = vala_ccode_constant_new (_tmp6_ = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", _tmp4_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL), _tmp5_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)))), NULL)));
+			_vala_ccode_node_unref0 (_tmp8_);
+			_vala_ccode_node_unref0 (_tmp7_);
+			_g_free0 (_tmp6_);
+			_g_free0 (_tmp5_);
+			_g_free0 (_tmp4_);
 			vala_ccode_fragment_append (frag, (ValaCCodeNode*) ctypedecl);
-			(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
-			(iface == NULL) ? NULL : (iface = (vala_code_node_unref (iface), NULL));
-			iface_info_name = (g_free (iface_info_name), NULL);
-			(ctypedecl == NULL) ? NULL : (ctypedecl = (vala_ccode_node_unref (ctypedecl), NULL));
+			_vala_code_node_unref0 (base_type);
+			_vala_code_node_unref0 (iface);
+			_g_free0 (iface_info_name);
+			_vala_ccode_node_unref0 (ctypedecl);
 		}
-		(_base_type_it == NULL) ? NULL : (_base_type_it = (gee_collection_object_unref (_base_type_it), NULL));
+		_gee_collection_object_unref0 (_base_type_it);
 	}
 	result = frag;
 	return result;
@@ -558,69 +517,53 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 		GeeList* _tmp0_;
 		GeeIterator* _tmp1_;
 		GeeIterator* _base_type_it;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		_base_type_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_class_get_base_types (self->priv->_class_reference))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
+		_base_type_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_class_get_base_types (self->priv->_class_reference))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
 		while (TRUE) {
 			ValaDataType* base_type;
-			ValaInterface* _tmp2_;
 			ValaInterface* iface;
+			char* _tmp2_;
 			char* _tmp3_;
-			char* _tmp4_;
 			char* iface_info_name;
-			ValaCCodeIdentifier* _tmp5_;
-			ValaCCodeFunctionCall* _tmp6_;
+			ValaCCodeIdentifier* _tmp4_;
+			ValaCCodeFunctionCall* _tmp5_;
 			ValaCCodeFunctionCall* reg_call;
-			ValaCCodeIdentifier* _tmp9_;
-			char* _tmp8_;
+			ValaCCodeIdentifier* _tmp8_;
 			char* _tmp7_;
-			ValaCCodeIdentifier* _tmp11_;
-			char* _tmp10_;
-			ValaCCodeIdentifier* _tmp13_;
-			char* _tmp12_;
-			ValaCCodeExpressionStatement* _tmp14_;
+			char* _tmp6_;
+			ValaCCodeIdentifier* _tmp10_;
+			char* _tmp9_;
+			ValaCCodeIdentifier* _tmp12_;
+			char* _tmp11_;
+			ValaCCodeExpressionStatement* _tmp13_;
 			if (!gee_iterator_next (_base_type_it)) {
 				break;
 			}
 			base_type = (ValaDataType*) gee_iterator_get (_base_type_it);
 			if (!VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type))) {
-				(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
+				_vala_code_node_unref0 (base_type);
 				continue;
 			}
-			_tmp2_ = NULL;
-			iface = (_tmp2_ = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
-			_tmp3_ = NULL;
-			_tmp4_ = NULL;
-			iface_info_name = (_tmp4_ = g_strdup_printf ("%s_info", _tmp3_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _tmp3_ = (g_free (_tmp3_), NULL), _tmp4_);
-			_tmp5_ = NULL;
-			_tmp6_ = NULL;
-			reg_call = (_tmp6_ = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp5_ = vala_ccode_identifier_new ("g_type_add_interface_static"))), (_tmp5_ == NULL) ? NULL : (_tmp5_ = (vala_ccode_node_unref (_tmp5_), NULL)), _tmp6_);
-			_tmp9_ = NULL;
-			_tmp8_ = NULL;
-			_tmp7_ = NULL;
-			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp9_ = vala_ccode_identifier_new (_tmp8_ = g_strdup_printf ("%s_type_id", _tmp7_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)))));
-			(_tmp9_ == NULL) ? NULL : (_tmp9_ = (vala_ccode_node_unref (_tmp9_), NULL));
-			_tmp8_ = (g_free (_tmp8_), NULL);
-			_tmp7_ = (g_free (_tmp7_), NULL);
-			_tmp11_ = NULL;
-			_tmp10_ = NULL;
-			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp11_ = vala_ccode_identifier_new (_tmp10_ = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface))));
-			(_tmp11_ == NULL) ? NULL : (_tmp11_ = (vala_ccode_node_unref (_tmp11_), NULL));
-			_tmp10_ = (g_free (_tmp10_), NULL);
-			_tmp13_ = NULL;
-			_tmp12_ = NULL;
-			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp13_ = vala_ccode_identifier_new (_tmp12_ = g_strdup_printf ("&%s", iface_info_name))));
-			(_tmp13_ == NULL) ? NULL : (_tmp13_ = (vala_ccode_node_unref (_tmp13_), NULL));
-			_tmp12_ = (g_free (_tmp12_), NULL);
-			_tmp14_ = NULL;
-			vala_ccode_fragment_append (frag, (ValaCCodeNode*) (_tmp14_ = vala_ccode_expression_statement_new ((ValaCCodeExpression*) reg_call)));
-			(_tmp14_ == NULL) ? NULL : (_tmp14_ = (vala_ccode_node_unref (_tmp14_), NULL));
-			(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
-			(iface == NULL) ? NULL : (iface = (vala_code_node_unref (iface), NULL));
-			iface_info_name = (g_free (iface_info_name), NULL);
-			(reg_call == NULL) ? NULL : (reg_call = (vala_ccode_node_unref (reg_call), NULL));
+			iface = _vala_code_node_ref0 (VALA_INTERFACE (vala_data_type_get_data_type (base_type)));
+			iface_info_name = (_tmp3_ = g_strdup_printf ("%s_info", _tmp2_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _g_free0 (_tmp2_), _tmp3_);
+			reg_call = (_tmp5_ = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp4_ = vala_ccode_identifier_new ("g_type_add_interface_static"))), _vala_ccode_node_unref0 (_tmp4_), _tmp5_);
+			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp8_ = vala_ccode_identifier_new (_tmp7_ = g_strdup_printf ("%s_type_id", _tmp6_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)))));
+			_vala_ccode_node_unref0 (_tmp8_);
+			_g_free0 (_tmp7_);
+			_g_free0 (_tmp6_);
+			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp10_ = vala_ccode_identifier_new (_tmp9_ = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface))));
+			_vala_ccode_node_unref0 (_tmp10_);
+			_g_free0 (_tmp9_);
+			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp12_ = vala_ccode_identifier_new (_tmp11_ = g_strdup_printf ("&%s", iface_info_name))));
+			_vala_ccode_node_unref0 (_tmp12_);
+			_g_free0 (_tmp11_);
+			vala_ccode_fragment_append (frag, (ValaCCodeNode*) (_tmp13_ = vala_ccode_expression_statement_new ((ValaCCodeExpression*) reg_call)));
+			_vala_ccode_node_unref0 (_tmp13_);
+			_vala_code_node_unref0 (base_type);
+			_vala_code_node_unref0 (iface);
+			_g_free0 (iface_info_name);
+			_vala_ccode_node_unref0 (reg_call);
 		}
-		(_base_type_it == NULL) ? NULL : (_base_type_it = (gee_collection_object_unref (_base_type_it), NULL));
+		_gee_collection_object_unref0 (_base_type_it);
 	}
 	result = frag;
 	return result;
