@@ -50,9 +50,6 @@ typedef struct _ValaStructRegisterFunction ValaStructRegisterFunction;
 typedef struct _ValaStructRegisterFunctionClass ValaStructRegisterFunctionClass;
 typedef struct _ValaStructRegisterFunctionPrivate ValaStructRegisterFunctionPrivate;
 
-/**
- * C function to register a type at runtime.
- */
 struct _ValaTypeRegisterFunction {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -83,9 +80,6 @@ struct _ValaTypeRegisterFunctionClass {
 	ValaSymbolAccessibility (*get_accessibility) (ValaTypeRegisterFunction* self);
 };
 
-/**
- * C function to register a class at runtime.
- */
 struct _ValaStructRegisterFunction {
 	ValaTypeRegisterFunction parent_instance;
 	ValaStructRegisterFunctionPrivate * priv;
@@ -113,6 +107,7 @@ GType vala_struct_register_function_get_type (void);
 enum  {
 	VALA_STRUCT_REGISTER_FUNCTION_DUMMY_PROPERTY
 };
+ValaTypeRegisterFunction* vala_typeregister_function_construct (GType object_type);
 void vala_struct_register_function_set_struct_reference (ValaStructRegisterFunction* self, ValaStruct* value);
 void vala_typeregister_function_set_context (ValaTypeRegisterFunction* self, ValaCodeContext* value);
 ValaStructRegisterFunction* vala_struct_register_function_new (ValaStruct* st, ValaCodeContext* context);
@@ -125,17 +120,11 @@ static void vala_struct_register_function_finalize (ValaTypeRegisterFunction* ob
 
 
 
-/**
- * Creates a new C function to register the specified class at runtime.
- *
- * @param cl a class
- * @return   newly created class register function
- */
 ValaStructRegisterFunction* vala_struct_register_function_construct (GType object_type, ValaStruct* st, ValaCodeContext* context) {
 	ValaStructRegisterFunction* self;
 	g_return_val_if_fail (st != NULL, NULL);
 	g_return_val_if_fail (context != NULL, NULL);
-	self = (ValaStructRegisterFunction*) g_type_create_instance (object_type);
+	self = (ValaStructRegisterFunction*) vala_typeregister_function_construct (object_type);
 	vala_struct_register_function_set_struct_reference (self, st);
 	vala_typeregister_function_set_context ((ValaTypeRegisterFunction*) self, context);
 	return self;
@@ -147,13 +136,16 @@ ValaStructRegisterFunction* vala_struct_register_function_new (ValaStruct* st, V
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static ValaTypeSymbol* vala_struct_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaStructRegisterFunction * self;
 	ValaTypeSymbol* result;
-	ValaTypeSymbol* _tmp0_;
 	self = (ValaStructRegisterFunction*) base;
-	_tmp0_ = NULL;
-	result = (_tmp0_ = (ValaTypeSymbol*) self->priv->_struct_reference, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	result = _vala_code_node_ref0 ((ValaTypeSymbol*) self->priv->_struct_reference);
 	return result;
 }
 
