@@ -91,10 +91,8 @@ typedef struct _GeeArrayListPrivate GeeArrayListPrivate;
 typedef struct _GeeArrayListIterator GeeArrayListIterator;
 typedef struct _GeeArrayListIteratorClass GeeArrayListIteratorClass;
 typedef struct _GeeArrayListIteratorPrivate GeeArrayListIteratorPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
-/**
- * Base class for all collections.
- */
 struct _GeeCollectionObject {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -106,30 +104,18 @@ struct _GeeCollectionObjectClass {
 	void (*finalize) (GeeCollectionObject *self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIteratorIface {
 	GTypeInterface parent_iface;
 	gboolean (*next) (GeeIterator* self);
 	gpointer (*get) (GeeIterator* self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIterableIface {
 	GTypeInterface parent_iface;
 	GType (*get_element_type) (GeeIterable* self);
 	GeeIterator* (*iterator) (GeeIterable* self);
 };
 
-/**
- * Serves as the base interface for implementing collection classes. Defines
- * size, iteration, and modification methods.
- */
 struct _GeeCollectionIface {
 	GTypeInterface parent_iface;
 	gboolean (*contains) (GeeCollection* self, gconstpointer item);
@@ -139,9 +125,6 @@ struct _GeeCollectionIface {
 	gint (*get_size) (GeeCollection* self);
 };
 
-/**
- * Represents a collection of items in a well-defined order.
- */
 struct _GeeListIface {
 	GTypeInterface parent_iface;
 	gpointer (*get) (GeeList* self, gint index);
@@ -151,9 +134,6 @@ struct _GeeListIface {
 	void (*remove_at) (GeeList* self, gint index);
 };
 
-/**
- * Arrays of arbitrary elements which grow automatically as elements are added.
- */
 struct _GeeArrayList {
 	GeeCollectionObject parent_instance;
 	GeeArrayListPrivate * priv;
@@ -216,6 +196,8 @@ GType gee_array_list_get_type (void);
 enum  {
 	GEE_ARRAY_LIST_DUMMY_PROPERTY
 };
+GeeCollectionObject* gee_collection_object_new (void);
+GeeCollectionObject* gee_collection_object_construct (GType object_type);
 void gee_array_list_set_equal_func (GeeArrayList* self, GEqualFunc value);
 GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func);
 GeeArrayList* gee_array_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func);
@@ -256,7 +238,7 @@ static void _vala_array_move (gpointer array, gsize element_size, gint src, gint
 
 GeeArrayList* gee_array_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func) {
 	GeeArrayList* self;
-	self = (GeeArrayList*) g_type_create_instance (object_type);
+	self = (GeeArrayList*) gee_collection_object_construct (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -340,7 +322,6 @@ static gpointer gee_array_list_real_get (GeeList* base, gint index) {
 		_tmp0_ = FALSE;
 	}
 	g_assert (_tmp0_);
-	_tmp1_ = NULL;
 	result = (_tmp1_ = self->priv->_items[index], ((_tmp1_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1_) : self->priv->g_dup_func ((gpointer) _tmp1_));
 	return result;
 }
@@ -359,8 +340,6 @@ static void gee_array_list_real_set (GeeList* base, gint index, gconstpointer it
 		_tmp0_ = FALSE;
 	}
 	g_assert (_tmp0_);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
 	self->priv->_items[index] = (_tmp2_ = (_tmp1_ = item, ((_tmp1_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1_) : self->priv->g_dup_func ((gpointer) _tmp1_)), ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp2_);
 }
 
@@ -375,8 +354,6 @@ static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
-	_tmp2_ = NULL;
-	_tmp0_ = NULL;
 	_tmp1_ = &self->priv->_items[self->priv->_size++];
 	(*_tmp1_) = (_tmp2_ = (_tmp0_ = item, ((_tmp0_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->g_dup_func ((gpointer) _tmp0_)), (((*_tmp1_) == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : ((*_tmp1_) = (self->priv->g_destroy_func ((*_tmp1_)), NULL)), _tmp2_);
 	self->priv->_stamp++;
@@ -402,8 +379,6 @@ static void gee_array_list_real_insert (GeeList* base, gint index, gconstpointer
 		gee_array_list_grow_if_needed (self, 1);
 	}
 	gee_array_list_shift (self, index, 1);
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
 	self->priv->_items[index] = (_tmp2_ = (_tmp1_ = item, ((_tmp1_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1_) : self->priv->g_dup_func ((gpointer) _tmp1_)), ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp2_);
 	self->priv->_stamp++;
 }
@@ -452,7 +427,6 @@ static void gee_array_list_real_remove_at (GeeList* base, gint index) {
 		_tmp0_ = FALSE;
 	}
 	g_assert (_tmp0_);
-	_tmp1_ = NULL;
 	self->priv->_items[index] = (_tmp1_ = NULL, ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp1_);
 	gee_array_list_shift (self, index + 1, -1);
 	self->priv->_stamp++;
@@ -477,7 +451,6 @@ static void gee_array_list_real_clear (GeeCollection* base) {
 				if (!(index < self->priv->_size)) {
 					break;
 				}
-				_tmp1_ = NULL;
 				self->priv->_items[index] = (_tmp1_ = NULL, ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp1_);
 			}
 		}
@@ -522,7 +495,6 @@ static void gee_array_list_grow_if_needed (GeeArrayList* self, gint new_count) {
 		} else {
 			_tmp0_ = 2 * self->priv->_items_length1;
 		}
-		/* double the capacity unless we add even more items at this time*/
 		gee_array_list_set_capacity (self, _tmp0_);
 	}
 }
@@ -557,7 +529,7 @@ void gee_array_list_set_equal_func (GeeArrayList* self, GEqualFunc value) {
 static GeeArrayListIterator* gee_array_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list) {
 	GeeArrayListIterator* self;
 	g_return_val_if_fail (list != NULL, NULL);
-	self = (GeeArrayListIterator*) g_type_create_instance (object_type);
+	self = (GeeArrayListIterator*) gee_collection_object_construct (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -605,13 +577,15 @@ static gpointer gee_array_list_iterator_real_get (GeeIterator* base) {
 }
 
 
+static gpointer _gee_collection_object_ref0 (gpointer self) {
+	return self ? gee_collection_object_ref (self) : NULL;
+}
+
+
 static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArrayList* value) {
-	GeeArrayList* _tmp1_;
 	GeeArrayList* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_list = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL)), _tmp1_);
+	self->priv->_list = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_list), _tmp0_);
 	self->_stamp = self->priv->_list->priv->_stamp;
 }
 
@@ -640,7 +614,7 @@ static void gee_array_list_iterator_instance_init (GeeArrayListIterator * self)
 static void gee_array_list_iterator_finalize (GeeCollectionObject* obj) {
 	GeeArrayListIterator * self;
 	self = GEE_ARRAY_LIST_ITERATOR (obj);
-	(self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL));
+	_gee_collection_object_unref0 (self->priv->_list);
 	GEE_COLLECTION_OBJECT_CLASS (gee_array_list_iterator_parent_class)->finalize (obj);
 }
 
