@@ -108,7 +108,9 @@ typedef struct _GeeHashMapKeySetClass GeeHashMapKeySetClass;
 
 typedef struct _GeeHashMapValueCollection GeeHashMapValueCollection;
 typedef struct _GeeHashMapValueCollectionClass GeeHashMapValueCollectionClass;
+#define _gee_hash_map_node_free0(var) ((var == NULL) ? NULL : (var = (gee_hash_map_node_free (var), NULL)))
 typedef struct _GeeHashMapKeySetPrivate GeeHashMapKeySetPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define GEE_HASH_MAP_TYPE_KEY_ITERATOR (gee_hash_map_key_iterator_get_type ())
 #define GEE_HASH_MAP_KEY_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_HASH_MAP_TYPE_KEY_ITERATOR, GeeHashMapKeyIterator))
@@ -133,9 +135,6 @@ typedef struct _GeeHashMapValueIterator GeeHashMapValueIterator;
 typedef struct _GeeHashMapValueIteratorClass GeeHashMapValueIteratorClass;
 typedef struct _GeeHashMapValueIteratorPrivate GeeHashMapValueIteratorPrivate;
 
-/**
- * Base class for all collections.
- */
 struct _GeeCollectionObject {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -147,30 +146,18 @@ struct _GeeCollectionObjectClass {
 	void (*finalize) (GeeCollectionObject *self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIteratorIface {
 	GTypeInterface parent_iface;
 	gboolean (*next) (GeeIterator* self);
 	gpointer (*get) (GeeIterator* self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIterableIface {
 	GTypeInterface parent_iface;
 	GType (*get_element_type) (GeeIterable* self);
 	GeeIterator* (*iterator) (GeeIterable* self);
 };
 
-/**
- * Serves as the base interface for implementing collection classes. Defines
- * size, iteration, and modification methods.
- */
 struct _GeeCollectionIface {
 	GTypeInterface parent_iface;
 	gboolean (*contains) (GeeCollection* self, gconstpointer item);
@@ -180,16 +167,10 @@ struct _GeeCollectionIface {
 	gint (*get_size) (GeeCollection* self);
 };
 
-/**
- * A set is a collection without duplicates.
- */
 struct _GeeSetIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * A map is a generic collection of key/value pairs.
- */
 struct _GeeMapIface {
 	GTypeInterface parent_iface;
 	GeeSet* (*get_keys) (GeeMap* self);
@@ -202,9 +183,6 @@ struct _GeeMapIface {
 	gint (*get_size) (GeeMap* self);
 };
 
-/**
- * Hashtable implementation of the Map interface.
- */
 struct _GeeHashMap {
 	GeeCollectionObject parent_instance;
 	GeeHashMapPrivate * priv;
@@ -354,12 +332,13 @@ enum  {
 };
 #define GEE_HASH_MAP_MIN_SIZE 11
 #define GEE_HASH_MAP_MAX_SIZE 13845163
+GeeCollectionObject* gee_collection_object_new (void);
+GeeCollectionObject* gee_collection_object_construct (GType object_type);
 void gee_hash_map_set_key_hash_func (GeeHashMap* self, GHashFunc value);
 void gee_hash_map_set_key_equal_func (GeeHashMap* self, GEqualFunc value);
 void gee_hash_map_set_value_equal_func (GeeHashMap* self, GEqualFunc value);
 GeeHashMap* gee_hash_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GHashFunc key_hash_func, GEqualFunc key_equal_func, GEqualFunc value_equal_func);
 GeeHashMap* gee_hash_map_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GHashFunc key_hash_func, GEqualFunc key_equal_func, GEqualFunc value_equal_func);
-GeeHashMap* gee_hash_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GHashFunc key_hash_func, GEqualFunc key_equal_func, GEqualFunc value_equal_func);
 static GeeHashMapKeySet* gee_hash_map_key_set_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GeeHashMapKeySet* gee_hash_map_key_set_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GType gee_hash_map_key_set_get_type (void);
@@ -385,7 +364,6 @@ enum  {
 	GEE_HASH_MAP_KEY_SET_DUMMY_PROPERTY
 };
 static void gee_hash_map_key_set_set_map (GeeHashMapKeySet* self, GeeHashMap* value);
-static GeeHashMapKeySet* gee_hash_map_key_set_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GType gee_hash_map_key_set_real_get_element_type (GeeIterable* base);
 static GeeHashMapKeyIterator* gee_hash_map_key_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GeeHashMapKeyIterator* gee_hash_map_key_iterator_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
@@ -403,7 +381,6 @@ enum  {
 	GEE_HASH_MAP_KEY_ITERATOR_DUMMY_PROPERTY
 };
 static void gee_hash_map_key_iterator_set_map (GeeHashMapKeyIterator* self, GeeHashMap* value);
-static GeeHashMapKeyIterator* gee_hash_map_key_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static gboolean gee_hash_map_key_iterator_real_next (GeeIterator* base);
 static gpointer gee_hash_map_key_iterator_real_get (GeeIterator* base);
 static void gee_hash_map_key_iterator_finalize (GeeCollectionObject* obj);
@@ -412,7 +389,6 @@ enum  {
 	GEE_HASH_MAP_VALUE_COLLECTION_DUMMY_PROPERTY
 };
 static void gee_hash_map_value_collection_set_map (GeeHashMapValueCollection* self, GeeHashMap* value);
-static GeeHashMapValueCollection* gee_hash_map_value_collection_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GType gee_hash_map_value_collection_real_get_element_type (GeeIterable* base);
 static GeeHashMapValueIterator* gee_hash_map_value_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static GeeHashMapValueIterator* gee_hash_map_value_iterator_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
@@ -431,7 +407,6 @@ enum  {
 	GEE_HASH_MAP_VALUE_ITERATOR_DUMMY_PROPERTY
 };
 static void gee_hash_map_value_iterator_set_map (GeeHashMapValueIterator* self, GeeHashMap* value);
-static GeeHashMapValueIterator* gee_hash_map_value_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map);
 static gboolean gee_hash_map_value_iterator_real_next (GeeIterator* base);
 static gpointer gee_hash_map_value_iterator_real_get (GeeIterator* base);
 static void gee_hash_map_value_iterator_finalize (GeeCollectionObject* obj);
@@ -444,7 +419,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 GeeHashMap* gee_hash_map_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GHashFunc key_hash_func, GEqualFunc key_equal_func, GEqualFunc value_equal_func) {
 	GeeHashMap* self;
 	GeeHashMapNode** _tmp0_;
-	self = (GeeHashMap*) g_type_create_instance (object_type);
+	self = (GeeHashMap*) gee_collection_object_construct (object_type);
 	self->priv->k_type = k_type;
 	self->priv->k_dup_func = k_dup_func;
 	self->priv->k_destroy_func = k_destroy_func;
@@ -455,7 +430,6 @@ GeeHashMap* gee_hash_map_construct (GType object_type, GType k_type, GBoxedCopyF
 	gee_hash_map_set_key_equal_func (self, key_equal_func);
 	gee_hash_map_set_value_equal_func (self, value_equal_func);
 	self->priv->_array_size = GEE_HASH_MAP_MIN_SIZE;
-	_tmp0_ = NULL;
 	self->priv->_nodes = (_tmp0_ = g_new0 (GeeHashMapNode*, self->priv->_array_size + 1), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL), self->priv->_nodes_length1 = self->priv->_array_size, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp0_);
 	return self;
 }
@@ -535,7 +509,6 @@ static gpointer gee_hash_map_real_get (GeeMap* base, gconstpointer key) {
 	node = *gee_hash_map_lookup_node (self, key);
 	if (node != NULL) {
 		gconstpointer _tmp0_;
-		_tmp0_ = NULL;
 		result = (_tmp0_ = node->value, ((_tmp0_ == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->v_dup_func ((gpointer) _tmp0_));
 		return result;
 	} else {
@@ -553,16 +526,12 @@ static void gee_hash_map_real_set (GeeMap* base, gconstpointer key, gconstpointe
 	if ((*node) != NULL) {
 		gpointer _tmp1_;
 		gconstpointer _tmp0_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
 		(*node)->value = (_tmp1_ = (_tmp0_ = value, ((_tmp0_ == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->v_dup_func ((gpointer) _tmp0_)), (((*node)->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL)), _tmp1_);
 	} else {
 		guint hash_value;
 		gconstpointer _tmp3_;
 		gconstpointer _tmp2_;
 		hash_value = self->priv->_key_hash_func (key);
-		_tmp3_ = NULL;
-		_tmp2_ = NULL;
 		*node = gee_hash_map_node_new ((_tmp2_ = key, ((_tmp2_ == NULL) || (self->priv->k_dup_func == NULL)) ? ((gpointer) _tmp2_) : self->priv->k_dup_func ((gpointer) _tmp2_)), (_tmp3_ = value, ((_tmp3_ == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp3_) : self->priv->v_dup_func ((gpointer) _tmp3_)), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_map_resize (self);
@@ -583,20 +552,16 @@ static gboolean gee_hash_map_real_remove (GeeMap* base, gconstpointer key) {
 		gpointer _tmp1_;
 		gpointer _tmp2_;
 		GeeHashMapNode* _tmp3_;
-		_tmp0_ = NULL;
 		next = (_tmp0_ = (*node)->next, (*node)->next = NULL, _tmp0_);
-		_tmp1_ = NULL;
 		(*node)->key = (_tmp1_ = NULL, (((*node)->key == NULL) || (self->priv->k_destroy_func == NULL)) ? NULL : ((*node)->key = (self->priv->k_destroy_func ((*node)->key), NULL)), _tmp1_);
-		_tmp2_ = NULL;
 		(*node)->value = (_tmp2_ = NULL, (((*node)->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL)), _tmp2_);
 		gee_hash_map_node_free (*node);
-		_tmp3_ = NULL;
 		*node = (_tmp3_ = next, next = NULL, _tmp3_);
 		self->priv->_nnodes--;
 		gee_hash_map_resize (self);
 		self->priv->_stamp++;
 		result = TRUE;
-		(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
+		_gee_hash_map_node_free0 (next);
 		return result;
 	}
 	result = FALSE;
@@ -623,7 +588,6 @@ static void gee_hash_map_real_clear (GeeMap* base) {
 				if (!(i < self->priv->_array_size)) {
 					break;
 				}
-				_tmp1_ = NULL;
 				node = (_tmp1_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp1_);
 				while (TRUE) {
 					GeeHashMapNode* _tmp2_;
@@ -635,18 +599,13 @@ static void gee_hash_map_real_clear (GeeMap* base) {
 					if (!(node != NULL)) {
 						break;
 					}
-					_tmp2_ = NULL;
 					next = (_tmp2_ = node->next, node->next = NULL, _tmp2_);
-					_tmp3_ = NULL;
 					node->key = (_tmp3_ = NULL, ((node->key == NULL) || (self->priv->k_destroy_func == NULL)) ? NULL : (node->key = (self->priv->k_destroy_func (node->key), NULL)), _tmp3_);
-					_tmp4_ = NULL;
 					node->value = (_tmp4_ = NULL, ((node->value == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : (node->value = (self->priv->v_destroy_func (node->value), NULL)), _tmp4_);
-					_tmp6_ = NULL;
-					_tmp5_ = NULL;
-					node = (_tmp6_ = (_tmp5_ = next, next = NULL, _tmp5_), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp6_);
-					(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
+					node = (_tmp6_ = (_tmp5_ = next, next = NULL, _tmp5_), _gee_hash_map_node_free0 (node), _tmp6_);
+					_gee_hash_map_node_free0 (next);
 				}
-				(node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL));
+				_gee_hash_map_node_free0 (node);
 			}
 		}
 	}
@@ -688,7 +647,6 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 		GeeHashMapNode** _tmp16_;
 		new_array_size = (gint) g_spaced_primes_closest ((guint) self->priv->_nnodes);
 		new_array_size = CLAMP (new_array_size, GEE_HASH_MAP_MIN_SIZE, GEE_HASH_MAP_MAX_SIZE);
-		_tmp3_ = NULL;
 		new_nodes = (_tmp3_ = g_new0 (GeeHashMapNode*, new_array_size + 1), new_nodes_length1 = new_array_size, new_nodes_size = new_nodes_length1, _tmp3_);
 		{
 			gint i;
@@ -712,9 +670,7 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 						GeeHashMapNode* _tmp6_;
 						GeeHashMapNode* _tmp5_;
 						gboolean _tmp7_;
-						_tmp6_ = NULL;
-						_tmp5_ = NULL;
-						node = (_tmp6_ = (_tmp5_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp5_), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp6_);
+						node = (_tmp6_ = (_tmp5_ = self->priv->_nodes[i], self->priv->_nodes[i] = NULL, _tmp5_), _gee_hash_map_node_free0 (node), _tmp6_);
 						_tmp7_ = TRUE;
 						while (TRUE) {
 							GeeHashMapNode* _tmp11_;
@@ -727,33 +683,23 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 							if (!_tmp7_) {
 								GeeHashMapNode* _tmp9_;
 								GeeHashMapNode* _tmp8_;
-								_tmp9_ = NULL;
-								_tmp8_ = NULL;
-								node = (_tmp9_ = (_tmp8_ = next, next = NULL, _tmp8_), (node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL)), _tmp9_);
+								node = (_tmp9_ = (_tmp8_ = next, next = NULL, _tmp8_), _gee_hash_map_node_free0 (node), _tmp9_);
 							}
 							_tmp7_ = FALSE;
 							if (!(node != NULL)) {
 								break;
 							}
-							_tmp11_ = NULL;
-							_tmp10_ = NULL;
-							next = (_tmp11_ = (_tmp10_ = node->next, node->next = NULL, _tmp10_), (next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL)), _tmp11_);
+							next = (_tmp11_ = (_tmp10_ = node->next, node->next = NULL, _tmp10_), _gee_hash_map_node_free0 (next), _tmp11_);
 							hash_val = node->key_hash % new_array_size;
-							_tmp13_ = NULL;
-							_tmp12_ = NULL;
-							node->next = (_tmp13_ = (_tmp12_ = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp12_), (node->next == NULL) ? NULL : (node->next = (gee_hash_map_node_free (node->next), NULL)), _tmp13_);
-							_tmp15_ = NULL;
-							_tmp14_ = NULL;
-							new_nodes[hash_val] = (_tmp15_ = (_tmp14_ = node, node = NULL, _tmp14_), (new_nodes[hash_val] == NULL) ? NULL : (new_nodes[hash_val] = (gee_hash_map_node_free (new_nodes[hash_val]), NULL)), _tmp15_);
+							node->next = (_tmp13_ = (_tmp12_ = new_nodes[hash_val], new_nodes[hash_val] = NULL, _tmp12_), _gee_hash_map_node_free0 (node->next), _tmp13_);
+							new_nodes[hash_val] = (_tmp15_ = (_tmp14_ = node, node = NULL, _tmp14_), _gee_hash_map_node_free0 (new_nodes[hash_val]), _tmp15_);
 						}
 					}
-					(node == NULL) ? NULL : (node = (gee_hash_map_node_free (node), NULL));
-					(next == NULL) ? NULL : (next = (gee_hash_map_node_free (next), NULL));
+					_gee_hash_map_node_free0 (node);
+					_gee_hash_map_node_free0 (next);
 				}
 			}
 		}
-		_tmp17_ = NULL;
-		_tmp16_ = NULL;
 		self->priv->_nodes = (_tmp17_ = (_tmp16_ = new_nodes, new_nodes = NULL, _tmp16_), self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL), self->priv->_nodes_length1 = new_nodes_length1, self->priv->_nodes_size = self->priv->_nodes_length1, _tmp17_);
 		self->priv->_array_size = new_array_size;
 		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, (GDestroyNotify) gee_hash_map_node_free), NULL);
@@ -794,9 +740,7 @@ static GeeHashMapNode* gee_hash_map_node_new (gpointer k, gpointer v, guint hash
 	gpointer _tmp1_;
 	self = g_slice_new0 (GeeHashMapNode);
 	gee_hash_map_node_instance_init (self);
-	_tmp0_ = NULL;
 	self->key = (_tmp0_ = k, k = NULL, _tmp0_);
-	_tmp1_ = NULL;
 	self->value = (_tmp1_ = v, v = NULL, _tmp1_);
 	self->key_hash = hash;
 	return self;
@@ -808,7 +752,7 @@ static void gee_hash_map_node_instance_init (GeeHashMapNode * self) {
 
 
 static void gee_hash_map_node_free (GeeHashMapNode* self) {
-	(self->next == NULL) ? NULL : (self->next = (gee_hash_map_node_free (self->next), NULL));
+	_gee_hash_map_node_free0 (self->next);
 	g_slice_free (GeeHashMapNode, self);
 }
 
@@ -816,7 +760,7 @@ static void gee_hash_map_node_free (GeeHashMapNode* self) {
 static GeeHashMapKeySet* gee_hash_map_key_set_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map) {
 	GeeHashMapKeySet* self;
 	g_return_val_if_fail (map != NULL, NULL);
-	self = (GeeHashMapKeySet*) g_type_create_instance (object_type);
+	self = (GeeHashMapKeySet*) gee_collection_object_construct (object_type);
 	self->priv->k_type = k_type;
 	self->priv->k_dup_func = k_dup_func;
 	self->priv->k_destroy_func = k_destroy_func;
@@ -853,7 +797,6 @@ static GeeIterator* gee_hash_map_key_set_real_iterator (GeeIterable* base) {
 
 static gboolean gee_hash_map_key_set_real_add (GeeCollection* base, gconstpointer key) {
 	GeeHashMapKeySet * self;
-	gboolean result;
 	self = (GeeHashMapKeySet*) base;
 	g_assert_not_reached ();
 }
@@ -868,7 +811,6 @@ static void gee_hash_map_key_set_real_clear (GeeCollection* base) {
 
 static gboolean gee_hash_map_key_set_real_remove (GeeCollection* base, gconstpointer key) {
 	GeeHashMapKeySet * self;
-	gboolean result;
 	self = (GeeHashMapKeySet*) base;
 	g_assert_not_reached ();
 }
@@ -883,13 +825,15 @@ static gboolean gee_hash_map_key_set_real_contains (GeeCollection* base, gconstp
 }
 
 
+static gpointer _gee_collection_object_ref0 (gpointer self) {
+	return self ? gee_collection_object_ref (self) : NULL;
+}
+
+
 static void gee_hash_map_key_set_set_map (GeeHashMapKeySet* self, GeeHashMap* value) {
-	GeeHashMap* _tmp1_;
 	GeeHashMap* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_map = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL)), _tmp1_);
+	self->priv->_map = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_map), _tmp0_);
 }
 
 
@@ -939,7 +883,7 @@ static void gee_hash_map_key_set_instance_init (GeeHashMapKeySet * self) {
 static void gee_hash_map_key_set_finalize (GeeCollectionObject* obj) {
 	GeeHashMapKeySet * self;
 	self = GEE_HASH_MAP_KEY_SET (obj);
-	(self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL));
+	_gee_collection_object_unref0 (self->priv->_map);
 	GEE_COLLECTION_OBJECT_CLASS (gee_hash_map_key_set_parent_class)->finalize (obj);
 }
 
@@ -963,7 +907,7 @@ static GType gee_hash_map_key_set_get_type (void) {
 static GeeHashMapKeyIterator* gee_hash_map_key_iterator_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map) {
 	GeeHashMapKeyIterator* self;
 	g_return_val_if_fail (map != NULL, NULL);
-	self = (GeeHashMapKeyIterator*) g_type_create_instance (object_type);
+	self = (GeeHashMapKeyIterator*) gee_collection_object_construct (object_type);
 	self->priv->k_type = k_type;
 	self->priv->k_dup_func = k_dup_func;
 	self->priv->k_destroy_func = k_destroy_func;
@@ -1013,19 +957,15 @@ static gpointer gee_hash_map_key_iterator_real_get (GeeIterator* base) {
 	self = (GeeHashMapKeyIterator*) base;
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
-	_tmp0_ = NULL;
 	result = (_tmp0_ = self->priv->_node->key, ((_tmp0_ == NULL) || (self->priv->k_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->k_dup_func ((gpointer) _tmp0_));
 	return result;
 }
 
 
 static void gee_hash_map_key_iterator_set_map (GeeHashMapKeyIterator* self, GeeHashMap* value) {
-	GeeHashMap* _tmp1_;
 	GeeHashMap* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_map = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL)), _tmp1_);
+	self->priv->_map = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_map), _tmp0_);
 	self->priv->_stamp = self->priv->_map->priv->_stamp;
 }
 
@@ -1053,7 +993,7 @@ static void gee_hash_map_key_iterator_instance_init (GeeHashMapKeyIterator * sel
 static void gee_hash_map_key_iterator_finalize (GeeCollectionObject* obj) {
 	GeeHashMapKeyIterator * self;
 	self = GEE_HASH_MAP_KEY_ITERATOR (obj);
-	(self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL));
+	_gee_collection_object_unref0 (self->priv->_map);
 	GEE_COLLECTION_OBJECT_CLASS (gee_hash_map_key_iterator_parent_class)->finalize (obj);
 }
 
@@ -1073,7 +1013,7 @@ static GType gee_hash_map_key_iterator_get_type (void) {
 static GeeHashMapValueCollection* gee_hash_map_value_collection_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map) {
 	GeeHashMapValueCollection* self;
 	g_return_val_if_fail (map != NULL, NULL);
-	self = (GeeHashMapValueCollection*) g_type_create_instance (object_type);
+	self = (GeeHashMapValueCollection*) gee_collection_object_construct (object_type);
 	self->priv->k_type = k_type;
 	self->priv->k_dup_func = k_dup_func;
 	self->priv->k_destroy_func = k_destroy_func;
@@ -1110,7 +1050,6 @@ static GeeIterator* gee_hash_map_value_collection_real_iterator (GeeIterable* ba
 
 static gboolean gee_hash_map_value_collection_real_add (GeeCollection* base, gconstpointer value) {
 	GeeHashMapValueCollection * self;
-	gboolean result;
 	self = (GeeHashMapValueCollection*) base;
 	g_assert_not_reached ();
 }
@@ -1125,7 +1064,6 @@ static void gee_hash_map_value_collection_real_clear (GeeCollection* base) {
 
 static gboolean gee_hash_map_value_collection_real_remove (GeeCollection* base, gconstpointer value) {
 	GeeHashMapValueCollection * self;
-	gboolean result;
 	self = (GeeHashMapValueCollection*) base;
 	g_assert_not_reached ();
 }
@@ -1143,26 +1081,22 @@ static gboolean gee_hash_map_value_collection_real_contains (GeeCollection* base
 		if (!gee_iterator_next (it)) {
 			break;
 		}
-		_tmp0_ = NULL;
 		if ((_tmp1_ = self->priv->_map->priv->_value_equal_func (_tmp0_ = gee_iterator_get (it), value), ((_tmp0_ == NULL) || (self->priv->v_destroy_func == NULL)) ? NULL : (_tmp0_ = (self->priv->v_destroy_func (_tmp0_), NULL)), _tmp1_)) {
 			result = TRUE;
-			(it == NULL) ? NULL : (it = (gee_collection_object_unref (it), NULL));
+			_gee_collection_object_unref0 (it);
 			return result;
 		}
 	}
 	result = FALSE;
-	(it == NULL) ? NULL : (it = (gee_collection_object_unref (it), NULL));
+	_gee_collection_object_unref0 (it);
 	return result;
 }
 
 
 static void gee_hash_map_value_collection_set_map (GeeHashMapValueCollection* self, GeeHashMap* value) {
-	GeeHashMap* _tmp1_;
 	GeeHashMap* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_map = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL)), _tmp1_);
+	self->priv->_map = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_map), _tmp0_);
 }
 
 
@@ -1207,7 +1141,7 @@ static void gee_hash_map_value_collection_instance_init (GeeHashMapValueCollecti
 static void gee_hash_map_value_collection_finalize (GeeCollectionObject* obj) {
 	GeeHashMapValueCollection * self;
 	self = GEE_HASH_MAP_VALUE_COLLECTION (obj);
-	(self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL));
+	_gee_collection_object_unref0 (self->priv->_map);
 	GEE_COLLECTION_OBJECT_CLASS (gee_hash_map_value_collection_parent_class)->finalize (obj);
 }
 
@@ -1229,7 +1163,7 @@ static GType gee_hash_map_value_collection_get_type (void) {
 static GeeHashMapValueIterator* gee_hash_map_value_iterator_construct (GType object_type, GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map) {
 	GeeHashMapValueIterator* self;
 	g_return_val_if_fail (map != NULL, NULL);
-	self = (GeeHashMapValueIterator*) g_type_create_instance (object_type);
+	self = (GeeHashMapValueIterator*) gee_collection_object_construct (object_type);
 	self->priv->k_type = k_type;
 	self->priv->k_dup_func = k_dup_func;
 	self->priv->k_destroy_func = k_destroy_func;
@@ -1279,19 +1213,15 @@ static gpointer gee_hash_map_value_iterator_real_get (GeeIterator* base) {
 	self = (GeeHashMapValueIterator*) base;
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
-	_tmp0_ = NULL;
 	result = (_tmp0_ = self->priv->_node->value, ((_tmp0_ == NULL) || (self->priv->v_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->v_dup_func ((gpointer) _tmp0_));
 	return result;
 }
 
 
 static void gee_hash_map_value_iterator_set_map (GeeHashMapValueIterator* self, GeeHashMap* value) {
-	GeeHashMap* _tmp1_;
 	GeeHashMap* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_map = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL)), _tmp1_);
+	self->priv->_map = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_map), _tmp0_);
 	self->priv->_stamp = self->priv->_map->priv->_stamp;
 }
 
@@ -1319,7 +1249,7 @@ static void gee_hash_map_value_iterator_instance_init (GeeHashMapValueIterator *
 static void gee_hash_map_value_iterator_finalize (GeeCollectionObject* obj) {
 	GeeHashMapValueIterator * self;
 	self = GEE_HASH_MAP_VALUE_ITERATOR (obj);
-	(self->priv->_map == NULL) ? NULL : (self->priv->_map = (gee_collection_object_unref (self->priv->_map), NULL));
+	_gee_collection_object_unref0 (self->priv->_map);
 	GEE_COLLECTION_OBJECT_CLASS (gee_hash_map_value_iterator_parent_class)->finalize (obj);
 }
 
