@@ -77,6 +77,7 @@ typedef struct _GeeListIface GeeListIface;
 typedef struct _GeeReadOnlyList GeeReadOnlyList;
 typedef struct _GeeReadOnlyListClass GeeReadOnlyListClass;
 typedef struct _GeeReadOnlyListPrivate GeeReadOnlyListPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define GEE_READ_ONLY_LIST_TYPE_ITERATOR (gee_read_only_list_iterator_get_type ())
 #define GEE_READ_ONLY_LIST_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_READ_ONLY_LIST_TYPE_ITERATOR, GeeReadOnlyListIterator))
@@ -89,9 +90,6 @@ typedef struct _GeeReadOnlyListIterator GeeReadOnlyListIterator;
 typedef struct _GeeReadOnlyListIteratorClass GeeReadOnlyListIteratorClass;
 typedef struct _GeeReadOnlyListIteratorPrivate GeeReadOnlyListIteratorPrivate;
 
-/**
- * Base class for all collections.
- */
 struct _GeeCollectionObject {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -103,30 +101,18 @@ struct _GeeCollectionObjectClass {
 	void (*finalize) (GeeCollectionObject *self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIteratorIface {
 	GTypeInterface parent_iface;
 	gboolean (*next) (GeeIterator* self);
 	gpointer (*get) (GeeIterator* self);
 };
 
-/**
- * Implemented by classes that support a simple iteration over instances of the
- * collection.
- */
 struct _GeeIterableIface {
 	GTypeInterface parent_iface;
 	GType (*get_element_type) (GeeIterable* self);
 	GeeIterator* (*iterator) (GeeIterable* self);
 };
 
-/**
- * Serves as the base interface for implementing collection classes. Defines
- * size, iteration, and modification methods.
- */
 struct _GeeCollectionIface {
 	GTypeInterface parent_iface;
 	gboolean (*contains) (GeeCollection* self, gconstpointer item);
@@ -136,9 +122,6 @@ struct _GeeCollectionIface {
 	gint (*get_size) (GeeCollection* self);
 };
 
-/**
- * Represents a collection of items in a well-defined order.
- */
 struct _GeeListIface {
 	GTypeInterface parent_iface;
 	gpointer (*get) (GeeList* self, gint index);
@@ -148,9 +131,6 @@ struct _GeeListIface {
 	void (*remove_at) (GeeList* self, gint index);
 };
 
-/**
- * Represents a read-only collection of items in a well-defined order.
- */
 struct _GeeReadOnlyList {
 	GeeCollectionObject parent_instance;
 	GeeReadOnlyListPrivate * priv;
@@ -205,6 +185,8 @@ GType gee_read_only_list_get_type (void);
 enum  {
 	GEE_READ_ONLY_LIST_DUMMY_PROPERTY
 };
+GeeCollectionObject* gee_collection_object_new (void);
+GeeCollectionObject* gee_collection_object_construct (GType object_type);
 void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value);
 GeeReadOnlyList* gee_read_only_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list);
 GeeReadOnlyList* gee_read_only_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list);
@@ -239,7 +221,7 @@ static void gee_read_only_list_finalize (GeeCollectionObject* obj);
 
 GeeReadOnlyList* gee_read_only_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list) {
 	GeeReadOnlyList* self;
-	self = (GeeReadOnlyList*) g_type_create_instance (object_type);
+	self = (GeeReadOnlyList*) gee_collection_object_construct (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -303,7 +285,6 @@ static gint gee_read_only_list_real_index_of (GeeList* base, gconstpointer item)
 
 static gboolean gee_read_only_list_real_add (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	gboolean result;
 	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
@@ -311,7 +292,6 @@ static gboolean gee_read_only_list_real_add (GeeCollection* base, gconstpointer
 
 static gboolean gee_read_only_list_real_remove (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	gboolean result;
 	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
@@ -367,13 +347,15 @@ static gint gee_read_only_list_real_get_size (GeeCollection* base) {
 }
 
 
+static gpointer _gee_collection_object_ref0 (gpointer self) {
+	return self ? gee_collection_object_ref (self) : NULL;
+}
+
+
 void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value) {
-	GeeList* _tmp1_;
 	GeeList* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_list = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL)), _tmp1_);
+	self->priv->_list = (_tmp0_ = _gee_collection_object_ref0 (value), _gee_collection_object_unref0 (self->priv->_list), _tmp0_);
 }
 
 
@@ -397,7 +379,7 @@ static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base) {
 
 static GeeReadOnlyListIterator* gee_read_only_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
 	GeeReadOnlyListIterator* self;
-	self = (GeeReadOnlyListIterator*) g_type_create_instance (object_type);
+	self = (GeeReadOnlyListIterator*) gee_collection_object_construct (object_type);
 	self->priv->g_type = g_type;
 	self->priv->g_dup_func = g_dup_func;
 	self->priv->g_destroy_func = g_destroy_func;
@@ -482,7 +464,7 @@ static void gee_read_only_list_instance_init (GeeReadOnlyList * self) {
 static void gee_read_only_list_finalize (GeeCollectionObject* obj) {
 	GeeReadOnlyList * self;
 	self = GEE_READ_ONLY_LIST (obj);
-	(self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL));
+	_gee_collection_object_unref0 (self->priv->_list);
 	GEE_COLLECTION_OBJECT_CLASS (gee_read_only_list_parent_class)->finalize (obj);
 }
 
