@@ -131,6 +131,8 @@ typedef struct _ValaArrayCreationExpressionPrivate ValaArrayCreationExpressionPr
 
 typedef struct _ValaInitializerList ValaInitializerList;
 typedef struct _ValaInitializerListClass ValaInitializerListClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -161,6 +163,7 @@ typedef struct _ValaLiteralClass ValaLiteralClass;
 
 typedef struct _ValaIntegerLiteral ValaIntegerLiteral;
 typedef struct _ValaIntegerLiteralClass ValaIntegerLiteralClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_REFERENCE_TYPE (vala_reference_type_get_type ())
 #define VALA_REFERENCE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_REFERENCE_TYPE, ValaReferenceType))
@@ -212,12 +215,6 @@ typedef struct _ValaIntegerTypeClass ValaIntegerTypeClass;
 typedef struct _ValaEnumValueType ValaEnumValueType;
 typedef struct _ValaEnumValueTypeClass ValaEnumValueTypeClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -238,9 +235,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -254,9 +248,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Represents an array creation expression e.g. "new int[] {1,2,3}".
- */
 struct _ValaArrayCreationExpression {
 	ValaExpression parent_instance;
 	ValaArrayCreationExpressionPrivate * priv;
@@ -302,6 +293,7 @@ enum  {
 };
 void vala_array_creation_expression_append_size (ValaArrayCreationExpression* self, ValaExpression* size);
 GeeList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self);
+ValaExpression* vala_expression_construct (GType object_type);
 void vala_array_creation_expression_set_element_type (ValaArrayCreationExpression* self, ValaDataType* value);
 void vala_array_creation_expression_set_rank (ValaArrayCreationExpression* self, gint value);
 void vala_array_creation_expression_set_initializer_list (ValaArrayCreationExpression* self, ValaInitializerList* value);
@@ -355,9 +347,6 @@ static void vala_array_creation_expression_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Add a size expression.
- */
 void vala_array_creation_expression_append_size (ValaArrayCreationExpression* self, ValaExpression* size) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (size != NULL);
@@ -365,9 +354,6 @@ void vala_array_creation_expression_append_size (ValaArrayCreationExpression* se
 }
 
 
-/**
- * Get the sizes for all dimensions ascending from left to right.
- */
 GeeList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -380,7 +366,7 @@ ValaArrayCreationExpression* vala_array_creation_expression_construct (GType obj
 	ValaArrayCreationExpression* self;
 	g_return_val_if_fail (element_type != NULL, NULL);
 	g_return_val_if_fail (source_reference != NULL, NULL);
-	self = (ValaArrayCreationExpression*) g_type_create_instance (object_type);
+	self = (ValaArrayCreationExpression*) vala_expression_construct (object_type);
 	vala_array_creation_expression_set_element_type (self, element_type);
 	vala_array_creation_expression_set_rank (self, rank);
 	vala_array_creation_expression_set_initializer_list (self, initializer_list);
@@ -411,9 +397,9 @@ static void vala_array_creation_expression_real_accept_children (ValaCodeNode* b
 			}
 			e = (ValaExpression*) gee_iterator_get (_e_it);
 			vala_code_node_accept ((ValaCodeNode*) e, visitor);
-			(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
+			_vala_code_node_unref0 (e);
 		}
-		(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+		_gee_collection_object_unref0 (_e_it);
 	}
 	if (vala_array_creation_expression_get_initializer_list (self) != NULL) {
 		vala_code_node_accept ((ValaCodeNode*) vala_array_creation_expression_get_initializer_list (self), visitor);
@@ -461,22 +447,17 @@ static gint vala_array_creation_expression_create_sizes_from_initializer_list (V
 		char* _tmp0_;
 		ValaIntegerLiteral* _tmp1_;
 		ValaIntegerLiteral* init;
-		/* only add size if this is the first initializer list of the current dimension*/
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		init = (_tmp1_ = vala_integer_literal_new (_tmp0_ = g_strdup_printf ("%i", vala_initializer_list_get_size (il)), vala_code_node_get_source_reference ((ValaCodeNode*) il)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+		init = (_tmp1_ = vala_integer_literal_new (_tmp0_ = g_strdup_printf ("%i", vala_initializer_list_get_size (il)), vala_code_node_get_source_reference ((ValaCodeNode*) il)), _g_free0 (_tmp0_), _tmp1_);
 		vala_code_node_check ((ValaCodeNode*) init, analyzer);
 		gee_collection_add ((GeeCollection*) sl, (ValaLiteral*) init);
-		(init == NULL) ? NULL : (init = (vala_code_node_unref (init), NULL));
+		_vala_code_node_unref0 (init);
 	}
 	subsize = -1;
 	{
 		GeeList* _tmp2_;
 		GeeIterator* _tmp3_;
 		GeeIterator* _e_it;
-		_tmp2_ = NULL;
-		_tmp3_ = NULL;
-		_e_it = (_tmp3_ = gee_iterable_iterator ((GeeIterable*) (_tmp2_ = vala_initializer_list_get_initializers (il))), (_tmp2_ == NULL) ? NULL : (_tmp2_ = (gee_collection_object_unref (_tmp2_), NULL)), _tmp3_);
+		_e_it = (_tmp3_ = gee_iterable_iterator ((GeeIterable*) (_tmp2_ = vala_initializer_list_get_initializers (il))), _gee_collection_object_unref0 (_tmp2_), _tmp3_);
 		while (TRUE) {
 			ValaExpression* e;
 			if (!gee_iterator_next (_e_it)) {
@@ -491,15 +472,15 @@ static gint vala_array_creation_expression_create_sizes_from_initializer_list (V
 					vala_code_node_set_error ((ValaCodeNode*) e, TRUE);
 					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), "Expected array element, got array initializer list");
 					result = -1;
-					(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
-					(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+					_vala_code_node_unref0 (e);
+					_gee_collection_object_unref0 (_e_it);
 					return result;
 				}
 				size = vala_array_creation_expression_create_sizes_from_initializer_list (self, analyzer, VALA_INITIALIZER_LIST (e), rank - 1, sl);
 				if (size == (-1)) {
 					result = -1;
-					(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
-					(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+					_vala_code_node_unref0 (e);
+					_gee_collection_object_unref0 (_e_it);
 					return result;
 				}
 				_tmp4_ = FALSE;
@@ -511,12 +492,11 @@ static gint vala_array_creation_expression_create_sizes_from_initializer_list (V
 				if (_tmp4_) {
 					char* _tmp5_;
 					vala_code_node_set_error ((ValaCodeNode*) il, TRUE);
-					_tmp5_ = NULL;
 					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) il), _tmp5_ = g_strdup_printf ("Expected initializer list of size %d, got size %d", subsize, size));
-					_tmp5_ = (g_free (_tmp5_), NULL);
+					_g_free0 (_tmp5_);
 					result = -1;
-					(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
-					(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+					_vala_code_node_unref0 (e);
+					_gee_collection_object_unref0 (_e_it);
 					return result;
 				} else {
 					subsize = size;
@@ -527,29 +507,33 @@ static gint vala_array_creation_expression_create_sizes_from_initializer_list (V
 					vala_code_node_set_error ((ValaCodeNode*) e, TRUE);
 					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), "Expected array initializer list, got array element");
 					result = -1;
-					(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
-					(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+					_vala_code_node_unref0 (e);
+					_gee_collection_object_unref0 (_e_it);
 					return result;
 				}
 			}
-			(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
+			_vala_code_node_unref0 (e);
 		}
-		(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+		_gee_collection_object_unref0 (_e_it);
 	}
 	result = vala_initializer_list_get_size (il);
 	return result;
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaArrayCreationExpression * self;
 	gboolean result;
 	GeeList* sizes;
-	ValaInitializerList* _tmp0_;
 	ValaInitializerList* initlist;
 	GeeArrayList* calc_sizes;
-	gboolean _tmp3_;
-	ValaArrayType* _tmp4_;
+	gboolean _tmp2_;
+	ValaArrayType* _tmp3_;
 	self = (ValaArrayCreationExpression*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -558,8 +542,7 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	sizes = vala_array_creation_expression_get_sizes (self);
-	_tmp0_ = NULL;
-	initlist = (_tmp0_ = vala_array_creation_expression_get_initializer_list (self), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	initlist = _vala_code_node_ref0 (vala_array_creation_expression_get_initializer_list (self));
 	if (vala_array_creation_expression_get_element_type (self) != NULL) {
 		vala_code_node_check ((ValaCodeNode*) vala_array_creation_expression_get_element_type (self), analyzer);
 	}
@@ -573,17 +556,16 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 			}
 			e = (ValaExpression*) gee_iterator_get (_e_it);
 			vala_code_node_check ((ValaCodeNode*) e, analyzer);
-			(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
+			_vala_code_node_unref0 (e);
 		}
-		(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+		_gee_collection_object_unref0 (_e_it);
 	}
 	calc_sizes = gee_array_list_new (VALA_TYPE_LITERAL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	if (initlist != NULL) {
-		ValaArrayType* _tmp1_;
+		ValaArrayType* _tmp0_;
 		gint ret;
-		_tmp1_ = NULL;
-		vala_expression_set_target_type ((ValaExpression*) initlist, (ValaDataType*) (_tmp1_ = vala_array_type_new (vala_array_creation_expression_get_element_type (self), self->priv->_rank, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-		(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL));
+		vala_expression_set_target_type ((ValaExpression*) initlist, (ValaDataType*) (_tmp0_ = vala_array_type_new (vala_array_creation_expression_get_element_type (self), self->priv->_rank, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+		_vala_code_node_unref0 (_tmp0_);
 		vala_code_node_check ((ValaCodeNode*) initlist, analyzer);
 		ret = vala_array_creation_expression_create_sizes_from_initializer_list (self, analyzer, initlist, self->priv->_rank, (GeeList*) calc_sizes);
 		if (ret == (-1)) {
@@ -591,51 +573,43 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 		}
 	}
 	if (gee_collection_get_size ((GeeCollection*) sizes) > 0) {
-		/* check for errors in the size list */
 		{
 			GeeIterator* _e_it;
-			/* check for errors in the size list */
 			_e_it = gee_iterable_iterator ((GeeIterable*) sizes);
-			/* check for errors in the size list */
 			while (TRUE) {
 				ValaExpression* e;
-				/* check for errors in the size list */
 				if (!gee_iterator_next (_e_it)) {
-					/* check for errors in the size list */
 					break;
 				}
-				/* check for errors in the size list */
 				e = (ValaExpression*) gee_iterator_get (_e_it);
 				if (vala_expression_get_value_type (e) == NULL) {
-					/* return on previous error */
 					result = FALSE;
-					(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
-					(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
-					(sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL));
-					(initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL));
-					(calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL));
+					_vala_code_node_unref0 (e);
+					_gee_collection_object_unref0 (_e_it);
+					_gee_collection_object_unref0 (sizes);
+					_vala_code_node_unref0 (initlist);
+					_gee_collection_object_unref0 (calc_sizes);
 					return result;
 				} else {
-					gboolean _tmp2_;
-					_tmp2_ = FALSE;
+					gboolean _tmp1_;
+					_tmp1_ = FALSE;
 					if (VALA_IS_INTEGER_TYPE (vala_expression_get_value_type (e))) {
-						_tmp2_ = TRUE;
+						_tmp1_ = TRUE;
 					} else {
-						_tmp2_ = VALA_IS_ENUM_VALUE_TYPE (vala_expression_get_value_type (e));
+						_tmp1_ = VALA_IS_ENUM_VALUE_TYPE (vala_expression_get_value_type (e));
 					}
-					if (!_tmp2_) {
+					if (!_tmp1_) {
 						vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 						vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), "Expression of integer type expected");
 					}
 				}
-				(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
+				_vala_code_node_unref0 (e);
 			}
-			(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+			_gee_collection_object_unref0 (_e_it);
 		}
 	} else {
 		if (initlist == NULL) {
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			/* this is an internal error because it is already handeld by the parser */
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "internal error: initializer list expected");
 		} else {
 			{
@@ -648,52 +622,49 @@ static gboolean vala_array_creation_expression_real_check (ValaCodeNode* base, V
 					}
 					size = (ValaExpression*) ((ValaLiteral*) gee_iterator_get (_size_it));
 					vala_array_creation_expression_append_size (self, size);
-					(size == NULL) ? NULL : (size = (vala_code_node_unref (size), NULL));
+					_vala_code_node_unref0 (size);
 				}
-				(_size_it == NULL) ? NULL : (_size_it = (gee_collection_object_unref (_size_it), NULL));
+				_gee_collection_object_unref0 (_size_it);
 			}
 		}
 	}
 	if (vala_code_node_get_error ((ValaCodeNode*) self)) {
 		result = FALSE;
-		(sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL));
-		(initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL));
-		(calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL));
+		_gee_collection_object_unref0 (sizes);
+		_vala_code_node_unref0 (initlist);
+		_gee_collection_object_unref0 (calc_sizes);
 		return result;
 	}
-	_tmp3_ = FALSE;
+	_tmp2_ = FALSE;
 	if (vala_array_creation_expression_get_initializer_list (self) != NULL) {
-		_tmp3_ = vala_expression_get_value_type ((ValaExpression*) vala_array_creation_expression_get_initializer_list (self)) == NULL;
+		_tmp2_ = vala_expression_get_value_type ((ValaExpression*) vala_array_creation_expression_get_initializer_list (self)) == NULL;
 	} else {
-		_tmp3_ = FALSE;
+		_tmp2_ = FALSE;
 	}
-	/* check for wrong elements inside the initializer */
-	if (_tmp3_) {
+	if (_tmp2_) {
 		result = FALSE;
-		(sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL));
-		(initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL));
-		(calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL));
+		_gee_collection_object_unref0 (sizes);
+		_vala_code_node_unref0 (initlist);
+		_gee_collection_object_unref0 (calc_sizes);
 		return result;
 	}
-	/* try to construct the type of the array */
 	if (vala_array_creation_expression_get_element_type (self) == NULL) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Cannot determine the element type of the created array");
 		result = FALSE;
-		(sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL));
-		(initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL));
-		(calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL));
+		_gee_collection_object_unref0 (sizes);
+		_vala_code_node_unref0 (initlist);
+		_gee_collection_object_unref0 (calc_sizes);
 		return result;
 	}
 	vala_data_type_set_value_owned (vala_array_creation_expression_get_element_type (self), TRUE);
-	_tmp4_ = NULL;
-	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp4_ = vala_array_type_new (vala_array_creation_expression_get_element_type (self), self->priv->_rank, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp4_ == NULL) ? NULL : (_tmp4_ = (vala_code_node_unref (_tmp4_), NULL));
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp3_ = vala_array_type_new (vala_array_creation_expression_get_element_type (self), self->priv->_rank, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	_vala_code_node_unref0 (_tmp3_);
 	vala_data_type_set_value_owned (vala_expression_get_value_type ((ValaExpression*) self), TRUE);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
-	(sizes == NULL) ? NULL : (sizes = (gee_collection_object_unref (sizes), NULL));
-	(initlist == NULL) ? NULL : (initlist = (vala_code_node_unref (initlist), NULL));
-	(calc_sizes == NULL) ? NULL : (calc_sizes = (gee_collection_object_unref (calc_sizes), NULL));
+	_gee_collection_object_unref0 (sizes);
+	_vala_code_node_unref0 (initlist);
+	_gee_collection_object_unref0 (calc_sizes);
 	return result;
 }
 
@@ -707,12 +678,9 @@ ValaDataType* vala_array_creation_expression_get_element_type (ValaArrayCreation
 
 
 void vala_array_creation_expression_set_element_type (ValaArrayCreationExpression* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_element_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_element_type == NULL) ? NULL : (self->priv->_element_type = (vala_code_node_unref (self->priv->_element_type), NULL)), _tmp1_);
+	self->priv->_element_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_element_type), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_element_type, (ValaCodeNode*) self);
 }
 
@@ -740,12 +708,9 @@ ValaInitializerList* vala_array_creation_expression_get_initializer_list (ValaAr
 
 
 void vala_array_creation_expression_set_initializer_list (ValaArrayCreationExpression* self, ValaInitializerList* value) {
-	ValaInitializerList* _tmp1_;
 	ValaInitializerList* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_initializer_list = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_initializer_list == NULL) ? NULL : (self->priv->_initializer_list = (vala_code_node_unref (self->priv->_initializer_list), NULL)), _tmp1_);
+	self->priv->_initializer_list = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_initializer_list), _tmp0_);
 	if (self->priv->_initializer_list != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_initializer_list, (ValaCodeNode*) self);
 	}
@@ -773,9 +738,9 @@ static void vala_array_creation_expression_instance_init (ValaArrayCreationExpre
 static void vala_array_creation_expression_finalize (ValaCodeNode* obj) {
 	ValaArrayCreationExpression * self;
 	self = VALA_ARRAY_CREATION_EXPRESSION (obj);
-	(self->priv->sizes == NULL) ? NULL : (self->priv->sizes = (gee_collection_object_unref (self->priv->sizes), NULL));
-	(self->priv->_element_type == NULL) ? NULL : (self->priv->_element_type = (vala_code_node_unref (self->priv->_element_type), NULL));
-	(self->priv->_initializer_list == NULL) ? NULL : (self->priv->_initializer_list = (vala_code_node_unref (self->priv->_initializer_list), NULL));
+	_gee_collection_object_unref0 (self->priv->sizes);
+	_vala_code_node_unref0 (self->priv->_element_type);
+	_vala_code_node_unref0 (self->priv->_initializer_list);
 	VALA_CODE_NODE_CLASS (vala_array_creation_expression_parent_class)->finalize (obj);
 }
 
