@@ -170,12 +170,17 @@ typedef struct _ValaInvalidTypeClass ValaInvalidTypeClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -196,9 +201,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -214,9 +216,6 @@ struct _ValaSymbolClass {
 	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a general class member.
- */
 struct _ValaMember {
 	ValaSymbol parent_instance;
 	ValaMemberPrivate * priv;
@@ -226,18 +225,12 @@ struct _ValaMemberClass {
 	ValaSymbolClass parent_class;
 };
 
-/**
- * Represents a lockable object.
- */
 struct _ValaLockableIface {
 	GTypeInterface parent_iface;
 	gboolean (*get_lock_used) (ValaLockable* self);
 	void (*set_lock_used) (ValaLockable* self, gboolean used);
 };
 
-/**
- * Represents a type or namespace field.
- */
 struct _ValaField {
 	ValaMember parent_instance;
 	ValaFieldPrivate * priv;
@@ -247,9 +240,6 @@ struct _ValaFieldClass {
 	ValaMemberClass parent_class;
 };
 
-/**
- * Represents the Array.length field.
- */
 struct _ValaArrayLengthField {
 	ValaField parent_instance;
 	ValaArrayLengthFieldPrivate * priv;
@@ -296,26 +286,26 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
-ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
+ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference, ValaComment* comment);
+ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference, ValaComment* comment);
 void vala_symbol_set_external (ValaSymbol* self, gboolean value);
 ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_reference);
 ValaArrayLengthField* vala_array_length_field_construct (GType object_type, ValaSourceReference* source_reference);
 
 
 
-/**
- * Creates a new array length field.
- *
- * @return newly created field
- */
 ValaArrayLengthField* vala_array_length_field_construct (GType object_type, ValaSourceReference* source_reference) {
 	ValaArrayLengthField* self;
 	ValaInvalidType* _tmp0_;
 	g_return_val_if_fail (source_reference != NULL, NULL);
-	_tmp0_ = NULL;
-	self = (ValaArrayLengthField*) vala_field_construct (object_type, "length", (ValaDataType*) (_tmp0_ = vala_invalid_type_new ()), NULL, source_reference);
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+	self = (ValaArrayLengthField*) vala_field_construct (object_type, "length", (ValaDataType*) (_tmp0_ = vala_invalid_type_new ()), NULL, source_reference, NULL);
+	_vala_code_node_unref0 (_tmp0_);
 	vala_symbol_set_external ((ValaSymbol*) self, TRUE);
 	return self;
 }
