@@ -162,12 +162,17 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaVoidType ValaVoidType;
 typedef struct _ValaVoidTypeClass ValaVoidTypeClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -188,9 +193,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -202,11 +204,10 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a general class member.
- */
 struct _ValaMember {
 	ValaSymbol parent_instance;
 	ValaMemberPrivate * priv;
@@ -216,9 +217,6 @@ struct _ValaMemberClass {
 	ValaSymbolClass parent_class;
 };
 
-/**
- * Represents a type or namespace method.
- */
 struct _ValaMethod {
 	ValaMember parent_instance;
 	ValaMethodPrivate * priv;
@@ -230,9 +228,6 @@ struct _ValaMethodClass {
 	char* (*get_real_cname) (ValaMethod* self);
 };
 
-/**
- * Represents the Array.move method.
- */
 struct _ValaArrayMoveMethod {
 	ValaMethod parent_instance;
 	ValaArrayMoveMethodPrivate * priv;
@@ -278,27 +273,26 @@ GType vala_source_reference_get_type (void);
 ValaVoidType* vala_void_type_new (ValaSourceReference* source_reference);
 ValaVoidType* vala_void_type_construct (GType object_type, ValaSourceReference* source_reference);
 GType vala_void_type_get_type (void);
-ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
+ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
+ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
 void vala_symbol_set_external (ValaSymbol* self, gboolean value);
 ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_reference);
 ValaArrayMoveMethod* vala_array_move_method_construct (GType object_type, ValaSourceReference* source_reference);
-ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_reference);
 
 
 
-/**
- * Creates a new array move method.
- *
- * @return newly created method
- */
 ValaArrayMoveMethod* vala_array_move_method_construct (GType object_type, ValaSourceReference* source_reference) {
 	ValaArrayMoveMethod* self;
 	ValaVoidType* _tmp0_;
 	g_return_val_if_fail (source_reference != NULL, NULL);
-	_tmp0_ = NULL;
-	self = (ValaArrayMoveMethod*) vala_method_construct (object_type, "move", (ValaDataType*) (_tmp0_ = vala_void_type_new (NULL)), source_reference);
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+	self = (ValaArrayMoveMethod*) vala_method_construct (object_type, "move", (ValaDataType*) (_tmp0_ = vala_void_type_new (NULL)), source_reference, NULL);
+	_vala_code_node_unref0 (_tmp0_);
 	vala_symbol_set_external ((ValaSymbol*) self, TRUE);
 	return self;
 }
