@@ -110,6 +110,8 @@ typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
 typedef struct _ValaAttribute ValaAttribute;
 typedef struct _ValaAttributeClass ValaAttributeClass;
 typedef struct _ValaAttributePrivate ValaAttributePrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -140,6 +142,7 @@ typedef struct _ValaLiteralClass ValaLiteralClass;
 
 typedef struct _ValaStringLiteral ValaStringLiteral;
 typedef struct _ValaStringLiteralClass ValaStringLiteralClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_INTEGER_LITERAL (vala_integer_literal_get_type ())
 #define VALA_INTEGER_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_INTEGER_LITERAL, ValaIntegerLiteral))
@@ -183,12 +186,6 @@ typedef struct _ValaUnaryExpressionClass ValaUnaryExpressionClass;
 typedef struct _ValaBooleanLiteral ValaBooleanLiteral;
 typedef struct _ValaBooleanLiteralClass ValaBooleanLiteralClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -209,9 +206,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents an attribute specified in the source code.
- */
 struct _ValaAttribute {
 	ValaCodeNode parent_instance;
 	ValaAttributePrivate * priv;
@@ -263,6 +257,7 @@ GType vala_attribute_get_type (void);
 enum  {
 	VALA_ATTRIBUTE_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_attribute_set_name (ValaAttribute* self, const char* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -297,17 +292,10 @@ static void vala_attribute_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new attribute.
- *
- * @param name             attribute type name
- * @param source_reference reference to source code
- * @return                 newly created attribute
- */
 ValaAttribute* vala_attribute_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
 	ValaAttribute* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaAttribute*) g_type_create_instance (object_type);
+	self = (ValaAttribute*) vala_code_node_construct (object_type);
 	vala_attribute_set_name (self, name);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
@@ -319,11 +307,6 @@ ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source
 }
 
 
-/**
- * Adds an attribute argument.
- *
- * @param arg named argument
- */
 void vala_attribute_add_argument (ValaAttribute* self, const char* key, ValaExpression* value) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (key != NULL);
@@ -332,12 +315,6 @@ void vala_attribute_add_argument (ValaAttribute* self, const char* key, ValaExpr
 }
 
 
-/**
- * Returns whether this attribute has the specified named argument.
- *
- * @param name argument name
- * @return     true if the argument has been found, false otherwise
- */
 gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name) {
 	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
@@ -347,62 +324,47 @@ gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name) {
 }
 
 
-/**
- * Returns the string value of the specified named argument.
- *
- * @param name argument name
- * @return     string value
- */
 char* vala_attribute_get_string (ValaAttribute* self, const char* name) {
 	char* result;
 	ValaExpression* _tmp0_;
 	ValaStringLiteral* lit;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
-	_tmp0_ = NULL;
 	lit = (_tmp0_ = (ValaExpression*) gee_map_get (self->args, name), VALA_IS_STRING_LITERAL (_tmp0_) ? ((ValaStringLiteral*) _tmp0_) : NULL);
 	if (lit != NULL) {
 		result = vala_string_literal_eval (lit);
-		(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
+		_vala_code_node_unref0 (lit);
 		return result;
 	}
 	result = NULL;
-	(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
+	_vala_code_node_unref0 (lit);
 	return result;
 }
 
 
-/**
- * Returns the integer value of the specified named argument.
- *
- * @param name argument name
- * @return     integer value
- */
 gint vala_attribute_get_integer (ValaAttribute* self, const char* name) {
 	gint result;
 	ValaExpression* _tmp0_;
 	ValaIntegerLiteral* lit;
 	g_return_val_if_fail (self != NULL, 0);
 	g_return_val_if_fail (name != NULL, 0);
-	_tmp0_ = NULL;
 	lit = (_tmp0_ = (ValaExpression*) gee_map_get (self->args, name), VALA_IS_INTEGER_LITERAL (_tmp0_) ? ((ValaIntegerLiteral*) _tmp0_) : NULL);
 	if (lit != NULL) {
 		result = atoi (vala_integer_literal_get_value (lit));
-		(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
+		_vala_code_node_unref0 (lit);
 		return result;
 	}
 	result = 0;
-	(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
+	_vala_code_node_unref0 (lit);
 	return result;
 }
 
 
-/**
- * Returns the double value of the specified named argument.
- *
- * @param name argument name
- * @return     double value
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 double vala_attribute_get_double (ValaAttribute* self, const char* name) {
 	double result;
 	ValaExpression* arg;
@@ -410,86 +372,69 @@ double vala_attribute_get_double (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (name != NULL, 0.0);
 	arg = (ValaExpression*) gee_map_get (self->args, name);
 	if (VALA_IS_REAL_LITERAL (arg)) {
-		ValaRealLiteral* _tmp0_;
 		ValaRealLiteral* lit;
-		_tmp0_ = NULL;
-		lit = (_tmp0_ = VALA_REAL_LITERAL (arg), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+		lit = _vala_code_node_ref0 (VALA_REAL_LITERAL (arg));
 		result = g_ascii_strtod (vala_real_literal_get_value (lit), NULL);
-		(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
-		(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+		_vala_code_node_unref0 (lit);
+		_vala_code_node_unref0 (arg);
 		return result;
 	} else {
 		if (VALA_IS_INTEGER_LITERAL (arg)) {
-			ValaIntegerLiteral* _tmp1_;
 			ValaIntegerLiteral* lit;
-			_tmp1_ = NULL;
-			lit = (_tmp1_ = VALA_INTEGER_LITERAL (arg), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+			lit = _vala_code_node_ref0 (VALA_INTEGER_LITERAL (arg));
 			result = (double) atoi (vala_integer_literal_get_value (lit));
-			(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
-			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+			_vala_code_node_unref0 (lit);
+			_vala_code_node_unref0 (arg);
 			return result;
 		} else {
 			if (VALA_IS_UNARY_EXPRESSION (arg)) {
-				ValaUnaryExpression* _tmp2_;
 				ValaUnaryExpression* unary;
-				_tmp2_ = NULL;
-				unary = (_tmp2_ = VALA_UNARY_EXPRESSION (arg), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
+				unary = _vala_code_node_ref0 (VALA_UNARY_EXPRESSION (arg));
 				if (vala_unary_expression_get_operator (unary) == VALA_UNARY_OPERATOR_MINUS) {
 					if (VALA_IS_REAL_LITERAL (vala_unary_expression_get_inner (unary))) {
-						ValaRealLiteral* _tmp3_;
 						ValaRealLiteral* lit;
-						_tmp3_ = NULL;
-						lit = (_tmp3_ = VALA_REAL_LITERAL (vala_unary_expression_get_inner (unary)), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_));
+						lit = _vala_code_node_ref0 (VALA_REAL_LITERAL (vala_unary_expression_get_inner (unary)));
 						result = -g_ascii_strtod (vala_real_literal_get_value (lit), NULL);
-						(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
-						(unary == NULL) ? NULL : (unary = (vala_code_node_unref (unary), NULL));
-						(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+						_vala_code_node_unref0 (lit);
+						_vala_code_node_unref0 (unary);
+						_vala_code_node_unref0 (arg);
 						return result;
 					} else {
 						if (VALA_IS_INTEGER_LITERAL (vala_unary_expression_get_inner (unary))) {
-							ValaIntegerLiteral* _tmp4_;
 							ValaIntegerLiteral* lit;
-							_tmp4_ = NULL;
-							lit = (_tmp4_ = VALA_INTEGER_LITERAL (vala_unary_expression_get_inner (unary)), (_tmp4_ == NULL) ? NULL : vala_code_node_ref (_tmp4_));
+							lit = _vala_code_node_ref0 (VALA_INTEGER_LITERAL (vala_unary_expression_get_inner (unary)));
 							result = (double) (-atoi (vala_integer_literal_get_value (lit)));
-							(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
-							(unary == NULL) ? NULL : (unary = (vala_code_node_unref (unary), NULL));
-							(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+							_vala_code_node_unref0 (lit);
+							_vala_code_node_unref0 (unary);
+							_vala_code_node_unref0 (arg);
 							return result;
 						}
 					}
 				}
-				(unary == NULL) ? NULL : (unary = (vala_code_node_unref (unary), NULL));
+				_vala_code_node_unref0 (unary);
 			}
 		}
 	}
 	result = (double) 0;
-	(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+	_vala_code_node_unref0 (arg);
 	return result;
 }
 
 
-/**
- * Returns the boolean value of the specified named argument.
- *
- * @param name argument name
- * @return     boolean value
- */
 gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name) {
 	gboolean result;
 	ValaExpression* _tmp0_;
 	ValaBooleanLiteral* lit;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
-	_tmp0_ = NULL;
 	lit = (_tmp0_ = (ValaExpression*) gee_map_get (self->args, name), VALA_IS_BOOLEAN_LITERAL (_tmp0_) ? ((ValaBooleanLiteral*) _tmp0_) : NULL);
 	if (lit != NULL) {
 		result = vala_boolean_literal_get_value (lit);
-		(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
+		_vala_code_node_unref0 (lit);
 		return result;
 	}
 	result = FALSE;
-	(lit == NULL) ? NULL : (lit = (vala_code_node_unref (lit), NULL));
+	_vala_code_node_unref0 (lit);
 	return result;
 }
 
@@ -503,12 +448,9 @@ const char* vala_attribute_get_name (ValaAttribute* self) {
 
 
 void vala_attribute_set_name (ValaAttribute* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -528,8 +470,8 @@ static void vala_attribute_instance_init (ValaAttribute * self) {
 static void vala_attribute_finalize (ValaCodeNode* obj) {
 	ValaAttribute * self;
 	self = VALA_ATTRIBUTE (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->args == NULL) ? NULL : (self->args = (gee_collection_object_unref (self->args), NULL));
+	_g_free0 (self->priv->_name);
+	_gee_collection_object_unref0 (self->args);
 	VALA_CODE_NODE_CLASS (vala_attribute_parent_class)->finalize (obj);
 }
 
