@@ -137,12 +137,6 @@ typedef struct _ValaBreakStatementPrivate ValaBreakStatementPrivate;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -163,16 +157,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a break statement in the source code.
- */
 struct _ValaBreakStatement {
 	ValaCodeNode parent_instance;
 	ValaBreakStatementPrivate * priv;
@@ -209,6 +197,7 @@ GType vala_break_statement_get_type (void);
 enum  {
 	VALA_BREAK_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -223,16 +212,10 @@ static void vala_break_statement_real_accept (ValaCodeNode* base, ValaCodeVisito
 
 
 
-/**
- * Creates a new break statement.
- *
- * @param source reference to source code
- * @return       newly created break statement
- */
 ValaBreakStatement* vala_break_statement_construct (GType object_type, ValaSourceReference* source) {
 	ValaBreakStatement* self;
 	g_return_val_if_fail (source != NULL, NULL);
-	self = (ValaBreakStatement*) g_type_create_instance (object_type);
+	self = (ValaBreakStatement*) vala_code_node_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
