@@ -190,13 +190,10 @@ typedef struct _ValaClassClass ValaClassClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -217,10 +214,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -229,6 +222,7 @@ struct _ValaDataType {
 struct _ValaDataTypeClass {
 	ValaCodeNodeClass parent_class;
 	char* (*get_cname) (ValaDataType* self);
+	char* (*get_cdeclarator_suffix) (ValaDataType* self);
 	char* (*get_lower_case_cname) (ValaDataType* self, const char* infix);
 	char* (*to_qualified_string) (ValaDataType* self, ValaScope* scope);
 	ValaDataType* (*copy) (ValaDataType* self);
@@ -249,9 +243,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * A reference type, i.e. a class, interface, or array type.
- */
 struct _ValaReferenceType {
 	ValaDataType parent_instance;
 	ValaReferenceTypePrivate * priv;
@@ -261,9 +252,6 @@ struct _ValaReferenceTypeClass {
 	ValaDataTypeClass parent_class;
 };
 
-/**
- * A class type.
- */
 struct _ValaClassType {
 	ValaReferenceType parent_instance;
 	ValaClassTypePrivate * priv;
@@ -278,6 +266,7 @@ struct _ValaClassTypePrivate {
 };
 
 
+static gpointer vala_class_type_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -313,10 +302,10 @@ GType vala_class_get_type (void);
 enum  {
 	VALA_CLASS_TYPE_DUMMY_PROPERTY
 };
+ValaReferenceType* vala_reference_type_construct (GType object_type);
 void vala_class_type_set_class_symbol (ValaClassType* self, ValaClass* value);
 ValaClassType* vala_class_type_new (ValaClass* class_symbol);
 ValaClassType* vala_class_type_construct (GType object_type, ValaClass* class_symbol);
-ValaClassType* vala_class_type_new (ValaClass* class_symbol);
 ValaClass* vala_class_type_get_class_symbol (ValaClassType* self);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -340,7 +329,6 @@ ValaDataType* vala_data_type_copy (ValaDataType* self);
 static ValaDataType* vala_class_type_real_copy (ValaDataType* base);
 char* vala_typesymbol_get_cname (ValaTypeSymbol* self, gboolean const_type);
 static char* vala_class_type_real_get_cname (ValaDataType* base);
-static gpointer vala_class_type_parent_class = NULL;
 static void vala_class_type_finalize (ValaCodeNode* obj);
 
 
@@ -348,7 +336,7 @@ static void vala_class_type_finalize (ValaCodeNode* obj);
 ValaClassType* vala_class_type_construct (GType object_type, ValaClass* class_symbol) {
 	ValaClassType* self;
 	g_return_val_if_fail (class_symbol != NULL, NULL);
-	self = (ValaClassType*) g_type_create_instance (object_type);
+	self = (ValaClassType*) vala_reference_type_construct (object_type);
 	vala_class_type_set_class_symbol (self, class_symbol);
 	return self;
 }
@@ -361,50 +349,54 @@ ValaClassType* vala_class_type_new (ValaClass* class_symbol) {
 
 static ValaDataType* vala_class_type_real_copy (ValaDataType* base) {
 	ValaClassType * self;
-	ValaClassType* result;
+	ValaDataType* result;
+	ValaClassType* _result_;
 	self = (ValaClassType*) base;
-	result = vala_class_type_new (self->priv->_class_symbol);
-	vala_code_node_set_source_reference ((ValaCodeNode*) result, vala_code_node_get_source_reference ((ValaCodeNode*) self));
-	vala_data_type_set_value_owned ((ValaDataType*) result, vala_data_type_get_value_owned ((ValaDataType*) self));
-	vala_data_type_set_nullable ((ValaDataType*) result, vala_data_type_get_nullable ((ValaDataType*) self));
-	vala_data_type_set_is_dynamic ((ValaDataType*) result, vala_data_type_get_is_dynamic ((ValaDataType*) self));
-	vala_data_type_set_floating_reference ((ValaDataType*) result, vala_data_type_get_floating_reference ((ValaDataType*) self));
+	_result_ = vala_class_type_new (self->priv->_class_symbol);
+	vala_code_node_set_source_reference ((ValaCodeNode*) _result_, vala_code_node_get_source_reference ((ValaCodeNode*) self));
+	vala_data_type_set_value_owned ((ValaDataType*) _result_, vala_data_type_get_value_owned ((ValaDataType*) self));
+	vala_data_type_set_nullable ((ValaDataType*) _result_, vala_data_type_get_nullable ((ValaDataType*) self));
+	vala_data_type_set_is_dynamic ((ValaDataType*) _result_, vala_data_type_get_is_dynamic ((ValaDataType*) self));
+	vala_data_type_set_floating_reference ((ValaDataType*) _result_, vala_data_type_get_floating_reference ((ValaDataType*) self));
 	{
-		GeeList* _tmp0;
-		GeeIterator* _tmp1;
+		GeeList* _tmp0_;
+		GeeIterator* _tmp1_;
 		GeeIterator* _arg_it;
-		_tmp0 = NULL;
-		_tmp1 = NULL;
-		_arg_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
-		while (gee_iterator_next (_arg_it)) {
+		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
+		while (TRUE) {
 			ValaDataType* arg;
-			ValaDataType* _tmp2;
+			ValaDataType* _tmp2_;
+			if (!gee_iterator_next (_arg_it)) {
+				break;
+			}
 			arg = (ValaDataType*) gee_iterator_get (_arg_it);
-			_tmp2 = NULL;
-			vala_data_type_add_type_argument ((ValaDataType*) result, _tmp2 = vala_data_type_copy (arg));
-			(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
-			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+			vala_data_type_add_type_argument ((ValaDataType*) _result_, _tmp2_ = vala_data_type_copy (arg));
+			_vala_code_node_unref0 (_tmp2_);
+			_vala_code_node_unref0 (arg);
 		}
-		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
+		_gee_collection_object_unref0 (_arg_it);
 	}
-	return (ValaDataType*) result;
+	result = (ValaDataType*) _result_;
+	return result;
 }
 
 
 static char* vala_class_type_real_get_cname (ValaDataType* base) {
 	ValaClassType * self;
-	char* _tmp0;
-	char* _tmp1;
+	char* result;
+	char* _tmp0_;
+	char* _tmp1_;
 	self = (ValaClassType*) base;
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%sClass*", _tmp0 = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_symbol, FALSE)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	result = (_tmp1_ = g_strdup_printf ("%sClass*", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_symbol, FALSE)), _g_free0 (_tmp0_), _tmp1_);
+	return result;
 }
 
 
 ValaClass* vala_class_type_get_class_symbol (ValaClassType* self) {
+	ValaClass* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_class_symbol;
+	result = self->priv->_class_symbol;
+	return result;
 }
 
 
