@@ -846,9 +846,6 @@ typedef struct _ValaCodeGeneratorPrivate ValaCodeGeneratorPrivate;
 typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -935,9 +932,6 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Abstract code visitor generating code.
- */
 struct _ValaCodeGenerator {
 	ValaCodeVisitor parent_instance;
 	ValaCodeGeneratorPrivate * priv;
@@ -1058,16 +1052,12 @@ enum  {
 };
 void vala_code_generator_emit (ValaCodeGenerator* self, ValaCodeContext* context);
 static void vala_code_generator_real_emit (ValaCodeGenerator* self, ValaCodeContext* context);
+ValaCodeVisitor* vala_code_visitor_construct (GType object_type);
 ValaCodeGenerator* vala_code_generator_new (void);
 ValaCodeGenerator* vala_code_generator_construct (GType object_type);
 
 
 
-/**
- * Generate and emit C code for the specified code context.
- *
- * @param context a code context
- */
 static void vala_code_generator_real_emit (ValaCodeGenerator* self, ValaCodeContext* context) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (context != NULL);
@@ -1079,12 +1069,9 @@ void vala_code_generator_emit (ValaCodeGenerator* self, ValaCodeContext* context
 }
 
 
-/**
- * Abstract code visitor generating code.
- */
 ValaCodeGenerator* vala_code_generator_construct (GType object_type) {
 	ValaCodeGenerator* self;
-	self = (ValaCodeGenerator*) g_type_create_instance (object_type);
+	self = (ValaCodeGenerator*) vala_code_visitor_construct (object_type);
 	return self;
 }
 
