@@ -137,12 +137,6 @@ typedef struct _ValaContinueStatementPrivate ValaContinueStatementPrivate;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -163,16 +157,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a continue statement in the source code.
- */
 struct _ValaContinueStatement {
 	ValaCodeNode parent_instance;
 	ValaContinueStatementPrivate * priv;
@@ -209,6 +197,7 @@ GType vala_continue_statement_get_type (void);
 enum  {
 	VALA_CONTINUE_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -218,22 +207,15 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source);
 ValaContinueStatement* vala_continue_statement_construct (GType object_type, ValaSourceReference* source);
-ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source);
 void vala_code_visitor_visit_continue_statement (ValaCodeVisitor* self, ValaContinueStatement* stmt);
 static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 
 
 
-/**
- * Creates a new continue statement.
- *
- * @param source reference to source code
- * @return       newly created continue statement
- */
 ValaContinueStatement* vala_continue_statement_construct (GType object_type, ValaSourceReference* source) {
 	ValaContinueStatement* self;
 	g_return_val_if_fail (source != NULL, NULL);
-	self = (ValaContinueStatement*) g_type_create_instance (object_type);
+	self = (ValaContinueStatement*) vala_code_node_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
