@@ -1,6 +1,6 @@
 /* valadeclarationstatement.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -126,6 +126,7 @@ typedef struct _ValaStatementIface ValaStatementIface;
 typedef struct _ValaDeclarationStatement ValaDeclarationStatement;
 typedef struct _ValaDeclarationStatementClass ValaDeclarationStatementClass;
 typedef struct _ValaDeclarationStatementPrivate ValaDeclarationStatementPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -136,13 +137,28 @@ typedef struct _ValaDeclarationStatementPrivate ValaDeclarationStatementPrivate;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+
+#define VALA_TYPE_REFERENCE_TYPE (vala_reference_type_get_type ())
+#define VALA_REFERENCE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_REFERENCE_TYPE, ValaReferenceType))
+#define VALA_REFERENCE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_REFERENCE_TYPE, ValaReferenceTypeClass))
+#define VALA_IS_REFERENCE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_REFERENCE_TYPE))
+#define VALA_IS_REFERENCE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_REFERENCE_TYPE))
+#define VALA_REFERENCE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_REFERENCE_TYPE, ValaReferenceTypeClass))
+
+typedef struct _ValaReferenceType ValaReferenceType;
+typedef struct _ValaReferenceTypeClass ValaReferenceTypeClass;
+
+#define VALA_TYPE_ARRAY_TYPE (vala_array_type_get_type ())
+#define VALA_ARRAY_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ARRAY_TYPE, ValaArrayType))
+#define VALA_ARRAY_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ARRAY_TYPE, ValaArrayTypeClass))
+#define VALA_IS_ARRAY_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ARRAY_TYPE))
+#define VALA_IS_ARRAY_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ARRAY_TYPE))
+#define VALA_ARRAY_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ARRAY_TYPE, ValaArrayTypeClass))
+
+typedef struct _ValaArrayType ValaArrayType;
+typedef struct _ValaArrayTypeClass ValaArrayTypeClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -163,16 +179,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a local variable or constant declaration statement in the source code.
- */
 struct _ValaDeclarationStatement {
 	ValaCodeNode parent_instance;
 	ValaDeclarationStatementPrivate * priv;
@@ -214,6 +224,7 @@ GType vala_declaration_statement_get_type (void);
 enum  {
 	VALA_DECLARATION_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaSymbol* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -224,7 +235,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaDeclarationStatement* vala_declaration_statement_new (ValaSymbol* declaration, ValaSourceReference* source_reference);
 ValaDeclarationStatement* vala_declaration_statement_construct (GType object_type, ValaSymbol* declaration, ValaSourceReference* source_reference);
-ValaDeclarationStatement* vala_declaration_statement_new (ValaSymbol* declaration, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_declaration_statement (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
 static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaSymbol* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self);
@@ -240,7 +250,11 @@ ValaDataType* vala_data_type_copy (ValaDataType* self);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
 void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type);
 static gboolean vala_declaration_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
+ValaDataType* vala_local_variable_get_variable_type (ValaLocalVariable* self);
+GType vala_reference_type_get_type (void);
+GType vala_array_type_get_type (void);
 void vala_code_node_get_defined_variables (ValaCodeNode* self, GeeCollection* collection);
+gboolean vala_array_type_get_fixed_length (ValaArrayType* self);
 static void vala_declaration_statement_real_get_defined_variables (ValaCodeNode* base, GeeCollection* collection);
 void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* collection);
 static void vala_declaration_statement_real_get_used_variables (ValaCodeNode* base, GeeCollection* collection);
@@ -249,17 +263,10 @@ static void vala_declaration_statement_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new declaration statement.
- *
- * @param decl   local variable declaration
- * @param source reference to source code
- * @return       newly created declaration statement
- */
 ValaDeclarationStatement* vala_declaration_statement_construct (GType object_type, ValaSymbol* declaration, ValaSourceReference* source_reference) {
 	ValaDeclarationStatement* self;
 	g_return_val_if_fail (declaration != NULL, NULL);
-	self = (ValaDeclarationStatement*) g_type_create_instance (object_type);
+	self = (ValaDeclarationStatement*) vala_code_node_construct (object_type);
 	vala_declaration_statement_set_declaration (self, declaration);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
@@ -287,13 +294,17 @@ static void vala_declaration_statement_real_accept_children (ValaCodeNode* base,
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_declaration_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaDeclarationStatement * self;
 	gboolean result;
-	ValaLocalVariable* _tmp1_;
 	ValaSymbol* _tmp0_;
 	ValaLocalVariable* local;
-	gboolean _tmp2_;
+	gboolean _tmp1_;
 	self = (ValaDeclarationStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -302,23 +313,19 @@ static gboolean vala_declaration_statement_real_check (ValaCodeNode* base, ValaS
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_code_node_check ((ValaCodeNode*) vala_declaration_statement_get_declaration (self), analyzer);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	local = (_tmp1_ = (_tmp0_ = vala_declaration_statement_get_declaration (self), VALA_IS_LOCAL_VARIABLE (_tmp0_) ? ((ValaLocalVariable*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-	_tmp2_ = FALSE;
+	local = _vala_code_node_ref0 ((_tmp0_ = vala_declaration_statement_get_declaration (self), VALA_IS_LOCAL_VARIABLE (_tmp0_) ? ((ValaLocalVariable*) _tmp0_) : NULL));
+	_tmp1_ = FALSE;
 	if (local != NULL) {
-		_tmp2_ = vala_local_variable_get_initializer (local) != NULL;
+		_tmp1_ = vala_local_variable_get_initializer (local) != NULL;
 	} else {
-		_tmp2_ = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp2_) {
+	if (_tmp1_) {
 		{
-			GeeList* _tmp3_;
-			GeeIterator* _tmp4_;
+			GeeList* _tmp2_;
+			GeeIterator* _tmp3_;
 			GeeIterator* _error_type_it;
-			_tmp3_ = NULL;
-			_tmp4_ = NULL;
-			_error_type_it = (_tmp4_ = gee_iterable_iterator ((GeeIterable*) (_tmp3_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_local_variable_get_initializer (local)))), (_tmp3_ == NULL) ? NULL : (_tmp3_ = (gee_collection_object_unref (_tmp3_), NULL)), _tmp4_);
+			_error_type_it = (_tmp3_ = gee_iterable_iterator ((GeeIterable*) (_tmp2_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_local_variable_get_initializer (local)))), _gee_collection_object_unref0 (_tmp2_), _tmp3_);
 			while (TRUE) {
 				ValaDataType* error_type;
 				ValaDataType* initializer_error_type;
@@ -326,68 +333,71 @@ static gboolean vala_declaration_statement_real_check (ValaCodeNode* base, ValaS
 					break;
 				}
 				error_type = (ValaDataType*) gee_iterator_get (_error_type_it);
-				/* ensure we can trace back which expression may throw errors of this type*/
 				initializer_error_type = vala_data_type_copy (error_type);
 				vala_code_node_set_source_reference ((ValaCodeNode*) initializer_error_type, vala_code_node_get_source_reference ((ValaCodeNode*) vala_local_variable_get_initializer (local)));
 				vala_code_node_add_error_type ((ValaCodeNode*) self, initializer_error_type);
-				(error_type == NULL) ? NULL : (error_type = (vala_code_node_unref (error_type), NULL));
-				(initializer_error_type == NULL) ? NULL : (initializer_error_type = (vala_code_node_unref (initializer_error_type), NULL));
+				_vala_code_node_unref0 (error_type);
+				_vala_code_node_unref0 (initializer_error_type);
 			}
-			(_error_type_it == NULL) ? NULL : (_error_type_it = (gee_collection_object_unref (_error_type_it), NULL));
+			_gee_collection_object_unref0 (_error_type_it);
 		}
 	}
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
-	(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+	_vala_code_node_unref0 (local);
 	return result;
 }
 
 
 static void vala_declaration_statement_real_get_defined_variables (ValaCodeNode* base, GeeCollection* collection) {
 	ValaDeclarationStatement * self;
-	ValaLocalVariable* _tmp1_;
 	ValaSymbol* _tmp0_;
 	ValaLocalVariable* local;
-	gboolean _tmp2_;
 	self = (ValaDeclarationStatement*) base;
 	g_return_if_fail (collection != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	local = (_tmp1_ = (_tmp0_ = vala_declaration_statement_get_declaration (self), VALA_IS_LOCAL_VARIABLE (_tmp0_) ? ((ValaLocalVariable*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-	_tmp2_ = FALSE;
+	local = _vala_code_node_ref0 ((_tmp0_ = vala_declaration_statement_get_declaration (self), VALA_IS_LOCAL_VARIABLE (_tmp0_) ? ((ValaLocalVariable*) _tmp0_) : NULL));
 	if (local != NULL) {
-		_tmp2_ = vala_local_variable_get_initializer (local) != NULL;
-	} else {
-		_tmp2_ = FALSE;
+		ValaDataType* _tmp1_;
+		ValaArrayType* array_type;
+		array_type = _vala_code_node_ref0 ((_tmp1_ = vala_local_variable_get_variable_type (local), VALA_IS_ARRAY_TYPE (_tmp1_) ? ((ValaArrayType*) _tmp1_) : NULL));
+		if (vala_local_variable_get_initializer (local) != NULL) {
+			vala_code_node_get_defined_variables ((ValaCodeNode*) vala_local_variable_get_initializer (local), collection);
+			gee_collection_add (collection, local);
+		} else {
+			gboolean _tmp2_;
+			_tmp2_ = FALSE;
+			if (array_type != NULL) {
+				_tmp2_ = vala_array_type_get_fixed_length (array_type);
+			} else {
+				_tmp2_ = FALSE;
+			}
+			if (_tmp2_) {
+				gee_collection_add (collection, local);
+			}
+		}
+		_vala_code_node_unref0 (array_type);
 	}
-	if (_tmp2_) {
-		vala_code_node_get_defined_variables ((ValaCodeNode*) vala_local_variable_get_initializer (local), collection);
-		gee_collection_add (collection, local);
-	}
-	(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+	_vala_code_node_unref0 (local);
 }
 
 
 static void vala_declaration_statement_real_get_used_variables (ValaCodeNode* base, GeeCollection* collection) {
 	ValaDeclarationStatement * self;
-	ValaLocalVariable* _tmp1_;
 	ValaSymbol* _tmp0_;
 	ValaLocalVariable* local;
-	gboolean _tmp2_;
+	gboolean _tmp1_;
 	self = (ValaDeclarationStatement*) base;
 	g_return_if_fail (collection != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	local = (_tmp1_ = (_tmp0_ = vala_declaration_statement_get_declaration (self), VALA_IS_LOCAL_VARIABLE (_tmp0_) ? ((ValaLocalVariable*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-	_tmp2_ = FALSE;
+	local = _vala_code_node_ref0 ((_tmp0_ = vala_declaration_statement_get_declaration (self), VALA_IS_LOCAL_VARIABLE (_tmp0_) ? ((ValaLocalVariable*) _tmp0_) : NULL));
+	_tmp1_ = FALSE;
 	if (local != NULL) {
-		_tmp2_ = vala_local_variable_get_initializer (local) != NULL;
+		_tmp1_ = vala_local_variable_get_initializer (local) != NULL;
 	} else {
-		_tmp2_ = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp2_) {
+	if (_tmp1_) {
 		vala_code_node_get_used_variables ((ValaCodeNode*) vala_local_variable_get_initializer (local), collection);
 	}
-	(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+	_vala_code_node_unref0 (local);
 }
 
 
@@ -400,12 +410,9 @@ ValaSymbol* vala_declaration_statement_get_declaration (ValaDeclarationStatement
 
 
 void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaSymbol* value) {
-	ValaSymbol* _tmp1_;
 	ValaSymbol* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_declaration = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_declaration == NULL) ? NULL : (self->priv->_declaration = (vala_code_node_unref (self->priv->_declaration), NULL)), _tmp1_);
+	self->priv->_declaration = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_declaration), _tmp0_);
 	if (self->priv->_declaration != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_declaration, (ValaCodeNode*) self);
 	}
@@ -437,7 +444,7 @@ static void vala_declaration_statement_instance_init (ValaDeclarationStatement *
 static void vala_declaration_statement_finalize (ValaCodeNode* obj) {
 	ValaDeclarationStatement * self;
 	self = VALA_DECLARATION_STATEMENT (obj);
-	(self->priv->_declaration == NULL) ? NULL : (self->priv->_declaration = (vala_code_node_unref (self->priv->_declaration), NULL));
+	_vala_code_node_unref0 (self->priv->_declaration);
 	VALA_CODE_NODE_CLASS (vala_declaration_statement_parent_class)->finalize (obj);
 }
 
