@@ -126,6 +126,7 @@ typedef struct _ValaStatementIface ValaStatementIface;
 typedef struct _ValaDeleteStatement ValaDeleteStatement;
 typedef struct _ValaDeleteStatementClass ValaDeleteStatementClass;
 typedef struct _ValaDeleteStatementPrivate ValaDeleteStatementPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -146,13 +147,8 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
 typedef struct _ValaPointerType ValaPointerType;
 typedef struct _ValaPointerTypeClass ValaPointerTypeClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -173,16 +169,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a delete statement e.g. "delete a".
- */
 struct _ValaDeleteStatement {
 	ValaCodeNode parent_instance;
 	ValaDeleteStatementPrivate * priv;
@@ -224,6 +214,7 @@ GType vala_delete_statement_get_type (void);
 enum  {
 	VALA_DELETE_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_delete_statement_set_expression (ValaDeleteStatement* self, ValaExpression* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -257,7 +248,7 @@ static void vala_delete_statement_finalize (ValaCodeNode* obj);
 ValaDeleteStatement* vala_delete_statement_construct (GType object_type, ValaExpression* expression, ValaSourceReference* source_reference) {
 	ValaDeleteStatement* self;
 	g_return_val_if_fail (expression != NULL, NULL);
-	self = (ValaDeleteStatement*) g_type_create_instance (object_type);
+	self = (ValaDeleteStatement*) vala_code_node_construct (object_type);
 	vala_delete_statement_set_expression (self, expression);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
@@ -296,7 +287,6 @@ static gboolean vala_delete_statement_real_check (ValaCodeNode* base, ValaSemant
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (!vala_code_node_check ((ValaCodeNode*) self->priv->_expression, analyzer)) {
-		/* if there was an error in the inner expression, skip this check*/
 		result = FALSE;
 		return result;
 	}
@@ -304,11 +294,9 @@ static gboolean vala_delete_statement_real_check (ValaCodeNode* base, ValaSemant
 		char* _tmp1_;
 		char* _tmp0_;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp1_ = g_strdup_printf ("delete operator not supported for `%s'", _tmp0_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (self->priv->_expression))));
-		_tmp1_ = (g_free (_tmp1_), NULL);
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		_g_free0 (_tmp1_);
+		_g_free0 (_tmp0_);
 	}
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
 	return result;
@@ -323,13 +311,15 @@ ValaExpression* vala_delete_statement_get_expression (ValaDeleteStatement* self)
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_delete_statement_set_expression (ValaDeleteStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp1_);
+	self->priv->_expression = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_expression), _tmp0_);
 }
 
 
@@ -356,7 +346,7 @@ static void vala_delete_statement_instance_init (ValaDeleteStatement * self) {
 static void vala_delete_statement_finalize (ValaCodeNode* obj) {
 	ValaDeleteStatement * self;
 	self = VALA_DELETE_STATEMENT (obj);
-	(self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL));
+	_vala_code_node_unref0 (self->priv->_expression);
 	VALA_CODE_NODE_CLASS (vala_delete_statement_parent_class)->finalize (obj);
 }
 
