@@ -136,6 +136,7 @@ typedef struct _ValaDoStatementPrivate ValaDoStatementPrivate;
 
 typedef struct _ValaBlock ValaBlock;
 typedef struct _ValaBlockClass ValaBlockClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -888,17 +889,12 @@ typedef struct _ValaValueTypeClass ValaValueTypeClass;
 
 typedef struct _ValaStructValueType ValaStructValueType;
 typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_UNARY_OPERATOR (vala_unary_operator_get_type ())
 
 #define VALA_TYPE_ASSIGNMENT_OPERATOR (vala_assignment_operator_get_type ())
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -919,16 +915,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a do iteration statement in the source code.
- */
 struct _ValaDoStatement {
 	ValaCodeNode parent_instance;
 	ValaDoStatementPrivate * priv;
@@ -943,9 +933,6 @@ struct _ValaDoStatementPrivate {
 	ValaBlock* _body;
 };
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -1032,17 +1019,12 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Code visitor analyzing and checking code.
- */
 struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 	ValaSymbol* root_symbol;
-	ValaDataType* current_return_type;
-	ValaClass* current_class;
-	ValaStruct* current_struct;
 	ValaBlock* insert_block;
+	ValaDataType* void_type;
 	ValaDataType* bool_type;
 	ValaDataType* string_type;
 	ValaDataType* uchar_type;
@@ -1129,6 +1111,7 @@ GType vala_block_get_type (void);
 enum  {
 	VALA_DO_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_do_statement_set_condition (ValaDoStatement* self, ValaExpression* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -1267,19 +1250,11 @@ static void vala_do_statement_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new do statement.
- *
- * @param cond   loop condition
- * @param body   loop body
- * @param source reference to source code
- * @return       newly created do statement
- */
 ValaDoStatement* vala_do_statement_construct (GType object_type, ValaBlock* body, ValaExpression* condition, ValaSourceReference* source_reference) {
 	ValaDoStatement* self;
 	g_return_val_if_fail (body != NULL, NULL);
 	g_return_val_if_fail (condition != NULL, NULL);
-	self = (ValaDoStatement*) g_type_create_instance (object_type);
+	self = (ValaDoStatement*) vala_code_node_construct (object_type);
 	vala_do_statement_set_condition (self, condition);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	vala_do_statement_set_body (self, body);
@@ -1310,25 +1285,27 @@ static void vala_do_statement_real_accept_children (ValaCodeNode* base, ValaCode
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_do_statement_always_true (ValaDoStatement* self, ValaExpression* condition) {
 	gboolean result;
-	ValaBooleanLiteral* _tmp1_;
 	ValaExpression* _tmp0_;
 	ValaBooleanLiteral* literal;
-	gboolean _tmp2_;
+	gboolean _tmp1_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (condition != NULL, FALSE);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	literal = (_tmp1_ = (_tmp0_ = condition, VALA_IS_BOOLEAN_LITERAL (_tmp0_) ? ((ValaBooleanLiteral*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-	_tmp2_ = FALSE;
+	literal = _vala_code_node_ref0 ((_tmp0_ = condition, VALA_IS_BOOLEAN_LITERAL (_tmp0_) ? ((ValaBooleanLiteral*) _tmp0_) : NULL));
+	_tmp1_ = FALSE;
 	if (literal != NULL) {
-		_tmp2_ = vala_boolean_literal_get_value (literal);
+		_tmp1_ = vala_boolean_literal_get_value (literal);
 	} else {
-		_tmp2_ = FALSE;
+		_tmp1_ = FALSE;
 	}
-	result = _tmp2_;
-	(literal == NULL) ? NULL : (literal = (vala_code_node_unref (literal), NULL));
+	result = _tmp1_;
+	_vala_code_node_unref0 (literal);
 	return result;
 }
 
@@ -1337,91 +1314,71 @@ static gboolean vala_do_statement_real_check (ValaCodeNode* base, ValaSemanticAn
 	ValaDoStatement * self;
 	gboolean result;
 	ValaBlock* block;
-	ValaBooleanLiteral* _tmp3_;
-	char* _tmp2_;
-	ValaDataType* _tmp1_;
-	ValaLocalVariable* _tmp4_;
+	ValaBooleanLiteral* _tmp2_;
+	char* _tmp1_;
+	ValaDataType* _tmp0_;
+	ValaLocalVariable* _tmp3_;
 	ValaLocalVariable* first_local;
-	ValaDeclarationStatement* _tmp5_;
+	ValaDeclarationStatement* _tmp4_;
 	ValaUnaryExpression* if_condition;
 	ValaBlock* true_block;
-	ValaBreakStatement* _tmp6_;
+	ValaBreakStatement* _tmp5_;
 	ValaIfStatement* if_stmt;
 	ValaBlock* condition_block;
-	ValaUnaryExpression* _tmp8_;
-	ValaMemberAccess* _tmp7_;
-	ValaIfStatement* _tmp9_;
+	ValaUnaryExpression* _tmp7_;
+	ValaMemberAccess* _tmp6_;
+	ValaIfStatement* _tmp8_;
 	ValaIfStatement* first_if;
-	ValaExpressionStatement* _tmp13_;
-	ValaAssignment* _tmp12_;
-	ValaBooleanLiteral* _tmp11_;
-	ValaMemberAccess* _tmp10_;
-	ValaLoop* _tmp14_;
-	ValaBlock* _tmp15_;
+	ValaExpressionStatement* _tmp12_;
+	ValaAssignment* _tmp11_;
+	ValaBooleanLiteral* _tmp10_;
+	ValaMemberAccess* _tmp9_;
+	ValaLoop* _tmp13_;
 	ValaBlock* parent_block;
 	self = (ValaDoStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
-	/* convert to simple loop
-	 do not generate variable and if block if condition is always true*/
 	if (vala_do_statement_always_true (self, vala_do_statement_get_condition (self))) {
 		ValaLoop* loop;
-		ValaBlock* _tmp0_;
 		ValaBlock* parent_block;
 		loop = vala_loop_new (vala_do_statement_get_body (self), vala_code_node_get_source_reference ((ValaCodeNode*) self));
-		_tmp0_ = NULL;
-		parent_block = (_tmp0_ = VALA_BLOCK (vala_code_node_get_parent_node ((ValaCodeNode*) self)), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+		parent_block = _vala_code_node_ref0 (VALA_BLOCK (vala_code_node_get_parent_node ((ValaCodeNode*) self)));
 		vala_block_replace_statement (parent_block, (ValaStatement*) self, (ValaStatement*) loop);
 		result = vala_code_node_check ((ValaCodeNode*) loop, analyzer);
-		(loop == NULL) ? NULL : (loop = (vala_code_node_unref (loop), NULL));
-		(parent_block == NULL) ? NULL : (parent_block = (vala_code_node_unref (parent_block), NULL));
+		_vala_code_node_unref0 (loop);
+		_vala_code_node_unref0 (parent_block);
 		return result;
 	}
 	block = vala_block_new (vala_code_node_get_source_reference ((ValaCodeNode*) self));
-	_tmp3_ = NULL;
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	_tmp4_ = NULL;
-	first_local = (_tmp4_ = vala_local_variable_new (_tmp1_ = vala_data_type_copy (analyzer->bool_type), _tmp2_ = vala_code_node_get_temp_name ((ValaCodeNode*) self), (ValaExpression*) (_tmp3_ = vala_boolean_literal_new (TRUE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self)), (_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_node_unref (_tmp3_), NULL)), _tmp2_ = (g_free (_tmp2_), NULL), (_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL)), _tmp4_);
-	_tmp5_ = NULL;
-	vala_block_add_statement (block, (ValaStatement*) (_tmp5_ = vala_declaration_statement_new ((ValaSymbol*) first_local, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp5_ == NULL) ? NULL : (_tmp5_ = (vala_code_node_unref (_tmp5_), NULL));
+	first_local = (_tmp3_ = vala_local_variable_new (_tmp0_ = vala_data_type_copy (analyzer->bool_type), _tmp1_ = vala_code_node_get_temp_name ((ValaCodeNode*) self), (ValaExpression*) (_tmp2_ = vala_boolean_literal_new (TRUE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self)), _vala_code_node_unref0 (_tmp2_), _g_free0 (_tmp1_), _vala_code_node_unref0 (_tmp0_), _tmp3_);
+	vala_block_add_statement (block, (ValaStatement*) (_tmp4_ = vala_declaration_statement_new ((ValaSymbol*) first_local, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	_vala_code_node_unref0 (_tmp4_);
 	if_condition = vala_unary_expression_new (VALA_UNARY_OPERATOR_LOGICAL_NEGATION, vala_do_statement_get_condition (self), vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)));
 	true_block = vala_block_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)));
-	_tmp6_ = NULL;
-	vala_block_add_statement (true_block, (ValaStatement*) (_tmp6_ = vala_break_statement_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)))));
-	(_tmp6_ == NULL) ? NULL : (_tmp6_ = (vala_code_node_unref (_tmp6_), NULL));
+	vala_block_add_statement (true_block, (ValaStatement*) (_tmp5_ = vala_break_statement_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)))));
+	_vala_code_node_unref0 (_tmp5_);
 	if_stmt = vala_if_statement_new ((ValaExpression*) if_condition, true_block, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)));
 	condition_block = vala_block_new (vala_code_node_get_source_reference ((ValaCodeNode*) vala_do_statement_get_condition (self)));
 	vala_block_add_statement (condition_block, (ValaStatement*) if_stmt);
-	_tmp8_ = NULL;
-	_tmp7_ = NULL;
-	_tmp9_ = NULL;
-	first_if = (_tmp9_ = vala_if_statement_new ((ValaExpression*) (_tmp8_ = vala_unary_expression_new (VALA_UNARY_OPERATOR_LOGICAL_NEGATION, (ValaExpression*) (_tmp7_ = vala_member_access_new_simple (vala_symbol_get_name ((ValaSymbol*) first_local), vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self))), condition_block, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self)), (_tmp8_ == NULL) ? NULL : (_tmp8_ = (vala_code_node_unref (_tmp8_), NULL)), (_tmp7_ == NULL) ? NULL : (_tmp7_ = (vala_code_node_unref (_tmp7_), NULL)), _tmp9_);
+	first_if = (_tmp8_ = vala_if_statement_new ((ValaExpression*) (_tmp7_ = vala_unary_expression_new (VALA_UNARY_OPERATOR_LOGICAL_NEGATION, (ValaExpression*) (_tmp6_ = vala_member_access_new_simple (vala_symbol_get_name ((ValaSymbol*) first_local), vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self))), condition_block, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self)), _vala_code_node_unref0 (_tmp7_), _vala_code_node_unref0 (_tmp6_), _tmp8_);
 	vala_block_insert_statement (vala_do_statement_get_body (self), 0, (ValaStatement*) first_if);
-	_tmp13_ = NULL;
-	_tmp12_ = NULL;
-	_tmp11_ = NULL;
-	_tmp10_ = NULL;
-	vala_block_insert_statement (vala_do_statement_get_body (self), 1, (ValaStatement*) (_tmp13_ = vala_expression_statement_new ((ValaExpression*) (_tmp12_ = vala_assignment_new ((ValaExpression*) (_tmp10_ = vala_member_access_new_simple (vala_symbol_get_name ((ValaSymbol*) first_local), vala_code_node_get_source_reference ((ValaCodeNode*) self))), (ValaExpression*) (_tmp11_ = vala_boolean_literal_new (FALSE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), VALA_ASSIGNMENT_OPERATOR_SIMPLE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp13_ == NULL) ? NULL : (_tmp13_ = (vala_code_node_unref (_tmp13_), NULL));
-	(_tmp12_ == NULL) ? NULL : (_tmp12_ = (vala_code_node_unref (_tmp12_), NULL));
-	(_tmp11_ == NULL) ? NULL : (_tmp11_ = (vala_code_node_unref (_tmp11_), NULL));
-	(_tmp10_ == NULL) ? NULL : (_tmp10_ = (vala_code_node_unref (_tmp10_), NULL));
-	_tmp14_ = NULL;
-	vala_block_add_statement (block, (ValaStatement*) (_tmp14_ = vala_loop_new (vala_do_statement_get_body (self), vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp14_ == NULL) ? NULL : (_tmp14_ = (vala_code_node_unref (_tmp14_), NULL));
-	_tmp15_ = NULL;
-	parent_block = (_tmp15_ = VALA_BLOCK (vala_code_node_get_parent_node ((ValaCodeNode*) self)), (_tmp15_ == NULL) ? NULL : vala_code_node_ref (_tmp15_));
+	vala_block_insert_statement (vala_do_statement_get_body (self), 1, (ValaStatement*) (_tmp12_ = vala_expression_statement_new ((ValaExpression*) (_tmp11_ = vala_assignment_new ((ValaExpression*) (_tmp9_ = vala_member_access_new_simple (vala_symbol_get_name ((ValaSymbol*) first_local), vala_code_node_get_source_reference ((ValaCodeNode*) self))), (ValaExpression*) (_tmp10_ = vala_boolean_literal_new (FALSE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), VALA_ASSIGNMENT_OPERATOR_SIMPLE, vala_code_node_get_source_reference ((ValaCodeNode*) self))), vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	_vala_code_node_unref0 (_tmp12_);
+	_vala_code_node_unref0 (_tmp11_);
+	_vala_code_node_unref0 (_tmp10_);
+	_vala_code_node_unref0 (_tmp9_);
+	vala_block_add_statement (block, (ValaStatement*) (_tmp13_ = vala_loop_new (vala_do_statement_get_body (self), vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+	_vala_code_node_unref0 (_tmp13_);
+	parent_block = _vala_code_node_ref0 (VALA_BLOCK (vala_code_node_get_parent_node ((ValaCodeNode*) self)));
 	vala_block_replace_statement (parent_block, (ValaStatement*) self, (ValaStatement*) block);
 	result = vala_code_node_check ((ValaCodeNode*) block, analyzer);
-	(block == NULL) ? NULL : (block = (vala_code_node_unref (block), NULL));
-	(first_local == NULL) ? NULL : (first_local = (vala_code_node_unref (first_local), NULL));
-	(if_condition == NULL) ? NULL : (if_condition = (vala_code_node_unref (if_condition), NULL));
-	(true_block == NULL) ? NULL : (true_block = (vala_code_node_unref (true_block), NULL));
-	(if_stmt == NULL) ? NULL : (if_stmt = (vala_code_node_unref (if_stmt), NULL));
-	(condition_block == NULL) ? NULL : (condition_block = (vala_code_node_unref (condition_block), NULL));
-	(first_if == NULL) ? NULL : (first_if = (vala_code_node_unref (first_if), NULL));
-	(parent_block == NULL) ? NULL : (parent_block = (vala_code_node_unref (parent_block), NULL));
+	_vala_code_node_unref0 (block);
+	_vala_code_node_unref0 (first_local);
+	_vala_code_node_unref0 (if_condition);
+	_vala_code_node_unref0 (true_block);
+	_vala_code_node_unref0 (if_stmt);
+	_vala_code_node_unref0 (condition_block);
+	_vala_code_node_unref0 (first_if);
+	_vala_code_node_unref0 (parent_block);
 	return result;
 }
 
@@ -1435,12 +1392,9 @@ ValaBlock* vala_do_statement_get_body (ValaDoStatement* self) {
 
 
 void vala_do_statement_set_body (ValaDoStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp1_;
 	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_body = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp1_);
+	self->priv->_body = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_body), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_body, (ValaCodeNode*) self);
 }
 
@@ -1454,12 +1408,9 @@ ValaExpression* vala_do_statement_get_condition (ValaDoStatement* self) {
 
 
 void vala_do_statement_set_condition (ValaDoStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_condition = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp1_);
+	self->priv->_condition = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_condition), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_condition, (ValaCodeNode*) self);
 }
 
@@ -1487,8 +1438,8 @@ static void vala_do_statement_instance_init (ValaDoStatement * self) {
 static void vala_do_statement_finalize (ValaCodeNode* obj) {
 	ValaDoStatement * self;
 	self = VALA_DO_STATEMENT (obj);
-	(self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL));
-	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL));
+	_vala_code_node_unref0 (self->priv->_condition);
+	_vala_code_node_unref0 (self->priv->_body);
 	VALA_CODE_NODE_CLASS (vala_do_statement_parent_class)->finalize (obj);
 }
 
