@@ -160,6 +160,8 @@ typedef struct _ValaMemberClass ValaMemberClass;
 
 typedef struct _ValaMethod ValaMethod;
 typedef struct _ValaMethodClass ValaMethodClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -171,6 +173,16 @@ typedef struct _ValaMethodClass ValaMethodClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+
 #define VALA_TYPE_SCOPE (vala_scope_get_type ())
 #define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
 #define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
@@ -222,6 +234,7 @@ typedef struct _ValaEnumValueTypeClass ValaEnumValueTypeClass;
 
 typedef struct _ValaFormalParameter ValaFormalParameter;
 typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
 #define VALA_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFile))
@@ -232,13 +245,8 @@ typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
 
 typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
+#define _vala_source_file_unref0(var) ((var == NULL) ? NULL : (var = (vala_source_file_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -259,9 +267,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -277,10 +282,6 @@ struct _ValaSymbolClass {
 	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a runtime data type. This data type may be defined in Vala source
- * code or imported from an external library with a Vala API file.
- */
 struct _ValaTypeSymbol {
 	ValaSymbol parent_instance;
 	ValaTypeSymbolPrivate * priv;
@@ -310,9 +311,6 @@ struct _ValaTypeSymbolClass {
 	char* (*get_type_signature) (ValaTypeSymbol* self);
 };
 
-/**
- * Represents an enum declaration in the source code.
- */
 struct _ValaEnum {
 	ValaTypeSymbol parent_instance;
 	ValaEnumPrivate * priv;
@@ -376,10 +374,15 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaTypeSymbol* vala_typesymbol_new (const char* name, ValaSourceReference* source_reference);
-ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference);
-ValaEnum* vala_enum_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
+ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
+ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference, ValaComment* comment);
+ValaEnum* vala_enum_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
 gpointer vala_scope_ref (gpointer instance);
 void vala_scope_unref (gpointer instance);
 GParamSpec* vala_param_spec_scope (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -468,31 +471,19 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-/**
- * Creates a new enum.
- *
- * @param name             type name
- * @param source_reference reference to source code
- * @return                 newly created enum
- */
-ValaEnum* vala_enum_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+ValaEnum* vala_enum_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment) {
 	ValaEnum* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaEnum*) vala_typesymbol_construct (object_type, name, source_reference);
+	self = (ValaEnum*) vala_typesymbol_construct (object_type, name, source_reference, comment);
 	return self;
 }
 
 
-ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference) {
-	return vala_enum_construct (VALA_TYPE_ENUM, name, source_reference);
+ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference, ValaComment* comment) {
+	return vala_enum_construct (VALA_TYPE_ENUM, name, source_reference, comment);
 }
 
 
-/**
- * Appends the specified enum value to the list of values.
- *
- * @param value an enum value
- */
 void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (value != NULL);
@@ -501,11 +492,6 @@ void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value) {
 }
 
 
-/**
- * Adds the specified method as a member to this enum.
- *
- * @param m a method
- */
 void vala_enum_add_method (ValaEnum* self, ValaMethod* m) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (m != NULL);
@@ -517,11 +503,9 @@ void vala_enum_add_method (ValaEnum* self, ValaMethod* m) {
 	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
 		ValaFormalParameter* _tmp1_;
 		ValaEnumValueType* _tmp0_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
 		vala_method_set_this_parameter (m, _tmp1_ = vala_formal_parameter_new ("this", (ValaDataType*) (_tmp0_ = vala_enum_value_type_new (self)), NULL));
-		(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL));
-		(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+		_vala_code_node_unref0 (_tmp1_);
+		_vala_code_node_unref0 (_tmp0_);
 		vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) m), vala_symbol_get_name ((ValaSymbol*) vala_method_get_this_parameter (m)), (ValaSymbol*) vala_method_get_this_parameter (m));
 	}
 	gee_collection_add ((GeeCollection*) self->priv->methods, m);
@@ -529,11 +513,6 @@ void vala_enum_add_method (ValaEnum* self, ValaMethod* m) {
 }
 
 
-/**
- * Returns a copy of the list of enum values.
- *
- * @return list of enum values
- */
 GeeList* vala_enum_get_values (ValaEnum* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -542,11 +521,6 @@ GeeList* vala_enum_get_values (ValaEnum* self) {
 }
 
 
-/**
- * Returns a copy of the list of methods.
- *
- * @return list of methods
- */
 GeeList* vala_enum_get_methods (ValaEnum* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -577,9 +551,9 @@ static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor*
 			}
 			value = (ValaEnumValue*) gee_iterator_get (_value_it);
 			vala_code_node_accept ((ValaCodeNode*) value, visitor);
-			(value == NULL) ? NULL : (value = (vala_code_node_unref (value), NULL));
+			_vala_code_node_unref0 (value);
 		}
-		(_value_it == NULL) ? NULL : (_value_it = (gee_collection_object_unref (_value_it), NULL));
+		_gee_collection_object_unref0 (_value_it);
 	}
 	{
 		GeeIterator* _m_it;
@@ -591,9 +565,9 @@ static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor*
 			}
 			m = (ValaMethod*) gee_iterator_get (_m_it);
 			vala_code_node_accept ((ValaCodeNode*) m, visitor);
-			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
+			_vala_code_node_unref0 (m);
 		}
-		(_m_it == NULL) ? NULL : (_m_it = (gee_collection_object_unref (_m_it), NULL));
+		_gee_collection_object_unref0 (_m_it);
 	}
 }
 
@@ -601,73 +575,58 @@ static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor*
 static char* vala_enum_real_get_cname (ValaTypeSymbol* base, gboolean const_type) {
 	ValaEnum * self;
 	char* result;
-	const char* _tmp3_;
 	self = (ValaEnum*) base;
 	if (self->priv->cname == NULL) {
 		ValaAttribute* attr;
 		attr = vala_code_node_get_attribute ((ValaCodeNode*) self, "CCode");
 		if (attr != NULL) {
 			char* _tmp0_;
-			_tmp0_ = NULL;
-			self->priv->cname = (_tmp0_ = vala_attribute_get_string (attr, "cname"), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
+			self->priv->cname = (_tmp0_ = vala_attribute_get_string (attr, "cname"), _g_free0 (self->priv->cname), _tmp0_);
 		}
 		if (self->priv->cname == NULL) {
 			char* _tmp2_;
 			char* _tmp1_;
-			_tmp2_ = NULL;
-			_tmp1_ = NULL;
-			self->priv->cname = (_tmp2_ = g_strdup_printf ("%s%s", _tmp1_ = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), vala_symbol_get_name ((ValaSymbol*) self)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp2_);
-			_tmp1_ = (g_free (_tmp1_), NULL);
+			self->priv->cname = (_tmp2_ = g_strdup_printf ("%s%s", _tmp1_ = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), vala_symbol_get_name ((ValaSymbol*) self)), _g_free0 (self->priv->cname), _tmp2_);
+			_g_free0 (_tmp1_);
 		}
-		(attr == NULL) ? NULL : (attr = (vala_code_node_unref (attr), NULL));
+		_vala_code_node_unref0 (attr);
 	}
-	_tmp3_ = NULL;
-	result = (_tmp3_ = self->priv->cname, (_tmp3_ == NULL) ? NULL : g_strdup (_tmp3_));
+	result = g_strdup (self->priv->cname);
 	return result;
 }
 
 
 void vala_enum_set_cname (ValaEnum* self, const char* cname) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (cname != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->cname = (_tmp1_ = (_tmp0_ = cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1_);
+	self->priv->cname = (_tmp0_ = g_strdup (cname), _g_free0 (self->priv->cname), _tmp0_);
 }
 
 
 static char* vala_enum_real_get_lower_case_cprefix (ValaSymbol* base) {
 	ValaEnum * self;
 	char* result;
-	const char* _tmp2_;
 	self = (ValaEnum*) base;
 	if (self->priv->lower_case_cprefix == NULL) {
 		char* _tmp1_;
 		char* _tmp0_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		self->priv->lower_case_cprefix = (_tmp1_ = g_strdup_printf ("%s_", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self, NULL)), self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL), _tmp1_);
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		self->priv->lower_case_cprefix = (_tmp1_ = g_strdup_printf ("%s_", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self, NULL)), _g_free0 (self->priv->lower_case_cprefix), _tmp1_);
+		_g_free0 (_tmp0_);
 	}
-	_tmp2_ = NULL;
-	result = (_tmp2_ = self->priv->lower_case_cprefix, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+	result = g_strdup (self->priv->lower_case_cprefix);
 	return result;
 }
 
 
 static char* vala_enum_get_lower_case_csuffix (ValaEnum* self) {
 	char* result;
-	const char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
-		self->priv->lower_case_csuffix = (_tmp0_ = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self)), self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL), _tmp0_);
+		self->priv->lower_case_csuffix = (_tmp0_ = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name ((ValaSymbol*) self)), _g_free0 (self->priv->lower_case_csuffix), _tmp0_);
 	}
-	_tmp1_ = NULL;
-	result = (_tmp1_ = self->priv->lower_case_csuffix, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
+	result = g_strdup (self->priv->lower_case_csuffix);
 	return result;
 }
 
@@ -682,10 +641,7 @@ static char* vala_enum_real_get_lower_case_cname (ValaSymbol* base, const char*
 	if (infix == NULL) {
 		infix = "";
 	}
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	_tmp2_ = NULL;
-	result = (_tmp2_ = g_strdup_printf ("%s%s%s", _tmp0_ = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), infix, _tmp1_ = vala_enum_get_lower_case_csuffix (self)), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp2_);
+	result = (_tmp2_ = g_strdup_printf ("%s%s%s", _tmp0_ = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), infix, _tmp1_ = vala_enum_get_lower_case_csuffix (self)), _g_free0 (_tmp1_), _g_free0 (_tmp0_), _tmp2_);
 	return result;
 }
 
@@ -696,9 +652,7 @@ static char* vala_enum_real_get_upper_case_cname (ValaTypeSymbol* base, const ch
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaEnum*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = g_utf8_strup (_tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self, infix), -1), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_utf8_strup (_tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self, infix), -1), _g_free0 (_tmp0_), _tmp1_);
 	return result;
 }
 
@@ -715,35 +669,22 @@ static gboolean vala_enum_real_is_reference_type (ValaTypeSymbol* base) {
 static char* vala_enum_real_get_cprefix (ValaSymbol* base) {
 	ValaEnum * self;
 	char* result;
-	const char* _tmp2_;
 	self = (ValaEnum*) base;
 	if (self->priv->cprefix == NULL) {
 		char* _tmp1_;
 		char* _tmp0_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		self->priv->cprefix = (_tmp1_ = g_strdup_printf ("%s_", _tmp0_ = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) self, NULL)), self->priv->cprefix = (g_free (self->priv->cprefix), NULL), _tmp1_);
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		self->priv->cprefix = (_tmp1_ = g_strdup_printf ("%s_", _tmp0_ = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) self, NULL)), _g_free0 (self->priv->cprefix), _tmp1_);
+		_g_free0 (_tmp0_);
 	}
-	_tmp2_ = NULL;
-	result = (_tmp2_ = self->priv->cprefix, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
+	result = g_strdup (self->priv->cprefix);
 	return result;
 }
 
 
-/**
- * Sets the string to be prepended to the name of members of this enum
- * when used in C code.
- *
- * @param cprefix the prefix to be used in C code
- */
 void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->cprefix = (_tmp1_ = (_tmp0_ = cprefix, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->cprefix = (g_free (self->priv->cprefix), NULL), _tmp1_);
+	self->priv->cprefix = (_tmp0_ = g_strdup (cprefix), _g_free0 (self->priv->cprefix), _tmp0_);
 }
 
 
@@ -752,14 +693,12 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 	g_return_if_fail (a != NULL);
 	if (vala_attribute_has_argument (a, "cprefix")) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
 		vala_enum_set_cprefix (self, _tmp0_ = vala_attribute_get_string (a, "cprefix"));
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		_g_free0 (_tmp0_);
 	}
 	if (vala_attribute_has_argument (a, "lower_case_csuffix")) {
 		char* _tmp1_;
-		_tmp1_ = NULL;
-		self->priv->lower_case_csuffix = (_tmp1_ = vala_attribute_get_string (a, "lower_case_csuffix"), self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL), _tmp1_);
+		self->priv->lower_case_csuffix = (_tmp1_ = vala_attribute_get_string (a, "lower_case_csuffix"), _g_free0 (self->priv->lower_case_csuffix), _tmp1_);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -769,37 +708,35 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 			char** filename_collection;
 			int filename_collection_length1;
 			int filename_it;
-			_tmp2_ = NULL;
 			filename_collection = _tmp2_ = g_strsplit (val, ",", 0);
 			filename_collection_length1 = _vala_array_length (_tmp2_);
 			for (filename_it = 0; filename_it < _vala_array_length (_tmp2_); filename_it = filename_it + 1) {
-				const char* _tmp3_;
 				char* filename;
-				_tmp3_ = NULL;
-				filename = (_tmp3_ = filename_collection[filename_it], (_tmp3_ == NULL) ? NULL : g_strdup (_tmp3_));
+				filename = g_strdup (filename_collection[filename_it]);
 				{
 					vala_typesymbol_add_cheader_filename ((ValaTypeSymbol*) self, filename);
-					filename = (g_free (filename), NULL);
+					_g_free0 (filename);
 				}
 			}
 			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, (GDestroyNotify) g_free), NULL);
 		}
-		val = (g_free (val), NULL);
+		_g_free0 (val);
 	}
 	if (vala_attribute_has_argument (a, "has_type_id")) {
 		vala_enum_set_has_type_id (self, vala_attribute_get_bool (a, "has_type_id"));
 	}
 	if (vala_attribute_has_argument (a, "type_id")) {
-		char* _tmp4_;
-		_tmp4_ = NULL;
-		self->priv->type_id = (_tmp4_ = vala_attribute_get_string (a, "type_id"), self->priv->type_id = (g_free (self->priv->type_id), NULL), _tmp4_);
+		char* _tmp3_;
+		self->priv->type_id = (_tmp3_ = vala_attribute_get_string (a, "type_id"), _g_free0 (self->priv->type_id), _tmp3_);
 	}
 }
 
 
-/**
- * Process all associated attributes.
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_enum_process_attributes (ValaEnum* self) {
 	g_return_if_fail (self != NULL);
 	{
@@ -807,10 +744,8 @@ void vala_enum_process_attributes (ValaEnum* self) {
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp0_;
 			ValaAttribute* a;
-			_tmp0_ = NULL;
-			a = (_tmp0_ = (ValaAttribute*) a_it->data, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+			a = _vala_code_node_ref0 ((ValaAttribute*) a_it->data);
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_enum_process_ccode_attribute (self, a);
@@ -819,7 +754,7 @@ void vala_enum_process_attributes (ValaEnum* self) {
 						vala_enum_set_is_flags (self, TRUE);
 					}
 				}
-				(a == NULL) ? NULL : (a = (vala_code_node_unref (a), NULL));
+				_vala_code_node_unref0 (a);
 			}
 		}
 	}
@@ -827,42 +762,33 @@ void vala_enum_process_attributes (ValaEnum* self) {
 
 
 void vala_enum_set_type_id (ValaEnum* self, const char* type_id) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->type_id = (_tmp1_ = (_tmp0_ = type_id, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->type_id = (g_free (self->priv->type_id), NULL), _tmp1_);
+	self->priv->type_id = (_tmp0_ = g_strdup (type_id), _g_free0 (self->priv->type_id), _tmp0_);
 }
 
 
 static char* vala_enum_real_get_type_id (ValaTypeSymbol* base) {
 	ValaEnum * self;
 	char* result;
-	const char* _tmp4_;
 	self = (ValaEnum*) base;
 	if (self->priv->type_id == NULL) {
 		if (self->priv->_has_type_id) {
 			char* _tmp0_;
-			_tmp0_ = NULL;
-			self->priv->type_id = (_tmp0_ = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) self, "TYPE_"), self->priv->type_id = (g_free (self->priv->type_id), NULL), _tmp0_);
+			self->priv->type_id = (_tmp0_ = vala_typesymbol_get_upper_case_cname ((ValaTypeSymbol*) self, "TYPE_"), _g_free0 (self->priv->type_id), _tmp0_);
 		} else {
 			const char* _tmp1_;
-			char* _tmp3_;
-			const char* _tmp2_;
+			char* _tmp2_;
 			_tmp1_ = NULL;
 			if (self->priv->_is_flags) {
 				_tmp1_ = "G_TYPE_UINT";
 			} else {
 				_tmp1_ = "G_TYPE_INT";
 			}
-			_tmp3_ = NULL;
-			_tmp2_ = NULL;
-			self->priv->type_id = (_tmp3_ = (_tmp2_ = _tmp1_, (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), self->priv->type_id = (g_free (self->priv->type_id), NULL), _tmp3_);
+			self->priv->type_id = (_tmp2_ = g_strdup (_tmp1_), _g_free0 (self->priv->type_id), _tmp2_);
 		}
 	}
-	_tmp4_ = NULL;
-	result = (_tmp4_ = self->priv->type_id, (_tmp4_ == NULL) ? NULL : g_strdup (_tmp4_));
+	result = g_strdup (self->priv->type_id);
 	return result;
 }
 
@@ -962,10 +888,14 @@ static char* vala_enum_real_get_type_signature (ValaTypeSymbol* base) {
 }
 
 
+static gpointer _vala_source_file_ref0 (gpointer self) {
+	return self ? vala_source_file_ref (self) : NULL;
+}
+
+
 static gboolean vala_enum_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaEnum * self;
 	gboolean result;
-	ValaSourceFile* _tmp0_;
 	ValaSourceFile* old_source_file;
 	self = (ValaEnum*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
@@ -975,8 +905,7 @@ static gboolean vala_enum_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_enum_process_attributes (self);
-	_tmp0_ = NULL;
-	old_source_file = (_tmp0_ = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp0_ == NULL) ? NULL : vala_source_file_ref (_tmp0_));
+	old_source_file = _vala_source_file_ref0 (vala_semantic_analyzer_get_current_source_file (analyzer));
 	if (vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL) {
 		vala_semantic_analyzer_set_current_source_file (analyzer, vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self)));
 	}
@@ -990,9 +919,9 @@ static gboolean vala_enum_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 			}
 			value = (ValaEnumValue*) gee_iterator_get (_value_it);
 			vala_code_node_check ((ValaCodeNode*) value, analyzer);
-			(value == NULL) ? NULL : (value = (vala_code_node_unref (value), NULL));
+			_vala_code_node_unref0 (value);
 		}
-		(_value_it == NULL) ? NULL : (_value_it = (gee_collection_object_unref (_value_it), NULL));
+		_gee_collection_object_unref0 (_value_it);
 	}
 	{
 		GeeIterator* _m_it;
@@ -1004,13 +933,13 @@ static gboolean vala_enum_real_check (ValaCodeNode* base, ValaSemanticAnalyzer*
 			}
 			m = (ValaMethod*) gee_iterator_get (_m_it);
 			vala_code_node_check ((ValaCodeNode*) m, analyzer);
-			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
+			_vala_code_node_unref0 (m);
 		}
-		(_m_it == NULL) ? NULL : (_m_it = (gee_collection_object_unref (_m_it), NULL));
+		_gee_collection_object_unref0 (_m_it);
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
-	(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
+	_vala_source_file_unref0 (old_source_file);
 	return result;
 }
 
@@ -1076,13 +1005,13 @@ static void vala_enum_instance_init (ValaEnum * self) {
 static void vala_enum_finalize (ValaCodeNode* obj) {
 	ValaEnum * self;
 	self = VALA_ENUM (obj);
-	(self->priv->values == NULL) ? NULL : (self->priv->values = (gee_collection_object_unref (self->priv->values), NULL));
-	(self->priv->methods == NULL) ? NULL : (self->priv->methods = (gee_collection_object_unref (self->priv->methods), NULL));
-	self->priv->cname = (g_free (self->priv->cname), NULL);
-	self->priv->cprefix = (g_free (self->priv->cprefix), NULL);
-	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
-	self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL);
-	self->priv->type_id = (g_free (self->priv->type_id), NULL);
+	_gee_collection_object_unref0 (self->priv->values);
+	_gee_collection_object_unref0 (self->priv->methods);
+	_g_free0 (self->priv->cname);
+	_g_free0 (self->priv->cprefix);
+	_g_free0 (self->priv->lower_case_cprefix);
+	_g_free0 (self->priv->lower_case_csuffix);
+	_g_free0 (self->priv->type_id);
 	VALA_CODE_NODE_CLASS (vala_enum_parent_class)->finalize (obj);
 }
 
