@@ -109,6 +109,9 @@ typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
 typedef struct _ValaAttribute ValaAttribute;
 typedef struct _ValaAttributeClass ValaAttributeClass;
 typedef struct _ValaExpressionPrivate ValaExpressionPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_ccode_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_ccode_node_unref (var), NULL)))
 
 #define VALA_TYPE_BLOCK (vala_block_get_type ())
 #define VALA_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_BLOCK, ValaBlock))
@@ -128,12 +131,6 @@ typedef struct _ValaBlockClass ValaBlockClass;
 typedef struct _ValaStatement ValaStatement;
 typedef struct _ValaStatementIface ValaStatementIface;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -154,9 +151,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -181,9 +175,6 @@ struct _ValaExpressionPrivate {
 	ValaCCodeExpression* _delegate_target;
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
@@ -226,6 +217,8 @@ GType vala_statement_get_type (void);
 void vala_block_insert_before (ValaBlock* self, ValaStatement* stmt, ValaStatement* new_stmt);
 ValaStatement* vala_expression_get_parent_statement (ValaExpression* self);
 void vala_expression_insert_statement (ValaExpression* self, ValaBlock* block, ValaStatement* stmt);
+ValaCodeNode* vala_code_node_construct (GType object_type);
+ValaExpression* vala_expression_construct (GType object_type);
 ValaDataType* vala_expression_get_value_type (ValaExpression* self);
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 ValaDataType* vala_expression_get_formal_value_type (ValaExpression* self);
@@ -245,10 +238,6 @@ static void vala_expression_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Returns whether this expression is constant, i.e. whether this
- * expression only consists of literals and other constants.
- */
 static gboolean vala_expression_real_is_constant (ValaExpression* self) {
 	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
@@ -269,18 +258,11 @@ static gboolean vala_expression_real_is_pure (ValaExpression* self) {
 }
 
 
-/**
- * Returns whether this expression is pure, i.e. whether this expression
- * is free of side-effects.
- */
 gboolean vala_expression_is_pure (ValaExpression* self) {
 	return VALA_EXPRESSION_GET_CLASS (self)->is_pure (self);
 }
 
 
-/**
- * Returns whether this expression is guaranteed to be non-null.
- */
 static gboolean vala_expression_real_is_non_null (ValaExpression* self) {
 	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
@@ -294,9 +276,6 @@ gboolean vala_expression_is_non_null (ValaExpression* self) {
 }
 
 
-/**
- * Add an array size C code expression.
- */
 void vala_expression_append_array_size (ValaExpression* self, ValaCCodeExpression* size) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (size != NULL);
@@ -304,10 +283,6 @@ void vala_expression_append_array_size (ValaExpression* self, ValaCCodeExpressio
 }
 
 
-/**
- * Get the C code expression for array sizes for all dimensions
- * ascending from left to right.
- */
 GeeList* vala_expression_get_array_sizes (ValaExpression* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -324,6 +299,13 @@ void vala_expression_insert_statement (ValaExpression* self, ValaBlock* block, V
 }
 
 
+ValaExpression* vala_expression_construct (GType object_type) {
+	ValaExpression* self;
+	self = (ValaExpression*) vala_code_node_construct (object_type);
+	return self;
+}
+
+
 ValaDataType* vala_expression_get_value_type (ValaExpression* self) {
 	ValaDataType* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -332,13 +314,15 @@ ValaDataType* vala_expression_get_value_type (ValaExpression* self) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_value_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_value_type == NULL) ? NULL : (self->priv->_value_type = (vala_code_node_unref (self->priv->_value_type), NULL)), _tmp1_);
+	self->priv->_value_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_value_type), _tmp0_);
 }
 
 
@@ -351,12 +335,9 @@ ValaDataType* vala_expression_get_formal_value_type (ValaExpression* self) {
 
 
 void vala_expression_set_formal_value_type (ValaExpression* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_formal_value_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_formal_value_type == NULL) ? NULL : (self->priv->_formal_value_type = (vala_code_node_unref (self->priv->_formal_value_type), NULL)), _tmp1_);
+	self->priv->_formal_value_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_formal_value_type), _tmp0_);
 }
 
 
@@ -369,12 +350,9 @@ ValaDataType* vala_expression_get_target_type (ValaExpression* self) {
 
 
 void vala_expression_set_target_type (ValaExpression* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_target_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_target_type == NULL) ? NULL : (self->priv->_target_type = (vala_code_node_unref (self->priv->_target_type), NULL)), _tmp1_);
+	self->priv->_target_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_target_type), _tmp0_);
 }
 
 
@@ -387,12 +365,9 @@ ValaDataType* vala_expression_get_formal_target_type (ValaExpression* self) {
 
 
 void vala_expression_set_formal_target_type (ValaExpression* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_formal_target_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_formal_target_type == NULL) ? NULL : (self->priv->_formal_target_type = (vala_code_node_unref (self->priv->_formal_target_type), NULL)), _tmp1_);
+	self->priv->_formal_target_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_formal_target_type), _tmp0_);
 }
 
 
@@ -432,69 +407,62 @@ ValaCCodeExpression* vala_expression_get_delegate_target (ValaExpression* self)
 }
 
 
+static gpointer _vala_ccode_node_ref0 (gpointer self) {
+	return self ? vala_ccode_node_ref (self) : NULL;
+}
+
+
 void vala_expression_set_delegate_target (ValaExpression* self, ValaCCodeExpression* value) {
-	ValaCCodeExpression* _tmp1_;
 	ValaCCodeExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_delegate_target = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_delegate_target == NULL) ? NULL : (self->priv->_delegate_target = (vala_ccode_node_unref (self->priv->_delegate_target), NULL)), _tmp1_);
+	self->priv->_delegate_target = (_tmp0_ = _vala_ccode_node_ref0 (value), _vala_ccode_node_unref0 (self->priv->_delegate_target), _tmp0_);
 }
 
 
 ValaStatement* vala_expression_get_parent_statement (ValaExpression* self) {
 	ValaStatement* result;
-	ValaExpression* _tmp1_;
 	ValaCodeNode* _tmp0_;
 	ValaExpression* expr;
-	ValaStatement* _tmp3_;
-	ValaCodeNode* _tmp2_;
+	ValaCodeNode* _tmp1_;
 	ValaStatement* stmt;
-	ValaLocalVariable* _tmp5_;
-	ValaCodeNode* _tmp4_;
+	ValaCodeNode* _tmp2_;
 	ValaLocalVariable* local;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	expr = (_tmp1_ = (_tmp0_ = vala_code_node_get_parent_node ((ValaCodeNode*) self), VALA_IS_EXPRESSION (_tmp0_) ? ((ValaExpression*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-	_tmp3_ = NULL;
-	_tmp2_ = NULL;
-	stmt = (_tmp3_ = (_tmp2_ = vala_code_node_get_parent_node ((ValaCodeNode*) self), VALA_IS_STATEMENT (_tmp2_) ? ((ValaStatement*) _tmp2_) : NULL), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_));
-	_tmp5_ = NULL;
-	_tmp4_ = NULL;
-	local = (_tmp5_ = (_tmp4_ = vala_code_node_get_parent_node ((ValaCodeNode*) self), VALA_IS_LOCAL_VARIABLE (_tmp4_) ? ((ValaLocalVariable*) _tmp4_) : NULL), (_tmp5_ == NULL) ? NULL : vala_code_node_ref (_tmp5_));
+	expr = _vala_code_node_ref0 ((_tmp0_ = vala_code_node_get_parent_node ((ValaCodeNode*) self), VALA_IS_EXPRESSION (_tmp0_) ? ((ValaExpression*) _tmp0_) : NULL));
+	stmt = _vala_code_node_ref0 ((_tmp1_ = vala_code_node_get_parent_node ((ValaCodeNode*) self), VALA_IS_STATEMENT (_tmp1_) ? ((ValaStatement*) _tmp1_) : NULL));
+	local = _vala_code_node_ref0 ((_tmp2_ = vala_code_node_get_parent_node ((ValaCodeNode*) self), VALA_IS_LOCAL_VARIABLE (_tmp2_) ? ((ValaLocalVariable*) _tmp2_) : NULL));
 	if (stmt != NULL) {
 		result = VALA_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) self));
-		(expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL));
-		(stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL));
-		(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+		_vala_code_node_unref0 (expr);
+		_vala_code_node_unref0 (stmt);
+		_vala_code_node_unref0 (local);
 		return result;
 	} else {
 		if (expr != NULL) {
 			result = vala_expression_get_parent_statement (expr);
-			(expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL));
-			(stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL));
-			(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+			_vala_code_node_unref0 (expr);
+			_vala_code_node_unref0 (stmt);
+			_vala_code_node_unref0 (local);
 			return result;
 		} else {
 			if (local != NULL) {
 				result = VALA_STATEMENT (vala_code_node_get_parent_node ((ValaCodeNode*) local));
-				(expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL));
-				(stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL));
-				(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+				_vala_code_node_unref0 (expr);
+				_vala_code_node_unref0 (stmt);
+				_vala_code_node_unref0 (local);
 				return result;
 			} else {
 				result = NULL;
-				(expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL));
-				(stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL));
-				(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+				_vala_code_node_unref0 (expr);
+				_vala_code_node_unref0 (stmt);
+				_vala_code_node_unref0 (local);
 				return result;
 			}
 		}
 	}
-	(expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL));
-	(stmt == NULL) ? NULL : (stmt = (vala_code_node_unref (stmt), NULL));
-	(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+	_vala_code_node_unref0 (expr);
+	_vala_code_node_unref0 (stmt);
+	_vala_code_node_unref0 (local);
 }
 
 
@@ -518,13 +486,13 @@ static void vala_expression_instance_init (ValaExpression * self) {
 static void vala_expression_finalize (ValaCodeNode* obj) {
 	ValaExpression * self;
 	self = VALA_EXPRESSION (obj);
-	(self->priv->_value_type == NULL) ? NULL : (self->priv->_value_type = (vala_code_node_unref (self->priv->_value_type), NULL));
-	(self->priv->_formal_value_type == NULL) ? NULL : (self->priv->_formal_value_type = (vala_code_node_unref (self->priv->_formal_value_type), NULL));
-	(self->priv->_target_type == NULL) ? NULL : (self->priv->_target_type = (vala_code_node_unref (self->priv->_target_type), NULL));
-	(self->priv->_formal_target_type == NULL) ? NULL : (self->priv->_formal_target_type = (vala_code_node_unref (self->priv->_formal_target_type), NULL));
-	(self->temp_vars == NULL) ? NULL : (self->temp_vars = (gee_collection_object_unref (self->temp_vars), NULL));
-	(self->priv->array_sizes == NULL) ? NULL : (self->priv->array_sizes = (gee_collection_object_unref (self->priv->array_sizes), NULL));
-	(self->priv->_delegate_target == NULL) ? NULL : (self->priv->_delegate_target = (vala_ccode_node_unref (self->priv->_delegate_target), NULL));
+	_vala_code_node_unref0 (self->priv->_value_type);
+	_vala_code_node_unref0 (self->priv->_formal_value_type);
+	_vala_code_node_unref0 (self->priv->_target_type);
+	_vala_code_node_unref0 (self->priv->_formal_target_type);
+	_gee_collection_object_unref0 (self->temp_vars);
+	_gee_collection_object_unref0 (self->priv->array_sizes);
+	_vala_ccode_node_unref0 (self->priv->_delegate_target);
 	VALA_CODE_NODE_CLASS (vala_expression_parent_class)->finalize (obj);
 }
 
