@@ -126,6 +126,7 @@ typedef struct _ValaStatementIface ValaStatementIface;
 typedef struct _ValaExpressionStatement ValaExpressionStatement;
 typedef struct _ValaExpressionStatementClass ValaExpressionStatementClass;
 typedef struct _ValaExpressionStatementPrivate ValaExpressionStatementPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -176,13 +177,8 @@ typedef struct _ValaMemberClass ValaMemberClass;
 
 typedef struct _ValaProperty ValaProperty;
 typedef struct _ValaPropertyClass ValaPropertyClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -203,17 +199,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * A code statement that evaluates a given expression. The value computed by the
- * expression, if any, is discarded.
- */
 struct _ValaExpressionStatement {
 	ValaCodeNode parent_instance;
 	ValaExpressionStatementPrivate * priv;
@@ -255,6 +244,7 @@ GType vala_expression_statement_get_type (void);
 enum  {
 	VALA_EXPRESSION_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -295,17 +285,10 @@ static void vala_expression_statement_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new expression statement.
- *
- * @param expr   expression to evaluate
- * @param source reference to source code
- * @return       newly created expression statement
- */
 ValaExpressionStatement* vala_expression_statement_construct (GType object_type, ValaExpression* expression, ValaSourceReference* source_reference) {
 	ValaExpressionStatement* self;
 	g_return_val_if_fail (expression != NULL, NULL);
-	self = (ValaExpressionStatement*) g_type_create_instance (object_type);
+	self = (ValaExpressionStatement*) vala_code_node_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	vala_expression_statement_set_expression (self, expression);
 	return self;
@@ -344,36 +327,29 @@ static void vala_expression_statement_real_replace_expression (ValaCodeNode* bas
 }
 
 
-/**
- * Returns the property this statement sets, if any.
- *
- * @return the property this statement sets, or null if it doesn't set
- *         a property
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 ValaProperty* vala_expression_statement_assigned_property (ValaExpressionStatement* self) {
 	ValaProperty* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (VALA_IS_ASSIGNMENT (vala_expression_statement_get_expression (self))) {
-		ValaAssignment* _tmp0_;
 		ValaAssignment* assign;
-		_tmp0_ = NULL;
-		assign = (_tmp0_ = VALA_ASSIGNMENT (vala_expression_statement_get_expression (self)), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+		assign = _vala_code_node_ref0 (VALA_ASSIGNMENT (vala_expression_statement_get_expression (self)));
 		if (VALA_IS_MEMBER_ACCESS (vala_assignment_get_left (assign))) {
-			ValaMemberAccess* _tmp1_;
 			ValaMemberAccess* ma;
-			_tmp1_ = NULL;
-			ma = (_tmp1_ = VALA_MEMBER_ACCESS (vala_assignment_get_left (assign)), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+			ma = _vala_code_node_ref0 (VALA_MEMBER_ACCESS (vala_assignment_get_left (assign)));
 			if (VALA_IS_PROPERTY (vala_expression_get_symbol_reference ((ValaExpression*) ma))) {
-				ValaProperty* _tmp2_;
-				_tmp2_ = NULL;
-				result = (_tmp2_ = VALA_PROPERTY (vala_expression_get_symbol_reference ((ValaExpression*) ma)), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
-				(ma == NULL) ? NULL : (ma = (vala_code_node_unref (ma), NULL));
-				(assign == NULL) ? NULL : (assign = (vala_code_node_unref (assign), NULL));
+				result = _vala_code_node_ref0 (VALA_PROPERTY (vala_expression_get_symbol_reference ((ValaExpression*) ma)));
+				_vala_code_node_unref0 (ma);
+				_vala_code_node_unref0 (assign);
 				return result;
 			}
-			(ma == NULL) ? NULL : (ma = (vala_code_node_unref (ma), NULL));
+			_vala_code_node_unref0 (ma);
 		}
-		(assign == NULL) ? NULL : (assign = (vala_code_node_unref (assign), NULL));
+		_vala_code_node_unref0 (assign);
 	}
 	result = NULL;
 	return result;
@@ -392,14 +368,12 @@ static gboolean vala_expression_statement_real_check (ValaCodeNode* base, ValaSe
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (!vala_code_node_check ((ValaCodeNode*) vala_expression_statement_get_expression (self), analyzer)) {
-		/* ignore inner error*/
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		result = FALSE;
 		return result;
 	}
-	_tmp0_ = NULL;
 	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp0_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_expression_statement_get_expression (self)));
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL));
+	_gee_collection_object_unref0 (_tmp0_);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
 	return result;
 }
@@ -430,12 +404,9 @@ ValaExpression* vala_expression_statement_get_expression (ValaExpressionStatemen
 
 
 void vala_expression_statement_set_expression (ValaExpressionStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp1_);
+	self->priv->_expression = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_expression), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_expression, (ValaCodeNode*) self);
 }
 
@@ -466,7 +437,7 @@ static void vala_expression_statement_instance_init (ValaExpressionStatement * s
 static void vala_expression_statement_finalize (ValaCodeNode* obj) {
 	ValaExpressionStatement * self;
 	self = VALA_EXPRESSION_STATEMENT (obj);
-	(self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL));
+	_vala_code_node_unref0 (self->priv->_expression);
 	VALA_CODE_NODE_CLASS (vala_expression_statement_parent_class)->finalize (obj);
 }
 
