@@ -180,13 +180,8 @@ typedef struct _ValaStructClass ValaStructClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -207,10 +202,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -240,9 +231,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * A value type, i.e. a struct or an enum type.
- */
 struct _ValaValueType {
 	ValaDataType parent_instance;
 	ValaValueTypePrivate * priv;
@@ -252,9 +240,6 @@ struct _ValaValueTypeClass {
 	ValaDataTypeClass parent_class;
 };
 
-/**
- * A floating-point type.
- */
 struct _ValaFloatingType {
 	ValaValueType parent_instance;
 	ValaFloatingTypePrivate * priv;
@@ -298,7 +283,6 @@ enum  {
 	VALA_FLOATING_TYPE_DUMMY_PROPERTY
 };
 GType vala_typesymbol_get_type (void);
-ValaValueType* vala_value_type_new (ValaTypeSymbol* type_symbol);
 ValaValueType* vala_value_type_construct (GType object_type, ValaTypeSymbol* type_symbol);
 GType vala_struct_get_type (void);
 ValaFloatingType* vala_floating_type_new (ValaStruct* type_symbol);
