@@ -125,6 +125,8 @@ typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
 typedef struct _ValaFormalParameterPrivate ValaFormalParameterPrivate;
 
 #define VALA_TYPE_PARAMETER_DIRECTION (vala_parameter_direction_get_type ())
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -167,6 +169,7 @@ typedef struct _ValaReferenceTypeClass ValaReferenceTypeClass;
 
 typedef struct _ValaArrayType ValaArrayType;
 typedef struct _ValaArrayTypeClass ValaArrayTypeClass;
+#define _vala_source_file_unref0(var) ((var == NULL) ? NULL : (var = (vala_source_file_unref (var), NULL)))
 
 #define VALA_TYPE_LITERAL (vala_literal_get_type ())
 #define VALA_LITERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LITERAL, ValaLiteral))
@@ -188,12 +191,6 @@ typedef struct _ValaLiteralClass ValaLiteralClass;
 typedef struct _ValaNullLiteral ValaNullLiteral;
 typedef struct _ValaNullLiteralClass ValaNullLiteralClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -214,9 +211,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -232,9 +226,6 @@ struct _ValaSymbolClass {
 	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a formal parameter in method and callback signatures.
- */
 struct _ValaFormalParameter {
 	ValaSymbol parent_instance;
 	ValaFormalParameterPrivate * priv;
@@ -254,15 +245,15 @@ struct _ValaFormalParameterPrivate {
 	ValaParameterDirection _direction;
 	gboolean _ellipsis;
 	gboolean _params_array;
-	ValaExpression* _default_expression;
 	gboolean _no_array_length;
 	gboolean _array_null_terminated;
 	double _cparameter_position;
 	double _carray_length_parameter_position;
 	double _cdelegate_target_parameter_position;
-	gboolean _async_only;
 	char* _ctype;
+	gboolean _captured;
 	ValaDataType* _data_type;
+	ValaExpression* _default_expression;
 };
 
 typedef enum  {
@@ -305,7 +296,6 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
 void vala_formal_parameter_set_parameter_type (ValaFormalParameter* self, ValaDataType* value);
 GType vala_symbol_accessibility_get_type (void);
@@ -323,16 +313,18 @@ void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 ValaExpression* vala_formal_parameter_get_default_expression (ValaFormalParameter* self);
 static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, ValaExpression* value);
+static void vala_formal_parameter_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name);
 char* vala_attribute_get_string (ValaAttribute* self, const char* name);
 void vala_formal_parameter_set_ctype (ValaFormalParameter* self, const char* value);
+double vala_attribute_get_double (ValaAttribute* self, const char* name);
+void vala_formal_parameter_set_cparameter_position (ValaFormalParameter* self, double value);
 gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name);
 void vala_formal_parameter_set_no_array_length (ValaFormalParameter* self, gboolean value);
 void vala_formal_parameter_set_array_null_terminated (ValaFormalParameter* self, gboolean value);
-double vala_attribute_get_double (ValaAttribute* self, const char* name);
 void vala_formal_parameter_set_carray_length_parameter_position (ValaFormalParameter* self, double value);
 void vala_formal_parameter_set_cdelegate_target_parameter_position (ValaFormalParameter* self, double value);
-void vala_formal_parameter_set_async_only (ValaFormalParameter* self, gboolean value);
 static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter* self, ValaAttribute* a);
 const char* vala_attribute_get_name (ValaAttribute* self);
 void vala_formal_parameter_process_attributes (ValaFormalParameter* self);
@@ -372,28 +364,19 @@ gboolean vala_semantic_analyzer_is_type_accessible (ValaSemanticAnalyzer* self,
 char* vala_symbol_get_full_name (ValaSymbol* self);
 static gboolean vala_formal_parameter_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, ValaExpression* value);
 gboolean vala_formal_parameter_get_no_array_length (ValaFormalParameter* self);
 gboolean vala_formal_parameter_get_array_null_terminated (ValaFormalParameter* self);
 double vala_formal_parameter_get_cparameter_position (ValaFormalParameter* self);
-void vala_formal_parameter_set_cparameter_position (ValaFormalParameter* self, double value);
 double vala_formal_parameter_get_carray_length_parameter_position (ValaFormalParameter* self);
 double vala_formal_parameter_get_cdelegate_target_parameter_position (ValaFormalParameter* self);
-gboolean vala_formal_parameter_get_async_only (ValaFormalParameter* self);
 const char* vala_formal_parameter_get_ctype (ValaFormalParameter* self);
+gboolean vala_formal_parameter_get_captured (ValaFormalParameter* self);
+void vala_formal_parameter_set_captured (ValaFormalParameter* self, gboolean value);
 static void vala_formal_parameter_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-/**
- * Creates a new formal parameter.
- *
- * @param name   parameter name
- * @param type   parameter type
- * @param source reference to source code
- * @return       newly created formal parameter
- */
 ValaFormalParameter* vala_formal_parameter_construct (GType object_type, const char* name, ValaDataType* parameter_type, ValaSourceReference* source_reference) {
 	ValaFormalParameter* self;
 	g_return_val_if_fail (name != NULL, NULL);
@@ -410,10 +393,6 @@ ValaFormalParameter* vala_formal_parameter_new (const char* name, ValaDataType*
 }
 
 
-/**
- * Creates a new ellipsis parameter representing an indefinite number of
- * parameters.
- */
 ValaFormalParameter* vala_formal_parameter_construct_with_ellipsis (GType object_type, ValaSourceReference* source_reference) {
 	ValaFormalParameter* self;
 	self = (ValaFormalParameter*) vala_symbol_construct (object_type, NULL, source_reference);
@@ -442,8 +421,8 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 	g_return_if_fail (visitor != NULL);
 	if (!self->priv->_ellipsis) {
 		vala_code_node_accept ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self), visitor);
-		if (self->priv->_default_expression != NULL) {
-			vala_code_node_accept ((ValaCodeNode*) self->priv->_default_expression, visitor);
+		if (vala_formal_parameter_get_default_expression (self) != NULL) {
+			vala_code_node_accept ((ValaCodeNode*) vala_formal_parameter_get_default_expression (self), visitor);
 		}
 	}
 }
@@ -460,14 +439,27 @@ static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDat
 }
 
 
+static void vala_formal_parameter_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
+	ValaFormalParameter * self;
+	self = (ValaFormalParameter*) base;
+	g_return_if_fail (old_node != NULL);
+	g_return_if_fail (new_node != NULL);
+	if (vala_formal_parameter_get_default_expression (self) == old_node) {
+		vala_formal_parameter_set_default_expression (self, new_node);
+	}
+}
+
+
 static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter* self, ValaAttribute* a) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (a != NULL);
 	if (vala_attribute_has_argument (a, "type")) {
 		char* _tmp0_;
-		_tmp0_ = NULL;
 		vala_formal_parameter_set_ctype (self, _tmp0_ = vala_attribute_get_string (a, "type"));
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		_g_free0 (_tmp0_);
+	}
+	if (vala_attribute_has_argument (a, "pos")) {
+		vala_formal_parameter_set_cparameter_position (self, vala_attribute_get_double (a, "pos"));
 	}
 	if (vala_attribute_has_argument (a, "array_length")) {
 		vala_formal_parameter_set_no_array_length (self, !vala_attribute_get_bool (a, "array_length"));
@@ -481,15 +473,14 @@ static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter*
 	if (vala_attribute_has_argument (a, "delegate_target_pos")) {
 		vala_formal_parameter_set_cdelegate_target_parameter_position (self, vala_attribute_get_double (a, "delegate_target_pos"));
 	}
-	if (vala_attribute_has_argument (a, "async_only")) {
-		vala_formal_parameter_set_async_only (self, vala_attribute_get_bool (a, "async_only"));
-	}
 }
 
 
-/**
- * Process all associated attributes.
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_formal_parameter_process_attributes (ValaFormalParameter* self) {
 	g_return_if_fail (self != NULL);
 	{
@@ -497,15 +488,13 @@ void vala_formal_parameter_process_attributes (ValaFormalParameter* self) {
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp0_;
 			ValaAttribute* a;
-			_tmp0_ = NULL;
-			a = (_tmp0_ = (ValaAttribute*) a_it->data, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+			a = _vala_code_node_ref0 ((ValaAttribute*) a_it->data);
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_formal_parameter_process_ccode_attribute (self, a);
 				}
-				(a == NULL) ? NULL : (a = (vala_code_node_unref (a), NULL));
+				_vala_code_node_unref0 (a);
 			}
 		}
 	}
@@ -529,12 +518,15 @@ ValaFormalParameter* vala_formal_parameter_copy (ValaFormalParameter* self) {
 }
 
 
+static gpointer _vala_source_file_ref0 (gpointer self) {
+	return self ? vala_source_file_ref (self) : NULL;
+}
+
+
 static gboolean vala_formal_parameter_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaFormalParameter * self;
 	gboolean result;
-	ValaSourceFile* _tmp0_;
 	ValaSourceFile* old_source_file;
-	ValaSymbol* _tmp1_;
 	ValaSymbol* old_symbol;
 	self = (ValaFormalParameter*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
@@ -544,10 +536,8 @@ static gboolean vala_formal_parameter_real_check (ValaCodeNode* base, ValaSemant
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_formal_parameter_process_attributes (self);
-	_tmp0_ = NULL;
-	old_source_file = (_tmp0_ = vala_semantic_analyzer_get_current_source_file (analyzer), (_tmp0_ == NULL) ? NULL : vala_source_file_ref (_tmp0_));
-	_tmp1_ = NULL;
-	old_symbol = (_tmp1_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+	old_source_file = _vala_source_file_ref0 (vala_semantic_analyzer_get_current_source_file (analyzer));
+	old_symbol = _vala_code_node_ref0 (vala_semantic_analyzer_get_current_symbol (analyzer));
 	if (vala_code_node_get_source_reference ((ValaCodeNode*) self) != NULL) {
 		vala_semantic_analyzer_set_current_source_file (analyzer, vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self)));
 	}
@@ -556,72 +546,66 @@ static gboolean vala_formal_parameter_real_check (ValaCodeNode* base, ValaSemant
 		vala_code_node_check ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self), analyzer);
 	}
 	if (!self->priv->_ellipsis) {
-		gboolean _tmp2_;
+		gboolean _tmp0_;
 		vala_code_node_check ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self), analyzer);
-		_tmp2_ = FALSE;
+		_tmp0_ = FALSE;
 		if (self->priv->_params_array) {
-			_tmp2_ = !VALA_IS_ARRAY_TYPE (vala_formal_parameter_get_parameter_type (self));
+			_tmp0_ = !VALA_IS_ARRAY_TYPE (vala_formal_parameter_get_parameter_type (self));
+		} else {
+			_tmp0_ = FALSE;
+		}
+		if (_tmp0_) {
+			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "parameter array expected");
+			result = FALSE;
+			_vala_source_file_unref0 (old_source_file);
+			_vala_code_node_unref0 (old_symbol);
+			return result;
+		}
+		if (vala_formal_parameter_get_default_expression (self) != NULL) {
+			vala_code_node_check ((ValaCodeNode*) vala_formal_parameter_get_default_expression (self), analyzer);
+		}
+	}
+	if (vala_formal_parameter_get_default_expression (self) != NULL) {
+		gboolean _tmp1_;
+		gboolean _tmp2_;
+		_tmp1_ = FALSE;
+		_tmp2_ = FALSE;
+		if (VALA_IS_NULL_LITERAL (vala_formal_parameter_get_default_expression (self))) {
+			_tmp2_ = !vala_data_type_get_nullable (vala_formal_parameter_get_parameter_type (self));
 		} else {
 			_tmp2_ = FALSE;
 		}
 		if (_tmp2_) {
-			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "parameter array expected");
-			result = FALSE;
-			(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
-			(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
-			return result;
-		}
-		if (self->priv->_default_expression != NULL) {
-			vala_code_node_check ((ValaCodeNode*) self->priv->_default_expression, analyzer);
-		}
-	}
-	if (self->priv->_default_expression != NULL) {
-		gboolean _tmp3_;
-		gboolean _tmp4_;
-		_tmp3_ = FALSE;
-		_tmp4_ = FALSE;
-		if (VALA_IS_NULL_LITERAL (self->priv->_default_expression)) {
-			_tmp4_ = !vala_data_type_get_nullable (vala_formal_parameter_get_parameter_type (self));
+			_tmp1_ = self->priv->_direction != VALA_PARAMETER_DIRECTION_OUT;
 		} else {
-			_tmp4_ = FALSE;
+			_tmp1_ = FALSE;
 		}
-		if (_tmp4_) {
-			_tmp3_ = self->priv->_direction != VALA_PARAMETER_DIRECTION_OUT;
-		} else {
-			_tmp3_ = FALSE;
-		}
-		if (_tmp3_) {
-			char* _tmp6_;
-			char* _tmp5_;
-			_tmp6_ = NULL;
-			_tmp5_ = NULL;
-			vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp6_ = g_strdup_printf ("`null' incompatible with parameter type `%s`", _tmp5_ = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self))));
-			_tmp6_ = (g_free (_tmp6_), NULL);
-			_tmp5_ = (g_free (_tmp5_), NULL);
+		if (_tmp1_) {
+			char* _tmp4_;
+			char* _tmp3_;
+			vala_report_warning (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp4_ = g_strdup_printf ("`null' incompatible with parameter type `%s`", _tmp3_ = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self))));
+			_g_free0 (_tmp4_);
+			_g_free0 (_tmp3_);
 		}
 	}
 	if (!self->priv->_ellipsis) {
-		/* check whether parameter type is at least as accessible as the method*/
 		if (!vala_semantic_analyzer_is_type_accessible (analyzer, (ValaSymbol*) self, vala_formal_parameter_get_parameter_type (self))) {
-			char* _tmp9_;
-			char* _tmp8_;
 			char* _tmp7_;
+			char* _tmp6_;
+			char* _tmp5_;
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-			_tmp9_ = NULL;
-			_tmp8_ = NULL;
-			_tmp7_ = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp9_ = g_strdup_printf ("parameter type `%s` is less accessible than method `%s`", _tmp7_ = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self)), _tmp8_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol ((ValaSymbol*) self))));
-			_tmp9_ = (g_free (_tmp9_), NULL);
-			_tmp8_ = (g_free (_tmp8_), NULL);
-			_tmp7_ = (g_free (_tmp7_), NULL);
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp7_ = g_strdup_printf ("parameter type `%s` is less accessible than method `%s`", _tmp5_ = vala_code_node_to_string ((ValaCodeNode*) vala_formal_parameter_get_parameter_type (self)), _tmp6_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol ((ValaSymbol*) self))));
+			_g_free0 (_tmp7_);
+			_g_free0 (_tmp6_);
+			_g_free0 (_tmp5_);
 		}
 	}
 	vala_semantic_analyzer_set_current_source_file (analyzer, old_source_file);
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
-	(old_source_file == NULL) ? NULL : (old_source_file = (vala_source_file_unref (old_source_file), NULL));
-	(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
+	_vala_source_file_unref0 (old_source_file);
+	_vala_code_node_unref0 (old_symbol);
 	return result;
 }
 
@@ -635,12 +619,9 @@ ValaDataType* vala_formal_parameter_get_parameter_type (ValaFormalParameter* sel
 
 
 void vala_formal_parameter_set_parameter_type (ValaFormalParameter* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_data_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp1_);
+	self->priv->_data_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_data_type), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
@@ -696,12 +677,12 @@ ValaExpression* vala_formal_parameter_get_default_expression (ValaFormalParamete
 
 
 void vala_formal_parameter_set_default_expression (ValaFormalParameter* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_default_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_default_expression == NULL) ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL)), _tmp1_);
+	self->priv->_default_expression = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_default_expression), _tmp0_);
+	if (self->priv->_default_expression != NULL) {
+		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_default_expression, (ValaCodeNode*) self);
+	}
 }
 
 
@@ -775,20 +756,6 @@ void vala_formal_parameter_set_cdelegate_target_parameter_position (ValaFormalPa
 }
 
 
-gboolean vala_formal_parameter_get_async_only (ValaFormalParameter* self) {
-	gboolean result;
-	g_return_val_if_fail (self != NULL, FALSE);
-	result = self->priv->_async_only;
-	return result;
-}
-
-
-void vala_formal_parameter_set_async_only (ValaFormalParameter* self, gboolean value) {
-	g_return_if_fail (self != NULL);
-	self->priv->_async_only = value;
-}
-
-
 const char* vala_formal_parameter_get_ctype (ValaFormalParameter* self) {
 	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -798,12 +765,23 @@ const char* vala_formal_parameter_get_ctype (ValaFormalParameter* self) {
 
 
 void vala_formal_parameter_set_ctype (ValaFormalParameter* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_ctype = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_ctype = (g_free (self->priv->_ctype), NULL), _tmp1_);
+	self->priv->_ctype = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_ctype), _tmp0_);
+}
+
+
+gboolean vala_formal_parameter_get_captured (ValaFormalParameter* self) {
+	gboolean result;
+	g_return_val_if_fail (self != NULL, FALSE);
+	result = self->priv->_captured;
+	return result;
+}
+
+
+void vala_formal_parameter_set_captured (ValaFormalParameter* self, gboolean value) {
+	g_return_if_fail (self != NULL);
+	self->priv->_captured = value;
 }
 
 
@@ -814,6 +792,7 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_formal_parameter_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_formal_parameter_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_formal_parameter_real_replace_type;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_formal_parameter_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->check = vala_formal_parameter_real_check;
 }
 
@@ -827,9 +806,9 @@ static void vala_formal_parameter_instance_init (ValaFormalParameter * self) {
 static void vala_formal_parameter_finalize (ValaCodeNode* obj) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (obj);
-	(self->priv->_default_expression == NULL) ? NULL : (self->priv->_default_expression = (vala_code_node_unref (self->priv->_default_expression), NULL));
-	self->priv->_ctype = (g_free (self->priv->_ctype), NULL);
-	(self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL));
+	_g_free0 (self->priv->_ctype);
+	_vala_code_node_unref0 (self->priv->_data_type);
+	_vala_code_node_unref0 (self->priv->_default_expression);
 	VALA_CODE_NODE_CLASS (vala_formal_parameter_parent_class)->finalize (obj);
 }
 
