@@ -159,13 +159,8 @@ typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -186,10 +181,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -219,9 +210,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * The type of a generic type parameter.
- */
 struct _ValaGenericType {
 	ValaDataType parent_instance;
 	ValaGenericTypePrivate * priv;
@@ -263,6 +251,7 @@ GType vala_generic_type_get_type (void);
 enum  {
 	VALA_GENERIC_TYPE_DUMMY_PROPERTY
 };
+ValaDataType* vala_data_type_construct (GType object_type);
 GType vala_typeparameter_get_type (void);
 void vala_data_type_set_type_parameter (ValaDataType* self, ValaTypeParameter* value);
 void vala_data_type_set_nullable (ValaDataType* self, gboolean value);
@@ -293,9 +282,8 @@ static char* vala_generic_type_real_to_qualified_string (ValaDataType* base, Val
 ValaGenericType* vala_generic_type_construct (GType object_type, ValaTypeParameter* type_parameter) {
 	ValaGenericType* self;
 	g_return_val_if_fail (type_parameter != NULL, NULL);
-	self = (ValaGenericType*) g_type_create_instance (object_type);
+	self = (ValaGenericType*) vala_data_type_construct (object_type);
 	vala_data_type_set_type_parameter ((ValaDataType*) self, type_parameter);
-	/* type parameters are always considered nullable*/
 	vala_data_type_set_nullable ((ValaDataType*) self, TRUE);
 	return self;
 }
@@ -347,10 +335,8 @@ static char* vala_generic_type_real_get_type_id (ValaDataType* base) {
 static char* vala_generic_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaGenericType * self;
 	char* result;
-	const char* _tmp0_;
 	self = (ValaGenericType*) base;
-	_tmp0_ = NULL;
-	result = (_tmp0_ = vala_symbol_get_name ((ValaSymbol*) vala_data_type_get_type_parameter ((ValaDataType*) self)), (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+	result = g_strdup (vala_symbol_get_name ((ValaSymbol*) vala_data_type_get_type_parameter ((ValaDataType*) self)));
 	return result;
 }
 
