@@ -51,8 +51,20 @@ typedef struct _ValaSourceFileClass ValaSourceFileClass;
 
 #define VALA_GENIE_TYPE_TOKEN_TYPE (vala_genie_token_type_get_type ())
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+
 #define VALA_GENIE_SCANNER_TYPE_CONDITIONAL (vala_genie_scanner_conditional_get_type ())
 typedef struct _ValaGenieScannerConditional ValaGenieScannerConditional;
+#define _vala_source_file_unref0(var) ((var == NULL) ? NULL : (var = (vala_source_file_unref (var), NULL)))
+#define _vala_comment_unref0(var) ((var == NULL) ? NULL : (var = (vala_comment_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -63,6 +75,8 @@ typedef struct _ValaGenieScannerConditional ValaGenieScannerConditional;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _vala_source_reference_unref0(var) ((var == NULL) ? NULL : (var = (vala_source_reference_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_SOURCE_LOCATION (vala_source_location_get_type ())
 typedef struct _ValaSourceLocation ValaSourceLocation;
@@ -78,9 +92,6 @@ typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
 typedef struct _ValaGenieParamSpecScanner ValaGenieParamSpecScanner;
 
-/**
- * Lexical scanner for Genie source files.
- */
 struct _ValaGenieScanner {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -255,15 +266,12 @@ struct _ValaGenieScannerPrivate {
 	gint pending_dedents;
 	ValaGenieTokenType last_token;
 	gboolean parse_started;
-	char* _comment;
+	ValaComment* _comment;
 	ValaGenieScannerConditional* conditional_stack;
 	gint conditional_stack_length1;
 	gint conditional_stack_size;
 };
 
-/**
- * Represents a position in a source file.
- */
 struct _ValaSourceLocation {
 	gchar* pos;
 	gint line;
@@ -290,6 +298,12 @@ void vala_value_set_source_file (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_file (const GValue* value);
 GType vala_source_file_get_type (void);
 GType vala_genie_token_type_get_type (void);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
 static GType vala_genie_scanner_conditional_get_type (void);
 static ValaGenieScannerConditional* vala_genie_scanner_conditional_dup (const ValaGenieScannerConditional* self);
 static void vala_genie_scanner_conditional_free (ValaGenieScannerConditional* self);
@@ -326,11 +340,13 @@ void vala_source_location_free (ValaSourceLocation* self);
 ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSourceLocation* token_begin, ValaSourceLocation* token_end);
 static void vala_genie_scanner_pp_directive (ValaGenieScanner* self);
 static gboolean vala_genie_scanner_whitespace (ValaGenieScanner* self);
-static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char* comment_item, gboolean file_comment);
+static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char* comment_item, ValaSourceReference* source_reference, gboolean file_comment);
 static gboolean vala_genie_scanner_comment (ValaGenieScanner* self);
 static gboolean vala_genie_scanner_skip_tabs (ValaGenieScanner* self);
-void vala_source_file_set_comment (ValaSourceFile* self, const char* value);
-char* vala_genie_scanner_pop_comment (ValaGenieScanner* self);
+ValaComment* vala_comment_new (const char* comment, ValaSourceReference* _source_reference);
+ValaComment* vala_comment_construct (GType object_type, const char* comment, ValaSourceReference* _source_reference);
+void vala_source_file_add_comment (ValaSourceFile* self, ValaComment* comment);
+ValaComment* vala_genie_scanner_pop_comment (ValaGenieScanner* self);
 static gboolean vala_genie_scanner_pp_whitespace (ValaGenieScanner* self);
 static void vala_genie_scanner_parse_pp_if (ValaGenieScanner* self);
 static void vala_genie_scanner_parse_pp_elif (ValaGenieScanner* self);
@@ -1265,7 +1281,6 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 	gchar* begin;
 	gint token_length_in_chars;
 	g_return_val_if_fail (self != NULL, 0);
-	/* emit dedents if outstanding before checking any other chars */
 	if (self->priv->pending_dedents > 0) {
 		self->priv->pending_dedents--;
 		self->priv->indent_level--;
@@ -1286,7 +1301,6 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 		_tmp0_ = self->priv->last_token != VALA_GENIE_TOKEN_TYPE_EOL;
 	}
 	if (_tmp0_) {
-		/* scrub whitespace (excluding newlines) and comments */
 		vala_genie_scanner_space (self);
 	}
 	while (TRUE) {
@@ -1329,7 +1343,6 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 	} else {
 		_tmp3_ = FALSE;
 	}
-	/* handle non-consecutive new line once parsing is underway - EOL */
 	if (_tmp3_) {
 		(*token_begin).pos = self->priv->current;
 		(*token_begin).line = self->priv->line;
@@ -1349,7 +1362,6 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 		(*token_begin).line = self->priv->line;
 		(*token_begin).column = self->priv->column;
 		self->priv->current_indent_level = vala_genie_scanner_count_tabs (self);
-		/* if its an empty new line then ignore */
 		if (self->priv->current_indent_level == (-1)) {
 			continue;
 		}
@@ -1421,7 +1433,6 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 				len = 0;
 				if (self->priv->current[1] == '@') {
 					(*token_begin).pos = (*token_begin).pos + 2;
-					/* @@ is not part of the identifier*/
 					self->priv->current = self->priv->current + 2;
 				} else {
 					self->priv->current++;
@@ -1618,7 +1629,6 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 									_tmp23_ = FALSE;
 								}
 								if (_tmp23_) {
-									/* hexadecimal integer literal*/
 									self->priv->current++;
 									while (TRUE) {
 										gboolean _tmp27_;
@@ -2066,9 +2076,8 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 													token_length_in_chars++;
 												} else {
 													ValaSourceReference* _tmp42_;
-													_tmp42_ = NULL;
 													vala_report_error (_tmp42_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), "invalid UTF-8 character");
-													(_tmp42_ == NULL) ? NULL : (_tmp42_ = (vala_source_reference_unref (_tmp42_), NULL));
+													_vala_source_reference_unref0 (_tmp42_);
 												}
 											}
 										}
@@ -2089,9 +2098,8 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 										self->priv->current = self->priv->current + 3;
 									} else {
 										ValaSourceReference* _tmp45_;
-										_tmp45_ = NULL;
 										vala_report_error (_tmp45_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), "syntax error, expected \"\"\"");
-										(_tmp45_ == NULL) ? NULL : (_tmp45_ = (vala_source_reference_unref (_tmp45_), NULL));
+										_vala_source_reference_unref0 (_tmp45_);
 									}
 									break;
 								} else {
@@ -2122,7 +2130,6 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 										_tmp47_ = FALSE;
 									}
 									if (_tmp47_) {
-										/* hexadecimal escape character*/
 										self->priv->current++;
 										token_length_in_chars++;
 										while (TRUE) {
@@ -2154,9 +2161,8 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 											token_length_in_chars++;
 										} else {
 											ValaSourceReference* _tmp49_;
-											_tmp49_ = NULL;
 											vala_report_error (_tmp49_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), "invalid UTF-8 character");
-											(_tmp49_ == NULL) ? NULL : (_tmp49_ = (vala_source_reference_unref (_tmp49_), NULL));
+											_vala_source_reference_unref0 (_tmp49_);
 										}
 									}
 								}
@@ -2172,11 +2178,9 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 							} else {
 								char* _tmp52_;
 								ValaSourceReference* _tmp51_;
-								_tmp52_ = NULL;
-								_tmp51_ = NULL;
 								vala_report_error (_tmp51_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column + token_length_in_chars, self->priv->line, self->priv->column + token_length_in_chars), _tmp52_ = g_strdup_printf ("syntax error, expected %c", (gint) begin[0]));
-								_tmp52_ = (g_free (_tmp52_), NULL);
-								(_tmp51_ == NULL) ? NULL : (_tmp51_ = (vala_source_reference_unref (_tmp51_), NULL));
+								_g_free0 (_tmp52_);
+								_vala_source_reference_unref0 (_tmp51_);
 							}
 							break;
 						}
@@ -2187,15 +2191,13 @@ ValaGenieTokenType vala_genie_scanner_read_token (ValaGenieScanner* self, ValaSo
 							if (u != ((gunichar) (-1))) {
 								ValaSourceReference* _tmp53_;
 								self->priv->current = self->priv->current + g_unichar_to_utf8 (u, NULL);
-								_tmp53_ = NULL;
 								vala_report_error (_tmp53_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, unexpected character");
-								(_tmp53_ == NULL) ? NULL : (_tmp53_ = (vala_source_reference_unref (_tmp53_), NULL));
+								_vala_source_reference_unref0 (_tmp53_);
 							} else {
 								ValaSourceReference* _tmp54_;
 								self->priv->current++;
-								_tmp54_ = NULL;
 								vala_report_error (_tmp54_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "invalid UTF-8 character");
-								(_tmp54_ == NULL) ? NULL : (_tmp54_ = (vala_source_reference_unref (_tmp54_), NULL));
+								_vala_source_reference_unref0 (_tmp54_);
 							}
 							self->priv->column++;
 							self->priv->last_token = VALA_GENIE_TOKEN_TYPE_STRING_LITERAL;
@@ -2263,7 +2265,6 @@ static gint vala_genie_scanner_count_tabs (ValaGenieScanner* self) {
 		}
 		tab_count = space_count / self->priv->_indent_spaces;
 	}
-	/* ignore comments and whitspace and other lines that contain no code */
 	vala_genie_scanner_space (self);
 	_tmp2_ = FALSE;
 	if (self->priv->current < self->priv->end) {
@@ -2419,11 +2420,8 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 		return result;
 	}
 	if (self->priv->current[1] == '/') {
-		gchar* begin;
-		char* _tmp4_;
-		/* single-line comment*/
+		gboolean _tmp4_;
 		self->priv->current = self->priv->current + 2;
-		begin = self->priv->current;
 		while (TRUE) {
 			gboolean _tmp3_;
 			_tmp3_ = FALSE;
@@ -2437,39 +2435,46 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 			}
 			self->priv->current++;
 		}
-		_tmp4_ = NULL;
-		vala_genie_scanner_push_comment (self, _tmp4_ = g_strndup ((const char*) begin, (gsize) ((glong) (self->priv->current - begin))), self->priv->line == 1);
-		_tmp4_ = (g_free (_tmp4_), NULL);
+		_tmp4_ = FALSE;
 		if (self->priv->current[0] == '\n') {
+			_tmp4_ = self->priv->last_token == VALA_GENIE_TOKEN_TYPE_EOL;
+		} else {
+			_tmp4_ = FALSE;
+		}
+		if (_tmp4_) {
 			self->priv->current++;
 			self->priv->line++;
 			self->priv->column = 1;
 			self->priv->current_indent_level = 0;
 		}
 	} else {
+		ValaSourceReference* source_reference;
 		gchar* begin;
 		gint begin_line;
-		char* _tmp8_;
-		/* delimited comment*/
+		source_reference = NULL;
+		if (self->priv->current[2] == '*') {
+			ValaSourceReference* _tmp5_;
+			source_reference = (_tmp5_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), _vala_source_reference_unref0 (source_reference), _tmp5_);
+		}
 		self->priv->current = self->priv->current + 2;
 		begin = self->priv->current;
 		begin_line = self->priv->line;
 		while (TRUE) {
-			gboolean _tmp5_;
-			_tmp5_ = FALSE;
+			gboolean _tmp6_;
+			_tmp6_ = FALSE;
 			if (self->priv->current < (self->priv->end - 1)) {
-				gboolean _tmp6_;
-				_tmp6_ = FALSE;
+				gboolean _tmp7_;
+				_tmp7_ = FALSE;
 				if (self->priv->current[0] != '*') {
-					_tmp6_ = TRUE;
+					_tmp7_ = TRUE;
 				} else {
-					_tmp6_ = self->priv->current[1] != '/';
+					_tmp7_ = self->priv->current[1] != '/';
 				}
-				_tmp5_ = _tmp6_;
+				_tmp6_ = _tmp7_;
 			} else {
-				_tmp5_ = FALSE;
+				_tmp6_ = FALSE;
 			}
-			if (!_tmp5_) {
+			if (!_tmp6_) {
 				break;
 			}
 			if (self->priv->current[0] == '\n') {
@@ -2480,18 +2485,29 @@ static gboolean vala_genie_scanner_comment (ValaGenieScanner* self) {
 			self->priv->column++;
 		}
 		if (self->priv->current == (self->priv->end - 1)) {
-			ValaSourceReference* _tmp7_;
-			_tmp7_ = NULL;
-			vala_report_error (_tmp7_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, expected */");
-			(_tmp7_ == NULL) ? NULL : (_tmp7_ = (vala_source_reference_unref (_tmp7_), NULL));
+			ValaSourceReference* _tmp8_;
+			vala_report_error (_tmp8_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, expected */");
+			_vala_source_reference_unref0 (_tmp8_);
 			result = TRUE;
+			_vala_source_reference_unref0 (source_reference);
 			return result;
 		}
-		_tmp8_ = NULL;
-		vala_genie_scanner_push_comment (self, _tmp8_ = g_strndup ((const char*) begin, (gsize) ((glong) (self->priv->current - begin))), begin_line == 1);
-		_tmp8_ = (g_free (_tmp8_), NULL);
+		if (source_reference != NULL) {
+			char* comment;
+			gboolean _tmp9_;
+			comment = g_strndup ((const char*) begin, (gsize) ((glong) (self->priv->current - begin)));
+			_tmp9_ = FALSE;
+			if (begin_line == 1) {
+				_tmp9_ = g_utf8_get_char (g_utf8_offset_to_pointer (comment, 0)) != '*';
+			} else {
+				_tmp9_ = FALSE;
+			}
+			vala_genie_scanner_push_comment (self, comment, source_reference, _tmp9_);
+			_g_free0 (comment);
+		}
 		self->priv->current = self->priv->current + 2;
 		self->priv->column = self->priv->column + 2;
+		_vala_source_reference_unref0 (source_reference);
 	}
 	result = TRUE;
 	return result;
@@ -2564,60 +2580,42 @@ static void vala_genie_scanner_space (ValaGenieScanner* self) {
 }
 
 
-static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char* comment_item, gboolean file_comment) {
+static void vala_genie_scanner_push_comment (ValaGenieScanner* self, const char* comment_item, ValaSourceReference* source_reference, gboolean file_comment) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (comment_item != NULL);
-	if (self->priv->_comment == NULL) {
-		char* _tmp1_;
-		const char* _tmp0_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		self->priv->_comment = (_tmp1_ = (_tmp0_ = comment_item, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp1_);
-	} else {
-		char* _tmp2_;
-		_tmp2_ = NULL;
-		self->priv->_comment = (_tmp2_ = g_strdup_printf ("%s\n%s", self->priv->_comment, comment_item), self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp2_);
+	g_return_if_fail (source_reference != NULL);
+	if (g_utf8_get_char (g_utf8_offset_to_pointer (comment_item, 0)) == '*') {
+		ValaComment* _tmp0_;
+		self->priv->_comment = (_tmp0_ = vala_comment_new (comment_item, source_reference), _vala_comment_unref0 (self->priv->_comment), _tmp0_);
 	}
 	if (file_comment) {
-		char* _tmp3_;
-		vala_source_file_set_comment (self->priv->_source_file, self->priv->_comment);
-		_tmp3_ = NULL;
-		self->priv->_comment = (_tmp3_ = NULL, self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp3_);
+		ValaComment* _tmp1_;
+		ValaComment* _tmp2_;
+		vala_source_file_add_comment (self->priv->_source_file, _tmp1_ = vala_comment_new (comment_item, source_reference));
+		_vala_comment_unref0 (_tmp1_);
+		self->priv->_comment = (_tmp2_ = NULL, _vala_comment_unref0 (self->priv->_comment), _tmp2_);
 	}
 }
 
 
-/**
- * Clears and returns the content of the comment stack.
- *
- * @return saved comment
- */
-char* vala_genie_scanner_pop_comment (ValaGenieScanner* self) {
-	char* result;
-	GString* result_builder;
-	char* _tmp0_;
-	const char* index;
-	const char* _tmp1_;
+static gpointer _vala_comment_ref0 (gpointer self) {
+	return self ? vala_comment_ref (self) : NULL;
+}
+
+
+ValaComment* vala_genie_scanner_pop_comment (ValaGenieScanner* self) {
+	ValaComment* result;
+	ValaComment* comment;
+	ValaComment* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_comment == NULL) {
 		result = NULL;
 		return result;
 	}
-	result_builder = g_string_new (self->priv->_comment);
-	_tmp0_ = NULL;
-	self->priv->_comment = (_tmp0_ = NULL, self->priv->_comment = (g_free (self->priv->_comment), NULL), _tmp0_);
-	index = NULL;
-	while (TRUE) {
-		if (!((index = g_utf8_strchr (result_builder->str, (gssize) (-1), (gunichar) '\t')) != NULL)) {
-			break;
-		}
-		g_string_erase (result_builder, g_utf8_pointer_to_offset (result_builder->str, index), (glong) 1);
-	}
-	_tmp1_ = NULL;
-	result = (_tmp1_ = result_builder->str, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
-	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
+	comment = _vala_comment_ref0 (self->priv->_comment);
+	self->priv->_comment = (_tmp0_ = NULL, _vala_comment_unref0 (self->priv->_comment), _tmp0_);
+	result = comment;
 	return result;
-	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
 }
 
 
@@ -2659,7 +2657,6 @@ static void vala_genie_scanner_pp_directive (ValaGenieScanner* self) {
 	gboolean _tmp1_;
 	gboolean _tmp6_;
 	g_return_if_fail (self != NULL);
-	/* hash sign*/
 	self->priv->current++;
 	self->priv->column++;
 	vala_genie_scanner_pp_whitespace (self);
@@ -2720,9 +2717,8 @@ static void vala_genie_scanner_pp_directive (ValaGenieScanner* self) {
 					vala_genie_scanner_parse_pp_endif (self);
 				} else {
 					ValaSourceReference* _tmp5_;
-					_tmp5_ = NULL;
 					vala_report_error (_tmp5_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column - len, self->priv->line, self->priv->column), "syntax error, invalid preprocessing directive");
-					(_tmp5_ == NULL) ? NULL : (_tmp5_ = (vala_source_reference_unref (_tmp5_), NULL));
+					_vala_source_reference_unref0 (_tmp5_);
 				}
 			}
 		}
@@ -2735,7 +2731,6 @@ static void vala_genie_scanner_pp_directive (ValaGenieScanner* self) {
 	}
 	if (_tmp6_) {
 		gboolean bol;
-		/* skip lines until next preprocessing directive*/
 		bol = FALSE;
 		while (TRUE) {
 			gboolean _tmp7_;
@@ -2749,7 +2744,6 @@ static void vala_genie_scanner_pp_directive (ValaGenieScanner* self) {
 				_tmp7_ = FALSE;
 			}
 			if (_tmp7_) {
-				/* go back to begin of line*/
 				self->priv->current = self->priv->current - (self->priv->column - 1);
 				self->priv->column = 1;
 				return;
@@ -2782,9 +2776,8 @@ static void vala_genie_scanner_pp_eol (ValaGenieScanner* self) {
 	}
 	if (_tmp0_) {
 		ValaSourceReference* _tmp1_;
-		_tmp1_ = NULL;
 		vala_report_error (_tmp1_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, expected newline");
-		(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_source_reference_unref (_tmp1_), NULL));
+		_vala_source_reference_unref0 (_tmp1_);
 	}
 }
 
@@ -2800,7 +2793,7 @@ static void _vala_array_add1 (ValaGenieScannerConditional** array, int* length,
 
 static void vala_genie_scanner_parse_pp_if (ValaGenieScanner* self) {
 	gboolean condition;
-	ValaGenieScannerConditional _tmp1_ = {0};
+	ValaGenieScannerConditional _tmp1_;
 	ValaGenieScannerConditional _tmp0_ = {0};
 	gboolean _tmp2_;
 	g_return_if_fail (self != NULL);
@@ -2822,10 +2815,8 @@ static void vala_genie_scanner_parse_pp_if (ValaGenieScanner* self) {
 		_tmp2_ = FALSE;
 	}
 	if (_tmp2_) {
-		/* condition true => process code within if*/
 		self->priv->conditional_stack[self->priv->conditional_stack_length1 - 1].matched = TRUE;
 	} else {
-		/* skip lines until next preprocessing directive*/
 		self->priv->conditional_stack[self->priv->conditional_stack_length1 - 1].skip_section = TRUE;
 	}
 }
@@ -2848,9 +2839,8 @@ static void vala_genie_scanner_parse_pp_elif (ValaGenieScanner* self) {
 	}
 	if (_tmp0_) {
 		ValaSourceReference* _tmp1_;
-		_tmp1_ = NULL;
 		vala_report_error (_tmp1_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, unexpected #elif");
-		(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_source_reference_unref (_tmp1_), NULL));
+		_vala_source_reference_unref0 (_tmp1_);
 		return;
 	}
 	_tmp2_ = FALSE;
@@ -2873,11 +2863,9 @@ static void vala_genie_scanner_parse_pp_elif (ValaGenieScanner* self) {
 		_tmp2_ = FALSE;
 	}
 	if (_tmp2_) {
-		/* condition true => process code within if*/
 		self->priv->conditional_stack[self->priv->conditional_stack_length1 - 1].matched = TRUE;
 		self->priv->conditional_stack[self->priv->conditional_stack_length1 - 1].skip_section = FALSE;
 	} else {
-		/* skip lines until next preprocessing directive*/
 		self->priv->conditional_stack[self->priv->conditional_stack_length1 - 1].skip_section = TRUE;
 	}
 }
@@ -2896,9 +2884,8 @@ static void vala_genie_scanner_parse_pp_else (ValaGenieScanner* self) {
 	}
 	if (_tmp0_) {
 		ValaSourceReference* _tmp1_;
-		_tmp1_ = NULL;
 		vala_report_error (_tmp1_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, unexpected #else");
-		(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_source_reference_unref (_tmp1_), NULL));
+		_vala_source_reference_unref0 (_tmp1_);
 		return;
 	}
 	_tmp2_ = FALSE;
@@ -2915,11 +2902,9 @@ static void vala_genie_scanner_parse_pp_else (ValaGenieScanner* self) {
 		_tmp2_ = FALSE;
 	}
 	if (_tmp2_) {
-		/* condition true => process code within if*/
 		self->priv->conditional_stack[self->priv->conditional_stack_length1 - 1].matched = TRUE;
 		self->priv->conditional_stack[self->priv->conditional_stack_length1 - 1].skip_section = FALSE;
 	} else {
-		/* skip lines until next preprocessing directive*/
 		self->priv->conditional_stack[self->priv->conditional_stack_length1 - 1].skip_section = TRUE;
 	}
 }
@@ -2930,9 +2915,8 @@ static void vala_genie_scanner_parse_pp_endif (ValaGenieScanner* self) {
 	vala_genie_scanner_pp_eol (self);
 	if (self->priv->conditional_stack_length1 == 0) {
 		ValaSourceReference* _tmp0_;
-		_tmp0_ = NULL;
 		vala_report_error (_tmp0_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, unexpected #endif");
-		(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_source_reference_unref (_tmp0_), NULL));
+		_vala_source_reference_unref0 (_tmp0_);
 		return;
 	}
 	self->priv->conditional_stack_length1--;
@@ -2963,9 +2947,8 @@ static gboolean vala_genie_scanner_parse_pp_symbol (ValaGenieScanner* self) {
 	}
 	if (len == 0) {
 		ValaSourceReference* _tmp1_;
-		_tmp1_ = NULL;
 		vala_report_error (_tmp1_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, expected identifier");
-		(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_source_reference_unref (_tmp1_), NULL));
+		_vala_source_reference_unref0 (_tmp1_);
 		result = FALSE;
 		return result;
 	}
@@ -2981,7 +2964,7 @@ static gboolean vala_genie_scanner_parse_pp_symbol (ValaGenieScanner* self) {
 		}
 	}
 	result = defined;
-	identifier = (g_free (identifier), NULL);
+	_g_free0 (identifier);
 	return result;
 }
 
@@ -2991,9 +2974,8 @@ static gboolean vala_genie_scanner_parse_pp_primary_expression (ValaGenieScanner
 	g_return_val_if_fail (self != NULL, FALSE);
 	if (self->priv->current >= self->priv->end) {
 		ValaSourceReference* _tmp0_;
-		_tmp0_ = NULL;
 		vala_report_error (_tmp0_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, expected identifier");
-		(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_source_reference_unref (_tmp0_), NULL));
+		_vala_source_reference_unref0 (_tmp0_);
 	} else {
 		if (vala_genie_scanner_is_ident_char (self, self->priv->current[0])) {
 			result = vala_genie_scanner_parse_pp_symbol (self);
@@ -3018,17 +3000,15 @@ static gboolean vala_genie_scanner_parse_pp_primary_expression (ValaGenieScanner
 					self->priv->column++;
 				} else {
 					ValaSourceReference* _tmp2_;
-					_tmp2_ = NULL;
 					vala_report_error (_tmp2_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, expected `)'");
-					(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_source_reference_unref (_tmp2_), NULL));
+					_vala_source_reference_unref0 (_tmp2_);
 				}
 				result = _result_;
 				return result;
 			} else {
 				ValaSourceReference* _tmp3_;
-				_tmp3_ = NULL;
 				vala_report_error (_tmp3_ = vala_source_reference_new (self->priv->_source_file, self->priv->line, self->priv->column, self->priv->line, self->priv->column), "syntax error, expected identifier");
-				(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_source_reference_unref (_tmp3_), NULL));
+				_vala_source_reference_unref0 (_tmp3_);
 			}
 		}
 	}
@@ -3221,13 +3201,15 @@ ValaSourceFile* vala_genie_scanner_get_source_file (ValaGenieScanner* self) {
 }
 
 
+static gpointer _vala_source_file_ref0 (gpointer self) {
+	return self ? vala_source_file_ref (self) : NULL;
+}
+
+
 static void vala_genie_scanner_set_source_file (ValaGenieScanner* self, ValaSourceFile* value) {
-	ValaSourceFile* _tmp1_;
 	ValaSourceFile* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_source_file = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_source_file_ref (_tmp0_)), (self->priv->_source_file == NULL) ? NULL : (self->priv->_source_file = (vala_source_file_unref (self->priv->_source_file), NULL)), _tmp1_);
+	self->priv->_source_file = (_tmp0_ = _vala_source_file_ref0 (value), _vala_source_file_unref0 (self->priv->_source_file), _tmp0_);
 }
 
 
@@ -3376,8 +3358,8 @@ static void vala_genie_scanner_instance_init (ValaGenieScanner * self) {
 static void vala_genie_scanner_finalize (ValaGenieScanner* obj) {
 	ValaGenieScanner * self;
 	self = VALA_GENIE_SCANNER (obj);
-	(self->priv->_source_file == NULL) ? NULL : (self->priv->_source_file = (vala_source_file_unref (self->priv->_source_file), NULL));
-	self->priv->_comment = (g_free (self->priv->_comment), NULL);
+	_vala_source_file_unref0 (self->priv->_source_file);
+	_vala_comment_unref0 (self->priv->_comment);
 	self->priv->conditional_stack = (g_free (self->priv->conditional_stack), NULL);
 }
 
