@@ -121,6 +121,7 @@ typedef struct _ValaExpressionPrivate ValaExpressionPrivate;
 typedef struct _ValaInitializerList ValaInitializerList;
 typedef struct _ValaInitializerListClass ValaInitializerListClass;
 typedef struct _ValaInitializerListPrivate ValaInitializerListPrivate;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -131,6 +132,7 @@ typedef struct _ValaInitializerListPrivate ValaInitializerListPrivate;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_REFERENCE_TYPE (vala_reference_type_get_type ())
 #define VALA_REFERENCE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_REFERENCE_TYPE, ValaReferenceType))
@@ -211,6 +213,7 @@ typedef struct _ValaStructClass ValaStructClass;
 
 typedef struct _ValaField ValaField;
 typedef struct _ValaFieldClass ValaFieldClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define TYPE_MEMBER_BINDING (member_binding_get_type ())
 
@@ -226,12 +229,6 @@ typedef struct _ValaUnaryExpressionClass ValaUnaryExpressionClass;
 
 #define VALA_TYPE_UNARY_OPERATOR (vala_unary_operator_get_type ())
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -252,9 +249,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -268,9 +262,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Represents an array or struct initializer list in the source code.
- */
 struct _ValaInitializerList {
 	ValaExpression parent_instance;
 	ValaInitializerListPrivate * priv;
@@ -303,6 +294,7 @@ typedef enum  {
 } ValaUnaryOperator;
 
 
+static gpointer vala_initializer_list_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -330,6 +322,7 @@ enum  {
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* expr);
 GeeList* vala_initializer_list_get_initializers (ValaInitializerList* self);
+ValaExpression* vala_expression_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -339,7 +332,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_reference);
 ValaInitializerList* vala_initializer_list_construct (GType object_type, ValaSourceReference* source_reference);
-ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_reference);
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_initializer_list_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 void vala_code_visitor_visit_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
@@ -388,16 +380,10 @@ gboolean vala_data_type_compatible (ValaDataType* self, ValaDataType* target_typ
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_initializer_list_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 gint vala_initializer_list_get_size (ValaInitializerList* self);
-static gpointer vala_initializer_list_parent_class = NULL;
 static void vala_initializer_list_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Appends the specified expression to this initializer 
- *
- * @param expr an expression
- */
 void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* expr) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (expr != NULL);
@@ -406,27 +392,18 @@ void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* ex
 }
 
 
-/**
- * Returns a copy of the expression 
- *
- * @return expression list
- */
 GeeList* vala_initializer_list_get_initializers (ValaInitializerList* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_EXPRESSION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->initializers);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_EXPRESSION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->initializers);
+	return result;
 }
 
 
-/**
- * Creates a new initializer 
- *
- * @param source_reference reference to source code
- * @return                 newly created initializer list
- */
 ValaInitializerList* vala_initializer_list_construct (GType object_type, ValaSourceReference* source_reference) {
 	ValaInitializerList* self;
 	g_return_val_if_fail (source_reference != NULL, NULL);
-	self = (ValaInitializerList*) g_type_create_instance (object_type);
+	self = (ValaInitializerList*) vala_expression_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
 }
@@ -444,13 +421,16 @@ static void vala_initializer_list_real_accept_children (ValaCodeNode* base, Vala
 	{
 		GeeIterator* _expr_it;
 		_expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->initializers);
-		while (gee_iterator_next (_expr_it)) {
+		while (TRUE) {
 			ValaExpression* expr;
+			if (!gee_iterator_next (_expr_it)) {
+				break;
+			}
 			expr = (ValaExpression*) gee_iterator_get (_expr_it);
 			vala_code_node_accept ((ValaCodeNode*) expr, visitor);
-			(expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL));
+			_vala_code_node_unref0 (expr);
 		}
-		(_expr_it == NULL) ? NULL : (_expr_it = (gee_collection_object_unref (_expr_it), NULL));
+		_gee_collection_object_unref0 (_expr_it);
 	}
 }
 
@@ -465,22 +445,29 @@ static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisit
 
 static gboolean vala_initializer_list_real_is_pure (ValaExpression* base) {
 	ValaInitializerList * self;
+	gboolean result;
 	self = (ValaInitializerList*) base;
 	{
 		GeeIterator* _initializer_it;
 		_initializer_it = gee_iterable_iterator ((GeeIterable*) self->priv->initializers);
-		while (gee_iterator_next (_initializer_it)) {
+		while (TRUE) {
 			ValaExpression* initializer;
+			if (!gee_iterator_next (_initializer_it)) {
+				break;
+			}
 			initializer = (ValaExpression*) gee_iterator_get (_initializer_it);
 			if (!vala_expression_is_pure (initializer)) {
-				gboolean _tmp0_;
-				return (_tmp0_ = FALSE, (initializer == NULL) ? NULL : (initializer = (vala_code_node_unref (initializer), NULL)), (_initializer_it == NULL) ? NULL : (_initializer_it = (gee_collection_object_unref (_initializer_it), NULL)), _tmp0_);
+				result = FALSE;
+				_vala_code_node_unref0 (initializer);
+				_gee_collection_object_unref0 (_initializer_it);
+				return result;
 			}
-			(initializer == NULL) ? NULL : (initializer = (vala_code_node_unref (initializer), NULL));
+			_vala_code_node_unref0 (initializer);
 		}
-		(_initializer_it == NULL) ? NULL : (_initializer_it = (gee_collection_object_unref (_initializer_it), NULL));
+		_gee_collection_object_unref0 (_initializer_it);
 	}
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
@@ -492,266 +479,269 @@ static void vala_initializer_list_real_replace_expression (ValaCodeNode* base, V
 	{
 		gint i;
 		i = 0;
-		for (; i < gee_collection_get_size ((GeeCollection*) self->priv->initializers); i++) {
-			ValaExpression* _tmp0_;
-			gboolean _tmp1_;
-			_tmp0_ = NULL;
-			if ((_tmp1_ = (_tmp0_ = (ValaExpression*) gee_list_get (self->priv->initializers, i)) == old_node, (_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL)), _tmp1_)) {
-				gee_list_set (self->priv->initializers, i, new_node);
+		{
+			gboolean _tmp0_;
+			_tmp0_ = TRUE;
+			while (TRUE) {
+				ValaExpression* _tmp1_;
+				gboolean _tmp2_;
+				if (!_tmp0_) {
+					i++;
+				}
+				_tmp0_ = FALSE;
+				if (!(i < gee_collection_get_size ((GeeCollection*) self->priv->initializers))) {
+					break;
+				}
+				if ((_tmp2_ = (_tmp1_ = (ValaExpression*) gee_list_get (self->priv->initializers, i)) == old_node, _vala_code_node_unref0 (_tmp1_), _tmp2_)) {
+					gee_list_set (self->priv->initializers, i, new_node);
+				}
 			}
 		}
 	}
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_initializer_list_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaInitializerList * self;
+	gboolean result;
 	gboolean _error_;
 	self = (ValaInitializerList*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (vala_expression_get_target_type ((ValaExpression*) self) == NULL) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "initializer list used for unknown type");
-		return FALSE;
+		result = FALSE;
+		return result;
 	} else {
 		if (VALA_IS_ARRAY_TYPE (vala_expression_get_target_type ((ValaExpression*) self))) {
-			ValaArrayType* _tmp2_;
 			ValaArrayType* array_type;
-			gboolean _tmp3_;
-			gboolean _tmp4_;
+			gboolean _tmp0_;
+			gboolean _tmp1_;
 			ValaDataType* inner_target_type;
-			/* initializer is used as array initializer */
-			_tmp2_ = NULL;
-			array_type = (_tmp2_ = VALA_ARRAY_TYPE (vala_expression_get_target_type ((ValaExpression*) self)), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
-			_tmp3_ = FALSE;
-			_tmp4_ = FALSE;
+			array_type = _vala_code_node_ref0 (VALA_ARRAY_TYPE (vala_expression_get_target_type ((ValaExpression*) self)));
+			_tmp0_ = FALSE;
+			_tmp1_ = FALSE;
 			if (!VALA_IS_ARRAY_CREATION_EXPRESSION (vala_code_node_get_parent_node ((ValaCodeNode*) self))) {
-				_tmp4_ = !VALA_IS_CONSTANT (vala_code_node_get_parent_node ((ValaCodeNode*) self));
+				_tmp1_ = !VALA_IS_CONSTANT (vala_code_node_get_parent_node ((ValaCodeNode*) self));
 			} else {
-				_tmp4_ = FALSE;
+				_tmp1_ = FALSE;
 			}
-			if (_tmp4_) {
-				_tmp3_ = !VALA_IS_INITIALIZER_LIST (vala_code_node_get_parent_node ((ValaCodeNode*) self));
+			if (_tmp1_) {
+				_tmp0_ = !VALA_IS_INITIALIZER_LIST (vala_code_node_get_parent_node ((ValaCodeNode*) self));
 			} else {
-				_tmp3_ = FALSE;
+				_tmp0_ = FALSE;
 			}
-			if (_tmp3_) {
-				ValaCodeNode* _tmp5_;
+			if (_tmp0_) {
 				ValaCodeNode* old_parent_node;
-				ValaDataType* _tmp6_;
-				ValaArrayCreationExpression* _tmp7_;
+				ValaDataType* _tmp2_;
+				ValaArrayCreationExpression* _tmp3_;
 				ValaArrayCreationExpression* array_creation;
-				gboolean _tmp8_;
-				/* transform shorthand form
-				     int[] array = { 42 };
-				 into
-				     int[] array = new int[] { 42 };*/
-				_tmp5_ = NULL;
-				old_parent_node = (_tmp5_ = vala_code_node_get_parent_node ((ValaCodeNode*) self), (_tmp5_ == NULL) ? NULL : vala_code_node_ref (_tmp5_));
-				_tmp6_ = NULL;
-				_tmp7_ = NULL;
-				array_creation = (_tmp7_ = vala_array_creation_expression_new (_tmp6_ = vala_data_type_copy (vala_array_type_get_element_type (array_type)), vala_array_type_get_rank (array_type), self, vala_code_node_get_source_reference ((ValaCodeNode*) self)), (_tmp6_ == NULL) ? NULL : (_tmp6_ = (vala_code_node_unref (_tmp6_), NULL)), _tmp7_);
+				old_parent_node = _vala_code_node_ref0 (vala_code_node_get_parent_node ((ValaCodeNode*) self));
+				array_creation = (_tmp3_ = vala_array_creation_expression_new (_tmp2_ = vala_data_type_copy (vala_array_type_get_element_type (array_type)), vala_array_type_get_rank (array_type), self, vala_code_node_get_source_reference ((ValaCodeNode*) self)), _vala_code_node_unref0 (_tmp2_), _tmp3_);
 				vala_expression_set_target_type ((ValaExpression*) array_creation, vala_expression_get_target_type ((ValaExpression*) self));
 				vala_code_node_replace_expression (old_parent_node, (ValaExpression*) self, (ValaExpression*) array_creation);
 				vala_code_node_set_checked ((ValaCodeNode*) self, FALSE);
-				return (_tmp8_ = vala_code_node_check ((ValaCodeNode*) array_creation, analyzer), (old_parent_node == NULL) ? NULL : (old_parent_node = (vala_code_node_unref (old_parent_node), NULL)), (array_creation == NULL) ? NULL : (array_creation = (vala_code_node_unref (array_creation), NULL)), (array_type == NULL) ? NULL : (array_type = (vala_code_node_unref (array_type), NULL)), _tmp8_);
+				result = vala_code_node_check ((ValaCodeNode*) array_creation, analyzer);
+				_vala_code_node_unref0 (old_parent_node);
+				_vala_code_node_unref0 (array_creation);
+				_vala_code_node_unref0 (array_type);
+				return result;
 			}
 			inner_target_type = NULL;
 			if (vala_array_type_get_rank (array_type) > 1) {
 				ValaArrayType* inner_array_type;
-				gint _tmp9_;
-				ValaDataType* _tmp11_;
-				ValaDataType* _tmp10_;
-				/* allow initialization of multi-dimensional arrays*/
+				gint _tmp4_;
+				ValaDataType* _tmp5_;
 				inner_array_type = VALA_ARRAY_TYPE (vala_data_type_copy ((ValaDataType*) array_type));
-				_tmp9_ = vala_array_type_get_rank (inner_array_type);
-				vala_array_type_set_rank (inner_array_type, _tmp9_ - 1);
-				_tmp9_;
-				_tmp11_ = NULL;
-				_tmp10_ = NULL;
-				inner_target_type = (_tmp11_ = (_tmp10_ = (ValaDataType*) inner_array_type, (_tmp10_ == NULL) ? NULL : vala_code_node_ref (_tmp10_)), (inner_target_type == NULL) ? NULL : (inner_target_type = (vala_code_node_unref (inner_target_type), NULL)), _tmp11_);
-				(inner_array_type == NULL) ? NULL : (inner_array_type = (vala_code_node_unref (inner_array_type), NULL));
+				_tmp4_ = vala_array_type_get_rank (inner_array_type);
+				vala_array_type_set_rank (inner_array_type, _tmp4_ - 1);
+				_tmp4_;
+				inner_target_type = (_tmp5_ = _vala_code_node_ref0 ((ValaDataType*) inner_array_type), _vala_code_node_unref0 (inner_target_type), _tmp5_);
+				_vala_code_node_unref0 (inner_array_type);
 			} else {
-				ValaDataType* _tmp12_;
-				_tmp12_ = NULL;
-				inner_target_type = (_tmp12_ = vala_data_type_copy (vala_array_type_get_element_type (array_type)), (inner_target_type == NULL) ? NULL : (inner_target_type = (vala_code_node_unref (inner_target_type), NULL)), _tmp12_);
+				ValaDataType* _tmp6_;
+				inner_target_type = (_tmp6_ = vala_data_type_copy (vala_array_type_get_element_type (array_type)), _vala_code_node_unref0 (inner_target_type), _tmp6_);
 			}
 			{
-				GeeList* _tmp13_;
-				GeeIterator* _tmp14_;
+				GeeList* _tmp7_;
+				GeeIterator* _tmp8_;
 				GeeIterator* _e_it;
-				_tmp13_ = NULL;
-				_tmp14_ = NULL;
-				_e_it = (_tmp14_ = gee_iterable_iterator ((GeeIterable*) (_tmp13_ = vala_initializer_list_get_initializers (self))), (_tmp13_ == NULL) ? NULL : (_tmp13_ = (gee_collection_object_unref (_tmp13_), NULL)), _tmp14_);
-				while (gee_iterator_next (_e_it)) {
+				_e_it = (_tmp8_ = gee_iterable_iterator ((GeeIterable*) (_tmp7_ = vala_initializer_list_get_initializers (self))), _gee_collection_object_unref0 (_tmp7_), _tmp8_);
+				while (TRUE) {
 					ValaExpression* e;
+					if (!gee_iterator_next (_e_it)) {
+						break;
+					}
 					e = (ValaExpression*) gee_iterator_get (_e_it);
 					vala_expression_set_target_type (e, inner_target_type);
-					(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
+					_vala_code_node_unref0 (e);
 				}
-				(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+				_gee_collection_object_unref0 (_e_it);
 			}
-			(array_type == NULL) ? NULL : (array_type = (vala_code_node_unref (array_type), NULL));
-			(inner_target_type == NULL) ? NULL : (inner_target_type = (vala_code_node_unref (inner_target_type), NULL));
+			_vala_code_node_unref0 (array_type);
+			_vala_code_node_unref0 (inner_target_type);
 		} else {
 			if (VALA_IS_STRUCT (vala_data_type_get_data_type (vala_expression_get_target_type ((ValaExpression*) self)))) {
-				ValaStruct* _tmp15_;
 				ValaStruct* st;
-				GeeList* _tmp16_;
-				GeeIterator* _tmp17_;
+				GeeList* _tmp9_;
+				GeeIterator* _tmp10_;
 				GeeIterator* field_it;
-				/* initializer is used as struct initializer */
-				_tmp15_ = NULL;
-				st = (_tmp15_ = VALA_STRUCT (vala_data_type_get_data_type (vala_expression_get_target_type ((ValaExpression*) self))), (_tmp15_ == NULL) ? NULL : vala_code_node_ref (_tmp15_));
-				_tmp16_ = NULL;
-				_tmp17_ = NULL;
-				field_it = (_tmp17_ = gee_iterable_iterator ((GeeIterable*) (_tmp16_ = vala_struct_get_fields (st))), (_tmp16_ == NULL) ? NULL : (_tmp16_ = (gee_collection_object_unref (_tmp16_), NULL)), _tmp17_);
+				st = _vala_code_node_ref0 (VALA_STRUCT (vala_data_type_get_data_type (vala_expression_get_target_type ((ValaExpression*) self))));
+				field_it = (_tmp10_ = gee_iterable_iterator ((GeeIterable*) (_tmp9_ = vala_struct_get_fields (st))), _gee_collection_object_unref0 (_tmp9_), _tmp10_);
 				{
-					GeeList* _tmp18_;
-					GeeIterator* _tmp19_;
+					GeeList* _tmp11_;
+					GeeIterator* _tmp12_;
 					GeeIterator* _e_it;
-					_tmp18_ = NULL;
-					_tmp19_ = NULL;
-					_e_it = (_tmp19_ = gee_iterable_iterator ((GeeIterable*) (_tmp18_ = vala_initializer_list_get_initializers (self))), (_tmp18_ == NULL) ? NULL : (_tmp18_ = (gee_collection_object_unref (_tmp18_), NULL)), _tmp19_);
-					while (gee_iterator_next (_e_it)) {
+					_e_it = (_tmp12_ = gee_iterable_iterator ((GeeIterable*) (_tmp11_ = vala_initializer_list_get_initializers (self))), _gee_collection_object_unref0 (_tmp11_), _tmp12_);
+					while (TRUE) {
 						ValaExpression* e;
 						ValaField* field;
-						ValaDataType* _tmp25_;
+						ValaDataType* _tmp17_;
+						if (!gee_iterator_next (_e_it)) {
+							break;
+						}
 						e = (ValaExpression*) gee_iterator_get (_e_it);
 						field = NULL;
-						while (field == NULL) {
-							ValaField* _tmp23_;
-							if (!gee_iterator_next (field_it)) {
-								char* _tmp21_;
-								char* _tmp20_;
-								gboolean _tmp22_;
-								vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-								_tmp21_ = NULL;
-								_tmp20_ = NULL;
-								vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), _tmp21_ = g_strdup_printf ("too many expressions in initializer list for `%s'", _tmp20_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type ((ValaExpression*) self))));
-								_tmp21_ = (g_free (_tmp21_), NULL);
-								_tmp20_ = (g_free (_tmp20_), NULL);
-								return (_tmp22_ = FALSE, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL)), (_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (field_it == NULL) ? NULL : (field_it = (gee_collection_object_unref (field_it), NULL)), _tmp22_);
+						while (TRUE) {
+							ValaField* _tmp15_;
+							if (!(field == NULL)) {
+								break;
 							}
-							_tmp23_ = NULL;
-							field = (_tmp23_ = (ValaField*) gee_iterator_get (field_it), (field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL)), _tmp23_);
+							if (!gee_iterator_next (field_it)) {
+								char* _tmp14_;
+								char* _tmp13_;
+								vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+								vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), _tmp14_ = g_strdup_printf ("too many expressions in initializer list for `%s'", _tmp13_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type ((ValaExpression*) self))));
+								_g_free0 (_tmp14_);
+								_g_free0 (_tmp13_);
+								result = FALSE;
+								_vala_code_node_unref0 (e);
+								_vala_code_node_unref0 (field);
+								_gee_collection_object_unref0 (_e_it);
+								_vala_code_node_unref0 (st);
+								_gee_collection_object_unref0 (field_it);
+								return result;
+							}
+							field = (_tmp15_ = (ValaField*) gee_iterator_get (field_it), _vala_code_node_unref0 (field), _tmp15_);
 							if (vala_field_get_binding (field) != MEMBER_BINDING_INSTANCE) {
-								ValaField* _tmp24_;
-								/* we only initialize instance fields*/
-								_tmp24_ = NULL;
-								field = (_tmp24_ = NULL, (field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL)), _tmp24_);
+								ValaField* _tmp16_;
+								field = (_tmp16_ = NULL, _vala_code_node_unref0 (field), _tmp16_);
 							}
 						}
-						_tmp25_ = NULL;
-						vala_expression_set_target_type (e, _tmp25_ = vala_data_type_copy (vala_field_get_field_type (field)));
-						(_tmp25_ == NULL) ? NULL : (_tmp25_ = (vala_code_node_unref (_tmp25_), NULL));
+						vala_expression_set_target_type (e, _tmp17_ = vala_data_type_copy (vala_field_get_field_type (field)));
+						_vala_code_node_unref0 (_tmp17_);
 						if (!vala_data_type_get_value_owned (vala_expression_get_target_type ((ValaExpression*) self))) {
 							vala_data_type_set_value_owned (vala_expression_get_target_type (e), FALSE);
 						}
-						(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
-						(field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL));
+						_vala_code_node_unref0 (e);
+						_vala_code_node_unref0 (field);
 					}
-					(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+					_gee_collection_object_unref0 (_e_it);
 				}
-				(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
-				(field_it == NULL) ? NULL : (field_it = (gee_collection_object_unref (field_it), NULL));
+				_vala_code_node_unref0 (st);
+				_gee_collection_object_unref0 (field_it);
 			} else {
-				char* _tmp27_;
-				char* _tmp26_;
+				char* _tmp19_;
+				char* _tmp18_;
 				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-				_tmp27_ = NULL;
-				_tmp26_ = NULL;
-				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp27_ = g_strdup_printf ("initializer list used for `%s', which is neither array nor struct", _tmp26_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type ((ValaExpression*) self))));
-				_tmp27_ = (g_free (_tmp27_), NULL);
-				_tmp26_ = (g_free (_tmp26_), NULL);
-				return FALSE;
+				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp19_ = g_strdup_printf ("initializer list used for `%s', which is neither array nor struct", _tmp18_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type ((ValaExpression*) self))));
+				_g_free0 (_tmp19_);
+				_g_free0 (_tmp18_);
+				result = FALSE;
+				return result;
 			}
 		}
 	}
 	{
 		GeeIterator* _expr_it;
 		_expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->initializers);
-		while (gee_iterator_next (_expr_it)) {
+		while (TRUE) {
 			ValaExpression* expr;
+			if (!gee_iterator_next (_expr_it)) {
+				break;
+			}
 			expr = (ValaExpression*) gee_iterator_get (_expr_it);
 			vala_code_node_check ((ValaCodeNode*) expr, analyzer);
-			(expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL));
+			_vala_code_node_unref0 (expr);
 		}
-		(_expr_it == NULL) ? NULL : (_expr_it = (gee_collection_object_unref (_expr_it), NULL));
+		_gee_collection_object_unref0 (_expr_it);
 	}
 	_error_ = FALSE;
 	{
-		GeeList* _tmp29_;
-		GeeIterator* _tmp30_;
+		GeeList* _tmp20_;
+		GeeIterator* _tmp21_;
 		GeeIterator* _e_it;
-		_tmp29_ = NULL;
-		_tmp30_ = NULL;
-		_e_it = (_tmp30_ = gee_iterable_iterator ((GeeIterable*) (_tmp29_ = vala_initializer_list_get_initializers (self))), (_tmp29_ == NULL) ? NULL : (_tmp29_ = (gee_collection_object_unref (_tmp29_), NULL)), _tmp30_);
-		while (gee_iterator_next (_e_it)) {
+		_e_it = (_tmp21_ = gee_iterable_iterator ((GeeIterable*) (_tmp20_ = vala_initializer_list_get_initializers (self))), _gee_collection_object_unref0 (_tmp20_), _tmp21_);
+		while (TRUE) {
 			ValaExpression* e;
-			ValaUnaryExpression* _tmp32_;
-			ValaExpression* _tmp31_;
+			ValaExpression* _tmp22_;
 			ValaUnaryExpression* unary;
-			gboolean _tmp33_;
+			gboolean _tmp23_;
+			if (!gee_iterator_next (_e_it)) {
+				break;
+			}
 			e = (ValaExpression*) gee_iterator_get (_e_it);
 			if (vala_expression_get_value_type (e) == NULL) {
 				_error_ = TRUE;
-				(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
+				_vala_code_node_unref0 (e);
 				continue;
 			}
-			_tmp32_ = NULL;
-			_tmp31_ = NULL;
-			unary = (_tmp32_ = (_tmp31_ = e, VALA_IS_UNARY_EXPRESSION (_tmp31_) ? ((ValaUnaryExpression*) _tmp31_) : NULL), (_tmp32_ == NULL) ? NULL : vala_code_node_ref (_tmp32_));
-			_tmp33_ = FALSE;
+			unary = _vala_code_node_ref0 ((_tmp22_ = e, VALA_IS_UNARY_EXPRESSION (_tmp22_) ? ((ValaUnaryExpression*) _tmp22_) : NULL));
+			_tmp23_ = FALSE;
 			if (unary != NULL) {
-				gboolean _tmp34_;
-				_tmp34_ = FALSE;
+				gboolean _tmp24_;
+				_tmp24_ = FALSE;
 				if (vala_unary_expression_get_operator (unary) == VALA_UNARY_OPERATOR_REF) {
-					_tmp34_ = TRUE;
+					_tmp24_ = TRUE;
 				} else {
-					_tmp34_ = vala_unary_expression_get_operator (unary) == VALA_UNARY_OPERATOR_OUT;
+					_tmp24_ = vala_unary_expression_get_operator (unary) == VALA_UNARY_OPERATOR_OUT;
 				}
-				_tmp33_ = _tmp34_;
+				_tmp23_ = _tmp24_;
 			} else {
-				_tmp33_ = FALSE;
+				_tmp23_ = FALSE;
 			}
-			if (_tmp33_) {
+			if (_tmp23_) {
 			} else {
 				if (!vala_data_type_compatible (vala_expression_get_value_type (e), vala_expression_get_target_type (e))) {
-					char* _tmp37_;
-					char* _tmp36_;
-					char* _tmp35_;
+					char* _tmp27_;
+					char* _tmp26_;
+					char* _tmp25_;
 					_error_ = TRUE;
 					vala_code_node_set_error ((ValaCodeNode*) e, TRUE);
-					_tmp37_ = NULL;
-					_tmp36_ = NULL;
-					_tmp35_ = NULL;
-					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), _tmp37_ = g_strdup_printf ("Expected initializer of type `%s' but got `%s'", _tmp35_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type (e)), _tmp36_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (e))));
-					_tmp37_ = (g_free (_tmp37_), NULL);
-					_tmp36_ = (g_free (_tmp36_), NULL);
-					_tmp35_ = (g_free (_tmp35_), NULL);
+					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), _tmp27_ = g_strdup_printf ("Expected initializer of type `%s' but got `%s'", _tmp25_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type (e)), _tmp26_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (e))));
+					_g_free0 (_tmp27_);
+					_g_free0 (_tmp26_);
+					_g_free0 (_tmp25_);
 				}
 			}
-			(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
-			(unary == NULL) ? NULL : (unary = (vala_code_node_unref (unary), NULL));
+			_vala_code_node_unref0 (e);
+			_vala_code_node_unref0 (unary);
 		}
-		(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+		_gee_collection_object_unref0 (_e_it);
 	}
 	if (!_error_) {
-		/* everything seems to be correct */
 		vala_expression_set_value_type ((ValaExpression*) self, vala_expression_get_target_type ((ValaExpression*) self));
 	}
-	return !_error_;
+	result = !_error_;
+	return result;
 }
 
 
 gint vala_initializer_list_get_size (ValaInitializerList* self) {
+	gint result;
 	g_return_val_if_fail (self != NULL, 0);
-	return gee_collection_get_size ((GeeCollection*) self->priv->initializers);
+	result = gee_collection_get_size ((GeeCollection*) self->priv->initializers);
+	return result;
 }
 
 
@@ -776,7 +766,7 @@ static void vala_initializer_list_instance_init (ValaInitializerList * self) {
 static void vala_initializer_list_finalize (ValaCodeNode* obj) {
 	ValaInitializerList * self;
 	self = VALA_INITIALIZER_LIST (obj);
-	(self->priv->initializers == NULL) ? NULL : (self->priv->initializers = (gee_collection_object_unref (self->priv->initializers), NULL));
+	_gee_collection_object_unref0 (self->priv->initializers);
 	VALA_CODE_NODE_CLASS (vala_initializer_list_parent_class)->finalize (obj);
 }
 
