@@ -190,13 +190,10 @@ typedef struct _ValaInterfaceClass ValaInterfaceClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -217,10 +214,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -250,9 +243,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * A reference type, i.e. a class, interface, or array type.
- */
 struct _ValaReferenceType {
 	ValaDataType parent_instance;
 	ValaReferenceTypePrivate * priv;
@@ -262,9 +252,6 @@ struct _ValaReferenceTypeClass {
 	ValaDataTypeClass parent_class;
 };
 
-/**
- * An interface type.
- */
 struct _ValaInterfaceType {
 	ValaReferenceType parent_instance;
 	ValaInterfaceTypePrivate * priv;
@@ -315,6 +302,7 @@ GType vala_interface_get_type (void);
 enum  {
 	VALA_INTERFACE_TYPE_DUMMY_PROPERTY
 };
+ValaReferenceType* vala_reference_type_construct (GType object_type);
 void vala_interface_type_set_interface_symbol (ValaInterfaceType* self, ValaInterface* value);
 ValaInterfaceType* vala_interface_type_new (ValaInterface* interface_symbol);
 ValaInterfaceType* vala_interface_type_construct (GType object_type, ValaInterface* interface_symbol);
@@ -348,7 +336,7 @@ static void vala_interface_type_finalize (ValaCodeNode* obj);
 ValaInterfaceType* vala_interface_type_construct (GType object_type, ValaInterface* interface_symbol) {
 	ValaInterfaceType* self;
 	g_return_val_if_fail (interface_symbol != NULL, NULL);
-	self = (ValaInterfaceType*) g_type_create_instance (object_type);
+	self = (ValaInterfaceType*) vala_reference_type_construct (object_type);
 	vala_interface_type_set_interface_symbol (self, interface_symbol);
 	return self;
 }
@@ -374,9 +362,7 @@ static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 		GeeList* _tmp0_;
 		GeeIterator* _tmp1_;
 		GeeIterator* _arg_it;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
+		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
 		while (TRUE) {
 			ValaDataType* arg;
 			ValaDataType* _tmp2_;
@@ -384,12 +370,11 @@ static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 				break;
 			}
 			arg = (ValaDataType*) gee_iterator_get (_arg_it);
-			_tmp2_ = NULL;
 			vala_data_type_add_type_argument ((ValaDataType*) _result_, _tmp2_ = vala_data_type_copy (arg));
-			(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
-			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+			_vala_code_node_unref0 (_tmp2_);
+			_vala_code_node_unref0 (arg);
 		}
-		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
+		_gee_collection_object_unref0 (_arg_it);
 	}
 	result = (ValaDataType*) _result_;
 	return result;
@@ -402,9 +387,7 @@ static char* vala_interface_type_real_get_cname (ValaDataType* base) {
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaInterfaceType*) base;
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = g_strdup_printf ("%sIface*", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_interface_symbol, FALSE)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strdup_printf ("%sIface*", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_interface_symbol, FALSE)), _g_free0 (_tmp0_), _tmp1_);
 	return result;
 }
 
