@@ -120,6 +120,18 @@ typedef struct _ValaMember ValaMember;
 typedef struct _ValaMemberClass ValaMemberClass;
 typedef struct _ValaMemberPrivate ValaMemberPrivate;
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+#define _vala_comment_unref0(var) ((var == NULL) ? NULL : (var = (vala_comment_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
 #define VALA_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
@@ -129,6 +141,7 @@ typedef struct _ValaMemberPrivate ValaMemberPrivate;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
 #define VALA_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFile))
@@ -179,6 +192,7 @@ typedef struct _ValaClassClass ValaClassClass;
 
 typedef struct _ValaScope ValaScope;
 typedef struct _ValaScopeClass ValaScopeClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SYMBOL_ACCESSIBILITY (vala_symbol_accessibility_get_type ())
 
@@ -194,12 +208,6 @@ typedef struct _ValaStructClass ValaStructClass;
 
 #define TYPE_MEMBER_BINDING (member_binding_get_type ())
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -220,9 +228,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -238,9 +243,6 @@ struct _ValaSymbolClass {
 	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a general class member.
- */
 struct _ValaMember {
 	ValaSymbol parent_instance;
 	ValaMemberPrivate * priv;
@@ -251,6 +253,7 @@ struct _ValaMemberClass {
 };
 
 struct _ValaMemberPrivate {
+	ValaComment* _comment;
 	GeeList* cheader_filenames;
 	gboolean _hides;
 };
@@ -290,6 +293,12 @@ GType vala_symbol_get_type (void);
 GType vala_local_variable_get_type (void);
 GType vala_attribute_get_type (void);
 GType vala_member_get_type (void);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
 #define VALA_MEMBER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_MEMBER, ValaMemberPrivate))
 enum  {
 	VALA_MEMBER_DUMMY_PROPERTY
@@ -300,10 +309,9 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaMember* vala_member_new (const char* name, ValaSourceReference* source_reference);
-ValaMember* vala_member_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
+void vala_member_set_comment (ValaMember* self, ValaComment* value);
+ValaMember* vala_member_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
 void vala_code_visitor_visit_member (ValaCodeVisitor* self, ValaMember* m);
 static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self);
@@ -338,6 +346,7 @@ ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self);
 GType vala_struct_get_type (void);
 ValaStruct* vala_struct_get_base_struct (ValaStruct* self);
 ValaSymbol* vala_member_get_hidden_member (ValaMember* self);
+ValaComment* vala_member_get_comment (ValaMember* self);
 gboolean vala_member_get_hides (ValaMember* self);
 void vala_member_set_hides (ValaMember* self, gboolean value);
 static void vala_member_finalize (ValaCodeNode* obj);
@@ -345,18 +354,14 @@ GType member_binding_get_type (void);
 
 
 
-ValaMember* vala_member_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+ValaMember* vala_member_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment) {
 	ValaMember* self;
 	self = (ValaMember*) vala_symbol_construct (object_type, name, source_reference);
+	vala_member_set_comment (self, comment);
 	return self;
 }
 
 
-ValaMember* vala_member_new (const char* name, ValaSourceReference* source_reference) {
-	return vala_member_construct (VALA_TYPE_MEMBER, name, source_reference);
-}
-
-
 static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMember * self;
 	self = (ValaMember*) base;
@@ -379,29 +384,21 @@ static GeeList* vala_member_real_get_cheader_filenames (ValaSymbol* base) {
 	if (_tmp0_) {
 		gboolean _tmp3_;
 		gboolean _tmp4_;
-		/* default to header filenames of the namespace */
 		{
 			GeeList* _tmp1_;
 			GeeIterator* _tmp2_;
 			GeeIterator* _filename_it;
-			/* default to header filenames of the namespace */
-			_tmp1_ = NULL;
-			_tmp2_ = NULL;
-			_filename_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol ((ValaSymbol*) self)))), (_tmp1_ == NULL) ? NULL : (_tmp1_ = (gee_collection_object_unref (_tmp1_), NULL)), _tmp2_);
-			/* default to header filenames of the namespace */
+			_filename_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol ((ValaSymbol*) self)))), _gee_collection_object_unref0 (_tmp1_), _tmp2_);
 			while (TRUE) {
 				char* filename;
-				/* default to header filenames of the namespace */
 				if (!gee_iterator_next (_filename_it)) {
-					/* default to header filenames of the namespace */
 					break;
 				}
-				/* default to header filenames of the namespace */
 				filename = (char*) gee_iterator_get (_filename_it);
 				vala_member_add_cheader_filename (self, filename);
-				filename = (g_free (filename), NULL);
+				_g_free0 (filename);
 			}
-			(_filename_it == NULL) ? NULL : (_filename_it = (gee_collection_object_unref (_filename_it), NULL));
+			_gee_collection_object_unref0 (_filename_it);
 		}
 		_tmp3_ = FALSE;
 		_tmp4_ = FALSE;
@@ -417,10 +414,8 @@ static GeeList* vala_member_real_get_cheader_filenames (ValaSymbol* base) {
 		}
 		if (_tmp3_) {
 			char* _tmp5_;
-			/* don't add default include directives for VAPI files*/
-			_tmp5_ = NULL;
 			gee_collection_add ((GeeCollection*) self->priv->cheader_filenames, _tmp5_ = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-			_tmp5_ = (g_free (_tmp5_), NULL);
+			_g_free0 (_tmp5_);
 		}
 	}
 	result = (GeeList*) gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->cheader_filenames);
@@ -428,12 +423,6 @@ static GeeList* vala_member_real_get_cheader_filenames (ValaSymbol* base) {
 }
 
 
-/**
- * Adds a filename to the list of C header filenames users of this data
- * type must include.
- *
- * @param filename a C header filename
- */
 void vala_member_add_cheader_filename (ValaMember* self, const char* filename) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (filename != NULL);
@@ -441,82 +430,95 @@ void vala_member_add_cheader_filename (ValaMember* self, const char* filename) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 ValaSymbol* vala_member_get_hidden_member (ValaMember* self) {
 	ValaSymbol* result;
 	ValaSymbol* sym;
 	g_return_val_if_fail (self != NULL, NULL);
 	sym = NULL;
 	if (VALA_IS_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
-		ValaClass* _tmp0_;
 		ValaClass* cl;
-		_tmp0_ = NULL;
-		cl = (_tmp0_ = vala_class_get_base_class (VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self))), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+		cl = _vala_code_node_ref0 (vala_class_get_base_class (VALA_CLASS (vala_symbol_get_parent_symbol ((ValaSymbol*) self))));
 		while (TRUE) {
-			ValaSymbol* _tmp1_;
-			gboolean _tmp2_;
-			ValaClass* _tmp4_;
-			ValaClass* _tmp3_;
+			ValaSymbol* _tmp0_;
+			gboolean _tmp1_;
+			ValaClass* _tmp2_;
 			if (!(cl != NULL)) {
 				break;
 			}
-			_tmp1_ = NULL;
-			sym = (_tmp1_ = vala_scope_lookup (vala_symbol_get_scope ((ValaSymbol*) cl), vala_symbol_get_name ((ValaSymbol*) self)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp1_);
-			_tmp2_ = FALSE;
+			sym = (_tmp0_ = vala_scope_lookup (vala_symbol_get_scope ((ValaSymbol*) cl), vala_symbol_get_name ((ValaSymbol*) self)), _vala_code_node_unref0 (sym), _tmp0_);
+			_tmp1_ = FALSE;
 			if (sym != NULL) {
-				_tmp2_ = vala_symbol_get_access (sym) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE;
+				_tmp1_ = vala_symbol_get_access (sym) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE;
 			} else {
-				_tmp2_ = FALSE;
+				_tmp1_ = FALSE;
 			}
-			if (_tmp2_) {
+			if (_tmp1_) {
 				result = sym;
-				(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+				_vala_code_node_unref0 (cl);
 				return result;
 			}
-			_tmp4_ = NULL;
-			_tmp3_ = NULL;
-			cl = (_tmp4_ = (_tmp3_ = vala_class_get_base_class (cl), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_)), (cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL)), _tmp4_);
+			cl = (_tmp2_ = _vala_code_node_ref0 (vala_class_get_base_class (cl)), _vala_code_node_unref0 (cl), _tmp2_);
 		}
-		(cl == NULL) ? NULL : (cl = (vala_code_node_unref (cl), NULL));
+		_vala_code_node_unref0 (cl);
 	} else {
 		if (VALA_IS_STRUCT (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
-			ValaStruct* _tmp5_;
 			ValaStruct* st;
-			_tmp5_ = NULL;
-			st = (_tmp5_ = vala_struct_get_base_struct (VALA_STRUCT (vala_symbol_get_parent_symbol ((ValaSymbol*) self))), (_tmp5_ == NULL) ? NULL : vala_code_node_ref (_tmp5_));
+			st = _vala_code_node_ref0 (vala_struct_get_base_struct (VALA_STRUCT (vala_symbol_get_parent_symbol ((ValaSymbol*) self))));
 			while (TRUE) {
-				ValaSymbol* _tmp6_;
-				gboolean _tmp7_;
-				ValaStruct* _tmp9_;
-				ValaStruct* _tmp8_;
+				ValaSymbol* _tmp3_;
+				gboolean _tmp4_;
+				ValaStruct* _tmp5_;
 				if (!(st != NULL)) {
 					break;
 				}
-				_tmp6_ = NULL;
-				sym = (_tmp6_ = vala_scope_lookup (vala_symbol_get_scope ((ValaSymbol*) st), vala_symbol_get_name ((ValaSymbol*) self)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp6_);
-				_tmp7_ = FALSE;
+				sym = (_tmp3_ = vala_scope_lookup (vala_symbol_get_scope ((ValaSymbol*) st), vala_symbol_get_name ((ValaSymbol*) self)), _vala_code_node_unref0 (sym), _tmp3_);
+				_tmp4_ = FALSE;
 				if (sym != NULL) {
-					_tmp7_ = vala_symbol_get_access (sym) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE;
+					_tmp4_ = vala_symbol_get_access (sym) != VALA_SYMBOL_ACCESSIBILITY_PRIVATE;
 				} else {
-					_tmp7_ = FALSE;
+					_tmp4_ = FALSE;
 				}
-				if (_tmp7_) {
+				if (_tmp4_) {
 					result = sym;
-					(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+					_vala_code_node_unref0 (st);
 					return result;
 				}
-				_tmp9_ = NULL;
-				_tmp8_ = NULL;
-				st = (_tmp9_ = (_tmp8_ = vala_struct_get_base_struct (st), (_tmp8_ == NULL) ? NULL : vala_code_node_ref (_tmp8_)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), _tmp9_);
+				st = (_tmp5_ = _vala_code_node_ref0 (vala_struct_get_base_struct (st)), _vala_code_node_unref0 (st), _tmp5_);
 			}
-			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+			_vala_code_node_unref0 (st);
 		}
 	}
 	result = NULL;
-	(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
+	_vala_code_node_unref0 (sym);
 	return result;
 }
 
 
+ValaComment* vala_member_get_comment (ValaMember* self) {
+	ValaComment* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = self->priv->_comment;
+	return result;
+}
+
+
+static gpointer _vala_comment_ref0 (gpointer self) {
+	return self ? vala_comment_ref (self) : NULL;
+}
+
+
+void vala_member_set_comment (ValaMember* self, ValaComment* value) {
+	ValaComment* _tmp0_;
+	g_return_if_fail (self != NULL);
+	self->priv->_comment = (_tmp0_ = _vala_comment_ref0 (value), _vala_comment_unref0 (self->priv->_comment), _tmp0_);
+}
+
+
 gboolean vala_member_get_hides (ValaMember* self) {
 	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
@@ -549,7 +551,8 @@ static void vala_member_instance_init (ValaMember * self) {
 static void vala_member_finalize (ValaCodeNode* obj) {
 	ValaMember * self;
 	self = VALA_MEMBER (obj);
-	(self->priv->cheader_filenames == NULL) ? NULL : (self->priv->cheader_filenames = (gee_collection_object_unref (self->priv->cheader_filenames), NULL));
+	_vala_comment_unref0 (self->priv->_comment);
+	_gee_collection_object_unref0 (self->priv->cheader_filenames);
 	VALA_CODE_NODE_CLASS (vala_member_parent_class)->finalize (obj);
 }
 
