@@ -159,6 +159,7 @@ typedef struct _ValaMemberClass ValaMemberClass;
 
 typedef struct _ValaMethod ValaMethod;
 typedef struct _ValaMethodClass ValaMethodClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_DELEGATE_TYPE (vala_delegate_type_get_type ())
 #define VALA_DELEGATE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_DELEGATE_TYPE, ValaDelegateType))
@@ -190,12 +191,6 @@ typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
 typedef struct _ValaDelegate ValaDelegate;
 typedef struct _ValaDelegateClass ValaDelegateClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -216,10 +211,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -249,9 +240,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * The type of a method referencea.
- */
 struct _ValaMethodType {
 	ValaDataType parent_instance;
 	ValaMethodTypePrivate * priv;
@@ -300,6 +288,7 @@ GType vala_method_get_type (void);
 enum  {
 	VALA_METHOD_TYPE_DUMMY_PROPERTY
 };
+ValaDataType* vala_data_type_construct (GType object_type);
 void vala_method_type_set_method_symbol (ValaMethodType* self, ValaMethod* value);
 ValaMethodType* vala_method_type_new (ValaMethod* method_symbol);
 ValaMethodType* vala_method_type_construct (GType object_type, ValaMethod* method_symbol);
@@ -320,6 +309,7 @@ char* vala_symbol_get_full_name (ValaSymbol* self);
 static char* vala_method_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
 static char* vala_method_type_real_get_cname (ValaDataType* base);
 gboolean vala_method_get_coroutine (ValaMethod* self);
+ValaMethod* vala_method_get_callback_method (ValaMethod* self);
 static ValaSymbol* vala_method_type_real_get_member (ValaDataType* base, const char* member_name);
 static void vala_method_type_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -329,7 +319,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 ValaMethodType* vala_method_type_construct (GType object_type, ValaMethod* method_symbol) {
 	ValaMethodType* self;
 	g_return_val_if_fail (method_symbol != NULL, NULL);
-	self = (ValaMethodType*) g_type_create_instance (object_type);
+	self = (ValaMethodType*) vala_data_type_construct (object_type);
 	vala_method_type_set_method_symbol (self, method_symbol);
 	return self;
 }
@@ -349,13 +339,16 @@ static gboolean vala_method_type_real_is_invokable (ValaDataType* base) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static ValaDataType* vala_method_type_real_get_return_type (ValaDataType* base) {
 	ValaMethodType * self;
 	ValaDataType* result;
-	ValaDataType* _tmp0_;
 	self = (ValaMethodType*) base;
-	_tmp0_ = NULL;
-	result = (_tmp0_ = vala_method_get_return_type (self->priv->_method_symbol), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	result = _vala_code_node_ref0 (vala_method_get_return_type (self->priv->_method_symbol));
 	return result;
 }
 
@@ -381,22 +374,18 @@ static ValaDataType* vala_method_type_real_copy (ValaDataType* base) {
 static gboolean vala_method_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaMethodType * self;
 	gboolean result;
-	ValaDelegateType* _tmp1_;
 	ValaDataType* _tmp0_;
 	ValaDelegateType* dt;
 	self = (ValaMethodType*) base;
 	g_return_val_if_fail (target_type != NULL, FALSE);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	dt = (_tmp1_ = (_tmp0_ = target_type, VALA_IS_DELEGATE_TYPE (_tmp0_) ? ((ValaDelegateType*) _tmp0_) : NULL), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+	dt = _vala_code_node_ref0 ((_tmp0_ = target_type, VALA_IS_DELEGATE_TYPE (_tmp0_) ? ((ValaDelegateType*) _tmp0_) : NULL));
 	if (dt == NULL) {
-		/* method types incompatible to anything but delegates*/
 		result = FALSE;
-		(dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL));
+		_vala_code_node_unref0 (dt);
 		return result;
 	}
 	result = vala_delegate_matches_method (vala_delegate_type_get_delegate_symbol (dt), self->priv->_method_symbol);
-	(dt == NULL) ? NULL : (dt = (vala_code_node_unref (dt), NULL));
+	_vala_code_node_unref0 (dt);
 	return result;
 }
 
@@ -432,10 +421,32 @@ static ValaSymbol* vala_method_type_real_get_member (ValaDataType* base, const c
 		_tmp0_ = FALSE;
 	}
 	if (_tmp0_) {
-		ValaSymbol* _tmp1_;
-		_tmp1_ = NULL;
-		result = (_tmp1_ = (ValaSymbol*) self->priv->_method_symbol, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+		result = _vala_code_node_ref0 ((ValaSymbol*) self->priv->_method_symbol);
 		return result;
+	} else {
+		gboolean _tmp1_;
+		_tmp1_ = FALSE;
+		if (vala_method_get_coroutine (self->priv->_method_symbol)) {
+			_tmp1_ = _vala_strcmp0 (member_name, "end") == 0;
+		} else {
+			_tmp1_ = FALSE;
+		}
+		if (_tmp1_) {
+			result = _vala_code_node_ref0 ((ValaSymbol*) self->priv->_method_symbol);
+			return result;
+		} else {
+			gboolean _tmp2_;
+			_tmp2_ = FALSE;
+			if (vala_method_get_coroutine (self->priv->_method_symbol)) {
+				_tmp2_ = _vala_strcmp0 (member_name, "callback") == 0;
+			} else {
+				_tmp2_ = FALSE;
+			}
+			if (_tmp2_) {
+				result = (ValaSymbol*) vala_method_get_callback_method (self->priv->_method_symbol);
+				return result;
+			}
+		}
 	}
 	result = NULL;
 	return result;
@@ -451,12 +462,9 @@ ValaMethod* vala_method_type_get_method_symbol (ValaMethodType* self) {
 
 
 void vala_method_type_set_method_symbol (ValaMethodType* self, ValaMethod* value) {
-	ValaMethod* _tmp1_;
 	ValaMethod* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_method_symbol = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_method_symbol == NULL) ? NULL : (self->priv->_method_symbol = (vala_code_node_unref (self->priv->_method_symbol), NULL)), _tmp1_);
+	self->priv->_method_symbol = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_method_symbol), _tmp0_);
 }
 
 
@@ -483,7 +491,7 @@ static void vala_method_type_instance_init (ValaMethodType * self) {
 static void vala_method_type_finalize (ValaCodeNode* obj) {
 	ValaMethodType * self;
 	self = VALA_METHOD_TYPE (obj);
-	(self->priv->_method_symbol == NULL) ? NULL : (self->priv->_method_symbol = (vala_code_node_unref (self->priv->_method_symbol), NULL));
+	_vala_code_node_unref0 (self->priv->_method_symbol);
 	VALA_CODE_NODE_CLASS (vala_method_type_parent_class)->finalize (obj);
 }
 
