@@ -160,13 +160,8 @@ typedef struct _ValaReferenceTypeClass ValaReferenceTypeClass;
 
 typedef struct _ValaNullType ValaNullType;
 typedef struct _ValaNullTypeClass ValaNullTypeClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -187,9 +182,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -203,9 +195,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Base class for all literals in the source code.
- */
 struct _ValaLiteral {
 	ValaExpression parent_instance;
 	ValaLiteralPrivate * priv;
@@ -215,9 +204,6 @@ struct _ValaLiteralClass {
 	ValaExpressionClass parent_class;
 };
 
-/**
- * Represents a literal `null' in the source code.
- */
 struct _ValaNullLiteral {
 	ValaLiteral parent_instance;
 	ValaNullLiteralPrivate * priv;
@@ -253,6 +239,7 @@ GType vala_null_literal_get_type (void);
 enum  {
 	VALA_NULL_LITERAL_DUMMY_PROPERTY
 };
+ValaLiteral* vala_literal_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -280,15 +267,9 @@ static gboolean vala_null_literal_real_check (ValaCodeNode* base, ValaSemanticAn
 
 
 
-/**
- * Creates a new null literal.
- *
- * @param source reference to source code
- * @return       newly created null literal
- */
 ValaNullLiteral* vala_null_literal_construct (GType object_type, ValaSourceReference* source) {
 	ValaNullLiteral* self;
-	self = (ValaNullLiteral*) g_type_create_instance (object_type);
+	self = (ValaNullLiteral*) vala_literal_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
@@ -337,9 +318,8 @@ static gboolean vala_null_literal_real_check (ValaCodeNode* base, ValaSemanticAn
 		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	_tmp0_ = NULL;
 	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp0_ = vala_null_type_new (vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+	_vala_code_node_unref0 (_tmp0_);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
 	return result;
 }
