@@ -182,6 +182,7 @@ typedef struct _ValaPropertyClass ValaPropertyClass;
 
 typedef struct _ValaTypeParameter ValaTypeParameter;
 typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -193,6 +194,16 @@ typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+
 #define VALA_TYPE_SCOPE (vala_scope_get_type ())
 #define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
 #define VALA_SCOPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SCOPE, ValaScopeClass))
@@ -202,13 +213,8 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
 typedef struct _ValaScope ValaScope;
 typedef struct _ValaScopeClass ValaScopeClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -229,9 +235,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -247,10 +250,6 @@ struct _ValaSymbolClass {
 	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a runtime data type. This data type may be defined in Vala source
- * code or imported from an external library with a Vala API file.
- */
 struct _ValaTypeSymbol {
 	ValaSymbol parent_instance;
 	ValaTypeSymbolPrivate * priv;
@@ -280,11 +279,6 @@ struct _ValaTypeSymbolClass {
 	char* (*get_type_signature) (ValaTypeSymbol* self);
 };
 
-/**
- * Represents a runtime data type for objects and interfaces. This data type may
- * be defined in Vala source code or imported from an external library with a 
- * Vala API file.
- */
 struct _ValaObjectTypeSymbol {
 	ValaTypeSymbol parent_instance;
 	ValaObjectTypeSymbolPrivate * priv;
@@ -339,10 +333,14 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaTypeSymbol* vala_typesymbol_new (const char* name, ValaSourceReference* source_reference);
-ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaObjectTypeSymbol* vala_object_type_symbol_new (const char* name, ValaSourceReference* source_reference);
-ValaObjectTypeSymbol* vala_object_type_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
+ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
+ValaObjectTypeSymbol* vala_object_type_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
 GeeList* vala_object_type_symbol_get_methods (ValaObjectTypeSymbol* self);
 static GeeList* vala_object_type_symbol_real_get_methods (ValaObjectTypeSymbol* self);
 GeeList* vala_object_type_symbol_get_signals (ValaObjectTypeSymbol* self);
@@ -366,19 +364,14 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-ValaObjectTypeSymbol* vala_object_type_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+ValaObjectTypeSymbol* vala_object_type_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment) {
 	ValaObjectTypeSymbol* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaObjectTypeSymbol*) vala_typesymbol_construct (object_type, name, source_reference);
+	self = (ValaObjectTypeSymbol*) vala_typesymbol_construct (object_type, name, source_reference, comment);
 	return self;
 }
 
 
-ValaObjectTypeSymbol* vala_object_type_symbol_new (const char* name, ValaSourceReference* source_reference) {
-	return vala_object_type_symbol_construct (VALA_TYPE_OBJECT_TYPE_SYMBOL, name, source_reference);
-}
-
-
 static GeeList* vala_object_type_symbol_real_get_methods (ValaObjectTypeSymbol* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	g_critical ("Type `%s' does not implement abstract method `vala_object_type_symbol_get_methods'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
@@ -415,11 +408,6 @@ GeeList* vala_object_type_symbol_get_properties (ValaObjectTypeSymbol* self) {
 }
 
 
-/**
- * Appends the specified parameter to the list of type parameters.
- *
- * @param p a type parameter
- */
 void vala_object_type_symbol_add_type_parameter (ValaObjectTypeSymbol* self, ValaTypeParameter* p) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (p != NULL);
@@ -428,11 +416,6 @@ void vala_object_type_symbol_add_type_parameter (ValaObjectTypeSymbol* self, Val
 }
 
 
-/**
- * Returns a copy of the type parameter list.
- *
- * @return list of type parameters
- */
 GeeList* vala_object_type_symbol_get_type_parameters (ValaObjectTypeSymbol* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -459,14 +442,14 @@ static gint vala_object_type_symbol_real_get_type_parameter_index (ValaTypeSymbo
 			parameter = (ValaTypeParameter*) gee_iterator_get (_parameter_it);
 			if (_vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) parameter), name) == 0) {
 				result = i;
-				(parameter == NULL) ? NULL : (parameter = (vala_code_node_unref (parameter), NULL));
-				(_parameter_it == NULL) ? NULL : (_parameter_it = (gee_collection_object_unref (_parameter_it), NULL));
+				_vala_code_node_unref0 (parameter);
+				_gee_collection_object_unref0 (_parameter_it);
 				return result;
 			}
 			i++;
-			(parameter == NULL) ? NULL : (parameter = (vala_code_node_unref (parameter), NULL));
+			_vala_code_node_unref0 (parameter);
 		}
-		(_parameter_it == NULL) ? NULL : (_parameter_it = (gee_collection_object_unref (_parameter_it), NULL));
+		_gee_collection_object_unref0 (_parameter_it);
 	}
 	result = -1;
 	return result;
@@ -493,7 +476,7 @@ static void vala_object_type_symbol_instance_init (ValaObjectTypeSymbol * self)
 static void vala_object_type_symbol_finalize (ValaCodeNode* obj) {
 	ValaObjectTypeSymbol * self;
 	self = VALA_OBJECT_TYPE_SYMBOL (obj);
-	(self->priv->type_parameters == NULL) ? NULL : (self->priv->type_parameters = (gee_collection_object_unref (self->priv->type_parameters), NULL));
+	_gee_collection_object_unref0 (self->priv->type_parameters);
 	VALA_CODE_NODE_CLASS (vala_object_type_symbol_parent_class)->finalize (obj);
 }
 
