@@ -57,6 +57,7 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
 typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_CODE_CONTEXT (vala_code_context_get_type ())
 #define VALA_CODE_CONTEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_CONTEXT, ValaCodeContext))
@@ -67,10 +68,8 @@ typedef struct _ValaSourceFileClass ValaSourceFileClass;
 
 typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
+#define _vala_code_context_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_context_unref (var), NULL)))
 
-/**
- * Namespace to centralize reporting warnings and errors.
- */
 struct _ValaReport {
 	GObject parent_instance;
 	ValaReportPrivate * priv;
@@ -139,18 +138,12 @@ static void vala_report_finalize (GObject* obj);
 
 
 
-/**
- * Set the error verbosity.
- */
 void vala_report_set_verbose_errors (ValaReport* self, gboolean verbose) {
 	g_return_if_fail (self != NULL);
 	self->priv->verbose_errors = verbose;
 }
 
 
-/**
- * Returns the total number of warnings reported.
- */
 gint vala_report_get_warnings (ValaReport* self) {
 	gint result;
 	g_return_val_if_fail (self != NULL, 0);
@@ -159,9 +152,6 @@ gint vala_report_get_warnings (ValaReport* self) {
 }
 
 
-/**
- * Returns the total number of errors reported.
- */
 gint vala_report_get_errors (ValaReport* self) {
 	gint result;
 	g_return_val_if_fail (self != NULL, 0);
@@ -170,14 +160,10 @@ gint vala_report_get_errors (ValaReport* self) {
 }
 
 
-/**
- * Pretty-print the actual line of offending code if possible.
- */
 static void vala_report_report_source (ValaSourceReference* source) {
 	char* offending_line;
 	g_return_if_fail (source != NULL);
 	if (vala_source_reference_get_first_line (source) != vala_source_reference_get_last_line (source)) {
-		/* FIXME Cannot report multi-line issues currently*/
 		return;
 	}
 	offending_line = vala_source_file_get_source_line (vala_source_reference_get_file (source), vala_source_reference_get_first_line (source));
@@ -185,29 +171,14 @@ static void vala_report_report_source (ValaSourceReference* source) {
 		gint idx;
 		fprintf (stderr, "%s\n", offending_line);
 		idx = 0;
-		/* We loop in this manner so that we don't fall over on differing
-		 * tab widths. This means we get the ^s in the right places.
-		 */
 		{
 			gboolean _tmp0_;
 			idx = 1;
-			/* We loop in this manner so that we don't fall over on differing
-			 * tab widths. This means we get the ^s in the right places.
-			 */
 			_tmp0_ = TRUE;
-			/* We loop in this manner so that we don't fall over on differing
-			 * tab widths. This means we get the ^s in the right places.
-			 */
 			while (TRUE) {
-				/* We loop in this manner so that we don't fall over on differing
-				 * tab widths. This means we get the ^s in the right places.
-				 */
 				if (!_tmp0_) {
 					idx = idx + 1;
 				}
-				/* We loop in this manner so that we don't fall over on differing
-				 * tab widths. This means we get the ^s in the right places.
-				 */
 				_tmp0_ = FALSE;
 				if (!(idx < vala_source_reference_get_first_column (source))) {
 					break;
@@ -240,16 +211,10 @@ static void vala_report_report_source (ValaSourceReference* source) {
 		}
 		fprintf (stderr, "\n");
 	}
-	offending_line = (g_free (offending_line), NULL);
+	_g_free0 (offending_line);
 }
 
 
-/**
- * Reports the specified message as warning.
- *
- * @param source  reference to source code
- * @param message warning message
- */
 static void vala_report_real_warn (ValaReport* self, ValaSourceReference* source, const char* message) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (message != NULL);
@@ -258,9 +223,8 @@ static void vala_report_real_warn (ValaReport* self, ValaSourceReference* source
 		fprintf (stderr, "warning: %s\n", message);
 	} else {
 		char* _tmp0_;
-		_tmp0_ = NULL;
 		fprintf (stderr, "%s: warning: %s\n", _tmp0_ = vala_source_reference_to_string (source), message);
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		_g_free0 (_tmp0_);
 		if (self->priv->verbose_errors) {
 			vala_report_report_source (source);
 		}
@@ -273,12 +237,6 @@ void vala_report_warn (ValaReport* self, ValaSourceReference* source, const char
 }
 
 
-/**
- * Reports the specified message as error.
- *
- * @param source  reference to source code
- * @param message error message
- */
 static void vala_report_real_err (ValaReport* self, ValaSourceReference* source, const char* message) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (message != NULL);
@@ -287,9 +245,8 @@ static void vala_report_real_err (ValaReport* self, ValaSourceReference* source,
 		fprintf (stderr, "error: %s\n", message);
 	} else {
 		char* _tmp0_;
-		_tmp0_ = NULL;
 		fprintf (stderr, "%s: error: %s\n", _tmp0_ = vala_source_reference_to_string (source), message);
-		_tmp0_ = (g_free (_tmp0_), NULL);
+		_g_free0 (_tmp0_);
 		if (self->priv->verbose_errors) {
 			vala_report_report_source (source);
 		}
@@ -302,31 +259,25 @@ void vala_report_err (ValaReport* self, ValaSourceReference* source, const char*
 }
 
 
-/* Convenience methods calling warn and err on correct instance */
 void vala_report_warning (ValaSourceReference* source, const char* message) {
 	ValaCodeContext* _tmp0_;
 	g_return_if_fail (message != NULL);
-	_tmp0_ = NULL;
 	vala_report_warn (vala_code_context_get_report (_tmp0_ = vala_code_context_get ()), source, message);
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_context_unref (_tmp0_), NULL));
+	_vala_code_context_unref0 (_tmp0_);
 }
 
 
 void vala_report_error (ValaSourceReference* source, const char* message) {
 	ValaCodeContext* _tmp0_;
 	g_return_if_fail (message != NULL);
-	_tmp0_ = NULL;
 	vala_report_err (vala_code_context_get_report (_tmp0_ = vala_code_context_get ()), source, message);
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_context_unref (_tmp0_), NULL));
+	_vala_code_context_unref0 (_tmp0_);
 }
 
 
-/**
- * Namespace to centralize reporting warnings and errors.
- */
 ValaReport* vala_report_construct (GType object_type) {
 	ValaReport * self;
-	self = g_object_newv (object_type, 0, NULL);
+	self = (ValaReport*) g_object_new (object_type, NULL);
 	return self;
 }
 
