@@ -169,6 +169,7 @@ typedef struct _ValaSignalClass ValaSignalClass;
 
 typedef struct _ValaMethod ValaMethod;
 typedef struct _ValaMethodClass ValaMethodClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_TYPESYMBOL (vala_typesymbol_get_type ())
 #define VALA_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))
@@ -250,14 +251,19 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaVoidType ValaVoidType;
 typedef struct _ValaVoidTypeClass ValaVoidTypeClass;
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+
 #define VALA_TYPE_SYMBOL_ACCESSIBILITY (vala_symbol_accessibility_get_type ())
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -278,10 +284,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -311,9 +313,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * The type of a signal referencea.
- */
 struct _ValaSignalType {
 	ValaDataType parent_instance;
 	ValaSignalTypePrivate * priv;
@@ -372,10 +371,10 @@ GType vala_method_get_type (void);
 enum  {
 	VALA_SIGNAL_TYPE_DUMMY_PROPERTY
 };
+ValaDataType* vala_data_type_construct (GType object_type);
 void vala_signal_type_set_signal_symbol (ValaSignalType* self, ValaSignal* value);
 ValaSignalType* vala_signal_type_new (ValaSignal* signal_symbol);
 ValaSignalType* vala_signal_type_construct (GType object_type, ValaSignal* signal_symbol);
-ValaSignalType* vala_signal_type_new (ValaSignal* signal_symbol);
 static gboolean vala_signal_type_real_is_invokable (ValaDataType* base);
 ValaSignal* vala_signal_type_get_signal_symbol (ValaSignalType* self);
 ValaDataType* vala_signal_get_return_type (ValaSignal* self);
@@ -408,8 +407,14 @@ GType vala_source_reference_get_type (void);
 ValaVoidType* vala_void_type_new (ValaSourceReference* source_reference);
 ValaVoidType* vala_void_type_construct (GType object_type, ValaSourceReference* source_reference);
 GType vala_void_type_get_type (void);
-ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
-ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
+ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
+ValaMethod* vala_method_construct (GType object_type, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference, ValaComment* comment);
 GType vala_symbol_accessibility_get_type (void);
 void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value);
 void vala_symbol_set_external (ValaSymbol* self, gboolean value);
@@ -430,7 +435,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 ValaSignalType* vala_signal_type_construct (GType object_type, ValaSignal* signal_symbol) {
 	ValaSignalType* self;
 	g_return_val_if_fail (signal_symbol != NULL, NULL);
-	self = (ValaSignalType*) g_type_create_instance (object_type);
+	self = (ValaSignalType*) vala_data_type_construct (object_type);
 	vala_signal_type_set_signal_symbol (self, signal_symbol);
 	return self;
 }
@@ -450,13 +455,16 @@ static gboolean vala_signal_type_real_is_invokable (ValaDataType* base) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static ValaDataType* vala_signal_type_real_get_return_type (ValaDataType* base) {
 	ValaSignalType * self;
 	ValaDataType* result;
-	ValaDataType* _tmp0_;
 	self = (ValaSignalType*) base;
-	_tmp0_ = NULL;
-	result = (_tmp0_ = vala_signal_get_return_type (self->priv->_signal_symbol), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	result = _vala_code_node_ref0 (vala_signal_get_return_type (self->priv->_signal_symbol));
 	return result;
 }
 
@@ -505,67 +513,53 @@ static ValaDelegateType* vala_signal_type_get_handler_type (ValaSignalType* self
 	ValaDelegateType* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	sender_type = vala_object_type_new (VALA_OBJECT_TYPE_SYMBOL (vala_symbol_get_parent_symbol ((ValaSymbol*) self->priv->_signal_symbol)));
-	_tmp0_ = NULL;
-	_tmp1_ = NULL;
-	result = (_tmp1_ = vala_delegate_type_new (_tmp0_ = vala_signal_get_delegate (self->priv->_signal_symbol, (ValaDataType*) sender_type, (ValaCodeNode*) self)), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL)), _tmp1_);
-	(sender_type == NULL) ? NULL : (sender_type = (vala_code_node_unref (sender_type), NULL));
+	result = (_tmp1_ = vala_delegate_type_new (_tmp0_ = vala_signal_get_delegate (self->priv->_signal_symbol, (ValaDataType*) sender_type, (ValaCodeNode*) self)), _vala_code_node_unref0 (_tmp0_), _tmp1_);
+	_vala_code_node_unref0 (sender_type);
 	return result;
-	(sender_type == NULL) ? NULL : (sender_type = (vala_code_node_unref (sender_type), NULL));
+	_vala_code_node_unref0 (sender_type);
 }
 
 
 static ValaMethod* vala_signal_type_get_connect_method (ValaSignalType* self) {
 	ValaMethod* result;
-	ValaMethod* _tmp4_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->connect_method == NULL) {
 		ValaMethod* _tmp1_;
 		ValaVoidType* _tmp0_;
 		ValaFormalParameter* _tmp3_;
 		ValaDelegateType* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		self->priv->connect_method = (_tmp1_ = vala_method_new ("connect", (ValaDataType*) (_tmp0_ = vala_void_type_new (NULL)), NULL), (self->priv->connect_method == NULL) ? NULL : (self->priv->connect_method = (vala_code_node_unref (self->priv->connect_method), NULL)), _tmp1_);
-		(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+		self->priv->connect_method = (_tmp1_ = vala_method_new ("connect", (ValaDataType*) (_tmp0_ = vala_void_type_new (NULL)), NULL, NULL), _vala_code_node_unref0 (self->priv->connect_method), _tmp1_);
+		_vala_code_node_unref0 (_tmp0_);
 		vala_symbol_set_access ((ValaSymbol*) self->priv->connect_method, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		vala_symbol_set_external ((ValaSymbol*) self->priv->connect_method, TRUE);
 		vala_symbol_set_owner ((ValaSymbol*) self->priv->connect_method, vala_symbol_get_scope ((ValaSymbol*) self->priv->_signal_symbol));
-		_tmp3_ = NULL;
-		_tmp2_ = NULL;
 		vala_method_add_parameter (self->priv->connect_method, _tmp3_ = vala_formal_parameter_new ("handler", (ValaDataType*) (_tmp2_ = vala_signal_type_get_handler_type (self)), NULL));
-		(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_node_unref (_tmp3_), NULL));
-		(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
+		_vala_code_node_unref0 (_tmp3_);
+		_vala_code_node_unref0 (_tmp2_);
 	}
-	_tmp4_ = NULL;
-	result = (_tmp4_ = self->priv->connect_method, (_tmp4_ == NULL) ? NULL : vala_code_node_ref (_tmp4_));
+	result = _vala_code_node_ref0 (self->priv->connect_method);
 	return result;
 }
 
 
 static ValaMethod* vala_signal_type_get_disconnect_method (ValaSignalType* self) {
 	ValaMethod* result;
-	ValaMethod* _tmp4_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->disconnect_method == NULL) {
 		ValaMethod* _tmp1_;
 		ValaVoidType* _tmp0_;
 		ValaFormalParameter* _tmp3_;
 		ValaDelegateType* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp0_ = NULL;
-		self->priv->disconnect_method = (_tmp1_ = vala_method_new ("disconnect", (ValaDataType*) (_tmp0_ = vala_void_type_new (NULL)), NULL), (self->priv->disconnect_method == NULL) ? NULL : (self->priv->disconnect_method = (vala_code_node_unref (self->priv->disconnect_method), NULL)), _tmp1_);
-		(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+		self->priv->disconnect_method = (_tmp1_ = vala_method_new ("disconnect", (ValaDataType*) (_tmp0_ = vala_void_type_new (NULL)), NULL, NULL), _vala_code_node_unref0 (self->priv->disconnect_method), _tmp1_);
+		_vala_code_node_unref0 (_tmp0_);
 		vala_symbol_set_access ((ValaSymbol*) self->priv->disconnect_method, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 		vala_symbol_set_external ((ValaSymbol*) self->priv->disconnect_method, TRUE);
 		vala_symbol_set_owner ((ValaSymbol*) self->priv->disconnect_method, vala_symbol_get_scope ((ValaSymbol*) self->priv->_signal_symbol));
-		_tmp3_ = NULL;
-		_tmp2_ = NULL;
 		vala_method_add_parameter (self->priv->disconnect_method, _tmp3_ = vala_formal_parameter_new ("handler", (ValaDataType*) (_tmp2_ = vala_signal_type_get_handler_type (self)), NULL));
-		(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_node_unref (_tmp3_), NULL));
-		(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
+		_vala_code_node_unref0 (_tmp3_);
+		_vala_code_node_unref0 (_tmp2_);
 	}
-	_tmp4_ = NULL;
-	result = (_tmp4_ = self->priv->disconnect_method, (_tmp4_ == NULL) ? NULL : vala_code_node_ref (_tmp4_));
+	result = _vala_code_node_ref0 (self->priv->disconnect_method);
 	return result;
 }
 
@@ -610,12 +604,9 @@ ValaSignal* vala_signal_type_get_signal_symbol (ValaSignalType* self) {
 
 
 void vala_signal_type_set_signal_symbol (ValaSignalType* self, ValaSignal* value) {
-	ValaSignal* _tmp1_;
 	ValaSignal* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_signal_symbol = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_signal_symbol == NULL) ? NULL : (self->priv->_signal_symbol = (vala_code_node_unref (self->priv->_signal_symbol), NULL)), _tmp1_);
+	self->priv->_signal_symbol = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_signal_symbol), _tmp0_);
 }
 
 
@@ -642,9 +633,9 @@ static void vala_signal_type_instance_init (ValaSignalType * self) {
 static void vala_signal_type_finalize (ValaCodeNode* obj) {
 	ValaSignalType * self;
 	self = VALA_SIGNAL_TYPE (obj);
-	(self->priv->_signal_symbol == NULL) ? NULL : (self->priv->_signal_symbol = (vala_code_node_unref (self->priv->_signal_symbol), NULL));
-	(self->priv->connect_method == NULL) ? NULL : (self->priv->connect_method = (vala_code_node_unref (self->priv->connect_method), NULL));
-	(self->priv->disconnect_method == NULL) ? NULL : (self->priv->disconnect_method = (vala_code_node_unref (self->priv->disconnect_method), NULL));
+	_vala_code_node_unref0 (self->priv->_signal_symbol);
+	_vala_code_node_unref0 (self->priv->connect_method);
+	_vala_code_node_unref0 (self->priv->disconnect_method);
 	VALA_CODE_NODE_CLASS (vala_signal_type_parent_class)->finalize (obj);
 }
 
