@@ -180,13 +180,9 @@ typedef struct _ValaStructClass ValaStructClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -207,10 +203,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -240,9 +232,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * A value type, i.e. a struct or an enum type.
- */
 struct _ValaValueType {
 	ValaDataType parent_instance;
 	ValaValueTypePrivate * priv;
@@ -252,9 +241,6 @@ struct _ValaValueTypeClass {
 	ValaDataTypeClass parent_class;
 };
 
-/**
- * A struct value type.
- */
 struct _ValaStructValueType {
 	ValaValueType parent_instance;
 	ValaStructValueTypePrivate * priv;
@@ -265,6 +251,7 @@ struct _ValaStructValueTypeClass {
 };
 
 
+static gpointer vala_struct_value_type_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -297,12 +284,10 @@ enum  {
 	VALA_STRUCT_VALUE_TYPE_DUMMY_PROPERTY
 };
 GType vala_typesymbol_get_type (void);
-ValaValueType* vala_value_type_new (ValaTypeSymbol* type_symbol);
 ValaValueType* vala_value_type_construct (GType object_type, ValaTypeSymbol* type_symbol);
 GType vala_struct_get_type (void);
 ValaStructValueType* vala_struct_value_type_new (ValaStruct* type_symbol);
 ValaStructValueType* vala_struct_value_type_construct (GType object_type, ValaStruct* type_symbol);
-ValaStructValueType* vala_struct_value_type_new (ValaStruct* type_symbol);
 ValaTypeSymbol* vala_value_type_get_type_symbol (ValaValueType* self);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -320,7 +305,6 @@ GeeList* vala_data_type_get_type_arguments (ValaDataType* self);
 void vala_data_type_add_type_argument (ValaDataType* self, ValaDataType* arg);
 ValaDataType* vala_data_type_copy (ValaDataType* self);
 static ValaDataType* vala_struct_value_type_real_copy (ValaDataType* base);
-static gpointer vala_struct_value_type_parent_class = NULL;
 
 
 
@@ -339,6 +323,7 @@ ValaStructValueType* vala_struct_value_type_new (ValaStruct* type_symbol) {
 
 static ValaDataType* vala_struct_value_type_real_copy (ValaDataType* base) {
 	ValaStructValueType * self;
+	ValaDataType* result;
 	ValaStructValueType* _result_;
 	self = (ValaStructValueType*) base;
 	_result_ = vala_struct_value_type_new (VALA_STRUCT (vala_value_type_get_type_symbol ((ValaValueType*) self)));
@@ -349,21 +334,22 @@ static ValaDataType* vala_struct_value_type_real_copy (ValaDataType* base) {
 		GeeList* _tmp0_;
 		GeeIterator* _tmp1_;
 		GeeIterator* _arg_it;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
-		while (gee_iterator_next (_arg_it)) {
+		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
+		while (TRUE) {
 			ValaDataType* arg;
 			ValaDataType* _tmp2_;
+			if (!gee_iterator_next (_arg_it)) {
+				break;
+			}
 			arg = (ValaDataType*) gee_iterator_get (_arg_it);
-			_tmp2_ = NULL;
 			vala_data_type_add_type_argument ((ValaDataType*) _result_, _tmp2_ = vala_data_type_copy (arg));
-			(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
-			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+			_vala_code_node_unref0 (_tmp2_);
+			_vala_code_node_unref0 (arg);
 		}
-		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
+		_gee_collection_object_unref0 (_arg_it);
 	}
-	return (ValaDataType*) _result_;
+	result = (ValaDataType*) _result_;
+	return result;
 }
 
 
