@@ -1,6 +1,6 @@
 /* valaswitchsection.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -148,6 +148,7 @@ typedef struct _ValaSwitchSectionPrivate ValaSwitchSectionPrivate;
 
 typedef struct _ValaSwitchLabel ValaSwitchLabel;
 typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -158,6 +159,7 @@ typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SCOPE (vala_scope_get_type ())
 #define VALA_SCOPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SCOPE, ValaScope))
@@ -881,12 +883,26 @@ typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
+#define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
+#define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
+#define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+#define VALA_IS_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VALUE_TYPE))
+#define VALA_IS_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VALUE_TYPE))
+#define VALA_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+
+typedef struct _ValaValueType ValaValueType;
+typedef struct _ValaValueTypeClass ValaValueTypeClass;
+
+#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
+#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
+#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+
+typedef struct _ValaStructValueType ValaStructValueType;
+typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -907,9 +923,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -921,18 +934,14 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a source code block.
- */
 struct _ValaBlock {
 	ValaSymbol parent_instance;
 	ValaBlockPrivate * priv;
@@ -942,9 +951,6 @@ struct _ValaBlockClass {
 	ValaSymbolClass parent_class;
 };
 
-/**
- * Represents a switch section in the source code.
- */
 struct _ValaSwitchSection {
 	ValaBlock parent_instance;
 	ValaSwitchSectionPrivate * priv;
@@ -958,9 +964,6 @@ struct _ValaSwitchSectionPrivate {
 	GeeList* labels;
 };
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -1047,17 +1050,12 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Code visitor analyzing and checking code.
- */
 struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 	ValaSymbol* root_symbol;
-	ValaDataType* current_return_type;
-	ValaClass* current_class;
-	ValaStruct* current_struct;
 	ValaBlock* insert_block;
+	ValaDataType* void_type;
 	ValaDataType* bool_type;
 	ValaDataType* string_type;
 	ValaDataType* uchar_type;
@@ -1074,9 +1072,11 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
+	ValaStructValueType* gvalue_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
+	ValaDataType* gvaluearray_type;
 	ValaClass* gerror_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
@@ -1125,7 +1125,7 @@ ValaBlock* vala_block_new (ValaSourceReference* source_reference);
 ValaBlock* vala_block_construct (GType object_type, ValaSourceReference* source_reference);
 ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference);
 ValaSwitchSection* vala_switch_section_construct (GType object_type, ValaSourceReference* source_reference);
-ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference);
+void vala_switch_label_set_section (ValaSwitchLabel* self, ValaSwitchSection* value);
 void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* label);
 GeeList* vala_switch_section_get_labels (ValaSwitchSection* self);
 ValaExpression* vala_switch_label_get_expression (ValaSwitchLabel* self);
@@ -1224,6 +1224,8 @@ GType vala_typecheck_get_type (void);
 GType vala_conditional_expression_get_type (void);
 GType vala_lambda_expression_get_type (void);
 GType vala_assignment_get_type (void);
+GType vala_value_type_get_type (void);
+GType vala_struct_value_type_get_type (void);
 void vala_semantic_analyzer_set_current_symbol (ValaSemanticAnalyzer* self, ValaSymbol* value);
 GeeList* vala_block_get_local_variables (ValaBlock* self);
 void vala_symbol_set_active (ValaSymbol* self, gboolean value);
@@ -1232,12 +1234,6 @@ static void vala_switch_section_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new switch section.
- *
- * @param source_reference reference to source code
- * @return                 newly created switch section
- */
 ValaSwitchSection* vala_switch_section_construct (GType object_type, ValaSourceReference* source_reference) {
 	ValaSwitchSection* self;
 	g_return_val_if_fail (source_reference != NULL, NULL);
@@ -1251,23 +1247,14 @@ ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_referenc
 }
 
 
-/**
- * Appends the specified label to the list of switch labels.
- *
- * @param label a switch label
- */
 void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* label) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (label != NULL);
 	gee_collection_add ((GeeCollection*) self->priv->labels, label);
+	vala_switch_label_set_section (label, self);
 }
 
 
-/**
- * Returns a copy of the list of switch labels.
- *
- * @return switch label list
- */
 GeeList* vala_switch_section_get_labels (ValaSwitchSection* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -1290,13 +1277,13 @@ gboolean vala_switch_section_has_default_label (ValaSwitchSection* self) {
 			label = (ValaSwitchLabel*) gee_iterator_get (_label_it);
 			if (vala_switch_label_get_expression (label) == NULL) {
 				result = TRUE;
-				(label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL));
-				(_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL));
+				_vala_code_node_unref0 (label);
+				_gee_collection_object_unref0 (_label_it);
 				return result;
 			}
-			(label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL));
+			_vala_code_node_unref0 (label);
 		}
-		(_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL));
+		_gee_collection_object_unref0 (_label_it);
 	}
 	result = FALSE;
 	return result;
@@ -1325,17 +1312,15 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 			}
 			label = (ValaSwitchLabel*) gee_iterator_get (_label_it);
 			vala_code_node_accept ((ValaCodeNode*) label, visitor);
-			(label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL));
+			_vala_code_node_unref0 (label);
 		}
-		(_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL));
+		_gee_collection_object_unref0 (_label_it);
 	}
 	{
 		GeeList* _tmp0_;
 		GeeIterator* _tmp1_;
 		GeeIterator* _st_it;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		_st_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_block_get_statements ((ValaBlock*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
+		_st_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_block_get_statements ((ValaBlock*) self))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
 		while (TRUE) {
 			ValaStatement* st;
 			if (!gee_iterator_next (_st_it)) {
@@ -1343,24 +1328,25 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 			}
 			st = (ValaStatement*) gee_iterator_get (_st_it);
 			vala_code_node_accept ((ValaCodeNode*) st, visitor);
-			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+			_vala_code_node_unref0 (st);
 		}
-		(_st_it == NULL) ? NULL : (_st_it = (gee_collection_object_unref (_st_it), NULL));
+		_gee_collection_object_unref0 (_st_it);
 	}
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaSwitchSection * self;
 	gboolean result;
-	ValaSymbol* _tmp2_;
 	ValaSymbol* old_symbol;
-	ValaBlock* _tmp3_;
 	ValaBlock* old_insert_block;
-	ValaBlock* _tmp5_;
-	ValaBlock* _tmp4_;
-	ValaBlock* _tmp11_;
-	ValaBlock* _tmp10_;
+	ValaBlock* _tmp2_;
+	ValaBlock* _tmp7_;
 	self = (ValaSwitchSection*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -1372,9 +1358,7 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 		GeeList* _tmp0_;
 		GeeIterator* _tmp1_;
 		GeeIterator* _label_it;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		_label_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_switch_section_get_labels (self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
+		_label_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_switch_section_get_labels (self))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
 		while (TRUE) {
 			ValaSwitchLabel* label;
 			if (!gee_iterator_next (_label_it)) {
@@ -1382,26 +1366,20 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 			}
 			label = (ValaSwitchLabel*) gee_iterator_get (_label_it);
 			vala_code_node_check ((ValaCodeNode*) label, analyzer);
-			(label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL));
+			_vala_code_node_unref0 (label);
 		}
-		(_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL));
+		_gee_collection_object_unref0 (_label_it);
 	}
 	vala_symbol_set_owner ((ValaSymbol*) self, vala_symbol_get_scope (vala_semantic_analyzer_get_current_symbol (analyzer)));
-	_tmp2_ = NULL;
-	old_symbol = (_tmp2_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
-	_tmp3_ = NULL;
-	old_insert_block = (_tmp3_ = analyzer->insert_block, (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_));
+	old_symbol = _vala_code_node_ref0 (vala_semantic_analyzer_get_current_symbol (analyzer));
+	old_insert_block = _vala_code_node_ref0 (analyzer->insert_block);
 	vala_semantic_analyzer_set_current_symbol (analyzer, (ValaSymbol*) self);
-	_tmp5_ = NULL;
-	_tmp4_ = NULL;
-	analyzer->insert_block = (_tmp5_ = (_tmp4_ = (ValaBlock*) self, (_tmp4_ == NULL) ? NULL : vala_code_node_ref (_tmp4_)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp5_);
+	analyzer->insert_block = (_tmp2_ = _vala_code_node_ref0 ((ValaBlock*) self), _vala_code_node_unref0 (analyzer->insert_block), _tmp2_);
 	{
-		GeeList* _tmp6_;
-		GeeIterator* _tmp7_;
+		GeeList* _tmp3_;
+		GeeIterator* _tmp4_;
 		GeeIterator* _st_it;
-		_tmp6_ = NULL;
-		_tmp7_ = NULL;
-		_st_it = (_tmp7_ = gee_iterable_iterator ((GeeIterable*) (_tmp6_ = vala_block_get_statements ((ValaBlock*) self))), (_tmp6_ == NULL) ? NULL : (_tmp6_ = (gee_collection_object_unref (_tmp6_), NULL)), _tmp7_);
+		_st_it = (_tmp4_ = gee_iterable_iterator ((GeeIterable*) (_tmp3_ = vala_block_get_statements ((ValaBlock*) self))), _gee_collection_object_unref0 (_tmp3_), _tmp4_);
 		while (TRUE) {
 			ValaStatement* st;
 			if (!gee_iterator_next (_st_it)) {
@@ -1409,17 +1387,15 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 			}
 			st = (ValaStatement*) gee_iterator_get (_st_it);
 			vala_code_node_check ((ValaCodeNode*) st, analyzer);
-			(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+			_vala_code_node_unref0 (st);
 		}
-		(_st_it == NULL) ? NULL : (_st_it = (gee_collection_object_unref (_st_it), NULL));
+		_gee_collection_object_unref0 (_st_it);
 	}
 	{
-		GeeList* _tmp8_;
-		GeeIterator* _tmp9_;
+		GeeList* _tmp5_;
+		GeeIterator* _tmp6_;
 		GeeIterator* _local_it;
-		_tmp8_ = NULL;
-		_tmp9_ = NULL;
-		_local_it = (_tmp9_ = gee_iterable_iterator ((GeeIterable*) (_tmp8_ = vala_block_get_local_variables ((ValaBlock*) self))), (_tmp8_ == NULL) ? NULL : (_tmp8_ = (gee_collection_object_unref (_tmp8_), NULL)), _tmp9_);
+		_local_it = (_tmp6_ = gee_iterable_iterator ((GeeIterable*) (_tmp5_ = vala_block_get_local_variables ((ValaBlock*) self))), _gee_collection_object_unref0 (_tmp5_), _tmp6_);
 		while (TRUE) {
 			ValaLocalVariable* local;
 			if (!gee_iterator_next (_local_it)) {
@@ -1427,17 +1403,15 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 			}
 			local = (ValaLocalVariable*) gee_iterator_get (_local_it);
 			vala_symbol_set_active ((ValaSymbol*) local, FALSE);
-			(local == NULL) ? NULL : (local = (vala_code_node_unref (local), NULL));
+			_vala_code_node_unref0 (local);
 		}
-		(_local_it == NULL) ? NULL : (_local_it = (gee_collection_object_unref (_local_it), NULL));
+		_gee_collection_object_unref0 (_local_it);
 	}
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	_tmp11_ = NULL;
-	_tmp10_ = NULL;
-	analyzer->insert_block = (_tmp11_ = (_tmp10_ = old_insert_block, (_tmp10_ == NULL) ? NULL : vala_code_node_ref (_tmp10_)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp11_);
+	analyzer->insert_block = (_tmp7_ = _vala_code_node_ref0 (old_insert_block), _vala_code_node_unref0 (analyzer->insert_block), _tmp7_);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
-	(old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL));
-	(old_insert_block == NULL) ? NULL : (old_insert_block = (vala_code_node_unref (old_insert_block), NULL));
+	_vala_code_node_unref0 (old_symbol);
+	_vala_code_node_unref0 (old_insert_block);
 	return result;
 }
 
@@ -1461,7 +1435,7 @@ static void vala_switch_section_instance_init (ValaSwitchSection * self) {
 static void vala_switch_section_finalize (ValaCodeNode* obj) {
 	ValaSwitchSection * self;
 	self = VALA_SWITCH_SECTION (obj);
-	(self->priv->labels == NULL) ? NULL : (self->priv->labels = (gee_collection_object_unref (self->priv->labels), NULL));
+	_gee_collection_object_unref0 (self->priv->labels);
 	VALA_CODE_NODE_CLASS (vala_switch_section_parent_class)->finalize (obj);
 }
 
