@@ -120,6 +120,9 @@ typedef struct _ValaSymbolPrivate ValaSymbolPrivate;
 
 typedef struct _ValaScope ValaScope;
 typedef struct _ValaScopeClass ValaScopeClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _vala_scope_unref0(var) ((var == NULL) ? NULL : (var = (vala_scope_unref (var), NULL)))
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -130,6 +133,89 @@ typedef struct _ValaScopeClass ValaScopeClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
+
+#define VALA_TYPE_MEMBER (vala_member_get_type ())
+#define VALA_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_MEMBER, ValaMember))
+#define VALA_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_MEMBER, ValaMemberClass))
+#define VALA_IS_MEMBER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_MEMBER))
+#define VALA_IS_MEMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_MEMBER))
+#define VALA_MEMBER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_MEMBER, ValaMemberClass))
+
+typedef struct _ValaMember ValaMember;
+typedef struct _ValaMemberClass ValaMemberClass;
+
+#define VALA_TYPE_FIELD (vala_field_get_type ())
+#define VALA_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FIELD, ValaField))
+#define VALA_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FIELD, ValaFieldClass))
+#define VALA_IS_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FIELD))
+#define VALA_IS_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FIELD))
+#define VALA_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FIELD, ValaFieldClass))
+
+typedef struct _ValaField ValaField;
+typedef struct _ValaFieldClass ValaFieldClass;
+
+#define TYPE_MEMBER_BINDING (member_binding_get_type ())
+
+#define VALA_TYPE_METHOD (vala_method_get_type ())
+#define VALA_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_METHOD, ValaMethod))
+#define VALA_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_METHOD, ValaMethodClass))
+#define VALA_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_METHOD))
+#define VALA_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_METHOD))
+#define VALA_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_METHOD, ValaMethodClass))
+
+typedef struct _ValaMethod ValaMethod;
+typedef struct _ValaMethodClass ValaMethodClass;
+
+#define VALA_TYPE_CREATION_METHOD (vala_creation_method_get_type ())
+#define VALA_CREATION_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CREATION_METHOD, ValaCreationMethod))
+#define VALA_CREATION_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CREATION_METHOD, ValaCreationMethodClass))
+#define VALA_IS_CREATION_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CREATION_METHOD))
+#define VALA_IS_CREATION_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CREATION_METHOD))
+#define VALA_CREATION_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CREATION_METHOD, ValaCreationMethodClass))
+
+typedef struct _ValaCreationMethod ValaCreationMethod;
+typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
+
+#define VALA_TYPE_PROPERTY (vala_property_get_type ())
+#define VALA_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_PROPERTY, ValaProperty))
+#define VALA_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_PROPERTY, ValaPropertyClass))
+#define VALA_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_PROPERTY))
+#define VALA_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PROPERTY))
+#define VALA_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PROPERTY, ValaPropertyClass))
+
+typedef struct _ValaProperty ValaProperty;
+typedef struct _ValaPropertyClass ValaPropertyClass;
+
+#define VALA_TYPE_ENUM_VALUE (vala_enum_value_get_type ())
+#define VALA_ENUM_VALUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM_VALUE, ValaEnumValue))
+#define VALA_ENUM_VALUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ENUM_VALUE, ValaEnumValueClass))
+#define VALA_IS_ENUM_VALUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ENUM_VALUE))
+#define VALA_IS_ENUM_VALUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ENUM_VALUE))
+#define VALA_ENUM_VALUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ENUM_VALUE, ValaEnumValueClass))
+
+typedef struct _ValaEnumValue ValaEnumValue;
+typedef struct _ValaEnumValueClass ValaEnumValueClass;
+
+#define VALA_TYPE_TYPESYMBOL (vala_typesymbol_get_type ())
+#define VALA_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbol))
+#define VALA_TYPESYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolClass))
+#define VALA_IS_TYPESYMBOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPESYMBOL))
+#define VALA_IS_TYPESYMBOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPESYMBOL))
+#define VALA_TYPESYMBOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolClass))
+
+typedef struct _ValaTypeSymbol ValaTypeSymbol;
+typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
+
+#define VALA_TYPE_ERROR_CODE (vala_error_code_get_type ())
+#define VALA_ERROR_CODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ERROR_CODE, ValaErrorCode))
+#define VALA_ERROR_CODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ERROR_CODE, ValaErrorCodeClass))
+#define VALA_IS_ERROR_CODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ERROR_CODE))
+#define VALA_IS_ERROR_CODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ERROR_CODE))
+#define VALA_ERROR_CODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ERROR_CODE, ValaErrorCodeClass))
+
+typedef struct _ValaErrorCode ValaErrorCode;
+typedef struct _ValaErrorCodeClass ValaErrorCodeClass;
 
 #define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
 #define VALA_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFile))
@@ -141,12 +227,6 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -167,9 +247,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -181,6 +258,8 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
 typedef enum  {
@@ -200,6 +279,12 @@ struct _ValaSymbolPrivate {
 	ValaScope* _scope;
 };
 
+typedef enum  {
+	MEMBER_BINDING_INSTANCE,
+	MEMBER_BINDING_CLASS,
+	MEMBER_BINDING_STATIC
+} MemberBinding;
+
 
 static gpointer vala_symbol_parent_class = NULL;
 
@@ -238,6 +323,7 @@ ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self);
 ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self);
 gboolean vala_symbol_is_internal_symbol (ValaSymbol* self);
 gboolean vala_symbol_is_private_symbol (ValaSymbol* self);
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_symbol_set_name (ValaSymbol* self, const char* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -248,9 +334,7 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaScope* vala_scope_new (ValaSymbol* owner);
 ValaScope* vala_scope_construct (GType object_type, ValaSymbol* owner);
-ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 const char* vala_symbol_get_name (ValaSymbol* self);
 char* vala_symbol_get_full_name (ValaSymbol* self);
 char* vala_symbol_get_cprefix (ValaSymbol* self);
@@ -266,6 +350,22 @@ char* vala_symbol_lower_case_to_camel_case (const char* lower_case);
 ValaScope* vala_symbol_get_owner (ValaSymbol* self);
 ValaScope* vala_symbol_get_scope (ValaSymbol* self);
 ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self, gboolean is_internal);
+GType vala_member_get_type (void);
+GType vala_field_get_type (void);
+GType member_binding_get_type (void);
+MemberBinding vala_field_get_binding (ValaField* self);
+GType vala_method_get_type (void);
+GType vala_creation_method_get_type (void);
+MemberBinding vala_method_get_binding (ValaMethod* self);
+GType vala_property_get_type (void);
+MemberBinding vala_property_get_binding (ValaProperty* self);
+GType vala_enum_value_get_type (void);
+GType vala_typesymbol_get_type (void);
+GType vala_error_code_get_type (void);
+gboolean vala_symbol_is_instance_member (ValaSymbol* self);
+static gboolean vala_symbol_real_is_instance_member (ValaSymbol* self);
+gboolean vala_symbol_is_class_member (ValaSymbol* self);
+static gboolean vala_symbol_real_is_class_member (ValaSymbol* self);
 ValaSymbol* vala_scope_get_owner (ValaScope* self);
 void vala_scope_set_parent_scope (ValaScope* self, ValaScope* value);
 void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value);
@@ -288,11 +388,11 @@ static void vala_symbol_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Check if this symbol is just internal API (and therefore doesn't need 
- * to be listed in header files for instance) by traversing parent symbols
- * and checking their accessibility.
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
 	gboolean result;
 	gboolean _tmp0_;
@@ -304,45 +404,39 @@ gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
 		_tmp0_ = FALSE;
 	}
 	if (_tmp0_) {
-		/* non-external symbols in VAPI files are internal symbols*/
 		result = TRUE;
 		return result;
 	}
 	{
-		ValaSymbol* _tmp1_;
 		ValaSymbol* sym;
-		_tmp1_ = NULL;
-		sym = (_tmp1_ = self, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+		sym = _vala_code_node_ref0 (self);
 		{
-			gboolean _tmp2_;
-			_tmp2_ = TRUE;
+			gboolean _tmp1_;
+			_tmp1_ = TRUE;
 			while (TRUE) {
-				gboolean _tmp5_;
-				if (!_tmp2_) {
-					ValaSymbol* _tmp4_;
-					ValaSymbol* _tmp3_;
-					_tmp4_ = NULL;
-					_tmp3_ = NULL;
-					sym = (_tmp4_ = (_tmp3_ = vala_symbol_get_parent_symbol (sym), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp4_);
+				gboolean _tmp3_;
+				if (!_tmp1_) {
+					ValaSymbol* _tmp2_;
+					sym = (_tmp2_ = _vala_code_node_ref0 (vala_symbol_get_parent_symbol (sym)), _vala_code_node_unref0 (sym), _tmp2_);
 				}
-				_tmp2_ = FALSE;
+				_tmp1_ = FALSE;
 				if (!(NULL != sym)) {
 					break;
 				}
-				_tmp5_ = FALSE;
+				_tmp3_ = FALSE;
 				if (sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-					_tmp5_ = TRUE;
+					_tmp3_ = TRUE;
 				} else {
-					_tmp5_ = sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_INTERNAL;
+					_tmp3_ = sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_INTERNAL;
 				}
-				if (_tmp5_) {
+				if (_tmp3_) {
 					result = TRUE;
-					(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
+					_vala_code_node_unref0 (sym);
 					return result;
 				}
 			}
 		}
-		(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
+		_vala_code_node_unref0 (sym);
 	}
 	result = FALSE;
 	return result;
@@ -360,38 +454,32 @@ gboolean vala_symbol_is_private_symbol (ValaSymbol* self) {
 		_tmp0_ = FALSE;
 	}
 	if (_tmp0_) {
-		/* non-external symbols in VAPI files are private symbols*/
 		result = TRUE;
 		return result;
 	}
 	{
-		ValaSymbol* _tmp1_;
 		ValaSymbol* sym;
-		_tmp1_ = NULL;
-		sym = (_tmp1_ = self, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
+		sym = _vala_code_node_ref0 (self);
 		{
-			gboolean _tmp2_;
-			_tmp2_ = TRUE;
+			gboolean _tmp1_;
+			_tmp1_ = TRUE;
 			while (TRUE) {
-				if (!_tmp2_) {
-					ValaSymbol* _tmp4_;
-					ValaSymbol* _tmp3_;
-					_tmp4_ = NULL;
-					_tmp3_ = NULL;
-					sym = (_tmp4_ = (_tmp3_ = vala_symbol_get_parent_symbol (sym), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_)), (sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL)), _tmp4_);
+				if (!_tmp1_) {
+					ValaSymbol* _tmp2_;
+					sym = (_tmp2_ = _vala_code_node_ref0 (vala_symbol_get_parent_symbol (sym)), _vala_code_node_unref0 (sym), _tmp2_);
 				}
-				_tmp2_ = FALSE;
+				_tmp1_ = FALSE;
 				if (!(NULL != sym)) {
 					break;
 				}
 				if (sym->priv->_access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 					result = TRUE;
-					(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
+					_vala_code_node_unref0 (sym);
 					return result;
 				}
 			}
 		}
-		(sym == NULL) ? NULL : (sym = (vala_code_node_unref (sym), NULL));
+		_vala_code_node_unref0 (sym);
 	}
 	result = FALSE;
 	return result;
@@ -401,63 +489,38 @@ gboolean vala_symbol_is_private_symbol (ValaSymbol* self) {
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
 	ValaSymbol* self;
 	ValaScope* _tmp0_;
-	self = (ValaSymbol*) g_type_create_instance (object_type);
+	self = (ValaSymbol*) vala_code_node_construct (object_type);
 	vala_symbol_set_name (self, name);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
-	_tmp0_ = NULL;
-	self->priv->_scope = (_tmp0_ = vala_scope_new (self), (self->priv->_scope == NULL) ? NULL : (self->priv->_scope = (vala_scope_unref (self->priv->_scope), NULL)), _tmp0_);
+	self->priv->_scope = (_tmp0_ = vala_scope_new (self), _vala_scope_unref0 (self->priv->_scope), _tmp0_);
 	return self;
 }
 
 
-ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference) {
-	return vala_symbol_construct (VALA_TYPE_SYMBOL, name, source_reference);
-}
-
-
-/**
- * Returns the fully expanded name of this symbol for use in
- * human-readable messages.
- *
- * @return full name
- */
 char* vala_symbol_get_full_name (ValaSymbol* self) {
 	char* result;
-	char* _tmp1_;
-	gboolean _tmp2_;
-	char* _tmp4_;
-	char* _tmp5_;
+	char* _tmp0_;
+	gboolean _tmp1_;
+	char* _tmp2_;
+	char* _tmp3_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (vala_symbol_get_parent_symbol (self) == NULL) {
-		const char* _tmp0_;
-		_tmp0_ = NULL;
-		result = (_tmp0_ = self->priv->_name, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+		result = g_strdup (self->priv->_name);
 		return result;
 	}
 	if (self->priv->_name == NULL) {
 		result = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self));
 		return result;
 	}
-	_tmp1_ = NULL;
-	if ((_tmp2_ = (_tmp1_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))) == NULL, _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_)) {
-		const char* _tmp3_;
-		_tmp3_ = NULL;
-		result = (_tmp3_ = self->priv->_name, (_tmp3_ == NULL) ? NULL : g_strdup (_tmp3_));
+	if ((_tmp1_ = (_tmp0_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))) == NULL, _g_free0 (_tmp0_), _tmp1_)) {
+		result = g_strdup (self->priv->_name);
 		return result;
 	}
-	_tmp4_ = NULL;
-	_tmp5_ = NULL;
-	result = (_tmp5_ = g_strdup_printf ("%s.%s", _tmp4_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self)), self->priv->_name), _tmp4_ = (g_free (_tmp4_), NULL), _tmp5_);
+	result = (_tmp3_ = g_strdup_printf ("%s.%s", _tmp2_ = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self)), self->priv->_name), _g_free0 (_tmp2_), _tmp3_);
 	return result;
 }
 
 
-/**
- * Returns the camel case string to be prepended to the name of members
- * of this symbol when used in C code.
- *
- * @return the camel case prefix to be used in C code
- */
 static char* vala_symbol_real_get_cprefix (ValaSymbol* self) {
 	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -465,9 +528,7 @@ static char* vala_symbol_real_get_cprefix (ValaSymbol* self) {
 		result = g_strdup ("");
 		return result;
 	} else {
-		const char* _tmp0_;
-		_tmp0_ = NULL;
-		result = (_tmp0_ = self->priv->_name, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+		result = g_strdup (self->priv->_name);
 		return result;
 	}
 }
@@ -478,15 +539,6 @@ char* vala_symbol_get_cprefix (ValaSymbol* self) {
 }
 
 
-/**
- * Returns the C name of this symbol in lower case. Words are
- * separated by underscores. The lower case C name of the parent symbol
- * is prefix of the result, if there is one.
- *
- * @param infix a string to be placed between namespace and data type
- *              name or null
- * @return      the lower case name to be used in C code
- */
 static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix) {
 	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -500,12 +552,6 @@ char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix) {
 }
 
 
-/**
- * Returns the string to be prefixed to members of this symbol in
- * lower case when used in C code.
- *
- * @return      the lower case prefix to be used in C code
- */
 static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self) {
 	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -519,12 +565,6 @@ char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self) {
 }
 
 
-/**
- * Returns a list of C header filenames users of this symbol must
- * include.
- *
- * @return list of C header filenames for this symbol
- */
 static GeeList* vala_symbol_real_get_cheader_filenames (ValaSymbol* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -538,19 +578,25 @@ GeeList* vala_symbol_get_cheader_filenames (ValaSymbol* self) {
 }
 
 
-/**
- * Converts a string from CamelCase to lower_case.
- *
- * @param camel_case a string in camel case
- * @return           the specified string converted to lower case
- */
+static gboolean string_contains (const char* self, const char* needle) {
+	gboolean result;
+	g_return_val_if_fail (self != NULL, FALSE);
+	g_return_val_if_fail (needle != NULL, FALSE);
+	result = strstr (self, needle) != NULL;
+	return result;
+}
+
+
 char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 	char* result;
 	GString* result_builder;
 	const char* i;
 	gboolean first;
-	const char* _tmp4_;
 	g_return_val_if_fail (camel_case != NULL, NULL);
+	if (string_contains (camel_case, "_")) {
+		result = g_utf8_strdown (camel_case, -1);
+		return result;
+	}
 	result_builder = g_string_new ("");
 	i = camel_case;
 	first = TRUE;
@@ -572,8 +618,6 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 			gboolean prev_upper;
 			gboolean next_upper;
 			gboolean _tmp1_;
-			/* current character is upper case and
-			 * we're not at the beginning */
 			t = g_utf8_prev_char (i);
 			prev_upper = g_unichar_isupper (g_utf8_get_char (t));
 			t = g_utf8_next_char (i);
@@ -594,8 +638,6 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 			if (_tmp1_) {
 				glong len;
 				gboolean _tmp3_;
-				/* previous character wasn't upper case or
-				 * next character isn't upper case*/
 				len = g_utf8_strlen (result_builder->str, -1);
 				_tmp3_ = FALSE;
 				if (len != 1) {
@@ -604,7 +646,6 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 					_tmp3_ = FALSE;
 				}
 				if (_tmp3_) {
-					/* we're not creating 1 character words */
 					g_string_append_c (result_builder, '_');
 				}
 			}
@@ -613,26 +654,17 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 		first = FALSE;
 		i = g_utf8_next_char (i);
 	}
-	_tmp4_ = NULL;
-	result = (_tmp4_ = result_builder->str, (_tmp4_ == NULL) ? NULL : g_strdup (_tmp4_));
-	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
+	result = g_strdup (result_builder->str);
+	_g_string_free0 (result_builder);
 	return result;
-	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
 }
 
 
-/**
- * Converts a string from lower_case to CamelCase.
- *
- * @param lower_case a string in lower case
- * @return           the specified string converted to camel case
- */
 char* vala_symbol_lower_case_to_camel_case (const char* lower_case) {
 	char* result;
 	GString* result_builder;
 	const char* i;
 	gboolean last_underscore;
-	const char* _tmp1_;
 	g_return_val_if_fail (lower_case != NULL, NULL);
 	result_builder = g_string_new ("");
 	i = lower_case;
@@ -647,11 +679,8 @@ char* vala_symbol_lower_case_to_camel_case (const char* lower_case) {
 			last_underscore = TRUE;
 		} else {
 			if (g_unichar_isupper (c)) {
-				const char* _tmp0_;
-				/* original string is not lower_case, don't apply transformation*/
-				_tmp0_ = NULL;
-				result = (_tmp0_ = lower_case, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
-				(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
+				result = g_strdup (lower_case);
+				_g_string_free0 (result_builder);
 				return result;
 			} else {
 				if (last_underscore) {
@@ -664,49 +693,131 @@ char* vala_symbol_lower_case_to_camel_case (const char* lower_case) {
 		}
 		i = g_utf8_next_char (i);
 	}
-	_tmp1_ = NULL;
-	result = (_tmp1_ = result_builder->str, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
-	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
+	result = g_strdup (result_builder->str);
+	_g_string_free0 (result_builder);
 	return result;
-	(result_builder == NULL) ? NULL : (result_builder = (g_string_free (result_builder, TRUE), NULL));
 }
 
 
-/* get the top scope from where this symbol is still accessible*/
+static gpointer _vala_scope_ref0 (gpointer self) {
+	return self ? vala_scope_ref (self) : NULL;
+}
+
+
 ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self, gboolean is_internal) {
 	ValaScope* result;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-		ValaScope* _tmp0_;
-		/* private symbols are accessible within the scope where the symbol has been declared*/
-		_tmp0_ = NULL;
-		result = (_tmp0_ = vala_symbol_get_owner (self), (_tmp0_ == NULL) ? NULL : vala_scope_ref (_tmp0_));
+		result = _vala_scope_ref0 (vala_symbol_get_owner (self));
 		return result;
 	}
 	if (self->priv->_access == VALA_SYMBOL_ACCESSIBILITY_INTERNAL) {
 		is_internal = TRUE;
 	}
 	if (vala_symbol_get_parent_symbol (self) == NULL) {
-		/* this is the root symbol*/
 		if (is_internal) {
-			ValaScope* _tmp1_;
-			/* only accessible within the same library
-			 return root scope*/
-			_tmp1_ = NULL;
-			result = (_tmp1_ = vala_symbol_get_scope (self), (_tmp1_ == NULL) ? NULL : vala_scope_ref (_tmp1_));
+			result = _vala_scope_ref0 (vala_symbol_get_scope (self));
 			return result;
 		} else {
-			/* unlimited access*/
 			result = NULL;
 			return result;
 		}
 	}
-	/* if this is a public symbol, it's equally accessible as the parent symbol*/
 	result = vala_symbol_get_top_accessible_scope (vala_symbol_get_parent_symbol (self), is_internal);
 	return result;
 }
 
 
+static gboolean vala_symbol_real_is_instance_member (ValaSymbol* self) {
+	gboolean result;
+	gboolean instance;
+	g_return_val_if_fail (self != NULL, FALSE);
+	instance = TRUE;
+	if (VALA_IS_FIELD (self)) {
+		ValaField* f;
+		f = _vala_code_node_ref0 (VALA_FIELD (self));
+		instance = vala_field_get_binding (f) == MEMBER_BINDING_INSTANCE;
+		_vala_code_node_unref0 (f);
+	} else {
+		if (VALA_IS_METHOD (self)) {
+			ValaMethod* m;
+			m = _vala_code_node_ref0 (VALA_METHOD (self));
+			if (!VALA_IS_CREATION_METHOD (m)) {
+				instance = vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE;
+			}
+			_vala_code_node_unref0 (m);
+		} else {
+			if (VALA_IS_PROPERTY (self)) {
+				ValaProperty* prop;
+				prop = _vala_code_node_ref0 (VALA_PROPERTY (self));
+				instance = vala_property_get_binding (prop) == MEMBER_BINDING_INSTANCE;
+				_vala_code_node_unref0 (prop);
+			} else {
+				if (VALA_IS_ENUM_VALUE (self)) {
+					instance = FALSE;
+				} else {
+					if (VALA_IS_ERROR_CODE (self)) {
+						instance = FALSE;
+					}
+				}
+			}
+		}
+	}
+	result = instance;
+	return result;
+}
+
+
+gboolean vala_symbol_is_instance_member (ValaSymbol* self) {
+	return VALA_SYMBOL_GET_CLASS (self)->is_instance_member (self);
+}
+
+
+static gboolean vala_symbol_real_is_class_member (ValaSymbol* self) {
+	gboolean result;
+	gboolean isclass;
+	g_return_val_if_fail (self != NULL, FALSE);
+	isclass = TRUE;
+	if (VALA_IS_FIELD (self)) {
+		ValaField* f;
+		f = _vala_code_node_ref0 (VALA_FIELD (self));
+		isclass = vala_field_get_binding (f) == MEMBER_BINDING_CLASS;
+		_vala_code_node_unref0 (f);
+	} else {
+		if (VALA_IS_METHOD (self)) {
+			ValaMethod* m;
+			m = _vala_code_node_ref0 (VALA_METHOD (self));
+			if (!VALA_IS_CREATION_METHOD (m)) {
+				isclass = vala_method_get_binding (m) == MEMBER_BINDING_CLASS;
+			}
+			_vala_code_node_unref0 (m);
+		} else {
+			if (VALA_IS_PROPERTY (self)) {
+				ValaProperty* prop;
+				prop = _vala_code_node_ref0 (VALA_PROPERTY (self));
+				isclass = vala_property_get_binding (prop) == MEMBER_BINDING_CLASS;
+				_vala_code_node_unref0 (prop);
+			} else {
+				if (VALA_IS_ENUM_VALUE (self)) {
+					isclass = FALSE;
+				} else {
+					if (VALA_IS_ERROR_CODE (self)) {
+						isclass = FALSE;
+					}
+				}
+			}
+		}
+	}
+	result = isclass;
+	return result;
+}
+
+
+gboolean vala_symbol_is_class_member (ValaSymbol* self) {
+	return VALA_SYMBOL_GET_CLASS (self)->is_class_member (self);
+}
+
+
 ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self) {
 	ValaSymbol* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -744,12 +855,9 @@ const char* vala_symbol_get_name (ValaSymbol* self) {
 
 
 void vala_symbol_set_name (ValaSymbol* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 }
 
 
@@ -840,6 +948,8 @@ static void vala_symbol_class_init (ValaSymbolClass * klass) {
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_symbol_real_get_lower_case_cname;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_symbol_real_get_lower_case_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_symbol_real_get_cheader_filenames;
+	VALA_SYMBOL_CLASS (klass)->is_instance_member = vala_symbol_real_is_instance_member;
+	VALA_SYMBOL_CLASS (klass)->is_class_member = vala_symbol_real_is_class_member;
 }
 
 
@@ -852,8 +962,8 @@ static void vala_symbol_instance_init (ValaSymbol * self) {
 static void vala_symbol_finalize (ValaCodeNode* obj) {
 	ValaSymbol * self;
 	self = VALA_SYMBOL (obj);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_scope == NULL) ? NULL : (self->priv->_scope = (vala_scope_unref (self->priv->_scope), NULL));
+	_g_free0 (self->priv->_name);
+	_vala_scope_unref0 (self->priv->_scope);
 	VALA_CODE_NODE_CLASS (vala_symbol_parent_class)->finalize (obj);
 }
 
