@@ -146,6 +146,8 @@ typedef struct _ValaBlockClass ValaBlockClass;
 
 typedef struct _ValaCatchClause ValaCatchClause;
 typedef struct _ValaCatchClauseClass ValaCatchClauseClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -157,12 +159,6 @@ typedef struct _ValaCatchClauseClass ValaCatchClauseClass;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -183,16 +179,10 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Interface for all statement types.
- */
 struct _ValaStatementIface {
 	GTypeInterface parent_iface;
 };
 
-/**
- * Represents a try statement in the source code.
- */
 struct _ValaTryStatement {
 	ValaCodeNode parent_instance;
 	ValaTryStatementPrivate * priv;
@@ -238,6 +228,7 @@ GType vala_catch_clause_get_type (void);
 enum  {
 	VALA_TRY_STATEMENT_DUMMY_PROPERTY
 };
+ValaCodeNode* vala_code_node_construct (GType object_type);
 void vala_try_statement_set_body (ValaTryStatement* self, ValaBlock* value);
 void vala_try_statement_set_finally_body (ValaTryStatement* self, ValaBlock* value);
 gpointer vala_source_reference_ref (gpointer instance);
@@ -272,18 +263,10 @@ static void vala_try_statement_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new try statement.
- *
- * @param body             body of the try statement
- * @param finally_body     body of the optional finally clause
- * @param source_reference reference to source code
- * @return                 newly created try statement
- */
 ValaTryStatement* vala_try_statement_construct (GType object_type, ValaBlock* body, ValaBlock* finally_body, ValaSourceReference* source_reference) {
 	ValaTryStatement* self;
 	g_return_val_if_fail (body != NULL, NULL);
-	self = (ValaTryStatement*) g_type_create_instance (object_type);
+	self = (ValaTryStatement*) vala_code_node_construct (object_type);
 	vala_try_statement_set_body (self, body);
 	vala_try_statement_set_finally_body (self, finally_body);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
@@ -296,11 +279,6 @@ ValaTryStatement* vala_try_statement_new (ValaBlock* body, ValaBlock* finally_bo
 }
 
 
-/**
- * Appends the specified clause to the list of catch clauses.
- *
- * @param clause a catch clause
- */
 void vala_try_statement_add_catch_clause (ValaTryStatement* self, ValaCatchClause* clause) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (clause != NULL);
@@ -309,11 +287,6 @@ void vala_try_statement_add_catch_clause (ValaTryStatement* self, ValaCatchClaus
 }
 
 
-/**
- * Returns a copy of the list of catch clauses.
- *
- * @return list of catch clauses
- */
 GeeList* vala_try_statement_get_catch_clauses (ValaTryStatement* self) {
 	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
@@ -345,9 +318,9 @@ static void vala_try_statement_real_accept_children (ValaCodeNode* base, ValaCod
 			}
 			clause = (ValaCatchClause*) gee_iterator_get (_clause_it);
 			vala_code_node_accept ((ValaCodeNode*) clause, visitor);
-			(clause == NULL) ? NULL : (clause = (vala_code_node_unref (clause), NULL));
+			_vala_code_node_unref0 (clause);
 		}
-		(_clause_it == NULL) ? NULL : (_clause_it = (gee_collection_object_unref (_clause_it), NULL));
+		_gee_collection_object_unref0 (_clause_it);
 	}
 	if (vala_try_statement_get_finally_body (self) != NULL) {
 		vala_code_node_accept ((ValaCodeNode*) vala_try_statement_get_finally_body (self), visitor);
@@ -373,9 +346,7 @@ static gboolean vala_try_statement_real_check (ValaCodeNode* base, ValaSemanticA
 		GeeList* _tmp0_;
 		GeeIterator* _tmp1_;
 		GeeIterator* _body_error_type_it;
-		_tmp0_ = NULL;
-		_tmp1_ = NULL;
-		_body_error_type_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_try_statement_get_body (self)))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
+		_body_error_type_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_try_statement_get_body (self)))), _gee_collection_object_unref0 (_tmp0_), _tmp1_);
 		while (TRUE) {
 			ValaDataType* body_error_type;
 			if (!gee_iterator_next (_body_error_type_it)) {
@@ -383,9 +354,9 @@ static gboolean vala_try_statement_real_check (ValaCodeNode* base, ValaSemanticA
 			}
 			body_error_type = (ValaDataType*) gee_iterator_get (_body_error_type_it);
 			gee_collection_add ((GeeCollection*) error_types, body_error_type);
-			(body_error_type == NULL) ? NULL : (body_error_type = (vala_code_node_unref (body_error_type), NULL));
+			_vala_code_node_unref0 (body_error_type);
 		}
-		(_body_error_type_it == NULL) ? NULL : (_body_error_type_it = (gee_collection_object_unref (_body_error_type_it), NULL));
+		_gee_collection_object_unref0 (_body_error_type_it);
 	}
 	handled_error_types = gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	{
@@ -416,9 +387,9 @@ static gboolean vala_try_statement_real_check (ValaCodeNode* base, ValaSemanticA
 					if (_tmp2_) {
 						gee_collection_add ((GeeCollection*) handled_error_types, body_error_type);
 					}
-					(body_error_type == NULL) ? NULL : (body_error_type = (vala_code_node_unref (body_error_type), NULL));
+					_vala_code_node_unref0 (body_error_type);
 				}
-				(_body_error_type_it == NULL) ? NULL : (_body_error_type_it = (gee_collection_object_unref (_body_error_type_it), NULL));
+				_gee_collection_object_unref0 (_body_error_type_it);
 			}
 			{
 				GeeIterator* _handled_error_type_it;
@@ -430,9 +401,9 @@ static gboolean vala_try_statement_real_check (ValaCodeNode* base, ValaSemanticA
 					}
 					handled_error_type = (ValaDataType*) gee_iterator_get (_handled_error_type_it);
 					gee_collection_remove ((GeeCollection*) error_types, handled_error_type);
-					(handled_error_type == NULL) ? NULL : (handled_error_type = (vala_code_node_unref (handled_error_type), NULL));
+					_vala_code_node_unref0 (handled_error_type);
 				}
-				(_handled_error_type_it == NULL) ? NULL : (_handled_error_type_it = (gee_collection_object_unref (_handled_error_type_it), NULL));
+				_gee_collection_object_unref0 (_handled_error_type_it);
 			}
 			gee_collection_clear ((GeeCollection*) handled_error_types);
 			vala_code_node_check ((ValaCodeNode*) clause, analyzer);
@@ -440,9 +411,7 @@ static gboolean vala_try_statement_real_check (ValaCodeNode* base, ValaSemanticA
 				GeeList* _tmp3_;
 				GeeIterator* _tmp4_;
 				GeeIterator* _body_error_type_it;
-				_tmp3_ = NULL;
-				_tmp4_ = NULL;
-				_body_error_type_it = (_tmp4_ = gee_iterable_iterator ((GeeIterable*) (_tmp3_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_catch_clause_get_body (clause)))), (_tmp3_ == NULL) ? NULL : (_tmp3_ = (gee_collection_object_unref (_tmp3_), NULL)), _tmp4_);
+				_body_error_type_it = (_tmp4_ = gee_iterable_iterator ((GeeIterable*) (_tmp3_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_catch_clause_get_body (clause)))), _gee_collection_object_unref0 (_tmp3_), _tmp4_);
 				while (TRUE) {
 					ValaDataType* body_error_type;
 					if (!gee_iterator_next (_body_error_type_it)) {
@@ -450,13 +419,13 @@ static gboolean vala_try_statement_real_check (ValaCodeNode* base, ValaSemanticA
 					}
 					body_error_type = (ValaDataType*) gee_iterator_get (_body_error_type_it);
 					gee_collection_add ((GeeCollection*) error_types, body_error_type);
-					(body_error_type == NULL) ? NULL : (body_error_type = (vala_code_node_unref (body_error_type), NULL));
+					_vala_code_node_unref0 (body_error_type);
 				}
-				(_body_error_type_it == NULL) ? NULL : (_body_error_type_it = (gee_collection_object_unref (_body_error_type_it), NULL));
+				_gee_collection_object_unref0 (_body_error_type_it);
 			}
-			(clause == NULL) ? NULL : (clause = (vala_code_node_unref (clause), NULL));
+			_vala_code_node_unref0 (clause);
 		}
-		(_clause_it == NULL) ? NULL : (_clause_it = (gee_collection_object_unref (_clause_it), NULL));
+		_gee_collection_object_unref0 (_clause_it);
 	}
 	if (vala_try_statement_get_finally_body (self) != NULL) {
 		vala_code_node_check ((ValaCodeNode*) vala_try_statement_get_finally_body (self), analyzer);
@@ -464,9 +433,7 @@ static gboolean vala_try_statement_real_check (ValaCodeNode* base, ValaSemanticA
 			GeeList* _tmp5_;
 			GeeIterator* _tmp6_;
 			GeeIterator* _body_error_type_it;
-			_tmp5_ = NULL;
-			_tmp6_ = NULL;
-			_body_error_type_it = (_tmp6_ = gee_iterable_iterator ((GeeIterable*) (_tmp5_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_try_statement_get_finally_body (self)))), (_tmp5_ == NULL) ? NULL : (_tmp5_ = (gee_collection_object_unref (_tmp5_), NULL)), _tmp6_);
+			_body_error_type_it = (_tmp6_ = gee_iterable_iterator ((GeeIterable*) (_tmp5_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_try_statement_get_finally_body (self)))), _gee_collection_object_unref0 (_tmp5_), _tmp6_);
 			while (TRUE) {
 				ValaDataType* body_error_type;
 				if (!gee_iterator_next (_body_error_type_it)) {
@@ -474,15 +441,15 @@ static gboolean vala_try_statement_real_check (ValaCodeNode* base, ValaSemanticA
 				}
 				body_error_type = (ValaDataType*) gee_iterator_get (_body_error_type_it);
 				gee_collection_add ((GeeCollection*) error_types, body_error_type);
-				(body_error_type == NULL) ? NULL : (body_error_type = (vala_code_node_unref (body_error_type), NULL));
+				_vala_code_node_unref0 (body_error_type);
 			}
-			(_body_error_type_it == NULL) ? NULL : (_body_error_type_it = (gee_collection_object_unref (_body_error_type_it), NULL));
+			_gee_collection_object_unref0 (_body_error_type_it);
 		}
 	}
 	vala_code_node_add_error_types ((ValaCodeNode*) self, (GeeList*) error_types);
 	result = !vala_code_node_get_error ((ValaCodeNode*) self);
-	(error_types == NULL) ? NULL : (error_types = (gee_collection_object_unref (error_types), NULL));
-	(handled_error_types == NULL) ? NULL : (handled_error_types = (gee_collection_object_unref (handled_error_types), NULL));
+	_gee_collection_object_unref0 (error_types);
+	_gee_collection_object_unref0 (handled_error_types);
 	return result;
 }
 
@@ -495,13 +462,15 @@ ValaBlock* vala_try_statement_get_body (ValaTryStatement* self) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_try_statement_set_body (ValaTryStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp1_;
 	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_body = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp1_);
+	self->priv->_body = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_body), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_body, (ValaCodeNode*) self);
 }
 
@@ -515,12 +484,9 @@ ValaBlock* vala_try_statement_get_finally_body (ValaTryStatement* self) {
 
 
 void vala_try_statement_set_finally_body (ValaTryStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp1_;
 	ValaBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_finally_body = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_finally_body == NULL) ? NULL : (self->priv->_finally_body = (vala_code_node_unref (self->priv->_finally_body), NULL)), _tmp1_);
+	self->priv->_finally_body = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_finally_body), _tmp0_);
 	if (self->priv->_finally_body != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_finally_body, (ValaCodeNode*) self);
 	}
@@ -551,9 +517,9 @@ static void vala_try_statement_instance_init (ValaTryStatement * self) {
 static void vala_try_statement_finalize (ValaCodeNode* obj) {
 	ValaTryStatement * self;
 	self = VALA_TRY_STATEMENT (obj);
-	(self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL));
-	(self->priv->_finally_body == NULL) ? NULL : (self->priv->_finally_body = (vala_code_node_unref (self->priv->_finally_body), NULL));
-	(self->priv->catch_clauses == NULL) ? NULL : (self->priv->catch_clauses = (gee_collection_object_unref (self->priv->catch_clauses), NULL));
+	_vala_code_node_unref0 (self->priv->_body);
+	_vala_code_node_unref0 (self->priv->_finally_body);
+	_gee_collection_object_unref0 (self->priv->catch_clauses);
 	VALA_CODE_NODE_CLASS (vala_try_statement_parent_class)->finalize (obj);
 }
 
