@@ -119,6 +119,7 @@ typedef struct _ValaExpressionPrivate ValaExpressionPrivate;
 typedef struct _ValaTypeCheck ValaTypeCheck;
 typedef struct _ValaTypeCheckClass ValaTypeCheckClass;
 typedef struct _ValaTypeCheckPrivate ValaTypeCheckPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -882,12 +883,6 @@ typedef struct _ValaValueTypeClass ValaValueTypeClass;
 typedef struct _ValaStructValueType ValaStructValueType;
 typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -908,9 +903,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -924,9 +916,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Represents a type check (`is') expression in the source code.
- */
 struct _ValaTypeCheck {
 	ValaExpression parent_instance;
 	ValaTypeCheckPrivate * priv;
@@ -941,9 +930,6 @@ struct _ValaTypeCheckPrivate {
 	ValaDataType* _data_type;
 };
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -1030,17 +1016,12 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Code visitor analyzing and checking code.
- */
 struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 	ValaSymbol* root_symbol;
-	ValaDataType* current_return_type;
-	ValaClass* current_class;
-	ValaStruct* current_struct;
 	ValaBlock* insert_block;
+	ValaDataType* void_type;
 	ValaDataType* bool_type;
 	ValaDataType* string_type;
 	ValaDataType* uchar_type;
@@ -1097,6 +1078,7 @@ GType vala_typecheck_get_type (void);
 enum  {
 	VALA_TYPECHECK_DUMMY_PROPERTY
 };
+ValaExpression* vala_expression_construct (GType object_type);
 void vala_typecheck_set_expression (ValaTypeCheck* self, ValaExpression* value);
 void vala_typecheck_set_type_reference (ValaTypeCheck* self, ValaDataType* value);
 gpointer vala_source_reference_ref (gpointer instance);
@@ -1117,6 +1099,7 @@ static void vala_typecheck_real_accept (ValaCodeNode* base, ValaCodeVisitor* vis
 gboolean vala_expression_is_pure (ValaExpression* self);
 static gboolean vala_typecheck_real_is_pure (ValaExpression* base);
 static void vala_typecheck_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static void vala_typecheck_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 gboolean vala_code_node_get_checked (ValaCodeNode* self);
 gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
@@ -1210,20 +1193,12 @@ static void vala_typecheck_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new type check expression.
- *
- * @param expr   an expression
- * @param type   a data type
- * @param source reference to source code
- * @return       newly created type check expression
- */
 ValaTypeCheck* vala_typecheck_construct (GType object_type, ValaExpression* expr, ValaDataType* type, ValaSourceReference* source) {
 	ValaTypeCheck* self;
 	g_return_val_if_fail (expr != NULL, NULL);
 	g_return_val_if_fail (type != NULL, NULL);
 	g_return_val_if_fail (source != NULL, NULL);
-	self = (ValaTypeCheck*) g_type_create_instance (object_type);
+	self = (ValaTypeCheck*) vala_expression_construct (object_type);
 	vala_typecheck_set_expression (self, expr);
 	vala_typecheck_set_type_reference (self, type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
@@ -1240,7 +1215,7 @@ static void vala_typecheck_real_accept (ValaCodeNode* base, ValaCodeVisitor* vis
 	ValaTypeCheck * self;
 	self = (ValaTypeCheck*) base;
 	g_return_if_fail (visitor != NULL);
-	vala_code_node_accept ((ValaCodeNode*) self->priv->_expression, visitor);
+	vala_code_node_accept ((ValaCodeNode*) vala_typecheck_get_expression (self), visitor);
 	vala_code_node_accept ((ValaCodeNode*) vala_typecheck_get_type_reference (self), visitor);
 	vala_code_visitor_visit_type_check (visitor, self);
 	vala_code_visitor_visit_expression (visitor, (ValaExpression*) self);
@@ -1251,7 +1226,7 @@ static gboolean vala_typecheck_real_is_pure (ValaExpression* base) {
 	ValaTypeCheck * self;
 	gboolean result;
 	self = (ValaTypeCheck*) base;
-	result = vala_expression_is_pure (self->priv->_expression);
+	result = vala_expression_is_pure (vala_typecheck_get_expression (self));
 	return result;
 }
 
@@ -1267,6 +1242,17 @@ static void vala_typecheck_real_replace_type (ValaCodeNode* base, ValaDataType*
 }
 
 
+static void vala_typecheck_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
+	ValaTypeCheck * self;
+	self = (ValaTypeCheck*) base;
+	g_return_if_fail (old_node != NULL);
+	g_return_if_fail (new_node != NULL);
+	if (vala_typecheck_get_expression (self) == old_node) {
+		vala_typecheck_set_expression (self, new_node);
+	}
+}
+
+
 static gboolean vala_typecheck_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaTypeCheck * self;
 	gboolean result;
@@ -1277,10 +1263,9 @@ static gboolean vala_typecheck_real_check (ValaCodeNode* base, ValaSemanticAnaly
 		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
-	vala_code_node_check ((ValaCodeNode*) self->priv->_expression, analyzer);
+	vala_code_node_check ((ValaCodeNode*) vala_typecheck_get_expression (self), analyzer);
 	vala_code_node_check ((ValaCodeNode*) vala_typecheck_get_type_reference (self), analyzer);
 	if (vala_data_type_get_data_type (vala_typecheck_get_type_reference (self)) == NULL) {
-		/* if type resolving didn't succeed, skip this check */
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		result = FALSE;
 		return result;
@@ -1299,13 +1284,16 @@ ValaExpression* vala_typecheck_get_expression (ValaTypeCheck* self) {
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_typecheck_set_expression (ValaTypeCheck* self, ValaExpression* value) {
-	ValaExpression* _tmp1_;
 	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp1_);
+	self->priv->_expression = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_expression), _tmp0_);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_expression, (ValaCodeNode*) self);
 }
 
 
@@ -1318,12 +1306,9 @@ ValaDataType* vala_typecheck_get_type_reference (ValaTypeCheck* self) {
 
 
 void vala_typecheck_set_type_reference (ValaTypeCheck* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_data_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp1_);
+	self->priv->_data_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_data_type), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
@@ -1335,6 +1320,7 @@ static void vala_typecheck_class_init (ValaTypeCheckClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_typecheck_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_typecheck_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_typecheck_real_replace_type;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_typecheck_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->check = vala_typecheck_real_check;
 }
 
@@ -1347,8 +1333,8 @@ static void vala_typecheck_instance_init (ValaTypeCheck * self) {
 static void vala_typecheck_finalize (ValaCodeNode* obj) {
 	ValaTypeCheck * self;
 	self = VALA_TYPECHECK (obj);
-	(self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL));
-	(self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL));
+	_vala_code_node_unref0 (self->priv->_expression);
+	_vala_code_node_unref0 (self->priv->_data_type);
 	VALA_CODE_NODE_CLASS (vala_typecheck_parent_class)->finalize (obj);
 }
 
