@@ -119,6 +119,7 @@ typedef struct _ValaExpressionPrivate ValaExpressionPrivate;
 typedef struct _ValaTypeofExpression ValaTypeofExpression;
 typedef struct _ValaTypeofExpressionClass ValaTypeofExpressionClass;
 typedef struct _ValaTypeofExpressionPrivate ValaTypeofExpressionPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -862,12 +863,26 @@ typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
 typedef struct _ValaSemanticAnalyzerPrivate ValaSemanticAnalyzerPrivate;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
+#define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
+#define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
+#define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+#define VALA_IS_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VALUE_TYPE))
+#define VALA_IS_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VALUE_TYPE))
+#define VALA_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+
+typedef struct _ValaValueType ValaValueType;
+typedef struct _ValaValueTypeClass ValaValueTypeClass;
+
+#define VALA_TYPE_STRUCT_VALUE_TYPE (vala_struct_value_type_get_type ())
+#define VALA_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueType))
+#define VALA_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+#define VALA_IS_STRUCT_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_IS_STRUCT_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_VALUE_TYPE))
+#define VALA_STRUCT_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_VALUE_TYPE, ValaStructValueTypeClass))
+
+typedef struct _ValaStructValueType ValaStructValueType;
+typedef struct _ValaStructValueTypeClass ValaStructValueTypeClass;
+
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -888,9 +903,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Base class for all code nodes that might be used as an expression.
- */
 struct _ValaExpression {
 	ValaCodeNode parent_instance;
 	ValaExpressionPrivate * priv;
@@ -904,9 +916,6 @@ struct _ValaExpressionClass {
 	gboolean (*is_non_null) (ValaExpression* self);
 };
 
-/**
- * Represents a typeof expression in the source code.
- */
 struct _ValaTypeofExpression {
 	ValaExpression parent_instance;
 	ValaTypeofExpressionPrivate * priv;
@@ -920,9 +929,6 @@ struct _ValaTypeofExpressionPrivate {
 	ValaDataType* _data_type;
 };
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
 struct _ValaCodeVisitor {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -1009,17 +1015,12 @@ struct _ValaCodeVisitorClass {
 	void (*visit_end_full_expression) (ValaCodeVisitor* self, ValaExpression* expr);
 };
 
-/**
- * Code visitor analyzing and checking code.
- */
 struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 	ValaSymbol* root_symbol;
-	ValaDataType* current_return_type;
-	ValaClass* current_class;
-	ValaStruct* current_struct;
 	ValaBlock* insert_block;
+	ValaDataType* void_type;
 	ValaDataType* bool_type;
 	ValaDataType* string_type;
 	ValaDataType* uchar_type;
@@ -1036,9 +1037,11 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* double_type;
 	ValaDataType* type_type;
 	ValaClass* object_type;
+	ValaStructValueType* gvalue_type;
 	ValaDataType* glist_type;
 	ValaDataType* gslist_type;
 	ValaDataType* garray_type;
+	ValaDataType* gvaluearray_type;
 	ValaClass* gerror_type;
 	gint next_lambda_id;
 	GeeList* replaced_nodes;
@@ -1074,6 +1077,7 @@ GType vala_typeof_expression_get_type (void);
 enum  {
 	VALA_TYPEOF_EXPRESSION_DUMMY_PROPERTY
 };
+ValaExpression* vala_expression_construct (GType object_type);
 void vala_typeof_expression_set_type_reference (ValaTypeofExpression* self, ValaDataType* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
@@ -1084,7 +1088,6 @@ GType vala_source_reference_get_type (void);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaTypeofExpression* vala_typeof_expression_new (ValaDataType* type, ValaSourceReference* source);
 ValaTypeofExpression* vala_typeof_expression_construct (GType object_type, ValaDataType* type, ValaSourceReference* source);
-ValaTypeofExpression* vala_typeof_expression_new (ValaDataType* type, ValaSourceReference* source);
 ValaDataType* vala_typeof_expression_get_type_reference (ValaTypeofExpression* self);
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_visitor_visit_typeof_expression (ValaCodeVisitor* self, ValaTypeofExpression* expr);
@@ -1174,6 +1177,8 @@ GType vala_typecheck_get_type (void);
 GType vala_conditional_expression_get_type (void);
 GType vala_lambda_expression_get_type (void);
 GType vala_assignment_get_type (void);
+GType vala_value_type_get_type (void);
+GType vala_struct_value_type_get_type (void);
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_typeof_expression_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
@@ -1181,18 +1186,11 @@ static void vala_typeof_expression_finalize (ValaCodeNode* obj);
 
 
 
-/**
- * Creates a new typeof expression.
- *
- * @param type   a data type
- * @param source reference to source code
- * @return       newly created typeof expression
- */
 ValaTypeofExpression* vala_typeof_expression_construct (GType object_type, ValaDataType* type, ValaSourceReference* source) {
 	ValaTypeofExpression* self;
 	g_return_val_if_fail (type != NULL, NULL);
 	g_return_val_if_fail (source != NULL, NULL);
-	self = (ValaTypeofExpression*) g_type_create_instance (object_type);
+	self = (ValaTypeofExpression*) vala_expression_construct (object_type);
 	vala_typeof_expression_set_type_reference (self, type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
@@ -1259,13 +1257,15 @@ ValaDataType* vala_typeof_expression_get_type_reference (ValaTypeofExpression* s
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_typeof_expression_set_type_reference (ValaTypeofExpression* self, ValaDataType* value) {
-	ValaDataType* _tmp1_;
 	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_data_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp1_);
+	self->priv->_data_type = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_data_type), _tmp0_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
@@ -1289,7 +1289,7 @@ static void vala_typeof_expression_instance_init (ValaTypeofExpression * self) {
 static void vala_typeof_expression_finalize (ValaCodeNode* obj) {
 	ValaTypeofExpression * self;
 	self = VALA_TYPEOF_EXPRESSION (obj);
-	(self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL));
+	_vala_code_node_unref0 (self->priv->_data_type);
 	VALA_CODE_NODE_CLASS (vala_typeof_expression_parent_class)->finalize (obj);
 }
 
