@@ -130,12 +130,6 @@ typedef struct _ValaTypeParameterPrivate ValaTypeParameterPrivate;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -156,9 +150,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -170,11 +161,10 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a generic type parameter in the source code.
- */
 struct _ValaTypeParameter {
 	ValaSymbol parent_instance;
 	ValaTypeParameterPrivate * priv;
@@ -215,24 +205,15 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
 ValaTypeParameter* vala_typeparameter_new (const char* name, ValaSourceReference* source_reference);
 ValaTypeParameter* vala_typeparameter_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaTypeParameter* vala_typeparameter_new (const char* name, ValaSourceReference* source_reference);
 void vala_code_visitor_visit_type_parameter (ValaCodeVisitor* self, ValaTypeParameter* p);
 static void vala_typeparameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 gboolean vala_typeparameter_equals (ValaTypeParameter* self, ValaTypeParameter* param2);
 
 
 
-/**
- * Creates a new generic type parameter.
- *
- * @param name   parameter name
- * @param source reference to source code
- * @return       newly created generic type parameter
- */
 ValaTypeParameter* vala_typeparameter_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
 	ValaTypeParameter* self;
 	g_return_val_if_fail (name != NULL, NULL);
@@ -255,21 +236,10 @@ static void vala_typeparameter_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 }
 
 
-/**
- * Checks two type parameters for equality.
- *
- * @param param2 a type parameter
- * @return      true if this type parameter is equal to param2, false
- *              otherwise
- */
 gboolean vala_typeparameter_equals (ValaTypeParameter* self, ValaTypeParameter* param2) {
 	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (param2 != NULL, FALSE);
-	/* FIXME check whether the corresponding data type of one of the
-	       parameters is a base type of the corresponding data
-	       type of the other parameter and check along the path
-	       whether one parameter maps to the other*/
 	result = TRUE;
 	return result;
 }
