@@ -121,6 +121,18 @@ typedef struct _ValaTypeSymbol ValaTypeSymbol;
 typedef struct _ValaTypeSymbolClass ValaTypeSymbolClass;
 typedef struct _ValaTypeSymbolPrivate ValaTypeSymbolPrivate;
 
+#define VALA_TYPE_COMMENT (vala_comment_get_type ())
+#define VALA_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_COMMENT, ValaComment))
+#define VALA_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_COMMENT, ValaCommentClass))
+#define VALA_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_COMMENT))
+#define VALA_IS_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_COMMENT))
+#define VALA_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_COMMENT, ValaCommentClass))
+
+typedef struct _ValaComment ValaComment;
+typedef struct _ValaCommentClass ValaCommentClass;
+#define _vala_comment_unref0(var) ((var == NULL) ? NULL : (var = (vala_comment_unref (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
+
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
 #define VALA_SOURCE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferenceClass))
@@ -130,6 +142,7 @@ typedef struct _ValaTypeSymbolPrivate ValaTypeSymbolPrivate;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
 #define VALA_SOURCE_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_FILE, ValaSourceFile))
@@ -141,12 +154,6 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -167,9 +174,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -181,12 +185,10 @@ struct _ValaSymbolClass {
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
 	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
+	gboolean (*is_instance_member) (ValaSymbol* self);
+	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * Represents a runtime data type. This data type may be defined in Vala source
- * code or imported from an external library with a Vala API file.
- */
 struct _ValaTypeSymbol {
 	ValaSymbol parent_instance;
 	ValaTypeSymbolPrivate * priv;
@@ -217,10 +219,12 @@ struct _ValaTypeSymbolClass {
 };
 
 struct _ValaTypeSymbolPrivate {
+	ValaComment* _comment;
 	GeeList* cheader_filenames;
 };
 
 
+static gpointer vala_typesymbol_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -241,6 +245,12 @@ GType vala_symbol_get_type (void);
 GType vala_local_variable_get_type (void);
 GType vala_attribute_get_type (void);
 GType vala_typesymbol_get_type (void);
+gpointer vala_comment_ref (gpointer instance);
+void vala_comment_unref (gpointer instance);
+GParamSpec* vala_param_spec_comment (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_comment (GValue* value, gpointer v_object);
+gpointer vala_value_get_comment (const GValue* value);
+GType vala_comment_get_type (void);
 #define VALA_TYPESYMBOL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPESYMBOL, ValaTypeSymbolPrivate))
 enum  {
 	VALA_TYPESYMBOL_DUMMY_PROPERTY
@@ -251,11 +261,9 @@ GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* ni
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-ValaSymbol* vala_symbol_new (const char* name, ValaSourceReference* source_reference);
 ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaTypeSymbol* vala_typesymbol_new (const char* name, ValaSourceReference* source_reference);
-ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
-ValaTypeSymbol* vala_typesymbol_new (const char* name, ValaSourceReference* source_reference);
+void vala_typesymbol_set_comment (ValaTypeSymbol* self, ValaComment* value);
+ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment);
 char* vala_typesymbol_get_cname (ValaTypeSymbol* self, gboolean const_type);
 static char* vala_typesymbol_real_get_cname (ValaTypeSymbol* self, gboolean const_type);
 gboolean vala_typesymbol_is_reference_type (ValaTypeSymbol* self);
@@ -310,23 +318,19 @@ gint vala_typesymbol_get_type_parameter_index (ValaTypeSymbol* self, const char*
 static gint vala_typesymbol_real_get_type_parameter_index (ValaTypeSymbol* self, const char* name);
 char* vala_typesymbol_get_type_signature (ValaTypeSymbol* self);
 static char* vala_typesymbol_real_get_type_signature (ValaTypeSymbol* self);
-static gpointer vala_typesymbol_parent_class = NULL;
+ValaComment* vala_typesymbol_get_comment (ValaTypeSymbol* self);
 static void vala_typesymbol_finalize (ValaCodeNode* obj);
 
 
 
-ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
+ValaTypeSymbol* vala_typesymbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference, ValaComment* comment) {
 	ValaTypeSymbol* self;
 	self = (ValaTypeSymbol*) vala_symbol_construct (object_type, name, source_reference);
+	vala_typesymbol_set_comment (self, comment);
 	return self;
 }
 
 
-ValaTypeSymbol* vala_typesymbol_new (const char* name, ValaSourceReference* source_reference) {
-	return vala_typesymbol_construct (VALA_TYPE_TYPESYMBOL, name, source_reference);
-}
-
-
 static char* vala_typesymbol_real_get_cname (ValaTypeSymbol* self, gboolean const_type) {
 	g_return_val_if_fail (self != NULL, NULL);
 	g_critical ("Type `%s' does not implement abstract method `vala_typesymbol_get_cname'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
@@ -334,24 +338,16 @@ static char* vala_typesymbol_real_get_cname (ValaTypeSymbol* self, gboolean cons
 }
 
 
-/**
- * Returns the name of this data type as it is used in C code.
- *
- * @return the name to be used in C code
- */
 char* vala_typesymbol_get_cname (ValaTypeSymbol* self, gboolean const_type) {
 	return VALA_TYPESYMBOL_GET_CLASS (self)->get_cname (self, const_type);
 }
 
 
-/**
- * Checks whether this data type has value or reference type semantics.
- *
- * @return true if this data type has reference type semantics
- */
 static gboolean vala_typesymbol_real_is_reference_type (ValaTypeSymbol* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
@@ -360,17 +356,11 @@ gboolean vala_typesymbol_is_reference_type (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the C function name that duplicates instances of this data
- * type. The specified C function must accept one argument referencing
- * the instance of this data type and return a reference to the
- * duplicate.
- *
- * @return the name of the C function if supported or null otherwise
- */
 static char* vala_typesymbol_real_get_dup_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -379,16 +369,11 @@ char* vala_typesymbol_get_dup_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the C function name that frees instances of this data type.
- * The specified C function must accept one argument pointing to the
- * instance to be freed.
- *
- * @return the name of the C function if supported or null otherwise
- */
 static char* vala_typesymbol_real_get_free_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -397,17 +382,11 @@ char* vala_typesymbol_get_free_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the C function name that copies contents of instances of
- * this data type. This is only applicable to structs. The specified
- * C function must accept two arguments, the first is the source value
- * and the second is the destination value.
- *
- * @return the name of the C function if supported or null otherwise
- */
 static char* vala_typesymbol_real_get_copy_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -416,17 +395,11 @@ char* vala_typesymbol_get_copy_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the C function name that destroys the contents of instances
- * of this data type. This is only applicable to structs. The specified
- * C function must accept one argument pointing to the instance to be
- * destroyed.
- *
- * @return the name of the C function if supported or null otherwise
- */
 static char* vala_typesymbol_real_get_destroy_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -435,15 +408,11 @@ char* vala_typesymbol_get_destroy_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Checks whether this data type supports reference counting. This is
- * only valid for reference types.
- *
- * @return true if this data type supports reference counting
- */
 static gboolean vala_typesymbol_real_is_reference_counting (ValaTypeSymbol* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return FALSE;
+	result = FALSE;
+	return result;
 }
 
 
@@ -452,19 +421,11 @@ gboolean vala_typesymbol_is_reference_counting (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the C function name that increments the reference count of
- * instances of this data type. This is only valid for data types
- * supporting reference counting. The specified C function must accept
- * one argument referencing the instance of this data type and return
- * the reference.
- *
- * @return the name of the C function or null if this data type does not
- *         support reference counting
- */
 static char* vala_typesymbol_real_get_ref_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -473,18 +434,11 @@ char* vala_typesymbol_get_ref_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the C function name that decrements the reference count of
- * instances of this data type. This is only valid for data types
- * supporting reference counting. The specified C function must accept
- * one argument referencing the instance of this data type.
- *
- * @return the name of the C function or null if this data type does not
- *         support reference counting
- */
 static char* vala_typesymbol_real_get_unref_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -493,23 +447,11 @@ char* vala_typesymbol_get_unref_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the C function name that sinks the reference count of
- * "floating" instances of this data type. This is only valid for data
- * types supporting floating references. The specified C function must
- * accept one argument referencing the instance of this data type and
- * return a non-floating reference.
- *
- * The ref_sink function is called for any constructor of the class and
- * for other methods that have the class as a return value and are
- * marked with the 'floating' attribute.
- *
- * @return the name of the C function or null if this data type does not
- *         support floating reference counts
- */
 static char* vala_typesymbol_real_get_ref_sink_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -518,16 +460,11 @@ char* vala_typesymbol_get_ref_sink_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the C symbol representing the runtime type id for this data
- * type. The specified symbol must express a registered GType.
- *
- * @return the name of the GType name in C code or null if this data
- *         type is not registered with GType
- */
 static char* vala_typesymbol_real_get_type_id (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -536,14 +473,11 @@ char* vala_typesymbol_get_type_id (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the name of this data type as used in C code marshallers
- *
- * @return type name for marshallers
- */
 static char* vala_typesymbol_real_get_marshaller_type_name (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -552,12 +486,11 @@ char* vala_typesymbol_get_marshaller_type_name (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the cname of the GValue parameter spec function.
- */
 static char* vala_typesymbol_real_get_param_spec_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -566,12 +499,11 @@ char* vala_typesymbol_get_param_spec_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the cname of the GValue getter function.
- */
 static char* vala_typesymbol_real_get_get_value_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -580,12 +512,11 @@ char* vala_typesymbol_get_get_value_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the cname of the GValue setter function.
- */
 static char* vala_typesymbol_real_get_set_value_function (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -594,18 +525,11 @@ char* vala_typesymbol_get_set_value_function (ValaTypeSymbol* self) {
 }
 
 
-/**
- * Returns the C name of this data type in upper case. Words are
- * separated by underscores. The upper case C name of the namespace is
- * prefix of the result.
- *
- * @param infix a string to be placed between namespace and data type
- *              name or null
- * @return      the upper case name to be used in C code
- */
 static char* vala_typesymbol_real_get_upper_case_cname (ValaTypeSymbol* self, const char* infix) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -614,15 +538,11 @@ char* vala_typesymbol_get_upper_case_cname (ValaTypeSymbol* self, const char* in
 }
 
 
-/**
- * Returns the default value for the given type. Returning null means
- * there is no default value (i.e. not that the default name is NULL).
- *
- * @returnthe name of the default value
- */
 static char* vala_typesymbol_real_get_default_value (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -633,6 +553,7 @@ char* vala_typesymbol_get_default_value (ValaTypeSymbol* self) {
 
 static GeeList* vala_typesymbol_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaTypeSymbol * self;
+	GeeList* result;
 	gboolean _tmp0_;
 	self = (ValaTypeSymbol*) base;
 	_tmp0_ = FALSE;
@@ -641,28 +562,24 @@ static GeeList* vala_typesymbol_real_get_cheader_filenames (ValaSymbol* base) {
 	} else {
 		_tmp0_ = FALSE;
 	}
-	/* parent_symbol can be null on incremental parsing*/
 	if (_tmp0_) {
 		gboolean _tmp3_;
 		gboolean _tmp4_;
-		/* default to header filenames of the namespace */
 		{
 			GeeList* _tmp1_;
 			GeeIterator* _tmp2_;
 			GeeIterator* _filename_it;
-			/* default to header filenames of the namespace */
-			_tmp1_ = NULL;
-			_tmp2_ = NULL;
-			_filename_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol ((ValaSymbol*) self)))), (_tmp1_ == NULL) ? NULL : (_tmp1_ = (gee_collection_object_unref (_tmp1_), NULL)), _tmp2_);
-			/* default to header filenames of the namespace */
-			while (gee_iterator_next (_filename_it)) {
+			_filename_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol ((ValaSymbol*) self)))), _gee_collection_object_unref0 (_tmp1_), _tmp2_);
+			while (TRUE) {
 				char* filename;
-				/* default to header filenames of the namespace */
+				if (!gee_iterator_next (_filename_it)) {
+					break;
+				}
 				filename = (char*) gee_iterator_get (_filename_it);
 				vala_typesymbol_add_cheader_filename (self, filename);
-				filename = (g_free (filename), NULL);
+				_g_free0 (filename);
 			}
-			(_filename_it == NULL) ? NULL : (_filename_it = (gee_collection_object_unref (_filename_it), NULL));
+			_gee_collection_object_unref0 (_filename_it);
 		}
 		_tmp3_ = FALSE;
 		_tmp4_ = FALSE;
@@ -678,22 +595,15 @@ static GeeList* vala_typesymbol_real_get_cheader_filenames (ValaSymbol* base) {
 		}
 		if (_tmp3_) {
 			char* _tmp5_;
-			/* don't add default include directives for VAPI files*/
-			_tmp5_ = NULL;
 			gee_collection_add ((GeeCollection*) self->priv->cheader_filenames, _tmp5_ = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-			_tmp5_ = (g_free (_tmp5_), NULL);
+			_g_free0 (_tmp5_);
 		}
 	}
-	return (GeeList*) gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->cheader_filenames);
+	result = (GeeList*) gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->cheader_filenames);
+	return result;
 }
 
 
-/**
- * Adds a filename to the list of C header filenames users of this data
- * type must include.
- *
- * @param filename a C header filename
- */
 void vala_typesymbol_add_cheader_filename (ValaTypeSymbol* self, const char* filename) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (filename != NULL);
@@ -701,17 +611,12 @@ void vala_typesymbol_add_cheader_filename (ValaTypeSymbol* self, const char* fil
 }
 
 
-/**
- * Checks whether this data type is equal to or a subtype of the
- * specified data type.
- *
- * @param t a data type
- * @return  true if t is a supertype of this data type, false otherwise
- */
 static gboolean vala_typesymbol_real_is_subtype_of (ValaTypeSymbol* self, ValaTypeSymbol* t) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (t != NULL, FALSE);
-	return self == t;
+	result = self == t;
+	return result;
 }
 
 
@@ -720,13 +625,12 @@ gboolean vala_typesymbol_is_subtype_of (ValaTypeSymbol* self, ValaTypeSymbol* t)
 }
 
 
-/**
- * Return the index of the specified type parameter name.
- */
 static gint vala_typesymbol_real_get_type_parameter_index (ValaTypeSymbol* self, const char* name) {
+	gint result;
 	g_return_val_if_fail (self != NULL, 0);
 	g_return_val_if_fail (name != NULL, 0);
-	return -1;
+	result = -1;
+	return result;
 }
 
 
@@ -735,12 +639,11 @@ gint vala_typesymbol_get_type_parameter_index (ValaTypeSymbol* self, const char*
 }
 
 
-/**
- * Returns type signature as used for GVariant and D-Bus
- */
 static char* vala_typesymbol_real_get_type_signature (ValaTypeSymbol* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return NULL;
+	result = NULL;
+	return result;
 }
 
 
@@ -749,6 +652,26 @@ char* vala_typesymbol_get_type_signature (ValaTypeSymbol* self) {
 }
 
 
+ValaComment* vala_typesymbol_get_comment (ValaTypeSymbol* self) {
+	ValaComment* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = self->priv->_comment;
+	return result;
+}
+
+
+static gpointer _vala_comment_ref0 (gpointer self) {
+	return self ? vala_comment_ref (self) : NULL;
+}
+
+
+void vala_typesymbol_set_comment (ValaTypeSymbol* self, ValaComment* value) {
+	ValaComment* _tmp0_;
+	g_return_if_fail (self != NULL);
+	self->priv->_comment = (_tmp0_ = _vala_comment_ref0 (value), _vala_comment_unref0 (self->priv->_comment), _tmp0_);
+}
+
+
 static void vala_typesymbol_class_init (ValaTypeSymbolClass * klass) {
 	vala_typesymbol_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->finalize = vala_typesymbol_finalize;
@@ -786,7 +709,8 @@ static void vala_typesymbol_instance_init (ValaTypeSymbol * self) {
 static void vala_typesymbol_finalize (ValaCodeNode* obj) {
 	ValaTypeSymbol * self;
 	self = VALA_TYPESYMBOL (obj);
-	(self->priv->cheader_filenames == NULL) ? NULL : (self->priv->cheader_filenames = (gee_collection_object_unref (self->priv->cheader_filenames), NULL));
+	_vala_comment_unref0 (self->priv->_comment);
+	_gee_collection_object_unref0 (self->priv->cheader_filenames);
 	VALA_CODE_NODE_CLASS (vala_typesymbol_parent_class)->finalize (obj);
 }
 
