@@ -1,6 +1,6 @@
 /* valaunresolvedsymbol.vala
  *
- * Copyright (C) 2008  Jürg Billeter
+ * Copyright (C) 2008-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -119,6 +119,7 @@ typedef struct _ValaSymbolPrivate ValaSymbolPrivate;
 typedef struct _ValaUnresolvedSymbol ValaUnresolvedSymbol;
 typedef struct _ValaUnresolvedSymbolClass ValaUnresolvedSymbolClass;
 typedef struct _ValaUnresolvedSymbolPrivate ValaUnresolvedSymbolPrivate;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -129,13 +130,8 @@ typedef struct _ValaUnresolvedSymbolPrivate ValaUnresolvedSymbolPrivate;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -156,9 +152,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * Represents a node in the symbol tree.
- */
 struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
@@ -174,9 +167,6 @@ struct _ValaSymbolClass {
 	gboolean (*is_class_member) (ValaSymbol* self);
 };
 
-/**
- * An unresolved reference to a symbol.
- */
 struct _ValaUnresolvedSymbol {
 	ValaSymbol parent_instance;
 	ValaUnresolvedSymbolPrivate * priv;
@@ -217,15 +207,14 @@ GType vala_unresolved_symbol_get_type (void);
 enum  {
 	VALA_UNRESOLVED_SYMBOL_DUMMY_PROPERTY
 };
-void vala_unresolved_symbol_set_inner (ValaUnresolvedSymbol* self, ValaUnresolvedSymbol* value);
-void vala_symbol_set_name (ValaSymbol* self, const char* value);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
 void vala_value_set_source_reference (GValue* value, gpointer v_object);
 gpointer vala_value_get_source_reference (const GValue* value);
 GType vala_source_reference_get_type (void);
-void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
+ValaSymbol* vala_symbol_construct (GType object_type, const char* name, ValaSourceReference* source_reference);
+void vala_unresolved_symbol_set_inner (ValaUnresolvedSymbol* self, ValaUnresolvedSymbol* value);
 ValaUnresolvedSymbol* vala_unresolved_symbol_new (ValaUnresolvedSymbol* inner, const char* name, ValaSourceReference* source_reference);
 ValaUnresolvedSymbol* vala_unresolved_symbol_construct (GType object_type, ValaUnresolvedSymbol* inner, const char* name, ValaSourceReference* source_reference);
 ValaUnresolvedSymbol* vala_unresolved_symbol_get_inner (ValaUnresolvedSymbol* self);
@@ -243,10 +232,8 @@ static void vala_unresolved_symbol_finalize (ValaCodeNode* obj);
 ValaUnresolvedSymbol* vala_unresolved_symbol_construct (GType object_type, ValaUnresolvedSymbol* inner, const char* name, ValaSourceReference* source_reference) {
 	ValaUnresolvedSymbol* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	self = (ValaUnresolvedSymbol*) g_type_create_instance (object_type);
+	self = (ValaUnresolvedSymbol*) vala_symbol_construct (object_type, name, source_reference);
 	vala_unresolved_symbol_set_inner (self, inner);
-	vala_symbol_set_name ((ValaSymbol*) self, name);
-	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
 }
 
@@ -261,16 +248,12 @@ static char* vala_unresolved_symbol_real_to_string (ValaCodeNode* base) {
 	char* result;
 	self = (ValaUnresolvedSymbol*) base;
 	if (self->priv->_inner == NULL) {
-		const char* _tmp0_;
-		_tmp0_ = NULL;
-		result = (_tmp0_ = vala_symbol_get_name ((ValaSymbol*) self), (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
+		result = g_strdup (vala_symbol_get_name ((ValaSymbol*) self));
 		return result;
 	} else {
+		char* _tmp0_;
 		char* _tmp1_;
-		char* _tmp2_;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		result = (_tmp2_ = g_strdup_printf ("%s.%s", _tmp1_ = vala_code_node_to_string ((ValaCodeNode*) self->priv->_inner), vala_symbol_get_name ((ValaSymbol*) self)), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
+		result = (_tmp1_ = g_strdup_printf ("%s.%s", _tmp0_ = vala_code_node_to_string ((ValaCodeNode*) self->priv->_inner), vala_symbol_get_name ((ValaSymbol*) self)), _g_free0 (_tmp0_), _tmp1_);
 		return result;
 	}
 }
@@ -292,13 +275,15 @@ ValaUnresolvedSymbol* vala_unresolved_symbol_get_inner (ValaUnresolvedSymbol* se
 }
 
 
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 void vala_unresolved_symbol_set_inner (ValaUnresolvedSymbol* self, ValaUnresolvedSymbol* value) {
-	ValaUnresolvedSymbol* _tmp1_;
 	ValaUnresolvedSymbol* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_inner = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL)), _tmp1_);
+	self->priv->_inner = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_inner), _tmp0_);
 }
 
 
@@ -332,7 +317,7 @@ static void vala_unresolved_symbol_instance_init (ValaUnresolvedSymbol * self) {
 static void vala_unresolved_symbol_finalize (ValaCodeNode* obj) {
 	ValaUnresolvedSymbol * self;
 	self = VALA_UNRESOLVED_SYMBOL (obj);
-	(self->priv->_inner == NULL) ? NULL : (self->priv->_inner = (vala_code_node_unref (self->priv->_inner), NULL));
+	_vala_code_node_unref0 (self->priv->_inner);
 	VALA_CODE_NODE_CLASS (vala_unresolved_symbol_parent_class)->finalize (obj);
 }
 
