@@ -150,6 +150,7 @@ typedef struct _ValaUnresolvedTypePrivate ValaUnresolvedTypePrivate;
 
 typedef struct _ValaUnresolvedSymbol ValaUnresolvedSymbol;
 typedef struct _ValaUnresolvedSymbolClass ValaUnresolvedSymbolClass;
+#define _vala_code_node_unref0(var) ((var == NULL) ? NULL : (var = (vala_code_node_unref (var), NULL)))
 
 #define VALA_TYPE_SOURCE_REFERENCE (vala_source_reference_get_type ())
 #define VALA_SOURCE_REFERENCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReference))
@@ -170,13 +171,8 @@ typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
 typedef struct _ValaMemberAccess ValaMemberAccess;
 typedef struct _ValaMemberAccessClass ValaMemberAccessClass;
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -197,10 +193,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -230,9 +222,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * An unresolved reference to a data type.
- */
 struct _ValaUnresolvedType {
 	ValaDataType parent_instance;
 	ValaUnresolvedTypePrivate * priv;
@@ -280,6 +269,7 @@ GType vala_unresolved_symbol_get_type (void);
 enum  {
 	VALA_UNRESOLVED_TYPE_DUMMY_PROPERTY
 };
+ValaDataType* vala_data_type_construct (GType object_type);
 ValaUnresolvedType* vala_unresolved_type_new (void);
 ValaUnresolvedType* vala_unresolved_type_construct (GType object_type);
 void vala_unresolved_type_set_unresolved_symbol (ValaUnresolvedType* self, ValaUnresolvedSymbol* value);
@@ -321,7 +311,7 @@ static void vala_unresolved_type_finalize (ValaCodeNode* obj);
 
 ValaUnresolvedType* vala_unresolved_type_construct (GType object_type) {
 	ValaUnresolvedType* self;
-	self = (ValaUnresolvedType*) g_type_create_instance (object_type);
+	self = (ValaUnresolvedType*) vala_data_type_construct (object_type);
 	return self;
 }
 
@@ -331,17 +321,10 @@ ValaUnresolvedType* vala_unresolved_type_new (void) {
 }
 
 
-/**
- * Creates a new type reference.
- *
- * @param symbol    unresolved type symbol
- * @param source    reference to source code
- * @return          newly created type reference
- */
 ValaUnresolvedType* vala_unresolved_type_construct_from_symbol (GType object_type, ValaUnresolvedSymbol* symbol, ValaSourceReference* source) {
 	ValaUnresolvedType* self;
 	g_return_val_if_fail (symbol != NULL, NULL);
-	self = (ValaUnresolvedType*) g_type_create_instance (object_type);
+	self = (ValaUnresolvedType*) vala_data_type_construct (object_type);
 	vala_unresolved_type_set_unresolved_symbol (self, symbol);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
@@ -353,47 +336,36 @@ ValaUnresolvedType* vala_unresolved_type_new_from_symbol (ValaUnresolvedSymbol*
 }
 
 
-/**
- * Creates a new type reference from a code expression.
- *
- * @param expr   member access expression
- * @param source reference to source code
- * @return       newly created type reference
- */
+static gpointer _vala_code_node_ref0 (gpointer self) {
+	return self ? vala_code_node_ref (self) : NULL;
+}
+
+
 ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* expr) {
 	ValaUnresolvedType* result;
 	g_return_val_if_fail (expr != NULL, NULL);
 	if (VALA_IS_MEMBER_ACCESS (expr)) {
 		ValaUnresolvedType* type_ref;
-		ValaMemberAccess* _tmp0_;
 		ValaMemberAccess* ma;
 		type_ref = NULL;
-		_tmp0_ = NULL;
-		ma = (_tmp0_ = VALA_MEMBER_ACCESS (expr), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+		ma = _vala_code_node_ref0 (VALA_MEMBER_ACCESS (expr));
 		if (vala_member_access_get_inner (ma) != NULL) {
 			if (VALA_IS_MEMBER_ACCESS (vala_member_access_get_inner (ma))) {
-				ValaMemberAccess* _tmp1_;
 				ValaMemberAccess* simple;
-				ValaUnresolvedType* _tmp4_;
-				ValaUnresolvedSymbol* _tmp3_;
-				ValaUnresolvedSymbol* _tmp2_;
-				_tmp1_ = NULL;
-				simple = (_tmp1_ = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
-				_tmp4_ = NULL;
-				_tmp3_ = NULL;
-				_tmp2_ = NULL;
-				type_ref = (_tmp4_ = vala_unresolved_type_new_from_symbol (_tmp3_ = vala_unresolved_symbol_new (_tmp2_ = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (simple), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), (type_ref == NULL) ? NULL : (type_ref = (vala_code_node_unref (type_ref), NULL)), _tmp4_);
-				(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_node_unref (_tmp3_), NULL));
-				(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
-				(simple == NULL) ? NULL : (simple = (vala_code_node_unref (simple), NULL));
+				ValaUnresolvedType* _tmp2_;
+				ValaUnresolvedSymbol* _tmp1_;
+				ValaUnresolvedSymbol* _tmp0_;
+				simple = _vala_code_node_ref0 (VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)));
+				type_ref = (_tmp2_ = vala_unresolved_type_new_from_symbol (_tmp1_ = vala_unresolved_symbol_new (_tmp0_ = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (simple), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), _vala_code_node_unref0 (type_ref), _tmp2_);
+				_vala_code_node_unref0 (_tmp1_);
+				_vala_code_node_unref0 (_tmp0_);
+				_vala_code_node_unref0 (simple);
 			}
 		} else {
-			ValaUnresolvedType* _tmp6_;
-			ValaUnresolvedSymbol* _tmp5_;
-			_tmp6_ = NULL;
-			_tmp5_ = NULL;
-			type_ref = (_tmp6_ = vala_unresolved_type_new_from_symbol (_tmp5_ = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), (type_ref == NULL) ? NULL : (type_ref = (vala_code_node_unref (type_ref), NULL)), _tmp6_);
-			(_tmp5_ == NULL) ? NULL : (_tmp5_ = (vala_code_node_unref (_tmp5_), NULL));
+			ValaUnresolvedType* _tmp4_;
+			ValaUnresolvedSymbol* _tmp3_;
+			type_ref = (_tmp4_ = vala_unresolved_type_new_from_symbol (_tmp3_ = vala_unresolved_symbol_new (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), vala_code_node_get_source_reference ((ValaCodeNode*) ma)), _vala_code_node_unref0 (type_ref), _tmp4_);
+			_vala_code_node_unref0 (_tmp3_);
 		}
 		if (type_ref != NULL) {
 			GeeList* type_args;
@@ -409,17 +381,17 @@ ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* ex
 					}
 					arg = (ValaDataType*) gee_iterator_get (_arg_it);
 					vala_data_type_add_type_argument ((ValaDataType*) type_ref, arg);
-					(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+					_vala_code_node_unref0 (arg);
 				}
-				(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
+				_gee_collection_object_unref0 (_arg_it);
 			}
 			result = type_ref;
-			(type_args == NULL) ? NULL : (type_args = (gee_collection_object_unref (type_args), NULL));
-			(ma == NULL) ? NULL : (ma = (vala_code_node_unref (ma), NULL));
+			_gee_collection_object_unref0 (type_args);
+			_vala_code_node_unref0 (ma);
 			return result;
 		}
-		(type_ref == NULL) ? NULL : (type_ref = (vala_code_node_unref (type_ref), NULL));
-		(ma == NULL) ? NULL : (ma = (vala_code_node_unref (ma), NULL));
+		_vala_code_node_unref0 (type_ref);
+		_vala_code_node_unref0 (ma);
 	}
 	vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) expr), "Type reference must be simple name or member access expression");
 	result = NULL;
@@ -438,16 +410,13 @@ static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base) {
 	vala_data_type_set_value_owned ((ValaDataType*) _result_, vala_data_type_get_value_owned ((ValaDataType*) self));
 	vala_data_type_set_nullable ((ValaDataType*) _result_, vala_data_type_get_nullable ((ValaDataType*) self));
 	vala_data_type_set_is_dynamic ((ValaDataType*) _result_, vala_data_type_get_is_dynamic ((ValaDataType*) self));
-	_tmp0_ = NULL;
 	vala_unresolved_type_set_unresolved_symbol (_result_, _tmp0_ = vala_unresolved_symbol_copy (self->priv->_unresolved_symbol));
-	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
+	_vala_code_node_unref0 (_tmp0_);
 	{
 		GeeList* _tmp1_;
 		GeeIterator* _tmp2_;
 		GeeIterator* _arg_it;
-		_tmp1_ = NULL;
-		_tmp2_ = NULL;
-		_arg_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp1_ == NULL) ? NULL : (_tmp1_ = (gee_collection_object_unref (_tmp1_), NULL)), _tmp2_);
+		_arg_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), _gee_collection_object_unref0 (_tmp1_), _tmp2_);
 		while (TRUE) {
 			ValaDataType* arg;
 			ValaDataType* _tmp3_;
@@ -455,12 +424,11 @@ static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base) {
 				break;
 			}
 			arg = (ValaDataType*) gee_iterator_get (_arg_it);
-			_tmp3_ = NULL;
 			vala_data_type_add_type_argument ((ValaDataType*) _result_, _tmp3_ = vala_data_type_copy (arg));
-			(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_node_unref (_tmp3_), NULL));
-			(arg == NULL) ? NULL : (arg = (vala_code_node_unref (arg), NULL));
+			_vala_code_node_unref0 (_tmp3_);
+			_vala_code_node_unref0 (arg);
 		}
-		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
+		_gee_collection_object_unref0 (_arg_it);
 	}
 	result = (ValaDataType*) _result_;
 	return result;
@@ -485,12 +453,9 @@ ValaUnresolvedSymbol* vala_unresolved_type_get_unresolved_symbol (ValaUnresolved
 
 
 void vala_unresolved_type_set_unresolved_symbol (ValaUnresolvedType* self, ValaUnresolvedSymbol* value) {
-	ValaUnresolvedSymbol* _tmp1_;
 	ValaUnresolvedSymbol* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_unresolved_symbol = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_unresolved_symbol == NULL) ? NULL : (self->priv->_unresolved_symbol = (vala_code_node_unref (self->priv->_unresolved_symbol), NULL)), _tmp1_);
+	self->priv->_unresolved_symbol = (_tmp0_ = _vala_code_node_ref0 (value), _vala_code_node_unref0 (self->priv->_unresolved_symbol), _tmp0_);
 }
 
 
@@ -511,7 +476,7 @@ static void vala_unresolved_type_instance_init (ValaUnresolvedType * self) {
 static void vala_unresolved_type_finalize (ValaCodeNode* obj) {
 	ValaUnresolvedType * self;
 	self = VALA_UNRESOLVED_TYPE (obj);
-	(self->priv->_unresolved_symbol == NULL) ? NULL : (self->priv->_unresolved_symbol = (vala_code_node_unref (self->priv->_unresolved_symbol), NULL));
+	_vala_code_node_unref0 (self->priv->_unresolved_symbol);
 	VALA_CODE_NODE_CLASS (vala_unresolved_type_parent_class)->finalize (obj);
 }
 
