@@ -150,12 +150,6 @@ typedef struct _ValaVoidTypePrivate ValaVoidTypePrivate;
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 
-/**
- * Represents a part of the parsed source code.
- *
- * Code nodes get created by the parser and are used throughout the whole
- * compilation process.
- */
 struct _ValaCodeNode {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
@@ -176,10 +170,6 @@ struct _ValaCodeNodeClass {
 	void (*get_used_variables) (ValaCodeNode* self, GeeCollection* collection);
 };
 
-/**
- * A reference to a data type. This is used to specify static types of
- * expressions.
- */
 struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
@@ -209,9 +199,6 @@ struct _ValaDataTypeClass {
 	gboolean (*is_disposable) (ValaDataType* self);
 };
 
-/**
- * The void type.
- */
 struct _ValaVoidType {
 	ValaDataType parent_instance;
 	ValaVoidTypePrivate * priv;
@@ -253,6 +240,7 @@ GType vala_void_type_get_type (void);
 enum  {
 	VALA_VOID_TYPE_DUMMY_PROPERTY
 };
+ValaDataType* vala_data_type_construct (GType object_type);
 gpointer vala_source_reference_ref (gpointer instance);
 void vala_source_reference_unref (gpointer instance);
 GParamSpec* vala_param_spec_source_reference (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
@@ -273,7 +261,7 @@ static char* vala_void_type_real_get_type_id (ValaDataType* base);
 
 ValaVoidType* vala_void_type_construct (GType object_type, ValaSourceReference* source_reference) {
 	ValaVoidType* self;
-	self = (ValaVoidType*) g_type_create_instance (object_type);
+	self = (ValaVoidType*) vala_data_type_construct (object_type);
 	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
 }
