@@ -38,12 +38,13 @@
 typedef struct _ValaMarkupReader ValaMarkupReader;
 typedef struct _ValaMarkupReaderClass ValaMarkupReaderClass;
 typedef struct _ValaMarkupReaderPrivate ValaMarkupReaderPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _g_mapped_file_free0(var) ((var == NULL) ? NULL : (var = (g_mapped_file_free (var), NULL)))
+#define _gee_collection_object_unref0(var) ((var == NULL) ? NULL : (var = (gee_collection_object_unref (var), NULL)))
 
 #define VALA_TYPE_MARKUP_TOKEN_TYPE (vala_markup_token_type_get_type ())
+#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
 
-/**
- * Simple reader for a subset of XML.
- */
 struct _ValaMarkupReader {
 	GObject parent_instance;
 	ValaMarkupReaderPrivate * priv;
@@ -181,7 +182,6 @@ static char* vala_markup_reader_read_name (ValaMarkupReader* self) {
 	}
 	if (self->priv->current == begin) {
 	}
-	/* syntax error: invalid name*/
 	result = g_strndup ((const char*) begin, self->priv->current - begin);
 	return result;
 }
@@ -216,7 +216,6 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 					if (self->priv->current[0] == '!') {
 						gboolean _tmp0_;
 						gboolean _tmp1_;
-						/* comment or doctype*/
 						self->priv->current++;
 						_tmp0_ = FALSE;
 						_tmp1_ = FALSE;
@@ -231,7 +230,6 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 							_tmp0_ = FALSE;
 						}
 						if (_tmp0_) {
-							/* comment*/
 							self->priv->current = self->priv->current + 2;
 							while (TRUE) {
 								gboolean _tmp2_;
@@ -252,13 +250,11 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 									_tmp2_ = FALSE;
 								}
 								if (_tmp2_) {
-									/* end of comment*/
 									self->priv->current = self->priv->current + 3;
 									break;
 								}
 								self->priv->current++;
 							}
-							/* ignore comment, read next token*/
 							result = vala_markup_reader_read_token (self, &(*token_begin), &(*token_end));
 							return result;
 						}
@@ -268,9 +264,8 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 							gboolean _tmp5_;
 							type = VALA_MARKUP_TOKEN_TYPE_END_ELEMENT;
 							self->priv->current++;
-							_tmp4_ = NULL;
 							vala_markup_reader_set_name (self, _tmp4_ = vala_markup_reader_read_name (self));
-							_tmp4_ = (g_free (_tmp4_), NULL);
+							_g_free0 (_tmp4_);
 							_tmp5_ = FALSE;
 							if (self->priv->current >= self->priv->end) {
 								_tmp5_ = TRUE;
@@ -279,15 +274,13 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 							}
 							if (_tmp5_) {
 							}
-							/* error*/
 							self->priv->current++;
 						} else {
 							char* _tmp6_;
 							gboolean _tmp13_;
 							type = VALA_MARKUP_TOKEN_TYPE_START_ELEMENT;
-							_tmp6_ = NULL;
 							vala_markup_reader_set_name (self, _tmp6_ = vala_markup_reader_read_name (self));
-							_tmp6_ = (g_free (_tmp6_), NULL);
+							_g_free0 (_tmp6_);
 							vala_markup_reader_space (self);
 							while (TRUE) {
 								gboolean _tmp7_;
@@ -322,7 +315,6 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 								}
 								if (_tmp9_) {
 								}
-								/* error*/
 								self->priv->current++;
 								_tmp10_ = FALSE;
 								if (self->priv->current >= self->priv->end) {
@@ -330,10 +322,8 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 								} else {
 									_tmp10_ = self->priv->current[0] != '"';
 								}
-								/* FIXME allow single quotes*/
 								if (_tmp10_) {
 								}
-								/* error*/
 								self->priv->current++;
 								attr_begin = self->priv->current;
 								while (TRUE) {
@@ -355,7 +345,6 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 										vala_report_error (NULL, "invalid UTF-8 character");
 									}
 								}
-								/* TODO process &amp; &gt; &lt; &quot; &apos;*/
 								attr_value = g_strndup ((const char*) attr_begin, self->priv->current - attr_begin);
 								_tmp12_ = FALSE;
 								if (self->priv->current >= self->priv->end) {
@@ -365,12 +354,11 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 								}
 								if (_tmp12_) {
 								}
-								/* error*/
 								self->priv->current++;
 								gee_map_set (self->priv->attributes, attr_name, attr_value);
 								vala_markup_reader_space (self);
-								attr_name = (g_free (attr_name), NULL);
-								attr_value = (g_free (attr_value), NULL);
+								_g_free0 (attr_name);
+								_g_free0 (attr_value);
 							}
 							if (self->priv->current[0] == '/') {
 								self->priv->empty_element = TRUE;
@@ -387,7 +375,6 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 							}
 							if (_tmp13_) {
 							}
-							/* error*/
 							self->priv->current++;
 						}
 					}
@@ -417,16 +404,12 @@ ValaMarkupTokenType vala_markup_reader_read_token (ValaMarkupReader* self, ValaS
 				}
 			}
 			if (text_begin == self->priv->current) {
-				/* no text
-				 read next token*/
 				result = vala_markup_reader_read_token (self, &(*token_begin), &(*token_end));
 				return result;
 			}
 			type = VALA_MARKUP_TOKEN_TYPE_TEXT;
 		}
 	}
-	/* TODO process &amp; &gt; &lt; &quot; &apos;
-	 string text = ((string) text_begin).ndup (current - text_begin);*/
 	self->priv->column = self->priv->column + ((gint) (self->priv->current - begin));
 	(*token_end).pos = self->priv->current;
 	(*token_end).line = self->priv->line;
@@ -468,12 +451,9 @@ const char* vala_markup_reader_get_filename (ValaMarkupReader* self) {
 
 
 static void vala_markup_reader_set_filename (ValaMarkupReader* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_filename = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp1_);
+	self->priv->_filename = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_filename), _tmp0_);
 	g_object_notify ((GObject *) self, "filename");
 }
 
@@ -487,12 +467,9 @@ const char* vala_markup_reader_get_name (ValaMarkupReader* self) {
 
 
 static void vala_markup_reader_set_name (ValaMarkupReader* self, const char* value) {
-	char* _tmp1_;
-	const char* _tmp0_;
+	char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
+	self->priv->_name = (_tmp0_ = g_strdup (value), _g_free0 (self->priv->_name), _tmp0_);
 	g_object_notify ((GObject *) self, "name");
 }
 
@@ -519,8 +496,7 @@ static GObject * vala_markup_reader_constructor (GType type, guint n_construct_p
 				}
 				goto __finally3;
 			}
-			_tmp1_ = NULL;
-			self->priv->mapped_file = (_tmp1_ = _tmp0_, (self->priv->mapped_file == NULL) ? NULL : (self->priv->mapped_file = (g_mapped_file_free (self->priv->mapped_file), NULL)), _tmp1_);
+			self->priv->mapped_file = (_tmp1_ = _tmp0_, _g_mapped_file_free0 (self->priv->mapped_file), _tmp1_);
 			self->priv->begin = g_mapped_file_get_contents (self->priv->mapped_file);
 			self->priv->end = self->priv->begin + g_mapped_file_get_length (self->priv->mapped_file);
 			self->priv->current = self->priv->begin;
@@ -535,10 +511,9 @@ static GObject * vala_markup_reader_constructor (GType type, guint n_construct_p
 			_inner_error_ = NULL;
 			{
 				char* _tmp2_;
-				_tmp2_ = NULL;
 				vala_report_error (NULL, _tmp2_ = g_strdup_printf ("Unable to map file `%s': %s", self->priv->_filename, e->message));
-				_tmp2_ = (g_free (_tmp2_), NULL);
-				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
+				_g_free0 (_tmp2_);
+				_g_error_free0 (e);
 			}
 		}
 		__finally3:
@@ -572,10 +547,10 @@ static void vala_markup_reader_instance_init (ValaMarkupReader * self) {
 static void vala_markup_reader_finalize (GObject* obj) {
 	ValaMarkupReader * self;
 	self = VALA_MARKUP_READER (obj);
-	self->priv->_filename = (g_free (self->priv->_filename), NULL);
-	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->mapped_file == NULL) ? NULL : (self->priv->mapped_file = (g_mapped_file_free (self->priv->mapped_file), NULL));
-	(self->priv->attributes == NULL) ? NULL : (self->priv->attributes = (gee_collection_object_unref (self->priv->attributes), NULL));
+	_g_free0 (self->priv->_filename);
+	_g_free0 (self->priv->_name);
+	_g_mapped_file_free0 (self->priv->mapped_file);
+	_gee_collection_object_unref0 (self->priv->attributes);
 	G_OBJECT_CLASS (vala_markup_reader_parent_class)->finalize (obj);
 }
 
@@ -592,7 +567,6 @@ GType vala_markup_reader_get_type (void) {
 
 static void vala_markup_reader_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaMarkupReader * self;
-	gpointer boxed;
 	self = VALA_MARKUP_READER (object);
 	switch (property_id) {
 		case VALA_MARKUP_READER_FILENAME:
